(function($) {
	"use strict";

    var common = {};
    mkdf.modules.common = common;

    common.mkdfFluidVideo = mkdfFluidVideo;
    common.mkdfEnableScroll = mkdfEnableScroll;
    common.mkdfDisableScroll = mkdfDisableScroll;
    common.mkdfOwlSlider = mkdfOwlSlider;
    common.mkdfInitParallax = mkdfInitParallax;
    common.mkdfInitSelfHostedVideoPlayer = mkdfInitSelfHostedVideoPlayer;
    common.mkdfSelfHostedVideoSize = mkdfSelfHostedVideoSize;
    common.mkdfBlogListZigZagParallax = mkdfBlogListZigZagParallax;
    common.mkdfAddTiltFxClasses = mkdfAddTiltFxClasses;
    common.mkdfPrettyPhoto = mkdfPrettyPhoto;
	common.mkdfStickySidebarWidget = mkdfStickySidebarWidget;
    common.getLoadMoreData = getLoadMoreData;
    common.setLoadMoreAjaxData = setLoadMoreAjaxData;
    common.setFixedImageProportionSize = setFixedImageProportionSize;
    common.mkdfInitPerfectScrollbar = mkdfInitPerfectScrollbar;

    common.mkdfOnDocumentReady = mkdfOnDocumentReady;
    common.mkdfOnWindowLoad = mkdfOnWindowLoad;
    common.mkdfOnWindowResize = mkdfOnWindowResize;

    $(document).ready(mkdfOnDocumentReady);
    $(window).on('load', mkdfOnWindowLoad);
    $(window).resize(mkdfOnWindowResize);
    
    /*
        All functions to be called on $(document).ready() should be in this function
    */
    function mkdfOnDocumentReady() {
	    mkdfIconWithHover().init();
	    mkdfDisableSmoothScrollForMac();
	    mkdfInitAnchor().init();
	    mkdfInitBackToTop();
	    mkdfBackButtonShowHide();
	    mkdfInitSelfHostedVideoPlayer();
	    mkdfSelfHostedVideoSize();
	    mkdfFluidVideo();
	    mkdfOwlSlider();
	    mkdfPreloadBackgrounds();
	    mkdfPrettyPhoto();
	    mkdfSearchPostTypeWidget();
	    mkdfDashboardForm();
		mkdfInitGridMasonryListLayout();
		mkdfSmoothTransition();
		mkdfAddTiltFxClasses();
		mkdfBlogListZigZagParallax();
		mkdfScrollToContent();
		mkdfUncoveringRowLanding();
    }

    /*
        All functions to be called on $(window).load() should be in this function
    */
    function mkdfOnWindowLoad() {
		mkdfInitParallax();
		mkdfBlogSliderCenterNav();
	    mkdfStickySidebarWidget().init();
    }

    /*
        All functions to be called on $(window).resize() should be in this function
    */
    function mkdfOnWindowResize() {
	    mkdfInitGridMasonryListLayout();
    	mkdfSelfHostedVideoSize();
    }
	
	/*
	 ** Disable smooth scroll for mac if smooth scroll is enabled
	 */
	function mkdfDisableSmoothScrollForMac() {
		var os = navigator.appVersion.toLowerCase();
		
		if (os.indexOf('mac') > -1 && mkdf.body.hasClass('mkdf-smooth-scroll')) {
			mkdf.body.removeClass('mkdf-smooth-scroll');
		}
	}
	
	function mkdfDisableScroll() {
		if (window.addEventListener) {
			window.addEventListener('wheel', mkdfWheel, {passive: false});
		}
		
		// window.onmousewheel = document.onmousewheel = mkdfWheel;
		document.onkeydown = mkdfKeydown;
	}
	
	function mkdfEnableScroll() {
		if (window.removeEventListener) {
			window.removeEventListener('wheel', mkdfWheel, {passive: false});
		}
		
		window.onmousewheel = document.onmousewheel = document.onkeydown = null;
	}
	
	function mkdfWheel(e) {
		mkdfPreventDefaultValue(e);
	}
	
	function mkdfKeydown(e) {
		var keys = [37, 38, 39, 40];
		
		for (var i = keys.length; i--;) {
			if (e.keyCode === keys[i]) {
				mkdfPreventDefaultValue(e);
				return;
			}
		}
	}
	
	function mkdfPreventDefaultValue(e) {
		e = e || window.event;
		if (e.preventDefault) {
			e.preventDefault();
		}
		e.returnValue = false;
	}
	
	/*
	 **	Anchor functionality
	 */
	var mkdfInitAnchor = function() {
		/**
		 * Set active state on clicked anchor
		 * @param anchor, clicked anchor
		 */
		var setActiveState = function(anchor){
			var headers = $('.mkdf-main-menu, .mkdf-mobile-nav, .mkdf-fullscreen-menu, .mkdf-vertical-menu');
			
			headers.each(function(){
				var currentHeader = $(this);
				
				if (anchor.parents(currentHeader).length) {
					currentHeader.find('.mkdf-active-item').removeClass('mkdf-active-item');
					anchor.parent().addClass('mkdf-active-item');
					
					currentHeader.find('a').removeClass('current');
					anchor.addClass('current');
				}
			});
		};
		
		/**
		 * Check anchor active state on scroll
		 */
		var checkActiveStateOnScroll = function(){
			var anchorData = $('[data-mkdf-anchor]'),
				anchorElement,
				siteURL = window.location.href.split('#')[0];
			
			if (siteURL.substr(-1) !== '/') {
				siteURL += '/';
			}
			
			anchorData.waypoint( function(direction) {
				if(direction === 'down') {
					if ($(this.element).length > 0) {
						anchorElement = $(this.element).data("mkdf-anchor");
					} else {
						anchorElement = $(this).data("mkdf-anchor");
					}
				
					setActiveState($("a[href='"+siteURL+"#"+anchorElement+"']"));
				}
			}, { offset: '50%' });
			
			anchorData.waypoint( function(direction) {
				if(direction === 'up') {
					if ($(this.element).length > 0) {
						anchorElement = $(this.element).data("mkdf-anchor");
					} else {
						anchorElement = $(this).data("mkdf-anchor");
					}
					
					setActiveState($("a[href='"+siteURL+"#"+anchorElement+"']"));
				}
			}, { offset: function(){
				return -($(this.element).outerHeight() - 150);
			} });
		};
		
		/**
		 * Check anchor active state on load
		 */
		var checkActiveStateOnLoad = function(){
			var hash = window.location.hash.split('#')[1];
			
			if(hash !== "" && $('[data-mkdf-anchor="'+hash+'"]').length > 0){
				anchorClickOnLoad(hash);
			}
		};
		
		/**
		 * Handle anchor on load
		 */
		var anchorClickOnLoad = function ($this) {
			var scrollAmount,
				anchor = $('.mkdf-main-menu a, .mkdf-mobile-nav a, .mkdf-fullscreen-menu a, .mkdf-vertical-menu a'),
				hash = $this,
				anchorData = hash !== '' ? $('[data-mkdf-anchor="' + hash + '"]') : '';
			
			if (hash !== '' && anchorData.length > 0) {
				var anchoredElementOffset = anchorData.offset().top;
				scrollAmount = anchoredElementOffset - headerHeightToSubtract(anchoredElementOffset) - mkdfGlobalVars.vars.mkdfAddForAdminBar;
				
				if(anchor.length) {
					anchor.each(function(){
						var thisAnchor = $(this);
						
						if(thisAnchor.attr('href').indexOf(hash) > -1) {
							setActiveState(thisAnchor);
						}
					});
				}
				
				mkdf.html.stop().animate({
					scrollTop: Math.round(scrollAmount)
				}, 1000, function () {
					//change hash tag in url
					if (history.pushState) {
						history.pushState(null, '', '#' + hash);
					}
				});
				
				return false;
			}
		};
		
		/**
		 * Calculate header height to be substract from scroll amount
		 * @param anchoredElementOffset, anchorded element offset
		 */
		var headerHeightToSubtract = function (anchoredElementOffset) {
			
			if (mkdf.modules.stickyHeader.behaviour === 'mkdf-sticky-header-on-scroll-down-up') {
				mkdf.modules.stickyHeader.isStickyVisible = (anchoredElementOffset > mkdf.modules.header.stickyAppearAmount);
			}
			
			if (mkdf.modules.stickyHeader.behaviour === 'mkdf-sticky-header-on-scroll-up') {
				if ((anchoredElementOffset > mkdf.scroll)) {
					mkdf.modules.stickyHeader.isStickyVisible = false;
				}
			}
			
			var headerHeight = mkdf.modules.stickyHeader.isStickyVisible ? mkdfGlobalVars.vars.mkdfStickyHeaderTransparencyHeight : mkdfPerPageVars.vars.mkdfHeaderTransparencyHeight;
			
			if (mkdf.windowWidth < 1025) {
				headerHeight = 0;
			}
			
			return headerHeight;
		};
		
		/**
		 * Handle anchor click
		 */
		var anchorClick = function () {
			mkdf.document.on("click", ".mkdf-main-menu a, .mkdf-fullscreen-menu a, a.mkdf-btn, .mkdf-anchor, .mkdf-mobile-nav a, .mkdf-vertical-menu a", function () {
				var scrollAmount,
					anchor = $(this),
					hash = anchor.prop("hash").split('#')[1],
					anchorData = hash !== '' ? $('[data-mkdf-anchor="' + hash + '"]') : '';
				
				if (hash !== '' && anchorData.length > 0) {
					var anchoredElementOffset = anchorData.offset().top;
					scrollAmount = anchoredElementOffset - headerHeightToSubtract(anchoredElementOffset) - mkdfGlobalVars.vars.mkdfAddForAdminBar;
					
					setActiveState(anchor);
					
					mkdf.html.stop().animate({
						scrollTop: Math.round(scrollAmount)
					}, 1000, function () {
						//change hash tag in url
						if (history.pushState) {
							history.pushState(null, '', '#' + hash);
						}
					});
					
					return false;
				}
			});
		};
		
		return {
			init: function () {
				if ($('[data-mkdf-anchor]').length) {
					anchorClick();
					checkActiveStateOnScroll();
					
					$(window).on('load', function () {
						checkActiveStateOnLoad();
					});
				}
			}
		};
	};
	
	function mkdfInitBackToTop() {
		var backToTopButton = $('#mkdf-back-to-top');
		backToTopButton.on('click', function (e) {
			e.preventDefault();
			mkdf.html.animate({scrollTop: 0}, mkdf.window.scrollTop() / 3, 'easeInOutCubic');
		});
	}
	
	function mkdfBackButtonShowHide() {
		mkdf.window.scroll(function () {
			var b = $(this).scrollTop(),
				c = $(this).height(),
				d;
			
			if (b > 0) {
				d = b + c / 2;
			} else {
				d = 1;
			}
			
			if (d < 1e3) {
				mkdfToTopButton('off');
			} else {
				mkdfToTopButton('on');
			}
		});
	}
	
	function mkdfToTopButton(a) {
		var b = $("#mkdf-back-to-top");
		b.removeClass('off on');
		if (a === 'on') {
			b.addClass('on');
		} else {
			b.addClass('off');
		}
	}
	
	function mkdfInitSelfHostedVideoPlayer() {
		var players = $('.mkdf-self-hosted-video');
		
		if (players.length) {
			players.mediaelementplayer({
				audioWidth: '100%'
			});
		}
	}
	
	function mkdfSelfHostedVideoSize(){
		var selfVideoHolder = $('.mkdf-self-hosted-video-holder .mkdf-video-wrap');
		
		if(selfVideoHolder.length) {
			selfVideoHolder.each(function(){
				var thisVideo = $(this),
					videoWidth = thisVideo.closest('.mkdf-self-hosted-video-holder').outerWidth(),
					videoHeight = videoWidth / mkdf.videoRatio;
				
				if(navigator.userAgent.match(/(Android|iPod|iPhone|iPad|IEMobile|Opera Mini)/)){
					thisVideo.parent().width(videoWidth);
					thisVideo.parent().height(videoHeight);
				}
				
				thisVideo.width(videoWidth);
				thisVideo.height(videoHeight);
				
				thisVideo.find('video, .mejs-overlay, .mejs-poster').width(videoWidth);
				thisVideo.find('video, .mejs-overlay, .mejs-poster').height(videoHeight);
			});
		}
	}
	
	function mkdfFluidVideo() {
        fluidvids.init({
			selector: ['iframe'],
			players: ['www.youtube.com', 'player.vimeo.com']
		});
	}
	
	function mkdfSmoothTransition() {

		if (mkdf.body.hasClass('mkdf-smooth-page-transitions')) {

			//check for preload animation
			if (mkdf.body.hasClass('mkdf-smooth-page-transitions-preloader')) {
				var loader = $('body > .mkdf-smooth-transition-loader.mkdf-mimic-ajax'),
					mainRevHolder = $('#mkdf-main-rev-holder'),
					wanderlandSpinner = $('.mkdf-wanderland-spinner');

				if (wanderlandSpinner.length) {
					loader.addClass('mkdf-smooth-transition-loader-wanderland');
				}

				/**
				 * Loader Fade Out function
				 *
				 * @param {number} speed - fade out duration
				 * @param {number} delay - fade out delay
				 * @param {string} easing - fade out easing function
				 */
				var fadeOutLoader = function(speed, delay, easing) {
					speed = speed ? speed : 600;
					delay = delay ? delay : 0;
					easing = easing ? easing : 'easeOutSine';

					loader.delay(delay).fadeOut(speed, easing);
					$(window).on('bind', 'pageshow', function (event) {
						if (event.originalEvent.persisted) {
							loader.fadeOut(speed, easing);
						}
					});
				};
				
				$(window).on('load', function() {
					if (wanderlandSpinner.length) {
						setTimeout(function() {
							loader.addClass('mkdf-smooth-transition-loader-wanderland-out');
						}, 1000);
						setTimeout(function() {
							if(mainRevHolder.length) {
								mainRevHolder.find('rs-module').revstart();
							}
						}, 2200);
					} else {
						fadeOutLoader();
					}
				});
			}
			
			//if back button is pressed, than show content to avoid state where content is on display:none
			window.addEventListener( "pageshow", function ( event ) {
				var historyPath = event.persisted || ( typeof window.performance != "undefined" && window.performance.navigation.type === 2 );
				if ( historyPath ) {
					$('.mkdf-wrapper-inner').show();
				}
			});
			
			//check for fade out animation
			if (mkdf.body.hasClass('mkdf-smooth-page-transitions-fadeout')) {
				var linkItem = $('a');
				
				linkItem.on('click', function (e) {
					var a = $(this);

					if ((a.parents('.mkdf-shopping-cart-dropdown').length || a.parent('.product-remove').length) && a.hasClass('remove')) {
						return;
					}
					
					if (a.parents('.woocommerce-product-gallery__image').length) {
						return;
					}

					if (
						e.which === 1 && // check if the left mouse button has been pressed
						a.attr('href').indexOf(window.location.host) >= 0 && // check if the link is to the same domain
						(typeof a.data('rel') === 'undefined') && //Not pretty photo link
						(typeof a.attr('rel') === 'undefined') && //Not VC pretty photo link
                        (!a.hasClass('lightbox-active')) && //Not lightbox plugin active
						(typeof a.attr('target') === 'undefined' || a.attr('target') === '_self') && // check if the link opens in the same window
						(a.attr('href').split('#')[0] !== window.location.href.split('#')[0]) // check if it is an anchor aiming for a different page
					) {
						e.preventDefault();
						$('.mkdf-wrapper-inner').fadeOut(600, 'easeOutSine', function () {
							window.location = a.attr('href');
						});
					}
				});
			}
		}
	}
	
	/*
	 *	Preload background images for elements that have 'mkdf-preload-background' class
	 */
	function mkdfPreloadBackgrounds(){
		var preloadBackHolder = $('.mkdf-preload-background');
		
		if(preloadBackHolder.length) {
			preloadBackHolder.each(function() {
				var preloadBackground = $(this);
				
				if(preloadBackground.css('background-image') !== '' && preloadBackground.css('background-image') !== 'none') {
					var bgUrl = preloadBackground.attr('style');
					
					bgUrl = bgUrl.match(/url\(["']?([^'")]+)['"]?\)/);
					bgUrl = bgUrl ? bgUrl[1] : "";
					
					if (bgUrl) {
						var backImg = new Image();
						backImg.src = bgUrl;
						$(backImg).load(function(){
							preloadBackground.removeClass('mkdf-preload-background');
						});
					}
				} else {
					$(window).on('load', function(){ preloadBackground.removeClass('mkdf-preload-background'); }); //make sure that mkdf-preload-background class is removed from elements with forced background none in css
				}
			});
		}
	}
	
	function mkdfPrettyPhoto() {
		/*jshint multistr: true */
		var markupWhole = '<div class="pp_pic_holder"> \
                        <div class="ppt">&nbsp;</div> \
                        <div class="pp_top"> \
                            <div class="pp_left"></div> \
                            <div class="pp_middle"></div> \
                            <div class="pp_right"></div> \
                        </div> \
                        <div class="pp_content_container"> \
                            <div class="pp_left"> \
                            <div class="pp_right"> \
                                <div class="pp_content"> \
                                    <div class="pp_loaderIcon"></div> \
                                    <div class="pp_fade"> \
                                        <a href="#" class="pp_expand" title="'+mkdfGlobalVars.vars.ppExpand+'">'+mkdfGlobalVars.vars.ppExpand+'</a> \
                                        <div class="pp_hoverContainer"> \
                                            <a class="pp_next" href="#"><span class="fa fa-angle-right"></span></a> \
                                            <a class="pp_previous" href="#"><span class="fa fa-angle-left"></span></a> \
                                        </div> \
                                        <div id="pp_full_res"></div> \
                                        <div class="pp_details"> \
                                            <div class="pp_nav"> \
                                                <a href="#" class="pp_arrow_previous">'+mkdfGlobalVars.vars.ppPrev+'</a> \
                                                <p class="currentTextHolder">0/0</p> \
                                                <a href="#" class="pp_arrow_next">'+mkdfGlobalVars.vars.ppNext+'</a> \
                                            </div> \
                                            <p class="pp_description"></p> \
                                            {pp_social} \
                                            <a class="pp_close" href="#">'+mkdfGlobalVars.vars.ppClose+'</a> \
                                        </div> \
                                    </div> \
                                </div> \
                            </div> \
                            </div> \
                        </div> \
                        <div class="pp_bottom"> \
                            <div class="pp_left"></div> \
                            <div class="pp_middle"></div> \
                            <div class="pp_right"></div> \
                        </div> \
                    </div> \
                    <div class="pp_overlay"></div>';
		
		$("a[data-rel^='prettyPhoto']").prettyPhoto({
			hook: 'data-rel',
			animation_speed: 'normal', /* fast/slow/normal */
			slideshow: false, /* false OR interval time in ms */
			autoplay_slideshow: false, /* true/false */
			opacity: 0.80, /* Value between 0 and 1 */
			show_title: true, /* true/false */
			allow_resize: true, /* Resize the photos bigger than viewport. true/false */
			horizontal_padding: 0,
			default_width: 960,
			default_height: 540,
			counter_separator_label: '/', /* The separator for the gallery counter 1 "of" 2 */
			theme: 'pp_default', /* light_rounded / dark_rounded / light_square / dark_square / facebook */
			hideflash: false, /* Hides all the flash object on a page, set to TRUE if flash appears over prettyPhoto */
			wmode: 'opaque', /* Set the flash wmode attribute */
			autoplay: true, /* Automatically start videos: True/False */
			modal: false, /* If set to true, only the close button will close the window */
			overlay_gallery: false, /* If set to true, a gallery will overlay the fullscreen image on mouse over */
			keyboard_shortcuts: true, /* Set to false if you open forms inside prettyPhoto */
			deeplinking: false,
			custom_markup: '',
			social_tools: false,
			markup: markupWhole
		});
	}

    function mkdfSearchPostTypeWidget() {
        var searchPostTypeHolder = $('.mkdf-search-post-type');

        if (searchPostTypeHolder.length) {
            searchPostTypeHolder.each(function () {
                var thisSearch = $(this),
                    searchField = thisSearch.find('.mkdf-post-type-search-field'),
                    resultsHolder = thisSearch.siblings('.mkdf-post-type-search-results'),
                    searchLoading = thisSearch.find('.mkdf-search-loading'),
                    searchIcon = thisSearch.find('.mkdf-search-icon');

                searchLoading.addClass('mkdf-hidden');

                var postType = thisSearch.data('post-type'),
                    keyPressTimeout;

                searchField.on('keyup paste', function() {
                    var field = $(this);
                    field.attr('autocomplete','off');
                    searchLoading.removeClass('mkdf-hidden');
                    searchIcon.addClass('mkdf-hidden');
                    clearTimeout(keyPressTimeout);

                    keyPressTimeout = setTimeout( function() {
                        var searchTerm = field.val();
                        
                        if(searchTerm.length < 3) {
                            resultsHolder.html('');
                            resultsHolder.fadeOut();
                            searchLoading.addClass('mkdf-hidden');
                            searchIcon.removeClass('mkdf-hidden');
                        } else {
                            var ajaxData = {
                                action: 'wanderland_mikado_search_post_types',
                                term: searchTerm,
                                postType: postType,
	                            search_post_types_nonce: $('input[name="mkdf_search_post_types_nonce"]').val()
                            };

                            $.ajax({
                                type: 'POST',
                                data: ajaxData,
                                url: mkdfGlobalVars.vars.mkdfAjaxUrl,
                                success: function (data) {
                                    var response = JSON.parse(data);
                                    if (response.status === 'success') {
                                        searchLoading.addClass('mkdf-hidden');
                                        searchIcon.removeClass('mkdf-hidden');
                                        resultsHolder.html(response.data.html);
                                        resultsHolder.fadeIn();
                                    }
                                },
                                error: function(XMLHttpRequest, textStatus, errorThrown) {
                                    console.log("Status: " + textStatus);
                                    console.log("Error: " + errorThrown);
                                    searchLoading.addClass('mkdf-hidden');
                                    searchIcon.removeClass('mkdf-hidden');
                                    resultsHolder.fadeOut();
                                }
                            });
                        }
                    }, 500);
                });

                searchField.on('focusout', function () {
                    searchLoading.addClass('mkdf-hidden');
                    searchIcon.removeClass('mkdf-hidden');
                    resultsHolder.fadeOut();
                });
            });
        }
    }
	
	/**
	 * Initializes load more data params
	 * @param container with defined data params
	 * return array
	 */
	function getLoadMoreData(container){
		var dataList = container.data(),
			returnValue = {};
		
		for (var property in dataList) {
			if (dataList.hasOwnProperty(property)) {
				if (typeof dataList[property] !== 'undefined' && dataList[property] !== false) {
					returnValue[property] = dataList[property];
				}
			}
		}
		
		return returnValue;
	}
	
	/**
	 * Sets load more data params for ajax function
	 * @param container with defined data params
	 * @param action with defined action name
	 * return array
	 */
	function setLoadMoreAjaxData(container, action) {
		var returnValue = {
			action: action
		};
		
		for (var property in container) {
			if (container.hasOwnProperty(property)) {
				
				if (typeof container[property] !== 'undefined' && container[property] !== false) {
					returnValue[property] = container[property];
				}
			}
		}
		
		return returnValue;
	}
	
	/*
	 ** Init Masonry List Layout
	 */
	function mkdfInitGridMasonryListLayout() {
		var holder = $('.mkdf-grid-masonry-list');
		
		if (holder.length) {
			holder.each(function () {
				var thisHolder = $(this),
					masonry = thisHolder.find('.mkdf-masonry-list-wrapper'),
					size = thisHolder.find('.mkdf-masonry-grid-sizer').width();
				
				masonry.waitForImages(function () {
					masonry.isotope({
						layoutMode: 'packery',
						itemSelector: '.mkdf-item-space',
						percentPosition: true,
						masonry: {
							columnWidth: '.mkdf-masonry-grid-sizer',
							gutter: '.mkdf-masonry-grid-gutter'
						}
					});
					
					if (thisHolder.find('.mkdf-fixed-masonry-item').length || thisHolder.hasClass('mkdf-fixed-masonry-items')) {
						setFixedImageProportionSize(masonry, masonry.find('.mkdf-item-space'), size, true);
					}
					
					setTimeout(function () {
						mkdfInitParallax();
					}, 600);
					
					masonry.isotope('layout').css('opacity', 1);
				});
			});
		}
	}
	
	/**
	 * Initializes size for fixed image proportion - masonry layout
	 */
	function setFixedImageProportionSize(container, item, size, isFixedEnabled) {
		if (container.hasClass('mkdf-masonry-images-fixed') || isFixedEnabled === true) {
			var padding = parseInt(item.css('paddingLeft'), 10),
				newSize = size - 2 * padding,
				defaultMasonryItem = container.find('.mkdf-masonry-size-small'),
				largeWidthMasonryItem = container.find('.mkdf-masonry-size-large-width'),
				largeHeightMasonryItem = container.find('.mkdf-masonry-size-large-height'),
				largeWidthHeightMasonryItem = container.find('.mkdf-masonry-size-large-width-height');

			defaultMasonryItem.css('height', newSize);
			largeHeightMasonryItem.css('height', Math.round(2 * (newSize + padding)));

			if (mkdf.windowWidth > 680) {
				largeWidthMasonryItem.css('height', newSize);
				largeWidthHeightMasonryItem.css('height', Math.round(2 * (newSize + padding)));
			} else {
				largeWidthMasonryItem.css('height', Math.round(newSize / 2));
				largeWidthHeightMasonryItem.css('height', newSize);
			}
		}
	}

	/**
	 * Object that represents icon with hover data
	 * @returns {{init: Function}} function that initializes icon's functionality
	 */
	var mkdfIconWithHover = function() {
		//get all icons on page
		var icons = $('.mkdf-icon-has-hover');
		
		/**
		 * Function that triggers icon hover color functionality
		 */
		var iconHoverColor = function(icon) {
			if(typeof icon.data('hover-color') !== 'undefined') {
				var changeIconColor = function(event) {
					event.data.icon.css('color', event.data.color);
				};
				
				var hoverColor = icon.data('hover-color'),
					originalColor = icon.css('color');
				
				if(hoverColor !== '') {
					icon.on('mouseenter', {icon: icon, color: hoverColor}, changeIconColor);
					icon.on('mouseleave', {icon: icon, color: originalColor}, changeIconColor);
				}
			}
		};
		
		return {
			init: function() {
				if(icons.length) {
					icons.each(function() {
						iconHoverColor($(this));
					});
				}
			}
		};
	};

	function mkdfBlogListZigZagParallax() {
		var blogList = $('.mkdf-bl-zig-zag');

		if (blogList.length) {
			blogList.each(function() {
				var thisBlogList = $(this),
					evenItems = thisBlogList.find('.mkdf-bl-item:nth-child(even) .mkdf-bli-inner');

				evenItems.attr('data-parallax', '{"y": -50, "smoothness": 30}');
			});
			setTimeout(function() {
				mkdfParallaxElements();
			}, 300);
		}
	}

	/**
	 * Init Parallax Items
	 */
	function mkdfParallaxElements() {
		var parallaxIntances = $("[data-parallax]");
		
		if (parallaxIntances.length && !mkdf.htmlEl.hasClass('touch')) {
			ParallaxScroll.init(); //initialzation removed from plugin js file to have it run only on non-touch devices
		}
	}

	function mkdfBlogSliderCenterNav() {
		var blogSlider = $('.mkdf-blog-slider');

		if (blogSlider.length) {
			blogSlider.each(function() {
				var thisBlogSlider = $(this);

				thisBlogSlider.waitForImages(function() {
					var thisBlogImage = thisBlogSlider.find('.mkdf-item-image'),
						thisBlogImageHeight = thisBlogImage.outerHeight();
					// Nav arrows positioning (middle of image)
					thisBlogSlider.find('.owl-next, .owl-prev').css('top', thisBlogImageHeight/2 + 10);
				});
			});
		}
	}

	function mkdfAddTiltFxClasses() {
		var tiltElements = $('.mkdf-bl-item .mkdf-post-image, .mkdf-blog-slider-item-inner > .mkdf-item-image, .mkdf-bs-carousel-centered .mkdf-blog-slider-item-inner, .mkdf-destination-list-holder .mkdf-dl-item-inner, .mkdf-team-holder .mkdf-team-image, .mkdf-image-behavior-custom-link, .mkdf-blwd-item-inner');

		// Different Tilt Amount for big images
		var bigImages = $('.mkdf-image-behavior-custom-link, .mkdf-blwd-item-inner, .mkdf-grid-masonry-list.mkdf-bl-zig-zag.mkdf-two-columns .mkdf-bl-item .mkdf-post-image'),
			hugeImages = $('.mkdf-destination-slider-holder .mkdf-one-columns .mkdf-dl-item-inner');

		if (bigImages.length) {
			bigImages.each(function() {
				var thisItem = $(this);

				thisItem.attr('data-tilt-amount', 180);
			});
		}

		if (hugeImages.length) {
			hugeImages.each(function() {
				var thisItem = $(this);

				thisItem.attr('data-tilt-amount', 350);
			});
		}

		if (tiltElements.length) {
			tiltElements.each(function() {
				var thisItem = $(this);
				if (!thisItem.hasClass('mkdf-tilt-trigger')) {
					thisItem.addClass('mkdf-tilt-trigger');
					thisItem.find('>:first-child').addClass('mkdf-tilt-target');
				}
			});
	
			setTimeout(function() {
				mkdfTiltFx().init();
			}, 300)
		}
	}

	function mkdfTiltFx() {
		var tilts = $('.mkdf-tilt-trigger');
		
        var enter = function(e, tr, ta, tiltAmount) {
            var aFx = tiltAmount,
                trF = 4,
                cH = tr.innerHeight(),
                cW = tr.innerWidth(),
                eX = (e.originalEvent.type === 'touchmove') ? e.originalEvent.touches[0].pageX : e.offsetX,
                eY = (e.originalEvent.type === 'touchmove') ? e.originalEvent.touches[0].pageY : e.offsetY;
            $.each(ta, function(i, el) {
                TweenLite.set($(el), {
                    transformOrigin: ((eX / (cW * trF) / 100 * 10000) + (trF * 10)) + '% ' + ((eY / (cH * trF) / 100 * 10000) + (trF * 10)) + '%',
                    transformPerspective: 1000 + (i * 500)
                });
                TweenLite.to($(el), 0.5, {
                    rotationX: ((eY - cH / 2) / aFx) - i * 2,
                    rotationY: ((eX - cW / 2) / aFx * -1) - i * 2,
                    y: (eY - (cH / 2)) / (70 - i * 20),
                    x: (eX - (cW / 2)) / (70 - i * 20)
                });
            });
        }
        var leave = function(ta) {
            $.each(ta, function(i, el) {
                TweenLite.to($(el), 1, {
                    delay: .2,
                    y: 0,
                    x: 0,
                    rotationX: 0,
                    rotationY: 0,
                    transformPerspective: '1500'
                });
            });
        }
        var init = function() {
            tilts.each(function() {
                var tiltTrigger = $(this),
					tiltTargets = tiltTrigger.find('.mkdf-tilt-target'),
					tiltAmountData = tiltTrigger.attr('data-tilt-amount');
				
				// Read Tilt Amount data
				if (tiltAmountData === undefined) {
					tiltAmountData = 70;
				}
					
                tiltTrigger.on('mousemove touchmove', function(e) {
                    enter(e, tiltTrigger, tiltTargets, tiltAmountData);
                }).on('mouseout touchend', function(e) {
                    leave(tiltTargets);
                });
            });
        }
        return {
            init: function() {
                tilts.length && !Modernizr.touch && init();
            }
        }
    }
	
	/*
	 ** Init parallax
	 */
	function mkdfInitParallax(){
		var parallaxHolder = $('.mkdf-parallax-row-holder');
		
		if(parallaxHolder.length){
			parallaxHolder.each(function() {
				var parallaxElement = $(this),
					image = parallaxElement.data('parallax-bg-image'),
					speed = parallaxElement.data('parallax-bg-speed') * 0.4,
					height = 0;
				
				if (typeof parallaxElement.data('parallax-bg-height') !== 'undefined' && parallaxElement.data('parallax-bg-height') !== false) {
					height = parseInt(parallaxElement.data('parallax-bg-height'));
				}
				
				parallaxElement.css({'background-image': 'url('+image+')'});
				
				if(height > 0) {
					parallaxElement.css({'min-height': height+'px', 'height': height+'px'});
				}
				
				parallaxElement.parallax('50%', speed);
			});
		}
	}
	
	/*
	 **  Init sticky sidebar widget
	 */
	function mkdfStickySidebarWidget(){
		var sswHolder = $('.mkdf-widget-sticky-sidebar'),
			headerHolder = $('.mkdf-page-header'),
			headerHeight = headerHolder.length ? headerHolder.outerHeight() : 0,
			widgetTopOffset = 0,
			widgetTopPosition = 0,
			sidebarHeight = 0,
			sidebarWidth = 0,
			objectsCollection = [];
		
		function addObjectItems() {
			if (sswHolder.length) {
				sswHolder.each(function () {
					var thisSswHolder = $(this),
						mainSidebarHolder = thisSswHolder.parents('aside.mkdf-sidebar'),
						widgetiseSidebarHolder = thisSswHolder.parents('.wpb_widgetised_column'),
						sidebarHolder = '',
						sidebarHolderHeight = 0;
					
					widgetTopOffset = thisSswHolder.offset().top;
					widgetTopPosition = thisSswHolder.position().top;
					sidebarHeight = 0;
					sidebarWidth = 0;
					
					if (mainSidebarHolder.length) {
						sidebarHeight = mainSidebarHolder.outerHeight();
						sidebarWidth = mainSidebarHolder.outerWidth();
						sidebarHolder = mainSidebarHolder;
						sidebarHolderHeight = mainSidebarHolder.parent().parent().outerHeight();
						
						var blogHolder = mainSidebarHolder.parent().parent().find('.mkdf-blog-holder');
						if (blogHolder.length) {
							sidebarHolderHeight -= parseInt(blogHolder.css('marginBottom'));
						}
					} else if (widgetiseSidebarHolder.length) {
						sidebarHeight = widgetiseSidebarHolder.outerHeight();
						sidebarWidth = widgetiseSidebarHolder.outerWidth();
						sidebarHolder = widgetiseSidebarHolder;
						sidebarHolderHeight = widgetiseSidebarHolder.parents('.vc_row').outerHeight();
					}
					
					objectsCollection.push({
						'object': thisSswHolder,
						'offset': widgetTopOffset,
						'position': widgetTopPosition,
						'height': sidebarHeight,
						'width': sidebarWidth,
						'sidebarHolder': sidebarHolder,
						'sidebarHolderHeight': sidebarHolderHeight
					});
				});
			}
		}
		
		function initStickySidebarWidget() {
			
			if (objectsCollection.length) {
				$.each(objectsCollection, function (i) {
					var thisSswHolder = objectsCollection[i].object,
						thisWidgetTopOffset = objectsCollection[i].offset,
						thisWidgetTopPosition = objectsCollection[i].position,
						thisSidebarHeight = objectsCollection[i].height,
						thisSidebarWidth = objectsCollection[i].width,
						thisSidebarHolder = objectsCollection[i].sidebarHolder,
						thisSidebarHolderHeight = objectsCollection[i].sidebarHolderHeight;
					
					if (mkdf.body.hasClass('mkdf-fixed-on-scroll')) {
						var fixedHeader = $('.mkdf-fixed-wrapper.fixed');
						
						if (fixedHeader.length) {
							headerHeight = fixedHeader.outerHeight() + mkdfGlobalVars.vars.mkdfAddForAdminBar;
						}
					} else if (mkdf.body.hasClass('mkdf-no-behavior')) {
						headerHeight = mkdfGlobalVars.vars.mkdfAddForAdminBar;
					}
					
					if (mkdf.windowWidth > 1024 && thisSidebarHolder.length) {
						var sidebarPosition = -(thisWidgetTopPosition - headerHeight),
							sidebarHeight = thisSidebarHeight - thisWidgetTopPosition + 100; // 40 is bottom margin of widget holder
						
						//move sidebar up when hits the end of section row
						var rowSectionEndInViewport = thisSidebarHolderHeight + thisWidgetTopOffset - headerHeight - thisWidgetTopPosition - mkdfGlobalVars.vars.mkdfTopBarHeight;
						
						if ((mkdf.scroll >= thisWidgetTopOffset - headerHeight) && thisSidebarHeight < thisSidebarHolderHeight) {
							if (thisSidebarHolder.hasClass('mkdf-sticky-sidebar-appeared')) {
								thisSidebarHolder.css({'top': sidebarPosition + 'px'});
							} else {
								thisSidebarHolder.addClass('mkdf-sticky-sidebar-appeared').css({
									'position': 'fixed',
									'top': sidebarPosition + 'px',
									'width': thisSidebarWidth,
									'margin-top': '-10px'
								}).animate({'margin-top': '0'}, 200);
							}
							
							if (mkdf.scroll + sidebarHeight >= rowSectionEndInViewport) {
								var absBottomPosition = thisSidebarHolderHeight - sidebarHeight + sidebarPosition - headerHeight;
								
								thisSidebarHolder.css({
									'position': 'absolute',
									'top': absBottomPosition + 'px'
								});
							} else {
								if (thisSidebarHolder.hasClass('mkdf-sticky-sidebar-appeared')) {
									thisSidebarHolder.css({
										'position': 'fixed',
										'top': sidebarPosition + 'px'
									});
								}
							}
						} else {
							thisSidebarHolder.removeClass('mkdf-sticky-sidebar-appeared').css({
								'position': 'relative',
								'top': '0',
								'width': 'auto'
							});
						}
					} else {
						thisSidebarHolder.removeClass('mkdf-sticky-sidebar-appeared').css({
							'position': 'relative',
							'top': '0',
							'width': 'auto'
						});
					}
				});
			}
		}
		
		return {
			init: function () {
				addObjectItems();
				initStickySidebarWidget();
				
				$(window).scroll(function () {
					initStickySidebarWidget();
				});
			},
			reInit: initStickySidebarWidget
		};
	}

	/*
	 * Slide to content on scroll - one scroll to page content
	*/
	function mkdfScrollToContent() {
		var revSliderLanding = $(".mkdf-rev-slider-landing");
		if (revSliderLanding.length && !mkdf.htmlEl.hasClass('touch')) {
			var sliderHolderHeight = revSliderLanding.height(),
				sliderHolderOffset = revSliderLanding.offset().top,
				sliderArea = sliderHolderHeight - sliderHolderOffset,
				revSlider = revSliderLanding.find('.rev_slider'),
				pageJump = false,
				normalScroll = true,
				set = false;

			var mkdfScrollHandler = function () {
				if ($(window).scrollTop() < sliderArea) {
					normalScroll = false;
				}

				function mkdfScrollTo() {
					if (!mkdf.body.hasClass('mkdf-fp-opened')) {
						pageJump = true;
						$('html, body').animate({
							scrollTop: sliderArea
						}, 1000, 'easeInOutQuint', function () {
							pageJump = false;
							normalScroll = true;
						});
					}
				}

				window.addEventListener('wheel', function (event) {
					var scroll = event.deltaY,
						scrollingForward = false,
						reInitOneScroll = false;

					if (scroll > 0) {
						scrollingForward = true;
					} else {
						scrollingForward = false;
					}

					if ($(window).scrollTop() - sliderHolderOffset <= Math.round(sliderHolderHeight * 0.5)) {
						reInitOneScroll = true;
					}

					if (!pageJump && !normalScroll) {
						if (scrollingForward && ($(window).scrollTop() < sliderArea)) {
							event.preventDefault();
							mkdfScrollTo();
						}
					} else {
						if (!normalScroll) {
							event.preventDefault();
						}

						if (normalScroll && !scrollingForward && reInitOneScroll) {
							pageJump = false;
							normalScroll = false;
							event.preventDefault();
						}
					}
				}, {
					passive: false
				});

				//scrollbar click
				$(document).on('mousedown', function (event) {
					if ($(window).outerWidth() <= event.pageX) {
						if ($(window).scrollTop() == sliderHolderOffset) {
							event.preventDefault();
							mkdfScrollTo();
						}
					}
				});
			}

			//prevent mousewheel scroll
			window.addEventListener('wheel', function (event) {
				if (!set) {
					event.preventDefault();
				}
			});

			//prevent scrollbar scroll
			window.addEventListener('scroll', function () {
				if (!set) {
					$(window).scrollTop(sliderHolderOffset);
				}
			})

			//init
			if (revSlider.length) {
				revSlider.bind('revolution.slide.onchange', function (e, data) {
					set = true;
					mkdfScrollHandler();
				});
			} else {
				$(window).on('load', function () {
					set = true;
					mkdfScrollHandler();
				});
			}
		}
	}

	function mkdfUncoveringRowLanding() {
		var uncoveringRow = $('.mkdf-uncovering-row-landing');

		if (uncoveringRow.length) {
			var closestContent = uncoveringRow.closest('.mkdf-content'),
				prevRow = uncoveringRow.prev();
			
			closestContent.append(uncoveringRow);
			prevRow.css({'margin-bottom': '100vh', 'position': 'relative'});
			uncoveringRow.css({
				'position': 'fixed',
				'width': '100vw',
				'height': '100vh',
				'bottom': '0',
				'left': '0',
			});

			var svgTest = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1922 52"><path d="M283.8 39.4zM227.6 39.2c-.1 0 0 0 0 0zM200.2 37.6zM374.6 33.2zM267.8 40.3s-.1 0 0 0zM373.2 31.3zM287.8 39.5c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3 0 .3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4 0-.8.1-1.1.3zM360.5 39.7c-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5 0-.1 0-.2-.1-.2-.4-.3-.6-.3-.9-.3zM229.7 42.7c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.8-1 1zM230.6 41.7s0-.1 0 0c0-.1 0-.1 0 0zM231.6 40.5zM230.2 39.1zM230.2 39.1c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.5-.7-1-1-1.4zM267.7 41.5v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.8-.8-.2-1.6-.5zM336.9 41.6c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.4-.5-1-.8-1.6-.7zM342.1 42.9c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM256.4 42.1c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.2-.5-.3-.7-.3zM327.2 37.4c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.2.6.2 1.1.3 1.6zM259.8 42c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.3-.4-.4zM185.9 33.4c0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.2-.5 0-.9-.5-.9h-.2c0-.1-.1-.2-.2-.2s-.2.1-.2.2c-.3 0-.6.1-.9.2.1.7.6.3.9.5-.1.4-.2.8-.2 1.2zM342 39.4c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3h3.1zM224.6 44.3c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.4-.5-.6z"/><path d="M228.1 39.7c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM221 43c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.3 0-.6-.3-.8zM385.8 43.1c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1.1-.3.1-.5.2-.8.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.2-.6-.4-1.2-1.2-1.5zM245.6 42.5c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.2-.4.1-.6-.2zM365.3 40c-.6-.1-1.2-.1-1.8-.2-.1 0-.2.2-.2.3l.1.2c.2.1.3.2.5.2.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.2-.9-.2-1.3-.2zM248.5 42.9c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.4-.8-.8-1.2zM233.5 44.3c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.5-.3-.9zM331.1 39.6c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.2-.2-.4-.4-.6zM349.2 39.5c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.3-4.2.1zM223.9 39.5c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.5-1 .5-1-.7-2.1zM262.1 43c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.5.2-.4.5zM262.5 42.5zM345 37.5c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-1-.4-1.4zM183.5 37.6c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.2-.1-.6-.2-1-.4zM229.8 46.2c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.1-.4 1.7zM374.5 36.2c.2-.5.4-.9.1-1.3-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.4 0 .6.1.8.2zM207.6 44.7s.1 0 0 0c.1-.2 0-.3-.1-.4-.1 0-.2.1-.2.1-.1-.1-.2-.2-.4-.3l-.2.1s0 .2.1.2h.4c.1.1.1.1.1.2v.7c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.8-.1-.8-.6-1.2zM361.8 42.5c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.2-1.1.3-1.9.6zM234.8 42.5c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.3-.2-.5-.4-.5zm.1.8c0 .1 0 .1 0 0l.1.1c-.1 0-.1 0-.1-.1zM249.7 43c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1-.4.3-.7.6-1 1zM194.8 39.8c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.2-.7-.5-.6zM196.3 40.9h-.2V42c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.8-.5-1.3zM191.5 41.7c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.3-.5-.6-.2zM231.6 44.4c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5.1-.7.3-.7.5zM381.7 43.5c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6.2-.2.5-.4.6-.6.1-.4-.3-.8-.6-.7zM184.1 35.5c-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.4.1-.9-.1-1.3l-.1-.1-.1.1v.1c-.1.2-.3.6-.4 1zM356.6 35.3c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.2-.5-.3-.7-.4zM331.6 35.6c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.1.2.2.7.6.6zM331.8 34.2zM269.5 44.2c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1 0-.1.3-.1.5zM221.8 45.3c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.5-.4.8-1 .8zM226.8 45.6c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .8.3 1.2.5 1.9zM375.4 40.6c-.2 0-.4.1-.6.2v.4c.2.3.7.4.9.3.1 0 .1-.2.1-.2 0-.3-.1-.6-.4-.7zM363.5 39.3c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4-.4 0-.9-.1-1.3-.1-.1 0-.2.2-.2.3-.1.1 0 .3.1.4zM192.5 39.6c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.1-.4-.3-.6-.5zM192.5 39.6zM360.8 34.9c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM365.5 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM365.6 36.1c.4-.9.3-1.3-.1-2.5-.2 1.8-.2 1.8.1 2.5zM293.1 42.4c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.1-.3-.1zM281.6 42.9c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5s-.2-.6-.5-.6zM392 47.4c.7 1.2.8 1.3 1.7 1.3-.6-.5-.8-1.1-1.7-1.3zM326.6 34.4c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM391.8 48.6c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.5.2-1-.3-1.1zM244.2 44.4c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 .1.2.1.4.1zM335.8 37.3c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.1-.1-.4 0-.5.2zM360.1 36.3c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM281.7 41.4c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.1.1-.3zM243.9 45.4c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.3.5-.4.6zM241.3 39.1c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM372.2 36.2c.1-.1.2-.3 0-.5-.1-.1-.3-.1-.5-.1-.1.1-.3.2-.3.4s.1.4.2.7c.3-.2.4-.3.6-.5zM376.7 41.7c.1 0 .3.1.4 0 .3-.3.8-.4 1-.8-.8-.1-.8-.1-1.4.8zM283.7 41.1c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM181.2 36.3c-.1 0-.1 0 0 0zM331.3 37.3c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.1-.3-.2-.6-.3-1z"/><path d="M246.2 41.9c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.2.6-.4.6-.7zM197.6 40.3l.3.6c.2-.1.5-.2.7-.3-.5-.9-.5-.9-1-.3zM267.8 40.9c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM267.8 40.3c-.1 0 0 0 0 0zM376.7 33.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM375.4 33.2c0 .3-.2.6.2.9.4-.3.9-.4 1.1-.9-.4.2-.9.1-1.3 0zM333.4 34.9v.1c.3.3.6.2 1-.1-.4-.2-.7-.3-1 0zM227.2 42.9c.1.8.1.8.9.4-.3-.4-.5-.6-.9-.4zM355.1 35.7c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2-.1.3-.3.3-.4zM221.9 40.3c0-.1-.2-.2-.3-.3-.1.1-.3.3-.3.4 0 .2.2.5.3.9.2-.5.3-.7.3-1zM381.5 41.1c-.2 0-.4-.1-.5 0-.2.1-.3.4-.4.6l.2.2c.2-.3.6-.2.7-.8zM327.6 33.9c.3-.6.1-1.2.1-1.8-.4.7-.5 1-.1 1.8zM186.6 36.5c0-.1-.2-.2-.2-.3l-.5.5c.2.1.3.3.4.3.2-.1.3-.3.3-.5zM266.1 43.6c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.2-.3-.3-.5-.1zM236.4 44.8c.3-.4.2-.8 0-1.4-.4.7-.4.7 0 1.4zM362.5 37.3c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.3-.1-.3-.1zM187.3 41v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM370 35c0 .8 0 .8.8.9-.3-.3-.5-.5-.8-.9zM345.9 38.1c.4.3.7.4 1.1.2-.3-.3-.6-.3-1.1-.2zM342.2 38.1c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM190.6 43.2c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM367.6 34.7c-.1 0-.3.2-.3.2 0 .1.1.3.2.5.2-.2.3-.3.3-.4.1-.2 0-.4-.2-.3zM407.3 33.4c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM408.7 33.5c-.1 0-.2-.1-.4-.1v-.2c0-.1-.2-.2-.2-.3l-.4.4c-.1 0-.3.1-.4.1.4.3.9.5 1.4.1zM181.3 38.9c.5-.6.3-1.2.4-1.7-.3.4-.5.9-.4 1.7zM181.7 37.2s0-.1 0 0c0-.1 0-.1 0 0zM274.9 43.5c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM219.2 45.3c0 .4.1.6.1 1 .5-.5.5-.7-.1-1zM228.3 44.6c-.1 0-.1.1-.1.2 0 .3.1.5.4.6.2-.3 0-.5 0-.7-.1 0-.3-.1-.3-.1zM273.1 41.6c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0 0-.1 0-.2.1zM203.9 45.5c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM247.6 44.6c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM389.2 43.9c.1 0 .1-.1.1-.2 0-.4-.3-.6-.7-.7.1.3.2.6.3.8 0 .1.2.1.3.1zM388.6 43zM191.7 40.8c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.4.2.4z"/><path d="M197.5 41.3c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM197.9 40.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM353.6 35.8c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM189 43c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM359.4 37.5c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4c0 .1.1.1.1 0zM201.3 40.1s0 .1 0 0c.1 0 0 0 0 0z"/><path d="M200.9 39.5s-.1 0 0 0c-.2.5.2.5.4.7 0-.3.1-.7-.4-.7zM191.5 39.2c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM192.5 39.6zM192 39.6s0 .1 0 0c0 .1 0 .1 0 0zM238.1 45.8l.2.2c.1-.1.2-.3.3-.4l-.2-.2c-.2.1-.2.3-.3.4zM201.3 38.6c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 .1.2 0 .3-.1zM198.5 38.4c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM309.4 42.5c0 .1.1.2.2.4.1-.2.2-.4.1-.4 0-.1-.2-.1-.3-.2 0 .1-.1.2 0 .2zM179.7 38.6c0 .1.1.2.2.4.1-.2.1-.3.1-.4 0-.1-.1-.1-.1-.2 0 0-.2.1-.2.2zM211 45.6c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.1 0-.3.1zM291.9 41.6c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7l-.3-.3zM240.5 43.1s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.1.2-.3.3zM212.9 44.3c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.1.1-.2zM211.4 44.3s0 .1 0 0c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM193.2 43.4s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM372.9 43.2c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM372.5 43zM179.7 35.8c0 .1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.2-.1-.3c-.1 0-.3.1-.3.2zM242.3 44.6c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3-.1-.1-.2-.1-.2-.2zM290 42.6c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1 0-.1.2-.2.3zM279 41.9h.1zM278.5 42.3s.1.1 0 0c.4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM370.6 37.4s.2-.1.2-.2-.1-.2-.2-.3c-.1.1-.2.1-.3.2.2.2.2.3.3.3zM364 36.2zM363.4 36.2c.1.1.1.2.2.3l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1zM362.4 36.3c0 .1.1.2.3.3.1-.2.1-.3.1-.4 0-.1-.2-.1-.3-.1-.1 0-.2.1-.1.2zM199.9 41.8c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM289.6 43.1c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM205.6 46s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.3-.2.4-.2.6zM204.7 44c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c-.1.1-.1.1-.1.2zM181 33.7h.2c0-.1.1-.3.1-.4v-.1c.1 0 .1 0 .2-.1v-.2s-.1 0-.1.1l-.1.1c0-.1.1-.2 0-.2 0-.1-.2-.1-.3-.1l-.1.2c0 .1.1.2.2.3l-.3.3c.2 0 .2.1.2.1zM194.1 39.3c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0-.1 0-.2.1-.2zM217.8 43.5s.1.1.2.1v-.2h-.2v.1zM208.7 43.8s0 .1 0 0c0 .1 0 .1.1.1l-.1-.1c.1.1 0 0 0 0zM197.2 43.8c.1.1.1.3.2.4h.2v-.1c-.1-.1-.3-.2-.4-.3zM253.3 41.9h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM253.3 41.4zM204.3 40.3s0-.1 0 0c-.1 0-.1.1-.1.1s.1 0 .1.1v-.2zM201.3 40.2c.1 0 .1 0 0 0 .1 0 .1 0 0 0zM201.4 40.2c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1-.2-.1-.3-.1-.3 0zM375.4 33.2zM374.6 33.2zM374.6 33.2c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM200.2 37.6v.7c.3-.3.1-.5 0-.7zM372.7 31.3s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1 0 0-.1.1-.2.1zM373.2 31.3zM190.8 34.2s.1 0 .1.1c0-.1.1-.1.1-.2 0 0-.1-.1-.1 0 0-.1 0 0-.1.1zM182.3 32.2l-.1.1s0 .1.1.1c-.1 0 0 0 0-.2 0 .1 0 0 0 0zM404.3 39.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM404.3 39.9c-.1.2-.2.4-.2.6.2-.2.4-.3.2-.6zM405.8 37.5zM406 37.7s0-.1 0 0c-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM211.4 43.9v.4c.1-.1.1-.2.2-.4 0 .1-.1 0-.2 0zM197.2 43.7c0 .1 0 .1 0 0 0 .1 0 0 0 0zM197.1 43.4c0 .1-.1.1-.1.2s.1.1.1.2v-.2c.1-.1 0-.2 0-.2zM295.5 39.2s.1 0 .1-.1c.1-.1.1-.1.1-.2-.1 0-.2 0-.2.1s.1.2 0 .2zM283.5 39.7h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2 0-.1 0 0-.1 0zM283.8 39.4zM329.7 36.8c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM330 36.6h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2 0 .1 0 0 .1 0zM181.1 36.3zM180.8 36.4c.1 0 .2 0 .2-.1l-.2.1c.1-.1.1 0 0 0zM336.9 29.7l-.2-.2c0 .1.1.1.1.2h.1zM199.2 34.2V34c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2.1 0 .1.1.1.1zM399.7 48.7h0c-.1 0-.1 0 0 0zM399.5 48.6zM402.4 44.3v.1c-.1.1-.1 0 0-.1 0 .1 0 .1 0 0zM388.6 43c0-.2 0-.3.1-.5-.1 0-.1-.1-.2-.1-.2.2-.1.4.1.6zM339.8 43.3c0-.1 0-.1.1-.2l-.1.1v.1zM243.2 42.9c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM343.4 39.2h.1-.1zM273.6 39.9v-.1.1zM345 37.3v0zM225.7 41.4s0-.1.1-.1c-.1 0-.1 0-.1.1zM225.7 41.3s.1 0 0 0c.1 0 .1-.1 0 0 .1-.1.1-.1 0 0zM364 36.2s.1 0 .1-.1c-.1 0-.1 0-.1.1zM250.4 40.2c.1 0 .1-.1.2-.1 0 0-.1 0-.2.1.1-.1.1-.1 0 0zM327.7 32.1zM327.8 31.9c0 .1 0 .1-.1.2l.1-.1v-.1zM181.5 29.3s.1 0 .1.1l-.1-.1c.1 0 .1 0 0 0zM300.3 30.2c-.1 0-.1 0 0 0-.1.1-.2.2-.2.3.1 0 .1-.1.2-.1v-.2zM300.1 30.5c-.1 0-.1 0 0 0zM343.7 29.1s0-.1-.1-.1l.1.1zM287.1 29.9c-.1 0-.1-.1-.2-.1l-.1.1h.3zM279.4 30.2c.1 0 .2-.1.3-.1-.1-.1-.1-.2-.2-.3h-.4v.1l.3.3zM196.5 34.2v.1h.1v-.1h-.1zM319.2 35.4c0-.1 0-.1.1-.2-.1.1-.1.1-.1.2-.1 0 0 0 0 0zM276.6 29.5s0-.1.1-.1l-.1.1zM229.4 39.4zM272 31.3l.2.2c0-.1-.1-.1-.1-.2h-.1zM317.2 34.4l-.1.1s0-.1.1-.1zM293.8 37.7l-.2.2c.1 0 .1-.1.2-.1s0-.1 0-.1zM298.4 33.5c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c-.1-.1-.2-.1-.2-.2zM233.8 26.8c-.1 0-.1 0 0 0-.1.1 0 .1 0 0 0 .1 0 0 0 0zM102.5 36.1zM33.5 32.3zM46.2 35.9zM18.9 34.3zM193.3 29.9zM86.4 37zM191.9 27.9c-.1 0-.1 0 0 0zM106.5 36.2c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.5-.1-.8 0-1.1.3zM180 36.4c-.3 0-.5-.1-.8 0-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5-.2-.3-.2-.4-.2-.5zM23.5 30.1c.1 0 .1 0 0 0 .1 0 0 0 0 0zM22.5 30.1v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 .1.1.1.2.1 0 .4 0 .8-.2 1.2 0-.1-.1-.1-.1-.2 0 .1.1.1.1.2-.3.1-.5.2-.8.3.2.5.2.5-.3 1.3.3.1.6.1.9.2.5-.2.5-.2.7.2.1.2 0 .4.4.3v-.8c-.1-.5 0-.9.2-1.4.2-.4.2-.8.3-1.2-.1-.2-.3-.4-.4-.6-.4.1-.6.3-.8.5zM48.4 39.4c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.7-1 1zM49.3 38.3zM7.4 28.7zM6.4 31.7c-.1.1-.1.2-.2.3.2.3.4.5.6.8.4-.1.6-.5.8-.9.2.1.4.4.8 0-.2-.3-.3-.6-.5-.8l.3-.3c.1-.9-.6-1.4-.8-2.1-.1.1-.2.3-.1.4.3 1.1-.2 1.8-.9 2.6zm1.1.1c-.1-.1-.2-.1-.3-.2 0-.1.1-.1.1-.2.1.2.2.3.2.4zM50.3 37.1zM48.9 35.8zM48.9 35.8c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.6-.7-1-1-1.4zM86.4 38.2v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.9-.9-.2-1.6-.5zM155.6 38.3c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.5-.5-1-.8-1.6-.7zM160.8 39.6c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM75.1 38.7c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.1-.5-.3-.7-.3zM145.9 34c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.1.6.2 1.1.3 1.6zM78.4 38.7c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4 0-.2-.2-.4-.4-.4zM5.4 28.1c-.5 0-1 0-1.5.2.1.7.6.3.9.5-.1.4-.1.8-.1 1.2 0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5 0-.5-.2-.8-.6-.9zM160.6 36c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3c1.1.1 2.1 0 3.1 0zM43.2 40.9c-.2-.3-.2-.5 0-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.3-.6-.6zM30.9 34.6c-.1-.1-.2-.3-.2-.4-.2.3-.4.7-.9.7l-.9-.6c0 .4.1.8.4 1.1.4.3.5.8.5 1.4.1-.3.3-.5.4-.8.9.2.9.2 1.1-.7-.2-.2-.3-.5-.4-.7zM29.7 36.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM46.8 36.4c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM39.7 39.7c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.4 0-.7-.3-.8zM204.5 39.8c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1v-.1c.1.2.3.3.4.5.1-.4 0-.6-.4-.6 0-.2.1-.4.1-.5.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.1-.7-.4-1.3-1.1-1.6zM10.2 27.1c-.3 0-.6.3-.6.8s.3.8.8.8c.4 0 .7-.3.7-.7 0-.5-.5-.9-.9-.9zM64.3 39.2c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.1-.4 0-.6-.2zM184 36.6c-.6-.1-1.2-.1-1.8-.2l-.1-.1c-.1.3-.2.6-.3.8.2 0 .4.2.4.1s.1-.1.1-.2c.1 0 .2.1.3.1.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.1-.9-.1-1.3-.2zM67.2 39.6c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.5-.8-.8-1.2zM52.2 41c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.6-.3-.9zM149.8 36.3c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4 0-.3-.2-.4-.4-.6zM11.9 31h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8-.1.2-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.6 1.1.9 1.5zM1.7 29.7c-.3.5-.6.9-.8 1.4.4.5.6.7 1 1 .1-.9.2-1.6-.2-2.4zM167.9 36.2c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.4-4.2.1zM42.6 36.2c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1z"/><path d="M80.8 39.6c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.3.1-.5.3-.4.5zM81.2 39.2zM163.7 34.1c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-.9-.4-1.4zM2.2 34.3c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.3-.1-.6-.2-1-.4zM48.5 42.8c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.5.6-.4 1.2-.4 1.7zM193.4 31.5c-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.2 0 .5.1.7.2-.1.1-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1 .9 1.4h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8.2-.4.5-.8.2-1.2zM36.6 36.6c0 .6 0 1.2.1 1.9.5-.4.7-.6.8-.8.1-.6-.2-.9-.9-1.1zM26 41.2v.8c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.9-.1-.8-.9-1.4zM180.5 39.2c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.1-1.1.3-1.9.6zM53.5 39.1c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.2-.2-.4-.4-.5zm0 .9c.1 0 .1 0 0 0l.1.1s0-.1-.1-.1zM68.4 39.6c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1l-1 1zM15.4 33.6zM14.8 33.8c.3.6.7 1.1.7 1.8.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1l-.3-.9h-.6c-.1.1-.1.2-.1.2zM13.5 36.5c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.3-.7-.5-.6zM28.8 34.2zM28.7 32.4s-.1-.3-.1-.4c-.2 0-.3 0-.5.1-.1 0-.1.2-.1.2 0 .4 0 .9.1 1.3.1.3.4.4.7.6-.1-.6-.6-1.2-.1-1.8zM15 37.6h-.2v1.1c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.9-.5-1.3zM10.1 38.3c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4.1-.3-.2-.4-.6-.2zM26.7 38.3c-.1-.4-.1-.6-.2-.9v-.9c-.5.3-.8.5-.7 1 .1.5.3.8.9.8zM50.3 41.1c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.6 0-.7.2-.7.5zM200.4 40.1c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6l.1-.1.1.1c0-.1 0-.2.1-.2.1-.1.3-.3.3-.4.1-.4-.3-.7-.6-.7zM21.4 34.1c0-.3-.2-.4-.4-.5-.3-.3-.6-.6-.9-1-.4.3-.4.7-.3 1.1.1.4.3.5.7.5 0 .1 0 .2-.1.3-.1.3.1.6.4.7.2.1.4-.1.5-.5.1-.2.1-.4.1-.6zM11.8 28.1c.7-.7.6-1-.3-1.9 0 .7-.2 1.3.3 1.9zM3.2 31c-.1.4-.3.8-.4 1.2-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.5.1-.9-.1-1.4h-.2zM175.3 31.9c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.1-.5-.3-.7-.4zM150.2 32.3c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.2.2.3.7.6.6zM150.5 30.9zM88.2 40.8c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1.1-.1.4-.1.5zM35.2 36.9c-.2.2-.3.4-.1.6.1.2.2.3.4.4 0 .1 0 .1.1.2v-.2c.2.1.3.1.5.2.2-.5 0-.8-.2-1.1-.3-.2-.5-.2-.7-.1zM40.5 41.9c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.6-.4.9-1 .8zM45.5 42.3c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .7.2 1.2.5 1.9zM182.2 35.9c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4h-.3c.2-.8.2-1.6-.1-2.3-.3.5-.6.9-.8 1.4.4.4.6.7 1 .9h-.9s-.1 0-.1.1c-.7-.2-.8-.1-.9.4v.5c.3-.2.6-.4.9-.7-.4.2-.3.3-.2.3zM11.2 36.3c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.2-.4-.3-.6-.5zM11.2 36.3zM179.5 31.6c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM184.2 30.2zM184.3 32.7c.4-.9.3-1.3-.1-2.5-.2 1.9-.2 1.9.1 2.5zM111.8 39.1c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.2-.3-.1zM100.3 39.6c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5 0-.4-.2-.6-.5-.6zM211.4 44.4c0-.1-.1-.1-.1-.1-.2-.1-.3-.2-.5-.2 0 .1.1.1.1.2-.2 0-.3.1-.2.2.1.1.2.1.3.1.4.7.7.8 1.4.8-.4-.3-.7-.7-1-1zM8.9 35.8c-.1.5-.2 1-.4 1.6.3 0 .5.1.7 0 .1-.1.2-.3.2-.5-.1-.4-.2-.7-.5-1.1zM145.3 31.1c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM10 33.3c-.3-.3-.6-.4-.9-.4-.1 0-.2.1-.5.3.4.1.6.2.8.3.2.1.4.3.6.4.3-.2.2-.4 0-.6zM210.5 45.3c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.6.2-1-.3-1.1zM62.9 41.1c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 0 .2.1.4.1zM154.5 34c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.2-.1-.4 0-.5.2zM178.8 33c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM100.4 38.1c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.2.1-.3zM62.6 42.1c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.3.4-.4.6zM60 35.8c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3H60zM102.3 37.8c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3.1-.1-.1-.2-.2-.2zM34.7 41.3c.6.2.9.2 1.3-.2-.4-.3-.8-.3-1.3.2zM150 34c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.2-.3-.2-.6-.3-1zM64.9 38.5c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.1.6-.3.6-.7zM16.3 36.9l.3.6c.2-.1.5-.2.7-.3-.5-.8-.5-.8-1-.3zM86.5 37.5c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2-.1.2-.1.4 0 .6zM86.4 37zM152.1 31.6v.1c.3.3.6.2 1-.1-.4-.3-.7-.3-1 0zM45.9 39.5c.1.8.1.8.9.4-.3-.3-.5-.5-.9-.4zM173.8 32.3c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2 0 .3-.2.3-.4zM40.3 36.6c-.1.2-.3.3-.3.4 0 .2.2.5.3.9.1-.5.3-.7.3-1 0 0-.2-.1-.3-.3zM146.2 30.5c.3-.6.1-1.2.1-1.8-.4.7-.4 1.1-.1 1.8zM5 32.9l-.5.5c.2.1.3.3.4.3.2 0 .4-.2.3-.4 0-.3-.1-.3-.2-.4zM24.8 33c-.2-.2-.5-.3-.7-.5-.1 0-.1.1-.2.1.1.2.1.4.2.6.2.2.7.1.7-.2zM84.8 40.3c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.3-.3-.3-.5-.1zM55.1 41.5c.3-.4.2-.8 0-1.4-.4.6-.4.6 0 1.4zM181.2 34c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.2-.1-.3-.1-.3-.1zM6 37.7v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3 0-.6-.4-.8zM164.6 34.8c.4.3.7.4 1.1.2-.3-.4-.6-.4-1.1-.2zM160.9 34.7c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM9.3 39.9c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM39.5 37.4c0-.1-.1-.3-.2-.6-.2.2-.3.4-.4.5-.1.2 0 .4.2.4s.4-.2.4-.3zM24.8 35.6c.3-.6.1-.9-.3-1.2 0 .4-.1.8.3 1.2zM31.2 32.7c.1.3.1.6.2.9h.6c0-.6-.3-.8-.8-.9zM31.4 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM206.5 41.4zM206.5 40.5l-.2-.2c0-.1-.1-.2-.2-.2 0 0-.1.1-.2.1 0 .1.1.1.1.2l-.1.1c.1.3.3.6.5.9.2-.3.3-.6.1-.9zM164.7 40.4c-.2 0-.4.1-.3.3 0 .1.2.2.4.3.1-.1.3-.2.3-.3-.1-.2-.3-.3-.4-.3zM93.6 40.2c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.4-.3-.5-.4zM37.9 42c0 .4.1.6.1 1 .5-.6.5-.7-.1-1zM47.2 42.1c.2-.3 0-.5 0-.7l-.2-.1c-.1 0-.1.1-.1.2-.1.3 0 .6.3.6zM91.8 38.3c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0-.1-.1 0-.2.1zM31.4 42c-.1.2-.3.3-.4.5.1.1.2.2.3.2.2-.1.3-.3.4-.5 0 0 0-.2-.1-.2 0-.1-.2-.1-.2 0zM22.5 42.2c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2 0 .1-.1.1-.2.1zM66.3 41.3c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM163.2 39.4c-.1.4-.1.7.4 1 0-.4 0-.8-.4-1zM207.3 39.7zM10.3 37.5c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7 0 .1 0 .3.2.4zM16.2 38c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM16.6 37.5zM172.3 32.5c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM7.7 39.7c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM178.1 34.2c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4h.1zM209 44.4c.1.1.2.2.3.2.1-.1.1-.2.2-.3-.1-.1-.2-.1-.3-.2-.1 0-.2.2-.2.3zM20 36.8zM19.6 36.1s-.1.1 0 0c-.2.5.2.5.4.7 0-.3.1-.6-.4-.7zM10.2 35.9c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM11.2 36.3zM10.7 36.3c-.1 0-.1 0 0 0zM171.7 38c-.1.2-.1.3-.2.5.1.1.1.2.2.2s.2-.1.2-.1c0-.2 0-.4-.1-.5 0-.1-.1-.1-.1-.1zM20 35.3c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 0 .2-.1.3-.1zM17.2 35.1c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM166.6 37.9c-.1 0-.2 0-.2.1-.1.1-.1.2-.2.3.1 0 .2.1.3.1.2 0 .3-.1.3-.4 0 0-.1-.1-.2-.1zM70.7 41.9l.2.2c.1-.2.2-.4.3-.5-.1 0-.2-.1-.2-.1-.1.1-.2.2-.3.4zM32.9 42.1s-.1 0 0 0c0 .2 0 .4.1.6h.2c-.1-.2-.1-.3-.2-.5 0-.1-.1-.1-.1-.1zM29.7 42.3c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.2 0-.3.1zM110.6 38.3c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.2-.2-.2-.3-.3zM59.2 39.8s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.1.2-.3.3zM31.5 41c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3 0 0 .2-.2.1-.2zM29.3 41.1c.1.1.3.1.5.1.1 0 .2-.1.3-.2-.1 0-.2-.1-.3-.1-.3-.1-.6.1-.5.2zM30.1 41zM11.9 40.1s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.2.2-.2.3-.2.5zM23.1 38.8l.6.6c.1-.5 0-.7-.6-.6zM150.8 33.4l.2-.1v-.4c-.1 0-.2.1-.4.1 0 .2.1.3.2.4zM165.8 31.9c-.1 0-.2.2-.3.3.1.1.2.2.3.2.1 0 .2-.2.2-.3 0-.1-.1-.3-.2-.2zM208.4 46.1l.2.2c.1 0 .2-.1.2-.2-.1-.1-.2-.1-.3-.2 0 .1 0 .1-.1.2zM63.9 51.6c.1 0 .1.1.2.1v-.2l-.1-.1s0 .1-.1.2zM222.2 41.4h-.4c-.1 0-.1.2-.1.3.1 0 .2.1.2 0 .1 0 .1-.1.3-.3zM191.6 39.9c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM191.2 39.7zM47 43h.3s.1-.1.1-.2c-.1 0-.2-.1-.3 0-.1 0-.1.1-.1.2zM76.6 41.4c0 .1.1.3.1.3.1 0 .2-.1.3-.1-.1-.1-.1-.3-.1-.3-.1 0-.2.1-.3.1zM60.9 41.3c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.2-.2-.2zM34.9 42.7c.4-.3.4-.3.3-.7-.1.3-.2.4-.3.7zM36.6 41.9c0 .1.1.2.2.3.1-.1.2-.1.2-.2-.1-.1-.1-.2-.2-.3 0 .1-.2.2-.2.2zM108.7 39.2c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1.1-.1.2-.2.3zM97.7 38.6v-.1zM97.2 38.9c0 .1.1.1 0 0 .4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM25.4 40.9s0 .2.1.2c.2 0 .4 0 .6.1-.1-.1-.3-.3-.5-.4 0 0-.1 0-.2.1zM26.1 41.2zM171.4 35.1c-.3 0-.5-.1-.8-.1.3.3.5.3.8.1zM182.6 32.8s0 .1 0 0c0 .1.1.1 0 0zM182.3 33.2l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1.1.1.1.2.2.3zM18.6 38.5c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM19.2 37.4c0 .2-.1.3-.1.4 0 .1.1.1.2.2 0-.1.1-.2.1-.4l-.2-.2zM22.2 34.4c-.1.7.4.9 1 1.3v-.8c-.1-.4-.5-.5-.8-.7.1-.4.1-.8-.2-1.2-.2.5-.4 1 0 1.4zM206.5 42c-.2 0-.5.1-.9.1.6.4.8.2.9-.1zM193.9 40.4c0 .1.1.1.1.2.1 0 .1-.1.2-.1 0 0 0-.1-.1-.1 0-.1-.1-.1-.2 0zM44.7 42.7c0 .1.1.1.1.2.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3-.1 0-.1.1-.1.2zM108.3 39.8c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM24.3 42.6s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.4-.2.5-.2.6zM23.3 40.7c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1 0 .1-.1.2zM66.5 38.2h.3c-.1-.1-.1-.2-.2-.3h-.2s-.1.1 0 .1c0 .1.1.2.1.2zM81.7 37.2c-.1 0-.1 0-.2.1 0 .1.1.1.1.2l.2-.2-.1-.1zM173.3 33.8s.1-.1.1-.2c-.1 0-.2-.1-.3-.1 0 0-.1.1-.1.2.1 0 .2.1.3.1zM80.6 36.8c-.1 0-.2.1-.3.1l.2.2c.1 0 .2-.1.3-.2-.1 0-.2-.1-.2-.1zM33.3 38.2c.1 0 .2.1.2.1s.1-.1.1-.2c-.1 0-.2-.1-.2-.1s-.1.1-.1.2zM30.5 38.3c.1.1.1.2.1.2l.2-.2v-.2c-.1.1-.2.1-.3.2zM21.3 38.7c0 .1.1.1.2.2.1-.1.1-.2.2-.3-.1 0-.1-.1-.2-.1-.1.1-.2.1-.2.2zM34.1 36.9c0 .1.1.1.1.2.1 0 .2-.1.2-.1 0-.1-.1-.1-.1-.2-.1 0-.1.1-.2.1zM24.9 36.8s-.1.1-.2.1c.1.1.1.2.2.3.1-.1.2-.2.1-.2 0-.1-.1-.2-.1-.2zM12.8 35.9c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0 0 0-.1.1-.2 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM40.6 41.2s-.1 0 0 0c-.1 0-.1 0-.1.1l.1-.1c0 .1 0 0 0 0zM72 38.6h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM72 38.1zM43.9 39.5c0-.1-.1-.1-.1-.2-.1 0-.1.1-.1.1 0 .1.1.1.1.2 0 0 .1 0 .1-.1z"/><path d="M193.9 32.8c-.1 0-.2 0-.2.1l.1.1c.1-.1.1-.1.1-.2zM82.9 37.1c0 .1-.1.2-.1.3.1-.1.2-.1.3-.2l-.2-.1zM82.7 37.4zM21.4 37.1h-.2v.1s.1.1.2.1v-.2zM28.3 36.9c.1 0 .1 0 .1-.1 0 0-.1-.1-.1.1 0-.1 0-.1 0 0zM22.9 37c0 .1 0 .1 0 0 .1 0 .1 0 .1-.1h-.1v.1zM20 36.8zM20.1 36.8c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1h-.3zM194 29.9c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1-.1.1 0 0 0zM193.3 29.9z"/><path d="M193.3 29.9c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM27.2 35.7l.1.1c0-.1 0-.1-.1-.1 0-.1 0-.1 0 0zM18.9 34.3v.7c.3-.4.1-.5 0-.7zM191.4 28s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1s-.1 0-.2.1zM191.9 27.9c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM24.4 34.2h-.2s0 .1.1.1.1.1.2.1c0-.1-.1-.2-.1-.2zM24.5 34.4zM6.8 32.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM6.7 33.3c.1-.1.2-.1.2-.2s0-.2-.1-.4c-.1.1-.1.2-.2.3 0 .1 0 .2.1.3zM9.6 30.6c0 .1-.1.1-.1.2 0 0 .1 0 .1.1 0-.1.1-.1.1-.2l-.1-.1zM205.4 42.9v.1l.1-.1c0-.1 0-.1-.1 0 .1-.1 0-.1 0 0zM200.3 42.1v.1h.2v-.1h-.2zM197.3 40.5c0-.1-.1-.1-.1-.2h-.1c0 .1.1.1.2.2-.1 0 0 0 0 0zM43.3 42.9s.1.1.1 0v-.1h-.1v.1zM224.5 34.2zM224.7 34.4c0-.1 0-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM30.1 41c.1-.1.1-.2.2-.4-.1 0-.1 0-.2-.1v.5zM45 39.6c0 .1-.1.1 0 0 0 .1 0 .1.1.1-.1 0 0 0-.1-.1zM102.2 36.4h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2 0-.1-.1-.1-.1 0zM102.5 36.1zM38.7 38.4c.1.1.1.1.2 0v-.1c-.1 0-.2 0-.2.1zM148.4 33.5c0 .1 0 .1 0 0zM148.6 33.2h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2.1.1.1.1.1 0zM17.5 33.5zM17.2 33.2v.2c.1 0 .1 0 .2.1 0-.1-.1-.1-.1-.2l-.1-.1zM7.8 32.9c0-.1-.1-.1 0 0-.1-.1-.1 0-.1 0h.1c-.1 0 0 0 0 0zM155.6 26.4l-.2-.2c0 .1.1.1.1.2h.1zM17.9 30.8v-.2c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2l.1.1zM3.4 29.6v.1zM11.8 24.5zM11.6 24.8h.2c0-.1 0-.2.1-.2l-.2.2c-.1-.1-.1 0-.1 0zM206.5 41.4v.5c.3-.1.2-.3 0-.5zM221 41v0c.1.1 0 0 0 0zM207.2 39c-.2.2-.1.4.1.6 0-.2 0-.3.1-.5-.1 0-.2 0-.2-.1zM158.5 39.9c0-.1 0-.1.1-.2l-.1.1v.1zM61.9 39.6c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM162 35.9h0zM82.7 37.4zM82.5 37.5l.1-.1-.1.1c.1-.1.1 0 0 0zM92.3 36.6v-.1.1zM163.7 34v0zM44.4 38.1s0-.1.1-.1c-.1 0-.1 0-.1.1 0-.1 0 0 0 0zM44.4 38s0-.1 0 0c.1-.1.1-.1 0 0 .1-.1 0-.1 0 0 0-.1 0 0 0 0zM182.6 32.8s.1 0 .1-.1c0 .1 0 .1-.1.1zM69.1 36.8c.1 0 .1-.1.2-.1 0 0-.1 0-.2.1.1 0 0 0 0 0zM29.7 36.8zM29.6 37c0-.1 0-.1.1-.2l-.1.1v.1zM41.8 36.4l.1-.1h-.1zM30.6 34.1c0 .1 0 .1 0 0 .1.1.1 0 0 0 .1 0 0 0 0 0zM30.6 34l.1.1c-.1 0-.1 0-.1-.1zM31.4 33.6l-.1.1.1-.1zM17.8 33.5h-.2c0 .2.1.2.2 0zM17.8 33.5zM146.4 28.7c0 .1 0 .1 0 0 0 .1 0 .1 0 0zM146.5 28.6c0 .1 0 .1-.1.2l.1-.1v-.1zM118.9 26.9s-.1 0-.1.1-.1.1-.1.2c.1 0 .1-.1.2-.1.1-.1 0-.2 0-.2zM118.8 27.2c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0 0 0 0 0zM162.4 25.8s0-.1-.1-.1l.1.1c0-.1 0-.1 0 0zM15.2 30.9h-.1v.1h.1c.1-.1.1-.1 0-.1zM137.8 32.1c0-.1 0-.1.1-.2 0 .1 0 .1-.1.2 0-.1 0 0 0 0zM95.3 26.2s0-.1.1-.1c0 0-.1 0-.1.1 0-.1 0 0 0 0zM47.9 35.9c.1 0 .1.1.2.1 0-.1-.1-.1-.1-.2l-.1.1zM48.1 36c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM90.7 28l.2.2c0-.1-.1-.1-.1-.2h-.1zM135.9 31.1l-.1.1c0-.1 0-.1.1-.1zM117.1 30.2c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1l-.2-.2zM52.5 23.5c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0 0 0 0 0zM686.9 39.4zM630.7 39.2zM603.3 37.6zM777.7 33.2zM670.9 40.3zM776.3 31.3zM690.9 39.5c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c0 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3 0 .3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4 0-.8.1-1.1.3zM763.6 39.7c-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5 0-.1 0-.2-.1-.2-.4-.3-.6-.3-.9-.3zM632.8 42.7c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.8-1 1zM633.7 41.7s0-.1 0 0c0-.1 0-.1 0 0zM634.7 40.5zM633.3 39.1c.1 0 .1 0 0 0 .1 0 .1 0 0 0zM633.3 39.1c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.3-.5-.6-1-1-1.4zM670.8 41.5v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.8-.8-.2-1.6-.5zM740 41.6c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.4-.5-1-.8-1.6-.7zM745.2 42.9c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM659.5 42.1c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.2-.5-.3-.7-.3zM730.4 37.4c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.1.6.1 1.1.3 1.6zM662.9 42c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.3-.4-.4zM589 33.4c0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.2-.5 0-.9-.5-.9h-.2c0-.1-.1-.2-.2-.2s-.2.1-.2.2c-.3 0-.6.1-.9.2.1.7.6.3.9.5-.1.4-.2.8-.2 1.2zM745.1 39.4c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3h3.1zM627.7 44.3c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.4-.5-.6zM631.2 39.7c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM624.1 43c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.3 0-.6-.3-.8zM788.9 43.1c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1.1-.3.1-.5.2-.8.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.2-.6-.4-1.2-1.2-1.5zM648.7 42.5c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.2-.4.1-.6-.2zM768.4 40c-.6-.1-1.2-.1-1.8-.2-.1 0-.2.2-.2.3l.1.2c.2.1.3.2.5.2.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.2-.9-.2-1.3-.2zM651.7 42.9c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5 0-.6-.5-.8-.8-1.2zM636.6 44.3c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.5-.3-.9zM734.2 39.6c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.2-.2-.4-.4-.6zM752.3 39.5c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.8-.3-4.2.1zM627.1 39.5c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1z"/><path d="M665.2 43c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.4.2-.4.5zM665.6 42.5zM748.1 37.5c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.1-.5-.3-1-.4-1.4zM586.6 37.6c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.2-.1-.6-.2-1-.4zM632.9 46.2c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.1-.4 1.7zM777.7 36.2c.2-.5.4-.9.1-1.3-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.3 0 .5.1.8.2zM610.7 44.7c.1 0 .1 0 0 0 .1-.2 0-.3-.1-.4-.1 0-.2.1-.2.1-.1-.1-.2-.2-.4-.3l-.2.1s0 .2.1.2h.4c.1.1.1.1.1.2v.7c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.8 0-.8-.6-1.2zM809.8 20.8c-.5.2-.7 1-.5 1.4.1.2.5.2.6.1.3-.3.4-.7.3-1.2 0-.1-.1-.2-.2-.3h-.2zM764.9 42.5c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.2-1.1.3-1.9.6zM637.9 42.5c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5 0-.3-.1-.5-.4-.5zm.1.8c0 .1 0 .1 0 0l.1.1c-.1 0-.1 0-.1-.1zM652.8 43c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1-.4.3-.6.6-1 1zM598 39.8c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4-.1-.3-.3-.7-.5-.6zM599.4 40.9h-.2V42c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.8-.5-1.3zM594.6 41.7c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.2-.5-.6-.2zM634.7 44.4c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5.1-.7.3-.7.5zM784.8 43.5c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6.2-.2.5-.4.6-.6.1-.4-.3-.8-.6-.7zM587.2 35.5c-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.4.1-.9-.1-1.3l-.1-.1-.1.1v.1c-.1.2-.3.6-.4 1zM759.7 35.3c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.2-.5-.3-.7-.4zM734.7 35.6c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.1.2.2.7.6.6zM734.9 34.2zM672.6 44.2c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1 0-.1.3-.1.5zM624.9 45.3c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.5-.4.8-1 .8zM629.9 45.6c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .8.3 1.2.5 1.9zM778.5 40.6c-.2 0-.4.1-.6.2v.4c.2.3.7.4.9.3.1 0 .1-.2.1-.2 0-.3-.1-.6-.4-.7zM766.6 39.3c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4-.4 0-.9-.1-1.3-.1-.1 0-.2.2-.2.3-.1.1 0 .3.1.4zM595.6 39.6c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.1-.4-.3-.6-.5zM595.6 39.6zM763.9 34.9c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.4.2-.6.5-.6 1zM768.6 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM768.7 36.1c.4-.9.3-1.3-.1-2.5-.2 1.8-.2 1.8.1 2.5zM696.2 42.4c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.1-.3-.1zM684.7 42.9c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5s-.2-.6-.5-.6zM795.1 47.4c.7 1.2.8 1.3 1.7 1.3-.5-.5-.8-1.1-1.7-1.3zM729.7 34.4c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM794.9 48.6c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.5.3-1-.3-1.1zM647.3 44.4c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 .1.3.1.4.1zM739 37.3c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.2-.1-.4 0-.5.2zM763.2 36.3c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8.1.1.2.1.2.1zM684.8 41.4c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.1.1-.3zM647.1 45.4c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.4.5-.4.6zM644.4 39.1c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM775.3 36.2c.1-.1.2-.3 0-.5-.1-.1-.3-.1-.5-.1-.1.1-.3.2-.3.4s.1.4.2.7c.3-.2.5-.3.6-.5zM779.8 41.7c.1 0 .3.1.4 0 .3-.3.8-.4 1-.8-.8-.1-.8-.1-1.4.8zM686.8 41.1c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM584.3 36.3zM734.4 37.3c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.1-.3-.2-.6-.3-1zM649.4 41.9c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.2.5-.4.6-.7zM600.7 40.3l.3.6c.2-.1.5-.2.7-.3-.4-.9-.5-.9-1-.3zM809.2 27.8c.2-1.3.2-1.3-.2-2.3 0 .6-.1 1.3-.1 1.9 0 .2.1.5.3.4zM670.9 40.9c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM670.9 40.3zM779.8 33.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM778.5 33.2c0 .3-.2.6.2.9.4-.3.9-.4 1.1-.9-.4.2-.9.1-1.3 0zM736.6 34.9v.1c.3.3.6.2 1-.1-.4-.2-.8-.3-1 0zM630.4 42.9c.1.8.1.8.9.4-.4-.4-.6-.6-.9-.4zM758.3 35.7c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.1-.1.3-.3.3-.4zM625 40.3c0-.1-.2-.2-.3-.3-.1.1-.3.3-.3.4 0 .2.2.5.3.9.2-.5.3-.7.3-1zM784.6 41.1c-.2 0-.4-.1-.5 0-.2.1-.3.4-.4.6l.2.2c.2-.3.7-.2.7-.8zM730.7 33.9c.3-.6.1-1.2.1-1.8-.4.7-.5 1-.1 1.8zM589.7 36.5c0-.1-.2-.2-.2-.3l-.5.5c.2.1.3.3.4.3.2-.1.4-.3.3-.5zM669.2 43.6c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.2-.3-.3-.5-.1zM639.5 44.8c.3-.4.2-.8 0-1.4-.4.7-.4.7 0 1.4zM765.6 37.3c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.3-.1-.3-.1zM590.4 41v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM773.1 35c0 .8 0 .8.8.9-.3-.3-.5-.5-.8-.9zM749.1 38.1c.4.3.7.4 1.1.2-.4-.3-.7-.3-1.1-.2zM745.3 38.1c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM593.7 43.2c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM770.7 34.7c-.1 0-.3.2-.3.2 0 .1.1.3.2.5.2-.2.3-.3.3-.4.1-.2 0-.4-.2-.3zM810.4 33.4c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM811.8 33.5c-.6-.2-1-.3-1.5 0 .5.2 1 .4 1.5 0zM584.4 38.9c.5-.6.3-1.2.4-1.7-.3.4-.5.9-.4 1.7zM584.8 37.2s0-.1 0 0c0-.1 0-.1 0 0zM678 43.5c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM622.3 45.3c0 .4.1.6.1 1 .6-.5.5-.7-.1-1zM631.4 44.6c-.1 0-.1.1-.1.2 0 .3.1.5.4.6.2-.3 0-.5 0-.7-.1 0-.3-.1-.3-.1zM676.3 41.6c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2-.1 0-.2 0-.2.1zM607 45.5c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM650.7 44.6c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM792.3 43.9c.1 0 .1-.1.1-.2 0-.4-.3-.6-.7-.7.1.3.2.6.3.8.1.1.2.1.3.1zM791.7 43zM594.8 40.8c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.4.2.4z"/><path d="M600.6 41.3c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.2.1-.5.2-.3.5zM601 40.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM756.7 35.8c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM592.1 43c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM762.5 37.5c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4c0 .1.1.1.1 0zM604.5 40.1s0 .1 0 0zM604.1 39.5c-.1 0-.1 0 0 0-.2.5.2.5.4.7-.1-.3 0-.7-.4-.7zM594.6 39.2c.2.2.4.3.5.4h.5c-.2-.4-.4-.6-1-.4zM595.6 39.6zM595.1 39.6s0 .1 0 0c0 .1 0 .1 0 0zM641.2 45.8l.2.2c.1-.1.2-.3.3-.4l-.2-.2c-.1.1-.2.3-.3.4zM604.4 38.6c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4.1.1.2 0 .3-.1zM601.6 38.4c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM712.5 42.5c0 .1.1.2.2.4.1-.2.2-.4.1-.4 0-.1-.2-.1-.3-.2v.2zM582.9 38.6c0 .1.1.2.2.4.1-.2.1-.3.1-.4 0-.1-.1-.1-.1-.2-.1 0-.2.1-.2.2zM614.2 45.6c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3-.1 0-.2 0-.3.1zM695 41.6c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7l-.3-.3zM643.7 43.1s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1-.3.3zM616 44.3c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.1.1-.2zM614.5 44.3s0 .1 0 0c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM596.3 43.4s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM776.1 43.2c.2-.1.3-.4 0-.5l-.4.4c.1 0 .3.1.4.1zM775.6 43zM582.9 35.8c0 .1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.2-.1-.3c-.2 0-.3.1-.3.2zM645.4 44.6c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM693.1 42.6c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1 0-.1.2-.2.3zM682.2 41.9zM681.6 42.3s.1.1 0 0c.4.2.4 0 .5-.3v-.1h-.1c-.1.1-.4.1-.4.4zM773.7 37.4s.2-.1.2-.2-.1-.2-.2-.3c-.1.1-.2.1-.3.2l.3.3zM767.1 36.2zM766.5 36.2c.1.1.1.2.2.3l.3-.3c-.1 0-.2-.1-.3-.1 0 0-.1.1-.2.1zM765.5 36.3c0 .1.1.2.3.3.1-.2.1-.3.1-.4 0-.1-.2-.1-.3-.1-.1 0-.2.1-.1.2zM603 41.8c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2.1-.1-.1-.3-.1-.3zM692.8 43.1c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.2-.1-.2-.2zM608.7 46s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.1.3-.2.4-.2.6zM607.8 44c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1-.1.1-.1.2zM584.1 33.7h.2c0-.1.1-.3.1-.4v-.1c.1 0 .1 0 .2-.1v-.2s-.1 0-.1.1l-.1.1c0-.1.1-.2 0-.2 0-.1-.2-.1-.3-.1l-.1.2c0 .1.1.2.2.3l-.3.3c.2 0 .2.1.2.1zM597.2 39.3c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0-.1.1-.2.1-.2zM620.9 43.5s.1.1.2.1v-.2h-.2v.1zM611.8 43.8s0 .1 0 0c0 .1 0 .1.1.1l-.1-.1c.1.1 0 0 0 0zM600.3 43.8c.1.1.1.3.2.4h.2v-.1c-.1-.1-.2-.2-.4-.3zM656.4 41.9h.1c.2-.2 0-.4-.1-.5 0 .2-.2.3 0 .5zM656.4 41.4c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM607.5 40.3c-.1 0-.1-.1 0 0-.1 0-.1.1-.1.1s.1 0 .1.1c-.1-.1-.1-.2 0-.2zM604.5 40.2zM604.5 40.2c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1-.2-.1-.2-.1-.3 0zM778.5 33.2zM777.7 33.2zM777.7 33.2c.3.2.5.1.8 0-.3-.2-.5-.1-.8 0zM603.3 37.6v.7c.3-.3.1-.5 0-.7zM775.9 31.3s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1s-.2.1-.2.1zM776.3 31.3zM593.9 34.2s.1 0 .1.1c0-.1.1-.1.1-.2 0 0-.1-.1-.1 0 0-.1 0 0-.1.1zM585.4 32.2l-.1.1s0 .1.1.1v-.2c.1.1 0 0 0 0zM807.4 39.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM807.4 39.9c-.1.2-.2.4-.2.6.2-.2.4-.3.2-.6zM808.9 37.5zM809.2 37.7c-.1 0-.1-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM614.6 43.9v.4c.1-.1.1-.2.2-.4-.1.1-.2 0-.2 0zM655.6 41.3s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1v.1c-.1.1 0 .2.1.2zM600.3 43.7c0 .1 0 .1 0 0 0 .1 0 0 0 0zM600.2 43.4c0 .1-.1.1-.1.2s.1.1.1.2v-.2c.1-.1 0-.2 0-.2zM698.7 39.2s.1 0 .1-.1c.1-.1.1-.1.1-.2-.1 0-.2 0-.2.1v.2zM686.7 39.7h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2-.1-.1-.1 0-.1 0zM686.9 39.4zM732.9 36.8c0 .1 0 .1 0 0-.1.1-.1.1 0 0-.1.1 0 .1 0 0 0 .1 0 .1 0 0zM733.1 36.6h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2.1.1.1 0 .1 0zM584.3 36.3c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM584 36.4c.1 0 .2 0 .2-.1 0 0-.1 0-.2.1 0-.1 0 0 0 0zM740 29.7l-.2-.2c0 .1.1.1.1.2h.1zM602.4 34.2V34c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2 0 0 0 .1.1.1zM802.8 48.7h-.1.1c-.1 0-.1 0 0 0zM802.6 48.6zM805.5 44.3v.1c-.1.1 0 0 0-.1 0 .1 0 .1 0 0zM791.7 43c0-.2 0-.3.1-.5-.1 0-.1-.1-.2-.1-.2.2-.1.4.1.6zM742.9 43.3c0-.1 0-.1.1-.2l-.1.1v.1zM646.3 42.9c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM746.5 39.2h0zM676.7 39.9v-.1.1zM748.2 37.3v.1c-.1 0 0 0 0-.1zM628.8 41.4s0-.1.1-.1c-.1 0-.1 0-.1.1zM628.9 41.3s0-.1 0 0c0-.1 0-.1 0 0zM767.1 36.2s.1 0 .1-.1c0 0-.1 0-.1.1zM653.6 40.2c.1 0 .1-.1.2-.1-.1 0-.2 0-.2.1 0-.1 0-.1 0 0zM730.8 32.1zM730.9 31.9c0 .1 0 .1-.1.2l.1-.1v-.1zM584.6 29.3s.1 0 .1.1c.1 0 0 0-.1-.1.1 0 .1 0 0 0zM703.4 30.2c-.1 0-.1 0 0 0-.1.1-.2.2-.2.3.1 0 .1-.1.2-.1v-.2zM703.2 30.5zM746.8 29.1s0-.1-.1-.1c.1 0 .1 0 .1.1zM690.2 29.9c-.1 0-.1-.1-.2-.1l-.1.1h.3zM682.5 30.2c.1 0 .2-.1.3-.1-.1-.1-.1-.2-.2-.3h-.4v.1l.3.3zM599.6 34.2v.1h.1v-.1h-.1zM722.3 35.4c0-.1 0-.1.1-.2-.1.1-.1.1-.1.2zM679.8 29.5s0-.1.1-.1c-.1 0-.1 0-.1.1zM632.5 39.4c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM675.1 31.3l.2.2c0-.1-.1-.1-.1-.2h-.1zM720.3 34.4l-.1.1.1-.1zM697 37.7l-.2.2c.1 0 .1-.1.2-.1v-.1zM701.5 33.5c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1l-.2-.2zM636.9 26.8c0 .1 0 .1 0 0 0 .1 0 0 0 0zM505.6 36.1zM436.6 32.3s.1 0 0 0c.1 0 .1 0 0 0zM449.4 35.9zM422 34.3zM596.4 29.9zM489.6 37zM595 27.9zM509.6 36.2c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c0 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4-.1-.8 0-1.1.3zM583.1 36.4c-.3 0-.5-.1-.8 0-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5-.2-.3-.2-.4-.2-.5zM426.7 30.1zM425.6 30.1v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 .1.1.1.2.1 0 .4 0 .8-.2 1.2 0-.1-.1-.1-.1-.2 0 .1.1.1.1.2-.3.1-.5.2-.8.3.2.5.2.5-.3 1.3.3.1.6.1.9.2.5-.2.5-.2.7.2.1.2 0 .4.4.3v-.8c-.1-.5 0-.9.2-1.4.2-.4.2-.8.3-1.2-.1-.2-.3-.4-.4-.6-.4.1-.6.3-.8.5zM451.5 39.4c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.7-1 1zM452.4 38.3zM410.5 28.7s.1 0 0 0c.1 0 .1 0 0 0 .1 0 0 0 0 0zM409.5 31.7c-.1.1-.1.2-.2.3.2.3.4.5.6.8.4-.1.6-.5.8-.9.3.1.5.5.9.1-.2-.3-.3-.6-.5-.8l.3-.3c.1-.9-.6-1.4-.8-2.1-.1.1-.2.3-.1.4.2 1-.3 1.7-1 2.5zm1.2.1c-.1-.1-.2-.1-.3-.2 0-.1.1-.1.1-.2.1.2.1.3.2.4zM453.4 37.1zM452 35.8zM452 35.8c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.6-.7-1-1-1.4zM489.5 38.2v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.9-.8-.2-1.6-.5zM558.7 38.3c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.4-.5-1-.8-1.6-.7zM563.9 39.6c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM478.2 38.7c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.1-.5-.3-.7-.3zM549 34c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.2.6.2 1.1.3 1.6zM481.6 38.7c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.4-.4-.4zM408.5 28.1c-.5 0-1 0-1.5.2.1.7.6.3.9.5-.1.4-.1.8-.1 1.2 0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.1-.5-.1-.8-.6-.9zM563.8 36c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3c1 .1 2 0 3.1 0zM446.4 40.9c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.3-.5-.6zM434 34.6c-.1-.1-.2-.3-.2-.4-.2.3-.4.7-.9.7l-.9-.6c0 .4.1.8.4 1.1.4.3.5.8.5 1.4.1-.3.3-.5.4-.8.9.2.9.2 1.1-.7-.2-.2-.3-.5-.4-.7zM432.8 36.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM433.8 34.2s0-.1 0 0zM449.9 36.4c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM442.8 39.7c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.4 0-.7-.3-.8z"/><path d="M607.6 39.8c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1v-.1c.1.2.3.3.4.5.1-.4 0-.6-.4-.6 0-.2.1-.4.1-.5.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.1-.7-.3-1.3-1.1-1.6zM413.3 27.1c-.3 0-.6.3-.6.8s.3.8.8.8c.4 0 .7-.3.7-.7 0-.5-.5-.9-.9-.9zM467.4 39.2c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.1-.4 0-.6-.2zM587.1 36.6c-.6-.1-1.2-.1-1.8-.2l-.1-.1c-.1.3-.2.6-.3.8.2 0 .4.2.4.1s.1-.1.1-.2c.1 0 .2.1.3.1.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.1-.9-.1-1.3-.2zM470.4 39.6c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5 0-.6-.5-.8-.8-1.2zM455.3 41c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.6-.3-.9zM552.9 36.3c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.3-.2-.4-.4-.6zM415 31h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8-.1.2-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.6 1.1.9 1.5zM571 36.2c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.4-4.2.1zM445.7 36.2c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.5-1 .5-1-.7-2.1zM483.9 39.6c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.4.3-.4.5zM484.3 39.2zM566.8 34.1c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-.9-.4-1.4zM451.6 42.8c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.2-.4 1.7zM596.5 31.5c-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.2 0 .5.1.7.2-.1.1-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1 .9 1.4h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8.3-.4.5-.8.2-1.2zM439.7 36.6c0 .6 0 1.2.1 1.9.5-.4.7-.6.8-.8.1-.6-.1-.9-.9-1.1zM429.2 41.2v.8c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1-.1-.9-.2-.8-.9-1.4zM583.6 39.2c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.1-1.1.3-1.9.6zM456.6 39.1c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.2-.2-.4-.4-.5zm.1.9l.1.1c-.1 0-.1-.1-.1-.1zM471.5 39.6c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1l-1 1zM418.5 33.6zM417.9 33.8c.3.6.7 1.1.7 1.8.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1l-.3-.9h-.6c-.1.1-.1.2-.1.2zM416.6 36.5c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.2-.7-.5-.6zM431.9 34.2zM431.8 32.4s-.1-.3-.1-.4c-.2 0-.3 0-.5.1-.1 0-.1.2-.1.2 0 .4 0 .9.1 1.3.1.3.4.4.7.6-.1-.6-.6-1.2-.1-1.8zM418.1 37.6h-.2v1.1c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.9-.5-1.3zM413.3 38.3c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.3-.4-.6-.2zM429.8 38.3c-.1-.4-.1-.6-.2-.9v-.9c-.5.3-.8.5-.7 1 .1.5.3.8.9.8zM453.4 41.1c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5 0-.7.2-.7.5zM603.5 40.1c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6l.1-.1.1.1c0-.1 0-.2.1-.2.1-.1.3-.3.3-.4.1-.4-.3-.7-.6-.7zM424.5 34.1c0-.3-.2-.4-.4-.5-.3-.3-.6-.6-.9-1-.4.3-.4.7-.3 1.1.1.4.3.5.7.5 0 .1 0 .2-.1.3-.1.3.1.6.4.7.2.1.4-.1.5-.5.1-.2.1-.4.1-.6zM414.9 28.1c.7-.7.6-1-.3-1.9.1.7-.2 1.3.3 1.9zM578.4 31.9c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.1-.5-.3-.7-.4zM553.4 32.3c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.1.2.2.7.6.6zM553.6 30.9zM491.3 40.8c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1.1-.1.4-.1.5zM438.3 36.9c-.2.2-.3.4-.1.6.1.2.2.3.4.4 0 .1 0 .1.1.2v-.2c.2.1.3.1.5.2.2-.5 0-.8-.2-1.1-.3-.2-.5-.2-.7-.1zM443.6 41.9c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.6-.4.9-1 .8zM448.6 42.3c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .7.3 1.2.5 1.9zM585.3 35.9c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4h-.3c.2-.8.2-1.6-.1-2.3-.3.5-.6.9-.8 1.4.4.4.6.7 1 .9h-.9s-.1 0-.1.1c-.7-.2-.8-.1-.9.4v.5c.3-.2.6-.4.9-.7-.4.2-.3.3-.2.3zM414.3 36.3c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.2-.4-.3-.6-.5zM414.3 36.3zM582.6 31.6c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM587.3 30.2zM587.4 32.7c.4-.9.3-1.3-.1-2.5-.2 1.9-.2 1.9.1 2.5zM514.9 39.1c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.2-.3-.1zM503.4 39.6c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5 0-.4-.2-.6-.5-.6zM614.5 44.4c0-.1-.1-.1-.1-.1-.2-.1-.3-.2-.5-.2 0 .1.1.1.1.2-.2 0-.3.1-.2.2.1.1.2.1.3.1.4.7.7.8 1.4.8-.4-.3-.6-.7-1-1zM412 35.8c-.1.5-.2 1-.4 1.6.3 0 .5.1.7 0 .1-.1.2-.3.2-.5-.1-.4-.1-.7-.5-1.1zM548.4 31.1c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM413.2 33.3c-.3-.3-.6-.4-.9-.4-.1 0-.2.1-.5.3.4.1.6.2.8.3.2.1.4.3.6.4.2-.2.1-.4 0-.6zM613.6 45.3c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.6.2-1-.3-1.1zM466 41.1c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 0 .3.1.4.1zM557.6 34c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.1-.1-.4 0-.5.2zM581.9 33c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM503.5 38.1c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.2.1-.3zM465.7 42.1c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.1.3-.3.4-.4.6zM463.1 35.8c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM505.5 37.8c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM437.8 41.3c.6.2.9.2 1.3-.2-.4-.3-.8-.3-1.3.2zM553.1 34c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.1-.3-.2-.6-.3-1zM468 38.5c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.1.6-.3.6-.7zM419.4 36.9l.3.6c.2-.1.5-.2.7-.3-.4-.8-.5-.8-1-.3zM489.6 37.5c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM489.6 37zM555.2 31.6v.1c.3.3.6.2 1-.1-.4-.3-.7-.3-1 0zM449 39.5c.1.8.1.8.9.4-.3-.3-.5-.5-.9-.4zM576.9 32.3c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2 0 .3-.2.3-.4zM443.4 36.6c-.1.1-.3.3-.3.4 0 .2.2.5.3.9.1-.5.3-.7.3-1 0 0-.2-.1-.3-.3zM549.4 30.5c.3-.6.1-1.2.1-1.8-.4.7-.5 1.1-.1 1.8zM427.9 33c-.2-.2-.5-.3-.7-.5-.1 0-.1.1-.2.1.1.2.1.4.2.6.2.2.7.1.7-.2zM487.9 40.3c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.3-.3-.3-.5-.1zM458.2 41.5c.3-.4.2-.8 0-1.4-.4.6-.4.6 0 1.4zM584.3 34c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.3-.1-.3-.1zM409.1 37.7v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM567.8 34.8c.4.3.7.4 1.1.2-.4-.4-.7-.4-1.1-.2zM564 34.7c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM412.4 39.9c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM442.7 37.4c0-.1-.1-.3-.2-.6-.2.2-.3.4-.4.5-.1.2 0 .4.2.4.1 0 .3-.2.4-.3zM427.9 35.6c.3-.6.1-.9-.3-1.2 0 .4-.1.8.3 1.2zM434.4 32.7c.1.3.1.6.2.9h.6c-.1-.6-.4-.8-.8-.9zM434.6 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM609.7 41.4s-.1 0 0 0zM609.6 40.5l-.2-.2c0-.1-.1-.2-.2-.2 0 0-.1.1-.2.1 0 .1.1.1.1.2l-.1.1c.1.3.3.6.5.9.2-.3.3-.6.1-.9zM567.8 40.4c-.2 0-.4.1-.3.3 0 .1.2.2.4.3.1-.1.3-.2.3-.3 0-.2-.2-.3-.4-.3zM496.7 40.2c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM441 42c0 .4.1.6.1 1 .5-.6.5-.7-.1-1zM450.3 42.1c.2-.3 0-.5 0-.7l-.2-.1c-.1 0-.1.1-.1.2-.1.3 0 .6.3.6zM494.9 38.3c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0-.1-.1 0-.2.1zM434.5 42c-.1.2-.3.3-.4.5.1.1.2.2.3.2.2-.1.3-.3.4-.5 0 0 0-.2-.1-.2 0-.1-.2-.1-.2 0zM425.7 42.2c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM469.4 41.3c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM566.3 39.4c-.1.4-.1.7.4 1 0-.4 0-.8-.4-1zM610.4 39.7zM413.5 37.5c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.3.2.4zM419.3 38c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM419.7 37.5zM575.4 32.5c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM410.8 39.7c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM581.2 34.2c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4h.1zM612.1 44.4c.1.1.2.2.3.2.1-.1.1-.2.2-.3-.1-.1-.2-.1-.3-.2-.1 0-.2.2-.2.3zM423.1 36.8s.1 0 0 0c.1 0 .1 0 0 0zM422.7 36.1s-.1.1 0 0c-.2.5.2.5.4.7 0-.3.1-.6-.4-.7zM413.3 35.9c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM414.3 36.3zM413.8 36.3zM574.8 38c-.1.2-.1.3-.2.5.1.1.1.2.2.2s.2-.1.2-.1c0-.2 0-.4-.1-.5 0-.1-.1-.1-.1-.1zM423.1 35.3c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 0 .2-.1.3-.1zM420.3 35.1c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM569.8 37.9c-.1 0-.2 0-.2.1-.1.1-.1.2-.2.3.1 0 .2.1.3.1.2 0 .3-.1.3-.4-.1 0-.2-.1-.2-.1zM473.8 41.9l.2.2c.1-.2.2-.4.3-.5-.1 0-.2-.1-.2-.1-.1.1-.2.2-.3.4zM436 42.1s-.1 0 0 0c0 .2 0 .4.1.6h.2c-.1-.2-.1-.3-.2-.5 0-.1 0-.1-.1-.1zM432.9 42.3c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3-.1 0-.2 0-.3.1zM513.7 38.3c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.2-.2-.2-.3-.3zM462.3 39.8s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.1.2-.3.3zM434.7 41c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.2.1-.2zM432.4 41.1c.1.1.3.1.5.1.1 0 .2-.1.3-.2-.1 0-.2-.1-.3-.1-.3-.1-.6.1-.5.2zM433.2 41zM415 40.1s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM426.3 38.8l.6.6c0-.5-.1-.7-.6-.6zM553.9 33.4l.2-.1v-.4c-.1 0-.2.1-.4.1.1.2.1.3.2.4zM568.9 31.9c-.1 0-.2.2-.3.3.1.1.2.2.3.2.1 0 .2-.2.2-.3.1-.1-.1-.3-.2-.2zM611.5 46.1l.2.2c.1 0 .2-.1.2-.2-.1-.1-.2-.1-.3-.2 0 .1 0 .1-.1.2zM467.1 51.6c.1 0 .1.1.2.1v-.2l-.1-.1c-.1 0-.1.1-.1.2zM625.3 41.4h-.4c-.1 0-.1.2-.1.3.1 0 .2.1.2 0 .1 0 .1-.1.3-.3zM594.7 39.9c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM594.3 39.7zM450.1 43h.3s.1-.1.1-.2c-.1 0-.2-.1-.3 0 0 0-.1.1-.1.2zM479.7 41.4c0 .1.1.3.1.3.1 0 .2-.1.3-.1-.1-.1-.1-.3-.1-.3-.1 0-.2.1-.3.1zM464.1 41.3c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.2-.2-.2-.2zM438 42.7c.4-.3.4-.3.3-.7-.1.3-.1.4-.3.7zM439.7 41.9c0 .1.1.2.2.3.1-.1.2-.1.2-.2-.1-.1-.1-.2-.2-.3 0 .1-.2.2-.2.2zM511.8 39.2c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1.1-.1.2-.2.3zM500.9 38.6v-.1zM500.3 38.9c0 .1.1.1 0 0 .4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM428.5 40.9s0 .2.1.2c.2 0 .4 0 .6.1-.1-.1-.3-.3-.5-.4 0 0-.1 0-.2.1zM429.2 41.2zM574.5 35.1c-.3 0-.5-.1-.8-.1.3.3.5.3.8.1zM585.8 32.8s0 .1 0 0c0 .1 0 .1 0 0zM585.4 33.2l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1.1.1.2.2.2.3zM421.7 38.5c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM422.3 37.4c0 .2-.1.3-.1.4 0 .1.1.1.2.2 0-.1.1-.2.1-.4l-.2-.2zM425.3 34.4c-.1.7.4.9 1 1.3v-.8c-.1-.4-.5-.5-.8-.7.1-.4.1-.8-.2-1.2-.1.5-.4 1 0 1.4zM609.7 42c-.2 0-.5.1-.9.1.5.4.7.2.9-.1zM597.1 40.4c0 .1.1.1.1.2.1 0 .1-.1.2-.1 0 0 0-.1-.1-.1-.1-.1-.2-.1-.2 0zM447.8 42.7c0 .1.1.1.1.2.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0 0-.1.1-.1.2zM511.4 39.8c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM427.4 42.6s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.1.4-.2.5-.2.6zM426.5 40.7c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c-.1.1-.1.1-.1.2zM469.6 38.2h.3c-.1-.1-.1-.2-.2-.3h-.2s-.1.1 0 .1c0 .1.1.2.1.2zM484.8 37.2c-.1 0-.1 0-.2.1 0 .1.1.1.1.2l.2-.2-.1-.1zM576.4 33.8s.1-.1.1-.2c-.1 0-.2-.1-.3-.1 0 0-.1.1-.1.2.1 0 .2.1.3.1zM483.7 36.8c-.1 0-.2.1-.3.1l.2.2c.1 0 .2-.1.3-.2-.1 0-.2-.1-.2-.1zM436.4 38.2c.1 0 .2.1.2.1s.1-.1.1-.2c-.1 0-.2-.1-.2-.1s0 .1-.1.2zM433.6 38.3c.1.1.1.2.1.2l.2-.2v-.2c-.1.1-.2.1-.3.2zM424.4 38.7c0 .1.1.1.2.2.1-.1.1-.2.2-.3-.1 0-.1-.1-.2-.1-.1.1-.2.1-.2.2zM437.2 36.9c0 .1.1.1.1.2.1 0 .2-.1.2-.1 0-.1-.1-.1-.1-.2-.1 0-.1.1-.2.1zM428 36.8s-.1.1-.2.1c.1.1.1.2.2.3.1-.1.2-.2.1-.2 0-.1 0-.2-.1-.2zM415.9 35.9c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0 0 0-.1.1-.2 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM443.7 41.2c-.1 0-.1 0-.1.1 0 0 .1 0 .1-.1 0 .1 0 0 0 0zM475.1 38.6h.1c.2-.2 0-.4-.1-.5-.1.2-.2.3 0 .5zM475.1 38.1zM447 39.5c0-.1-.1-.1-.1-.2-.1 0-.1.1-.1.1 0 .1.1.1.1.2 0 0 .1 0 .1-.1z"/><path d="M597 32.8c-.1 0-.2 0-.2.1l.1.1c.1-.1.1-.1.1-.2zM486 37.1c0 .1-.1.2-.1.3.1-.1.2-.1.3-.2-.1-.1-.2-.1-.2-.1zM485.8 37.4zM424.5 37.1h-.2v.1s.1.1.2.1v-.2zM431.4 36.9s.1 0 0 0c.1 0 .1 0 .1-.1 0 0 0-.1-.1.1 0-.1 0-.1 0 0zM426 37c0 .1.1.1 0 0 .1 0 .1 0 .1-.1h-.1v.1zM423.2 36.8zM423.2 36.8c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1h-.3zM597.2 29.9c0-.1 0 0 0 0zM596.4 29.9zM596.4 29.9c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM430.3 35.7l.1.1c0-.1 0-.1-.1-.1 0-.1 0-.1 0 0zM422 34.3v.7c.3-.4.1-.5 0-.7zM594.5 28s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1 0 0-.1 0-.2.1zM595 27.9zM427.5 34.2h-.2s0 .1.1.1.1.1.2.1c0-.1 0-.2-.1-.2zM427.6 34.4zM409.9 32.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM409.8 33.3c.1-.1.2-.1.2-.2s0-.2-.1-.4c-.1.1-.1.2-.2.3 0 .1.1.2.1.3zM412.8 30.6c0 .1-.1.1-.1.2 0 0 .1 0 .1.1 0-.1.1-.1.1-.2-.1 0-.1-.1-.1-.1zM608.5 42.9v.1l.1-.1c.1-.1 0-.1-.1 0 .1-.1 0-.1 0 0zM603.4 42.1v.1h.2v-.1h-.2zM600.4 40.5c0-.1-.1-.1-.1-.2h-.1c0 .1.1.1.2.2-.1 0 0 0 0 0zM446.4 42.9s.1.1.1 0v-.1h-.1v.1zM627.6 34.2zM627.9 34.4c-.1-.1-.1-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM433.2 41c.1-.1.1-.2.2-.4-.1 0-.1 0-.2-.1v.5zM448.1 39.6c0 .1 0 .1 0 0 0 .1 0 .1.1.1-.1 0 0 0-.1-.1.1 0 0 0 0 0zM505.3 36.4h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2 0-.1 0-.1-.1 0zM505.6 36.1zM441.8 38.4c.1.1.1.1.2 0v-.1c-.1 0-.2 0-.2.1zM551.6 33.5c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1.1-.1.1 0 0-.1 0-.1 0 0 0zM551.8 33.2h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2 0 .1.1.1.1 0zM420.6 33.5zM420.3 33.2v.2c.1 0 .1 0 .2.1 0-.1-.1-.1-.1-.2l-.1-.1zM410.9 32.9c0-.1 0-.1 0 0-.1-.1-.1 0-.1 0h.1zM558.7 26.4l-.2-.2c0 .1.1.1.1.2h.1zM421 30.8v-.2c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2l.1.1zM406.6 29.7l-.1-.1v.1zM414.9 24.5zM414.7 24.8h.2c0-.1 0-.2.1-.2l-.2.2c-.1-.1-.1 0-.1 0zM609.7 41.4v.5c.2-.1.1-.3 0-.5zM624.2 41v.1c-.1 0-.1 0 0-.1 0 .1 0 0 0 0zM610.3 39c-.2.2-.1.4.1.6 0-.2 0-.3.1-.5-.1 0-.2 0-.2-.1zM561.6 39.9c0-.1 0-.1.1-.2l-.1.1v.1zM465 39.6c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM565.2 35.9h.1-.1zM485.8 37.4zM485.7 37.5l.1-.1s-.1 0-.1.1c0-.1 0 0 0 0zM495.4 36.6v-.1.1zM566.9 34v.1c-.1 0-.1-.1 0-.1zM447.5 38.1s0-.1.1-.1c-.1 0-.1 0-.1.1 0-.1 0 0 0 0zM447.5 38s.1-.1 0 0c.1-.1.1-.1 0 0 .1-.1.1-.1 0 0 0-.1 0 0 0 0zM585.8 32.8s.1 0 .1-.1l-.1.1zM472.3 36.8c.1 0 .1-.1.2-.1-.1 0-.2 0-.2.1zM432.8 36.8zM432.7 37c0-.1 0-.1.1-.2l-.1.1v.1zM445 36.4v-.1h-.1zM433.8 34.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM433.7 34l.1.1s-.1 0-.1-.1zM434.6 33.6l-.1.1c0-.1 0-.1.1-.1zM420.9 33.5h-.2c0 .2.1.2.2 0zM420.9 33.5zM549.5 28.7c0 .1 0 .1 0 0 0 .1 0 .1 0 0zM549.6 28.6c0 .1 0 .1-.1.2l.1-.1v-.1zM522.1 26.9c-.1 0-.1 0 0 0-.1.1-.2.2-.2.3.1 0 .1-.1.2-.1v-.2zM521.9 27.2zM565.5 25.8s0-.1-.1-.1c0 0 .1 0 .1.1 0-.1 0-.1 0 0zM418.4 30.9h-.1v.1h.1v-.1zM541 32.1c0-.1 0-.1.1-.2-.1.1-.1.1-.1.2 0-.1 0 0 0 0zM498.4 26.2s0-.1.1-.1l-.1.1c0-.1 0 0 0 0zM451 35.9l.2.2c0-.1-.1-.1-.1-.2s0 0-.1 0zM451.2 36c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM493.8 28l.2.2c0-.1-.1-.1-.1-.2h-.1zM539 31.1l-.1.1c0-.1 0-.1.1-.1zM520.2 30.2c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c-.1-.1-.1-.2-.2-.2zM455.6 23.5c-.1 0-.1 0 0 0zM1093.9 39.4zM1037.6 39.2zM1010.3 37.6zM1184.7 33.2h-.1.1zM1077.8 40.3zM1183.3 31.3s-.1 0 0 0c-.1 0-.1 0 0 0zM1097.9 39.5c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3 0 .3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.5 0-.8.1-1.1.3zM1170.6 39.7c-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5 0-.1 0-.2-.1-.2-.4-.3-.7-.3-.9-.3zM1039.8 42.7c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.3.4-.5.8-1 1zM1040.7 41.7s0-.1 0 0c0-.1 0-.1 0 0zM1041.7 40.5zM1040.3 39.1zM1040.3 39.1c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.5-.7-1-1-1.4zM1077.8 41.5v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.8-.9-.2-1.6-.5zM1147 41.6c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.5-.5-1-.8-1.6-.7zM1152.2 42.9c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM1066.5 42.1c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.4-.2-.5-.3-.7-.3zM1137.3 37.4c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.1.6.2 1.1.3 1.6zM1069.8 42c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4 0-.2-.2-.3-.4-.4zM996 33.4c0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.2-.5 0-.9-.5-.9h-.2c0-.1-.1-.2-.2-.2s-.2.1-.2.2c-.3 0-.6.1-.9.2.1.7.6.3.9.5-.1.4-.2.8-.2 1.2zM1152 39.4c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3h3.1zM1034.6 44.3c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.2-.1-.3-.4-.5-.6z"/><path d="M1038.2 39.7c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM1031.1 43c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.3 0-.6-.3-.8zM1195.9 43.1c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1.1-.3.1-.5.2-.8.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.2-.6-.5-1.2-1.2-1.5zM1055.7 42.5c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.2-.4.1-.6-.2zM1175.4 40c-.6-.1-1.2-.1-1.8-.2-.1 0-.2.2-.2.3l.1.2c.2.1.3.2.5.2.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.2-.9-.2-1.3-.2zM1058.6 42.9c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.5-.8-.8-1.2zM1043.6 44.3c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.5-.3-.9zM1141.2 39.6c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4 0-.2-.2-.4-.4-.6zM1159.3 39.5c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.3-4.2.1zM1034 39.5c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1zM1072.2 43c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.3.1-.5.2-.4.5zM1072.6 42.5c-.1 0 0 0 0 0zM1155.1 37.5c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-1-.4-1.4zM993.6 37.6c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.3-.1-.6-.2-1-.4zM1039.9 46.2c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.5.6-.4 1.1-.4 1.7zM1184.6 36.2c.2-.5.4-.9.1-1.3-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.3 0 .6.1.8.2zM1017.7 44.7s.1 0 0 0c.1-.2 0-.3-.1-.4-.1 0-.2.1-.2.1-.1-.1-.2-.2-.4-.3l-.2.1s0 .2.1.2h.4c.1.1.1.1.1.2v.7c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.8-.1-.8-.6-1.2zM1171.9 42.5c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.2-1.1.3-1.9.6zM1044.9 42.5c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.3-.2-.5-.4-.5zm0 .8c.1.1.1.1 0 0l.1.1-.1-.1zM1059.8 43c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1-.4.3-.7.6-1 1zM1004.9 39.8c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.3-.7-.5-.6zM1006.4 40.9h-.2V42c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.8-.5-1.3zM1001.5 41.7c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4.1-.3-.2-.5-.6-.2zM1041.7 44.4c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.6.1-.8.3-.7.5zM1191.8 43.5c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6.2-.2.5-.4.6-.6 0-.4-.3-.8-.6-.7zM994.2 35.5c-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.4.1-.9-.1-1.3l-.1-.1-.1.1v.1c-.2.2-.3.6-.4 1zM1166.7 35.3c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.2-.5-.3-.7-.4zM1141.6 35.6c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.2.2.3.7.6.6zM1141.9 34.2s-.1 0 0 0c-.1 0-.1 0 0 0zM1079.6 44.2c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1 0-.2.3-.1.5zM1031.9 45.3c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.5-.4.8-1 .8zM1036.9 45.6c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .8.2 1.2.5 1.9zM1185.5 40.6c-.2 0-.4.1-.6.2v.4c.2.3.7.4.9.3.1 0 .1-.2.1-.2 0-.3-.1-.6-.4-.7zM1173.6 39.3c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4-.4 0-.9-.1-1.3-.1-.1 0-.2.2-.2.3-.1.1 0 .3.1.4zM1002.6 39.6c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.1-.4-.3-.6-.5zM1002.6 39.6zM1170.9 34.9c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM1175.6 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1175.7 36.1c.4-.9.3-1.3-.1-2.5-.3 1.8-.3 1.8.1 2.5zM1103.2 42.4c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7-.1-.1-.2-.1-.3-.1zM1091.7 42.9c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5s-.2-.6-.5-.6zM1202.1 47.4c.7 1.2.8 1.3 1.7 1.3-.6-.5-.9-1.1-1.7-1.3zM1136.7 34.4c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM1201.9 48.6c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.5.2-1-.3-1.1zM1054.3 44.4c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 .1.2.1.4.1zM1145.9 37.3c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.2-.1-.4 0-.5.2zM1170.2 36.3c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM1091.8 41.4c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.1.1-.3zM1054 45.4c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.4.5-.4.6zM1051.4 39.1c-.1 0-.2.1-.2.2-.1.4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM1182.3 36.2c.1-.1.2-.3 0-.5-.1-.1-.3-.1-.5-.1-.1.1-.3.2-.3.4s.1.4.2.7c.3-.2.4-.3.6-.5zM1186.8 41.7c.1 0 .3.1.4 0 .3-.3.8-.4 1-.8-.8-.1-.9-.1-1.4.8zM1093.7 41.1c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.1-.2-.2-.2zM991.2 36.3zM1141.4 37.3c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.2-.3-.2-.6-.3-1z"/><path d="M1056.3 41.9c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.2.5-.4.6-.7zM1007.7 40.3l.3.6c.2-.1.5-.2.7-.3-.5-.9-.5-.9-1-.3zM1077.9 40.9c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2-.1.2-.1.4 0 .6zM1077.8 40.3zM1186.8 33.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1185.5 33.2c0 .3-.2.6.2.9.4-.3.9-.4 1.1-.9-.4.2-.9.1-1.3 0zM1143.5 34.9v.1c.3.3.6.2 1-.1-.4-.2-.7-.3-1 0zM1037.3 42.9c.1.8.1.8.9.4-.3-.4-.5-.6-.9-.4zM1165.2 35.7c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2-.1.3-.3.3-.4zM1032 40.3c0-.1-.2-.2-.3-.3-.1.1-.3.3-.3.4 0 .2.2.5.3.9.2-.5.3-.7.3-1zM1191.5 41.1c-.2 0-.4-.1-.5 0-.2.1-.3.4-.4.6l.2.2c.3-.3.7-.2.7-.8zM1137.6 33.9c.3-.6.1-1.2.1-1.8-.4.7-.4 1-.1 1.8zM996.6 36.5c0-.1-.2-.2-.2-.3l-.5.5c.2.1.3.3.4.3.2-.1.4-.3.3-.5zM1076.1 43.6c0 .3.1.6.1 1.1.6-.2.5-.6.4-1 0-.2-.2-.3-.5-.1zM1046.5 44.8c.3-.4.2-.8 0-1.4-.4.7-.4.7 0 1.4zM1172.5 37.3c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.2-.1-.3-.1zM997.4 41v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3 0-.6-.4-.8zM1180.1 35c0 .8 0 .8.8.9-.3-.3-.5-.5-.8-.9zM1156 38.1c.4.3.7.4 1.1.2-.3-.3-.6-.3-1.1-.2zM1152.2 38.1c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.2 0 .3-.1.6-.2zM1000.7 43.2c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM1177.7 34.7c-.1 0-.3.2-.3.2 0 .1.1.3.2.5.2-.2.3-.3.3-.4.1-.2 0-.4-.2-.3zM1217.3 33.4zM1218.8 33.5c-.1 0-.2-.1-.4-.1v-.2c0-.1-.2-.2-.2-.3l-.4.4c-.1 0-.3.1-.4.1.4.3.8.5 1.4.1zM991.4 38.9c.5-.6.3-1.2.4-1.7-.3.4-.5.9-.4 1.7zM991.8 37.2s0-.1 0 0c0-.1 0-.1 0 0zM1085 43.5c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.4-.3-.5-.4zM1029.3 45.3c0 .4.1.6.1 1 .5-.5.5-.7-.1-1zM1038.3 44.6c-.1 0-.1.1-.1.2 0 .3.1.5.4.6.2-.3 0-.5 0-.7-.1 0-.2-.1-.3-.1zM1083.2 41.6c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0 0-.1 0-.2.1zM1013.9 45.5c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.1.1-.2.1zM1057.7 44.6c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1-.1-.2-.2-.4zM1199.2 43.9c.1 0 .1-.1.1-.2 0-.4-.3-.6-.7-.7.1.3.2.6.3.8.1.1.3.1.3.1zM1198.7 43zM1001.7 40.8c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7 0 .1 0 .4.2.4z"/><path d="M1007.6 41.3c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM1008 40.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM1163.7 35.8c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM999.1 43c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3-.1-.2-.1-.4-.3-.4zM1169.5 37.5c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4c0 .1.1.1.1 0zM1011.4 40.1s0 .1 0 0zM1011 39.5s-.1 0 0 0c-.2.5.2.5.4.7 0-.3.1-.7-.4-.7zM1001.6 39.2c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM1002.6 39.6zM1002 39.6s0 .1 0 0c0 .1.1.1 0 0 .1 0 .1 0 0 0zM1048.2 45.8l.2.2c.1-.1.2-.3.3-.4l-.2-.2c-.2.1-.3.3-.3.4zM1011.4 38.6c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 .1.2 0 .3-.1zM1008.6 38.4c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2-.1-.4-.2-.4zM1119.4 42.5c0 .1.1.2.2.4.1-.2.2-.4.1-.4 0-.1-.2-.1-.3-.2.1.1 0 .2 0 .2zM989.8 38.6c0 .1.1.2.2.4.1-.2.1-.3.1-.4 0-.1-.1-.1-.1-.2-.1 0-.2.1-.2.2zM1021.1 45.6c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.2 0-.3.1zM1102 41.6c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.1-.3-.2-.3-.3zM1050.6 43.1s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.2.2-.3.3zM1022.9 44.3c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3 0 0 .1-.1.1-.2zM1021.5 44.3s0 .1 0 0c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM1003.2 43.4s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.1.3-.2.5zM1183 43.2c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM1182.6 43zM989.8 35.8c0 .1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.2-.1-.3c-.2 0-.3.1-.3.2zM1052.3 44.6c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1100.1 42.6c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1 0-.1.2-.2.3zM1089.1 41.9zM1088.6 42.3s.1.1 0 0c.4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM1180.7 37.4s.2-.1.2-.2-.1-.2-.2-.3c-.1.1-.2.1-.3.2.1.2.2.3.3.3zM1174 36.2zM1173.5 36.2c.1.1.1.2.2.3l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1zM1172.4 36.3c0 .1.1.2.3.3.1-.2.1-.3.1-.4 0-.1-.2-.1-.3-.1 0 0-.1.1-.1.2zM1010 41.8c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM1099.7 43.1c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1015.7 46s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.3-.2.4-.2.6zM1014.7 44c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1 0 .1-.1.2zM991.1 33.7h.2c0-.1.1-.3.1-.4v-.1c.1 0 .1 0 .2-.1v-.2s-.1 0-.1.1l-.1.1c0-.1.1-.2 0-.2 0-.1-.2-.1-.3-.1l-.1.2c0 .1.1.2.2.3l-.3.3c.1 0 .2.1.2.1zM1004.2 39.3c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0-.1 0-.2.1-.2zM1027.9 43.5s.1.1.2.1v-.2h-.2v.1zM1018.8 43.8s0 .1 0 0c0 .1 0 .1.1.1-.1 0 0 0-.1-.1 0 .1 0 0 0 0zM1007.3 43.8c.1.1.1.3.2.4h.2v-.1c-.2-.1-.3-.2-.4-.3zM1063.4 41.9h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM1063.4 41.4zM1014.4 40.3s-.1-.1 0 0c-.1 0-.1.1-.1.1s.1 0 .1.1v-.2zM1011.4 40.2zM1011.4 40.2c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1-.1-.1-.2-.1-.3 0zM1185.4 33.2s.1 0 0 0c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM1184.6 33.2s.1 0 0 0c.1 0 .1 0 0 0zM1184.7 33.2c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM1010.3 37.6v.7c.3-.3.1-.5 0-.7zM1182.8 31.3s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1s-.2.1-.2.1zM1183.3 31.3c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM1000.9 34.2s.1 0 .1.1c0-.1.1-.1.1-.2 0 0-.1-.1-.1 0 0-.1-.1 0-.1.1zM992.4 32.2l-.1.1s0 .1.1.1c-.1 0 0 0 0-.2 0 .1 0 0 0 0zM1214.3 39.9c.1 0 .1-.1 0 0 .1-.1 0-.1 0 0 0-.1 0 0 0 0zM1214.3 39.9c-.1.2-.2.4-.2.6.3-.2.4-.3.2-.6zM1215.9 37.5zM1216.1 37.7s0-.1 0 0c-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM1021.5 43.9v.4c.1-.1.1-.2.2-.4-.1.1-.1 0-.2 0zM1062.5 41.3s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1v.1c0 .1 0 .2.1.2zM1007.3 43.7c0 .1 0 .1 0 0 0 .1 0 0 0 0zM1007.2 43.4c0 .1-.1.1-.1.2s.1.1.1.2v-.2-.2zM1105.6 39.2s.1 0 .1-.1c.1-.1.1-.1.1-.2-.1 0-.2 0-.2.1v.2zM1093.6 39.7h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2-.1-.1-.1 0-.1 0zM1093.9 39.4zM1139.8 36.8c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1140 36.6h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2.1.1.1 0 .1 0zM991.2 36.3zM990.9 36.4c.1 0 .2 0 .2-.1l-.2.1c.1-.1.1 0 0 0zM1147 29.7l-.2-.2c0 .1.1.1.1.2h.1zM1009.3 34.2V34c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2l.1.1zM1209.7 48.7h-.1.1zM1209.6 48.6zM1212.4 44.3v0c0 .1 0 .1 0 0zM1198.7 43c0-.2 0-.3.1-.5-.1 0-.1-.1-.2-.1-.2.2-.1.4.1.6zM1149.9 43.3c0-.1 0-.1.1-.2l-.1.1v.1zM1053.3 42.9c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM1153.4 39.2h0zM1083.7 39.9v-.1.1zM1155.1 37.3v0zM1035.8 41.4s0-.1.1-.1c-.1 0-.1 0-.1.1zM1035.8 41.3s0-.1 0 0c0-.1 0-.1 0 0zM1174 36.2s.1 0 .1-.1l-.1.1zM1060.5 40.2c.1 0 .1-.1.2-.1-.1 0-.1 0-.2.1.1-.1 0-.1 0 0zM1137.8 32.1zM1137.8 31.9c0 .1 0 .1-.1.2l.1-.1c.1 0 0-.1 0-.1zM991.6 29.3s.1 0 .1.1l-.1-.1c.1 0 0 0 0 0zM1110.3 30.2s-.1 0-.1.1-.1.1-.1.2c.1 0 .1-.1.2-.1s0-.1 0-.2zM1110.1 30.5zM1153.8 29.1s0-.1-.1-.1l.1.1c-.1 0 0 0 0 0zM1089.5 30.2c.1 0 .2-.1.3-.1-.1-.1-.1-.2-.2-.3h-.4v.1l.3.3zM1006.5 34.2v.1h.1v-.1h-.1zM1129.2 35.4c0-.1 0-.1.1-.2 0 .1 0 .1-.1.2zM1086.7 29.5s0-.1.1-.1c0 0-.1 0-.1.1zM1039.5 39.4zM1082.1 31.3l.2.2c0-.1-.1-.1-.1-.2h-.1zM1127.3 34.4l-.1.1s0-.1.1-.1zM1103.9 37.7l-.2.2c.1 0 .1-.1.2-.1v-.1zM1108.5 33.5c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c-.1-.1-.2-.1-.2-.2zM1043.9 26.8c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1.1-.1.1 0 0-.1.1-.1 0 0 0zM912.6 36.1s-.1 0 0 0c-.1 0-.1 0 0 0zM843.6 32.3zM856.3 35.9zM829 34.3zM1003.3 29.9zM896.5 37zM1001.9 27.9zM916.6 36.2c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3 0 .3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.5-.1-.8 0-1.1.3zM990 36.4c-.3 0-.5-.1-.8 0-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5-.1-.3-.1-.4-.2-.5zM833.6 30.1zM832.6 30.1v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4-.1.1.1.1.2.1 0 .4 0 .8-.2 1.2 0-.1-.1-.1-.1-.2 0 .1.1.1.1.2-.3.1-.5.2-.8.3.2.5.2.5-.3 1.3.3.1.6.1.9.2.5-.2.5-.2.7.2.1.2 0 .4.4.3v-.8c-.1-.5 0-.9.2-1.4.2-.4.2-.8.3-1.2-.1-.2-.3-.4-.4-.6-.4.1-.6.3-.8.5zM858.5 39.4c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.3.4-.5.7-1 1zM859.4 38.3zM817.5 28.7zM816.5 31.7c-.1.1-.1.2-.2.3.2.3.4.5.6.8.4-.1.6-.5.8-.9.3.1.5.5.9.1-.2-.3-.3-.6-.5-.8l.3-.3c.1-.9-.6-1.4-.8-2.1-.1.1-.2.3-.1.4.2 1-.3 1.7-1 2.5zm1.1.1c-.1-.1-.2-.1-.3-.2 0-.1.1-.1.1-.2.1.2.2.3.2.4zM860.4 37.1zM859 35.8zM859 35.8c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.6-.7-1-1-1.4zM896.5 38.2v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.9-.9-.2-1.6-.5zM965.7 38.3c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.5-.5-1-.8-1.6-.7zM970.9 39.6c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5-.1-.1-.2-.3-.4-.4zM885.2 38.7c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.4-.1-.5-.3-.7-.3zM956 34c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.1.6.2 1.1.3 1.6zM888.5 38.7c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.2-.4-.4-.4zM815.4 28.1c-.5 0-1 0-1.5.2.1.7.6.3.9.5-.1.4-.1.8-.1 1.2 0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.1-.5-.1-.8-.6-.9zM970.7 36c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3c1.1.1 2.1 0 3.1 0zM853.3 40.9c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.2-.1-.3-.3-.5-.6zM841 34.6c-.1-.1-.2-.3-.2-.4-.2.3-.4.7-.9.7l-.9-.6c0 .4.1.8.4 1.1.4.3.5.8.5 1.4.1-.3.3-.5.4-.8.9.2.9.2 1.1-.7-.2-.2-.3-.5-.4-.7zM839.8 36.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM840.7 34.2s0-.1 0 0zM856.9 36.4c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.4-.1-.6-.3-.8-.6zM849.7 39.7c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.4 0-.7-.3-.8z"/><path d="M1014.5 39.8c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1v-.1c.1.2.3.3.4.5.1-.4 0-.6-.4-.6 0-.2.1-.4.1-.5.2 0 .3.1.5 0 .1-.1.4-.2.3-.3 0-.7-.3-1.3-1.1-1.6zM820.3 27.1c-.3 0-.6.3-.6.8s.3.8.8.8c.4 0 .7-.3.7-.7-.1-.5-.5-.9-.9-.9zM874.4 39.2c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.1-.4 0-.6-.2zM994.1 36.6c-.6-.1-1.2-.1-1.8-.2l-.1-.1c-.1.3-.2.6-.3.8.2 0 .4.2.4.1s.1-.1.1-.2c.1 0 .2.1.3.1.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.1-.9-.1-1.3-.2zM877.3 39.6c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.5-.8-.8-1.2zM862.3 41c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.4-.6-.3-.9zM959.8 36.3c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.3-.1-.4-.4-.6zM822 31h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8-.1.2-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1.1.9 1.5zM811.8 29.7c-.3.5-.6.9-.8 1.4.4.5.6.7 1 1 .1-.9.2-1.6-.2-2.4zM977.9 36.2c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.4.2-2.8-.4-4.2.1zM852.7 36.2c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1zM890.9 39.6c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.3.1-.5.3-.4.5zM891.2 39.2c.1 0 0 0 0 0zM973.8 34.1c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-.9-.4-1.4zM812.3 34.3c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.3-.1-.6-.2-1-.4zM858.6 42.8c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.5.6-.4 1.2-.4 1.7zM1003.4 31.5c-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.2 0 .5.1.7.2-.1.1-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1 .9 1.4h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8.3-.4.5-.8.2-1.2zM846.7 36.6c0 .6 0 1.2.1 1.9.5-.4.7-.6.8-.8.1-.6-.2-.9-.9-1.1zM836.1 41.2v.8c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1-.1-.9-.1-.8-.9-1.4zM990.6 39.2c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.1-1.1.3-1.9.6zM863.5 39.1c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5s-.1-.4-.4-.5zm.1.9s.1 0 0 0l.1.1-.1-.1zM878.5 39.6c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1l-1 1zM825.5 33.6s-.1 0 0 0c-.1 0-.1 0 0 0zM824.9 33.8c.3.6.7 1.1.7 1.8.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1l-.3-.9h-.6c-.2.1-.2.2-.1.2zM823.6 36.5c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.3-.7-.5-.6zM838.9 34.2zM838.8 32.4s-.1-.3-.1-.4c-.2 0-.3 0-.5.1-.1 0-.1.2-.1.2 0 .4 0 .9.1 1.3.1.3.4.4.7.6-.1-.6-.6-1.2-.1-1.8zM825.1 37.6h-.2v1.1c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.3-.4-.4-.9-.5-1.3zM820.2 38.3c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.2-.4-.6-.2zM836.8 38.3c-.1-.4-.1-.6-.2-.9v-.9c-.5.3-.8.5-.7 1 0 .5.3.8.9.8zM860.4 41.1c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.6 0-.8.2-.7.5zM1010.5 40.1c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6l.1-.1.1.1c0-.1 0-.2.1-.2.1-.1.3-.3.3-.4 0-.4-.3-.7-.6-.7zM831.5 34.1c0-.3-.2-.4-.4-.5-.3-.3-.6-.6-.9-1-.4.3-.4.7-.3 1.1.1.4.3.5.7.5 0 .1 0 .2-.1.3-.1.3.1.6.4.7.2.1.4-.1.5-.5 0-.2.1-.4.1-.6zM821.9 28.1c.7-.7.6-1-.3-1.9 0 .7-.2 1.3.3 1.9zM813.3 31c-.1.4-.3.8-.4 1.2-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.5.1-.9-.1-1.4h-.2zM985.4 31.9c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.1-.5-.3-.7-.4zM960.3 32.3c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.2.2.2.7.6.6zM960.5 30.9zM898.3 40.8c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1.1-.2.4-.1.5zM845.3 36.9c-.2.2-.3.4-.1.6.1.2.2.3.4.4 0 .1 0 .1.1.2v-.2c.2.1.3.1.5.2.2-.5 0-.8-.2-1.1-.3-.2-.5-.2-.7-.1zM850.6 41.9c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.6-.5.9-1 .8zM855.6 42.3c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .7.2 1.2.5 1.9zM992.3 35.9c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4h-.3c.2-.8.2-1.6-.1-2.3-.3.5-.6.9-.8 1.4.4.4.6.7 1 .9h-.9s-.1 0-.1.1c-.7-.2-.8-.1-.9.4v.5c.3-.2.6-.4.9-.7-.4.2-.3.3-.2.3zM821.3 36.3c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.2-.2-.4-.3-.6-.5zM821.3 36.3zM989.5 31.6c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.4.2-.6.5-.6 1zM994.3 30.2c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM994.3 32.7c.4-.9.3-1.3-.1-2.5-.2 1.9-.2 1.9.1 2.5zM921.8 39.1c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.2-.3-.1zM910.4 39.6c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5-.1-.4-.2-.6-.5-.6zM1021.4 44.4c.1 0 .1 0 0 0 0-.1-.1-.1-.1-.1-.2-.1-.3-.2-.5-.2 0 .1.1.1.1.2-.2 0-.3.1-.2.2.1.1.2.1.3.1.4.7.7.8 1.4.8-.3-.3-.6-.7-1-1zM819 35.8c-.1.5-.2 1-.4 1.6.3 0 .5.1.7 0 .1-.1.2-.3.2-.5-.2-.4-.2-.7-.5-1.1zM955.4 31.1c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM820.1 33.3c-.3-.3-.6-.4-.9-.4-.1 0-.2.1-.5.3.4.1.6.2.8.3.2.1.4.3.6.4.3-.2.2-.4 0-.6zM1020.6 45.3c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.6.2-1-.3-1.1zM873 41.1c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 0 .2.1.4.1zM964.6 34c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.2-.1-.4 0-.5.2zM988.9 33c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM910.4 38.1c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2.1 0 .1-.2.1-.3zM872.7 42.1c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.4.4-.4.6zM870.1 35.8c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM912.4 37.8c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.1-.2-.2-.2zM844.8 41.3c.6.2.9.2 1.3-.2-.5-.3-.8-.3-1.3.2zM960.1 34c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.2-.3-.2-.6-.3-1zM875 38.5c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.1.5-.3.6-.7zM826.4 36.9l.3.6c.2-.1.5-.2.7-.3-.5-.8-.6-.8-1-.3zM896.6 37.5c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2-.1.2-.1.4 0 .6zM896.5 37zM962.2 31.6v.1c.3.3.6.2 1-.1-.4-.3-.7-.3-1 0zM856 39.5c.1.8.1.8.9.4-.3-.3-.5-.5-.9-.4zM983.9 32.3c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2 0 .3-.2.3-.4zM850.3 36.6c-.1.1-.3.3-.3.4 0 .2.2.5.3.9.1-.5.3-.7.3-1 .1 0-.1-.1-.3-.3zM956.3 30.5c.3-.6.1-1.2.1-1.8-.4.7-.4 1.1-.1 1.8zM815.1 32.9l-.5.5c.2.1.3.3.4.3.2 0 .4-.2.3-.4 0-.3-.1-.3-.2-.4zM834.9 33c-.2-.2-.5-.3-.7-.5-.1 0-.1.1-.2.1.1.2.1.4.2.6.2.2.6.1.7-.2zM894.8 40.3c0 .3.1.6.1 1.1.6-.2.5-.6.4-1 0-.3-.2-.3-.5-.1zM865.2 41.5c.3-.4.2-.8 0-1.4-.4.6-.4.6 0 1.4zM991.2 34c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.2-.1-.3-.1zM816 37.7v.8c0 .1.1.1.2.1s.2-.1.2-.1c.1-.3.1-.6-.4-.8zM974.7 34.8c.4.3.7.4 1.1.2-.3-.4-.6-.4-1.1-.2zM970.9 34.7c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .3-.1.6-.2zM819.4 39.9c-.2-.5-.4-.8-.7-1.4 0 .9 0 .9.7 1.4zM849.6 37.4c0-.1-.1-.3-.2-.6-.2.2-.3.4-.4.5-.1.2 0 .4.2.4s.4-.2.4-.3zM834.9 35.6c.3-.6.1-.9-.3-1.2 0 .4-.1.8.3 1.2zM841.3 32.7c.1.3.1.6.2.9h.6c-.1-.6-.3-.8-.8-.9zM841.5 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1016.6 41.4zM1016.6 40.5l-.2-.2c0-.1-.1-.2-.2-.2 0 0-.1.1-.2.1 0 .1.1.1.1.2l-.1.1c.1.3.3.6.5.9.2-.3.3-.6.1-.9zM974.7 40.4c-.2 0-.4.1-.3.3 0 .1.2.2.4.3.1-.1.3-.2.3-.3 0-.2-.2-.3-.4-.3zM903.6 40.2c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.1-.2-.3-.3-.5-.4zM848 42c0 .4.1.6.1 1 .5-.6.5-.7-.1-1zM857.3 42.1c.2-.3 0-.5 0-.7l-.2-.1c-.1 0-.1.1-.1.2-.1.3 0 .6.3.6zM901.9 38.3c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0-.1-.2 0-.2.1zM841.5 42c-.1.2-.3.3-.4.5.1.1.2.2.3.2.2-.1.3-.3.4-.5 0 0 0-.2-.1-.2-.1-.1-.2-.1-.2 0zM832.6 42.2c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.1.1-.2.1zM876.4 41.3c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4 0-.1-.1-.2-.2-.4zM973.3 39.4c-.1.4-.1.7.4 1 0-.4 0-.8-.4-1zM1017.3 39.7s.1 0 0 0c.1 0 .1 0 0 0 .1 0 0 0 0 0zM820.4 37.5c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7 0 .1-.1.3.2.4zM826.3 38c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM826.7 37.5zM982.4 32.5c-.2-.3-.3-.5-.6-1-.1 1.1-.1 1.1.6 1zM817.8 39.7c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3-.1-.2-.1-.4-.3-.4zM988.2 34.2c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4h.1zM1019 44.4c.1.1.2.2.3.2.1-.1.1-.2.2-.3-.1-.1-.2-.1-.3-.2 0 0-.1.2-.2.3zM830.1 36.8zM829.7 36.1s-.1.1 0 0c-.2.5.2.5.4.7 0-.3 0-.6-.4-.7zM820.2 35.9c.2.2.4.3.5.4h.5c-.1-.4-.4-.6-1-.4zM821.3 36.3zM820.7 36.3zM981.8 38c-.1.2-.1.3-.2.5.1.1.1.2.2.2s.2-.1.2-.1c0-.2 0-.4-.1-.5 0-.1-.1-.1-.1-.1zM830.1 35.3c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 0 .2-.1.3-.1zM827.3 35.1c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2-.1-.4-.2-.4zM976.7 37.9c-.1 0-.2 0-.2.1-.1.1-.1.2-.2.3.1 0 .2.1.3.1.2 0 .3-.1.3-.4 0 0-.1-.1-.2-.1zM880.7 41.9l.2.2c.1-.2.2-.4.3-.5-.1 0-.2-.1-.2-.1-.1.1-.2.2-.3.4zM843 42.1s-.1 0 0 0c0 .2 0 .4.1.6h.2c-.1-.2-.1-.3-.2-.5 0-.1-.1-.1-.1-.1zM839.8 42.3c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.2 0-.3.1zM920.7 38.3c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.2-.3-.2-.3-.3zM869.3 39.8s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.2.2-.3.3zM841.6 41c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3l.1-.2zM839.4 41.1c.1.1.3.1.5.1.1 0 .2-.1.3-.2-.1 0-.2-.1-.3-.1-.4-.1-.7.1-.5.2zM840.2 41zM821.9 40.1s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.1.3-.2.5zM833.2 38.8l.6.6c.1-.5 0-.7-.6-.6zM960.8 33.4l.2-.1v-.4c-.1 0-.2.1-.4.1.1.2.2.3.2.4zM975.9 31.9c-.1 0-.2.2-.3.3.1.1.2.2.3.2.1 0 .2-.2.2-.3 0-.1-.1-.3-.2-.2zM1018.5 46.1l.2.2c.1 0 .2-.1.2-.2-.1-.1-.2-.1-.3-.2 0 .1-.1.1-.1.2zM874 51.6c.1 0 .1.1.2.1v-.2l-.1-.1s0 .1-.1.2zM1032.3 41.4h-.4c-.1 0-.1.2-.1.3.1 0 .2.1.2 0l.3-.3zM1001.7 39.9c.2-.1.3-.4 0-.5l-.4.4c.1 0 .3.1.4.1zM1001.3 39.7zM857 43h.3s.1-.1.1-.2c-.1 0-.2-.1-.3 0 0 0 0 .1-.1.2zM886.6 41.4c0 .1.1.3.1.3.1 0 .2-.1.3-.1-.1-.1-.1-.3-.1-.3s-.1.1-.3.1zM871 41.3c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.2-.2-.2zM845 42.7c.4-.3.4-.3.3-.7-.1.3-.2.4-.3.7zM846.7 41.9c0 .1.1.2.2.3.1-.1.2-.1.2-.2-.1-.1-.1-.2-.2-.3l-.2.2zM918.8 39.2c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1.1-.2.2-.2.3zM907.8 38.6v-.1zM907.3 38.9c0 .1 0 .1 0 0 .4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM835.5 40.9s0 .2.1.2c.2 0 .4 0 .6.1-.1-.1-.3-.3-.5-.4 0 0-.2 0-.2.1zM836.2 41.2zM981.5 35.1c-.3 0-.5-.1-.8-.1.3.3.4.3.8.1zM992.7 32.8s0 .1 0 0c0 .1 0 .1 0 0zM992.4 33.2l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1.1.1.1.2.2.3zM828.7 38.5c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM829.2 37.4c0 .2-.1.3-.1.4 0 .1.1.1.2.2 0-.1.1-.2.1-.4l-.2-.2zM832.2 34.4c-.1.7.4.9 1 1.3v-.8c-.1-.4-.5-.5-.8-.7.1-.4.1-.8-.2-1.2-.1.5-.4 1 0 1.4zM1016.6 42c-.2 0-.5.1-.9.1.6.4.8.2.9-.1zM1004 40.4c0 .1.1.1.1.2.1 0 .1-.1.2-.1 0 0 0-.1-.1-.1 0-.1-.1-.1-.2 0zM854.7 42.7c0 .1.1.1.1.2.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0 0 0 .1-.1.2zM918.4 39.8c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM834.4 42.6s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.4-.2.5-.2.6zM833.4 40.7c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1 0 .1-.1.2zM876.6 38.2h.3c-.1-.1-.1-.2-.2-.3h-.2s-.1.1 0 .1c0 .1 0 .2.1.2zM891.8 37.2c-.1 0-.1 0-.2.1 0 .1.1.1.1.2l.2-.2c-.1 0-.1-.1-.1-.1zM983.4 33.8s.1-.1.1-.2c-.1 0-.2-.1-.3-.1 0 0-.1.1-.1.2.1 0 .2.1.3.1zM890.7 36.8c-.1 0-.2.1-.3.1l.2.2c.1 0 .2-.1.3-.2-.1 0-.2-.1-.2-.1zM843.4 38.2c.1 0 .2.1.2.1s.1-.1.1-.2c-.1 0-.2-.1-.2-.1-.1 0-.1.1-.1.2zM840.6 38.3c.1.1.1.2.1.2l.2-.2v-.2c-.1.1-.2.1-.3.2zM831.4 38.7c0 .1.1.1.2.2.1-.1.1-.2.2-.3-.1 0-.1-.1-.2-.1-.1.1-.2.1-.2.2zM844.2 36.9c0 .1.1.1.1.2.1 0 .2-.1.2-.1 0-.1-.1-.1-.1-.2-.1 0-.2.1-.2.1zM835 36.8s-.1.1-.2.1c.1.1.1.2.2.3.1-.1.2-.2.1-.2 0-.1-.1-.2-.1-.2zM822.9 35.9s-.1 0 0 0c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0 0 0-.1.1-.2 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM850.7 41.2s-.1 0 0 0c-.1 0-.1 0-.1.1l.1-.1c0 .1 0 0 0 0zM882.1 38.6h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM882.1 38.1zM854 39.5c0-.1-.1-.1-.1-.2-.1 0-.1.1-.1.1 0 .1.1.1.1.2 0 0 .1 0 .1-.1zM1004 32.8s-.1 0 0 0c-.1 0-.2 0-.2.1l.1.1c0-.1.1-.1.1-.2zM892.9 37.1c0 .1-.1.2-.1.3.1-.1.2-.1.3-.2-.1-.1-.1-.1-.2-.1zM892.8 37.4zM831.5 37.1h-.2v.1s.1.1.2.1v-.2zM838.4 36.9c.1 0 .1 0 .1-.1 0 0-.1-.1-.1.1 0-.1 0-.1 0 0zM833 37c0 .1 0 .1 0 0 .1 0 .1 0 .1-.1h-.1v.1zM830.1 36.8zM830.1 36.8c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1h-.3zM1004.1 29.9c.1 0 .1 0 0 0 0-.1 0 0 0 0zM1003.3 29.9zM1003.3 29.9c.3.2.5.1.8 0-.2-.2-.5-.1-.8 0zM837.2 35.7c.1 0 .1 0 0 0l.1.1c.1-.1.1-.1-.1-.1.1-.1.1-.1 0 0zM829 34.3v.7c.2-.4.1-.5 0-.7zM1001.5 28s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1s-.2 0-.2.1zM1001.9 27.9z"/><path d="M834.5 34.2h-.2s0 .1.1.1.1.1.2.1c-.1-.1-.1-.2-.1-.2zM834.6 34.4zM816.8 32.8c.1-.1.1-.1 0 0 .1-.1.1-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0z"/><path d="M816.8 33.3c.1-.1.2-.1.2-.2s0-.2-.1-.4c-.1.1-.1.2-.2.3-.1.1 0 .2.1.3zM819.7 30.6c0 .1-.1.1-.1.2 0 0 .1 0 .1.1 0-.1.1-.1.1-.2l-.1-.1zM1015.5 42.9v.1l.1-.1c0-.1 0-.1-.1 0 0-.1 0-.1 0 0zM1010.3 42.1v.1h.2v-.1h-.2zM1007.4 40.5c0-.1-.1-.1-.1-.2h-.1c0 .1 0 .1.2.2-.1 0-.1 0 0 0zM853.4 42.9s.1.1.1 0v-.1h-.1v.1zM1034.6 34.2c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM1034.8 34.4c0-.1 0-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM840.2 41c.1-.1.1-.2.2-.4-.1 0-.1 0-.2-.1v.5zM855 39.6c0 .1 0 .1 0 0 0 .1 0 .1.1.1l-.1-.1c.1 0 .1 0 0 0zM912.3 36.4h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2-.1-.1-.1-.1-.1 0zM912.6 36.1c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM848.8 38.4c.1.1.1.1.2 0v-.1c-.1 0-.2 0-.2.1zM958.5 33.5c0 .1 0 .1 0 0zM958.7 33.2h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2.1.1.1.1.1 0zM827.6 33.5zM827.3 33.2v.2c.1 0 .1 0 .2.1 0-.1-.1-.1-.1-.2l-.1-.1zM817.9 32.9c0-.1-.1-.1 0 0-.1-.1-.1 0-.1 0h.1c-.1 0 0 0 0 0zM965.7 26.4l-.2-.2c0 .1.1.1.1.2h.1zM828 30.8v-.2c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2s.1.1.1.1zM813.5 29.6v.1zM821.9 24.5zM821.7 24.8h.2c0-.1 0-.2.1-.2l-.2.2c-.1-.1-.1 0-.1 0zM1016.6 41.4v.5c.3-.1.2-.3 0-.5zM1031.1 41v0c0 .1 0 0 0 0zM1017.3 39c-.2.2-.1.4.1.6 0-.2 0-.3.1-.5-.1 0-.2 0-.2-.1zM968.5 39.9c0-.1 0-.1.1-.2l-.1.1v.1zM872 39.6c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM972.1 35.9h0zM892.8 37.4zM892.6 37.5l.1-.1-.1.1c0-.1 0 0 0 0zM902.4 36.6v-.1.1zM973.8 34v0zM854.4 38.1s0-.1.1-.1l-.1.1c.1-.1.1 0 0 0zM854.5 38s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0 0 0 0zM992.7 32.8s.1 0 .1-.1c0 .1 0 .1-.1.1zM879.2 36.8c.1 0 .1-.1.2-.1-.1 0-.1 0-.2.1zM839.8 36.8c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM839.7 37c0-.1 0-.1.1-.2l-.1.1v.1zM851.9 36.4l.1-.1h-.1zM840.7 34.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM840.6 34l.1.1-.1-.1c.1 0 .1 0 0 0zM841.5 33.6l-.1.1.1-.1zM827.8 33.5h-.2c.1.2.2.2.2 0zM827.8 33.5c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM956.5 28.7c-.1.1-.1.1 0 0-.1.1 0 .1 0 0z"/><path d="M956.5 28.6c0 .1 0 .1-.1.2l.1-.1v-.1zM929 26.9s-.1 0-.1.1-.1.1-.1.2c.1 0 .1-.1.2-.1.1-.1 0-.2 0-.2zM928.8 27.2zM972.5 25.8s0-.1-.1-.1l.1.1c-.1-.1 0-.1 0 0zM825.3 30.9h-.1v.1h.1c.1-.1 0-.1 0-.1zM947.9 32.1c0-.1 0-.1.1-.2 0 .1-.1.1-.1.2 0-.1 0 0 0 0zM905.4 26.2s0-.1.1-.1c-.1 0-.1 0-.1.1 0-.1 0 0 0 0zM858 35.9l.2.2c0-.1-.1-.1-.1-.2s-.1 0-.1 0zM858.2 36c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM900.8 28l.2.2c0-.1-.1-.1-.1-.2h-.1zM946 31.1l-.1.1c0-.1 0-.1.1-.1-.1 0 0 0 0 0zM927.1 30.2c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c0-.1-.1-.2-.2-.2zM862.5 23.5zM1497 39.4zM1440.8 39.2c-.1 0-.1 0 0 0zM1413.4 37.6zM1587.8 33.2zM1481 40.3c-.1 0-.1 0 0 0zM1586.4 31.3zM1501 39.5c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4 0-.8.1-1.1.3zM1573.7 39.7c-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5 0-.1 0-.2-.1-.2-.4-.3-.6-.3-.9-.3zM1442.9 42.7c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.8-1 1zM1443.8 41.7s0-.1 0 0c0-.1 0-.1 0 0zM1444.8 40.5zM1443.4 39.1zM1443.4 39.1c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.5-.7-1-1-1.4zM1480.9 41.5v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.8-.8-.2-1.6-.5zM1550.1 41.6c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.4-.5-1-.8-1.6-.7zM1555.3 42.9c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM1469.6 42.1c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.2-.5-.3-.7-.3zM1540.4 37.4c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.2.6.2 1.1.3 1.6zM1473 42c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.3-.4-.4zM1399.1 33.4c0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.2-.5 0-.9-.5-.9h-.2c0-.1-.1-.2-.2-.2s-.2.1-.2.2c-.3 0-.6.1-.9.2.1.7.6.3.9.5-.1.4-.2.8-.2 1.2zM1555.2 39.4c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3h3.1zM1437.8 44.3c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.4-.5-.6zM1441.3 39.7c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM1434.2 43c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.3 0-.6-.3-.8zM1599 43.1c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1.1-.3.1-.5.2-.8.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.2-.6-.4-1.2-1.2-1.5zM1458.8 42.5c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.2-.4.1-.6-.2zM1578.5 40c-.6-.1-1.2-.1-1.8-.2-.1 0-.2.2-.2.3l.1.2c.2.1.3.2.5.2.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.2-.9-.2-1.3-.2zM1461.7 42.9c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.4-.8-.8-1.2zM1446.7 44.3c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.5-.3-.9zM1544.3 39.6c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.2-.2-.4-.4-.6zM1562.4 39.5c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.3-4.2.1zM1437.1 39.5c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.5-1 .5-1-.7-2.1zM1475.3 43c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.5.2-.4.5zM1475.7 42.5zM1558.2 37.5c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-1-.4-1.4zM1396.7 37.6c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.2-.1-.6-.2-1-.4zM1443 46.2c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.1-.4 1.7zM1587.7 36.2c.2-.5.4-.9.1-1.3-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.4 0 .6.1.8.2zM1420.8 44.7s.1 0 0 0c.1-.2 0-.3-.1-.4-.1 0-.2.1-.2.1-.1-.1-.2-.2-.4-.3l-.2.1s0 .2.1.2h.4c.1.1.1.1.1.2v.7c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.8-.1-.8-.6-1.2zM1575 42.5c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.2-1.1.3-1.9.6zM1448 42.5c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.3-.2-.5-.4-.5zm.1.8c0 .1 0 .1 0 0l.1.1c-.1 0-.1 0-.1-.1zM1462.9 43c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1-.4.3-.7.6-1 1zM1408 39.8c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.2-.7-.5-.6zM1409.5 40.9h-.2V42c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.8-.5-1.3zM1404.7 41.7c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.3-.5-.6-.2zM1444.8 44.4c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5.1-.7.3-.7.5zM1594.9 43.5c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6.2-.2.5-.4.6-.6.1-.4-.3-.8-.6-.7zM1397.3 35.5c-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.4.1-.9-.1-1.3l-.1-.1-.1.1v.1c-.1.2-.3.6-.4 1zM1569.8 35.3c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.2-.5-.3-.7-.4zM1544.8 35.6c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.1.2.2.7.6.6zM1545 34.2zM1482.7 44.2c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1 0-.1.3-.1.5zM1435 45.3c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.5-.4.8-1 .8zM1440 45.6c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .8.3 1.2.5 1.9zM1588.6 40.6c-.2 0-.4.1-.6.2v.4c.2.3.7.4.9.3.1 0 .1-.2.1-.2 0-.3-.1-.6-.4-.7zM1576.7 39.3c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4-.4 0-.9-.1-1.3-.1-.1 0-.2.2-.2.3-.1.1 0 .3.1.4zM1405.7 39.6c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.1-.4-.3-.6-.5zM1405.7 39.6zM1574 34.9c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM1578.7 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1578.8 36.1c.4-.9.3-1.3-.1-2.5-.2 1.8-.2 1.8.1 2.5zM1506.3 42.4c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.1-.3-.1zM1494.8 42.9c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5s-.2-.6-.5-.6zM1605.2 47.4c.7 1.2.8 1.3 1.7 1.3-.6-.5-.9-1.1-1.7-1.3zM1539.8 34.4c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM1605 48.6c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.5.2-1-.3-1.1zM1457.4 44.4c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 .1.2.1.4.1zM1549 37.3c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.1-.1-.4 0-.5.2zM1573.3 36.3c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM1494.9 41.4c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.1.1-.3zM1457.1 45.4c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.3.5-.4.6zM1454.5 39.1c-.1 0-.2.1-.2.2-.1.4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM1585.4 36.2c.1-.1.2-.3 0-.5-.1-.1-.3-.1-.5-.1-.1.1-.3.2-.3.4s.1.4.2.7c.3-.2.4-.3.6-.5zM1589.9 41.7c.1 0 .3.1.4 0 .3-.3.8-.4 1-.8-.8-.1-.8-.1-1.4.8zM1496.9 41.1c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM1394.3 36.3zM1544.5 37.3c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.1-.3-.2-.6-.3-1z"/><path d="M1459.4 41.9c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.2.6-.4.6-.7zM1410.8 40.3l.3.6c.2-.1.5-.2.7-.3-.5-.9-.5-.9-1-.3zM1481 40.9c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM1481 40.3c-.1 0 0 0 0 0zM1589.9 33.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1588.6 33.2c0 .3-.2.6.2.9.4-.3.9-.4 1.1-.9-.4.2-.9.1-1.3 0zM1546.6 34.9v.1c.3.3.6.2 1-.1-.4-.2-.7-.3-1 0zM1440.4 42.9c.1.8.1.8.9.4-.3-.4-.5-.6-.9-.4zM1568.3 35.7c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2-.1.3-.3.3-.4zM1435.1 40.3c0-.1-.2-.2-.3-.3-.1.1-.3.3-.3.4 0 .2.2.5.3.9.2-.5.3-.7.3-1zM1594.7 41.1c-.2 0-.4-.1-.5 0-.2.1-.3.4-.4.6l.2.2c.2-.3.6-.2.7-.8zM1540.8 33.9c.3-.6.1-1.2.1-1.8-.4.7-.5 1-.1 1.8zM1399.8 36.5c0-.1-.2-.2-.2-.3l-.5.5c.2.1.3.3.4.3.2-.1.3-.3.3-.5zM1479.3 43.6c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.2-.3-.3-.5-.1zM1449.6 44.8c.3-.4.2-.8 0-1.4-.4.7-.4.7 0 1.4zM1575.7 37.3c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.3-.1-.3-.1zM1400.5 41v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM1583.2 35c0 .8 0 .8.8.9-.3-.3-.5-.5-.8-.9zM1559.1 38.1c.4.3.7.4 1.1.2-.3-.3-.6-.3-1.1-.2zM1555.4 38.1c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM1403.8 43.2c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM1580.8 34.7c-.1 0-.3.2-.3.2 0 .1.1.3.2.5.2-.2.3-.3.3-.4.1-.2 0-.4-.2-.3zM1620.5 33.4c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM1621.9 33.5c-.1 0-.2-.1-.4-.1v-.2c0-.1-.2-.2-.2-.3l-.4.4c-.1 0-.3.1-.4.1.4.3.9.5 1.4.1zM1394.5 38.9c.5-.6.3-1.2.4-1.7-.3.4-.5.9-.4 1.7zM1394.9 37.2s0-.1 0 0c0-.1 0-.1 0 0zM1488.1 43.5c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM1432.4 45.3c0 .4.1.6.1 1 .5-.5.5-.7-.1-1zM1441.5 44.6c-.1 0-.1.1-.1.2 0 .3.1.5.4.6.2-.3 0-.5 0-.7-.1 0-.3-.1-.3-.1zM1486.3 41.6c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0 0-.1 0-.2.1zM1417.1 45.5c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM1460.8 44.6c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM1602.3 43.9c.1 0 .1-.1.1-.2 0-.4-.3-.6-.7-.7.1.3.2.6.3.8.1.1.3.1.3.1zM1601.8 43zM1404.9 40.8c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.4.2.4z"/><path d="M1410.7 41.3c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM1411.1 40.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM1566.8 35.8c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM1402.2 43c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM1572.6 37.5c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4c0 .1.1.1.1 0zM1414.5 40.1s0 .1 0 0c.1 0 0 0 0 0z"/><path d="M1414.1 39.5s-.1 0 0 0c-.2.5.2.5.4.7 0-.3.1-.7-.4-.7zM1404.7 39.2c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM1405.7 39.6zM1405.2 39.6s0 .1 0 0c0 .1 0 .1 0 0zM1451.3 45.8l.2.2c.1-.1.2-.3.3-.4l-.2-.2c-.2.1-.3.3-.3.4zM1414.5 38.6c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 .1.2 0 .3-.1zM1411.7 38.4c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM1522.6 42.5c0 .1.1.2.2.4.1-.2.2-.4.1-.4 0-.1-.2-.1-.3-.2 0 .1-.1.2 0 .2zM1392.9 38.6c0 .1.1.2.2.4.1-.2.1-.3.1-.4 0-.1-.1-.1-.1-.2 0 0-.2.1-.2.2zM1424.2 45.6c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.1 0-.3.1zM1505.1 41.6c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7l-.3-.3zM1453.7 43.1s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.1.2-.3.3zM1426.1 44.3c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.1.1-.2zM1424.6 44.3s0 .1 0 0c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM1406.4 43.4s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM1586.1 43.2c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM1585.7 43zM1392.9 35.8c0 .1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.2-.1-.3c-.1 0-.3.1-.3.2zM1455.5 44.6c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3-.1-.1-.2-.1-.2-.2zM1503.2 42.6c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1 0-.1.2-.2.3zM1492.2 41.9h.1-.1zM1491.7 42.3s.1.1 0 0c.4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM1583.8 37.4s.2-.1.2-.2-.1-.2-.2-.3c-.1.1-.2.1-.3.2.2.2.2.3.3.3zM1577.2 36.2zM1576.6 36.2c.1.1.1.2.2.3l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1zM1575.5 36.3c0 .1.1.2.3.3.1-.2.1-.3.1-.4 0-.1-.2-.1-.3-.1 0 0-.1.1-.1.2zM1413.1 41.8c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM1502.8 43.1c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1418.8 46s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.3-.2.4-.2.6zM1417.8 44c.1.1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1 0 .1-.1.2zM1394.2 33.7h.2c0-.1.1-.3.1-.4v-.1c.1 0 .1 0 .2-.1v-.2s-.1 0-.1.1l-.1.1c0-.1.1-.2 0-.2 0-.1-.2-.1-.3-.1l-.1.2c0 .1.1.2.2.3l-.3.3c.2 0 .2.1.2.1zM1407.3 39.3c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0-.1 0-.2.1-.2zM1431 43.5s.1.1.2.1v-.2h-.2v.1zM1421.9 43.8s0 .1 0 0c0 .1 0 .1.1.1l-.1-.1c.1.1 0 0 0 0zM1410.4 43.8c.1.1.1.3.2.4h.2v-.1c-.1-.1-.3-.2-.4-.3zM1466.5 41.9h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM1466.5 41.4zM1417.5 40.3s0-.1 0 0c-.1 0-.1.1-.1.1s.1 0 .1.1v-.2zM1414.5 40.2c.1 0 .1 0 0 0 .1 0 .1 0 0 0zM1414.6 40.2c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1-.2-.1-.3-.1-.3 0zM1588.6 33.2zM1587.8 33.2zM1587.8 33.2c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM1413.4 37.6v.7c.3-.3.1-.5 0-.7zM1585.9 31.3s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1 0 0-.1.1-.2.1zM1586.4 31.3zM1404 34.2s.1 0 .1.1c0-.1.1-.1.1-.2 0 0-.1-.1-.1 0 0-.1 0 0-.1.1zM1395.5 32.2l-.1.1s0 .1.1.1c-.1 0 0 0 0-.2 0 .1 0 0 0 0zM1617.5 39.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM1617.5 39.9c-.1.2-.2.4-.2.6.2-.2.4-.3.2-.6zM1619 37.5zM1619.2 37.7s0-.1 0 0c-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM1424.6 43.9v.4c.1-.1.1-.2.2-.4 0 .1-.1 0-.2 0zM1410.4 43.7c0 .1 0 .1 0 0 0 .1 0 0 0 0zM1410.3 43.4c0 .1-.1.1-.1.2s.1.1.1.2v-.2c.1-.1 0-.2 0-.2zM1508.7 39.2s.1 0 .1-.1c.1-.1.1-.1.1-.2-.1 0-.2 0-.2.1s.1.2 0 .2zM1496.7 39.7h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2 0-.1 0 0-.1 0zM1497 39.4zM1542.9 36.8c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1543.2 36.6h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2 0 .1 0 0 .1 0zM1394.3 36.3zM1394 36.4c.1 0 .2 0 .2-.1l-.2.1c.1-.1.1 0 0 0zM1550.1 29.7l-.2-.2c0 .1.1.1.1.2h.1zM1412.4 34.2V34c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2.1 0 .1.1.1.1zM1612.9 48.7h0c-.1 0-.1 0 0 0zM1612.7 48.6zM1615.6 44.3v.1c-.1.1-.1 0 0-.1 0 .1 0 .1 0 0zM1601.8 43c0-.2 0-.3.1-.5-.1 0-.1-.1-.2-.1-.2.2-.1.4.1.6zM1553 43.3c0-.1 0-.1.1-.2l-.1.1v.1zM1456.4 42.9c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM1556.6 39.2h.1-.1zM1486.8 39.9v-.1.1zM1558.2 37.3v0zM1438.9 41.4s0-.1.1-.1c-.1 0-.1 0-.1.1zM1438.9 41.3s.1 0 0 0c.1 0 .1-.1 0 0 .1-.1.1-.1 0 0zM1577.2 36.2s.1 0 .1-.1c-.1 0-.1 0-.1.1zM1463.6 40.2c.1 0 .1-.1.2-.1 0 0-.1 0-.2.1.1-.1.1-.1 0 0zM1540.9 32.1zM1541 31.9c0 .1 0 .1-.1.2l.1-.1v-.1zM1394.7 29.3s.1 0 .1.1l-.1-.1c.1 0 .1 0 0 0zM1513.4 30.2s-.1 0-.1.1-.1.1-.1.2c.1 0 .1-.1.2-.1s.1-.1 0-.2zM1513.3 30.5c-.1 0-.1 0 0 0zM1556.9 29.1s0-.1-.1-.1l.1.1zM1500.3 29.9c-.1 0-.1-.1-.2-.1l-.1.1h.3zM1492.6 30.2c.1 0 .2-.1.3-.1-.1-.1-.1-.2-.2-.3h-.4v.1l.3.3zM1409.7 34.2v.1h.1v-.1h-.1zM1532.3 35.4c0-.1 0-.1.1-.2 0 .1 0 .1-.1.2 0 0 .1 0 0 0zM1489.8 29.5s0-.1.1-.1l-.1.1zM1442.6 39.4zM1485.2 31.3l.2.2c0-.1-.1-.1-.1-.2h-.1zM1530.4 34.4l-.1.1s0-.1.1-.1zM1507 37.7l-.2.2c.1 0 .1-.1.2-.1s0-.1 0-.1zM1511.6 33.5c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c-.1-.1-.2-.1-.2-.2zM1447 26.8c-.1 0-.1 0 0 0-.1.1-.1.1 0 0 0 .1 0 0 0 0zM1315.7 36.1zM1246.7 32.3zM1259.4 35.9zM1232.1 34.3zM1406.5 29.9h-.1zM1299.6 37zM1405.1 27.9c-.1 0-.1 0 0 0zM1319.7 36.2c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c-.1 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.5-.1-.8 0-1.1.3zM1393.2 36.4c-.3 0-.5-.1-.8 0-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5-.2-.3-.2-.4-.2-.5zM1236.7 30.1c.1 0 .1 0 0 0 .1 0 0 0 0 0zM1235.7 30.1v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 .1.1.1.2.1 0 .4 0 .8-.2 1.2 0-.1-.1-.1-.1-.2 0 .1.1.1.1.2-.3.1-.5.2-.8.3.2.5.2.5-.3 1.3.3.1.6.1.9.2.5-.2.5-.2.7.2.1.2 0 .4.4.3v-.8c-.1-.5 0-.9.2-1.4.2-.4.2-.8.3-1.2-.1-.2-.3-.4-.4-.6-.4.1-.6.3-.8.5zM1261.6 39.4c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.7-1 1zM1262.5 38.3zM1220.6 28.7zM1219.6 31.7c-.1.1-.1.2-.2.3.2.3.4.5.6.8.4-.1.6-.5.8-.9.3.1.5.5.9.1-.2-.3-.3-.6-.5-.8l.3-.3c.1-.9-.6-1.4-.8-2.1-.1.1-.2.3-.1.4.2 1-.3 1.7-1 2.5zm1.1.1c-.1-.1-.2-.1-.3-.2 0-.1.1-.1.1-.2.1.2.2.3.2.4zM1263.5 37.1zM1262.1 35.8zM1262.1 35.8c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.6-.7-1-1-1.4zM1299.6 38.2v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.9-.9-.2-1.6-.5zM1368.8 38.3c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.5-.5-1-.8-1.6-.7zM1374 39.6c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM1288.3 38.7c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.4-.1-.5-.3-.7-.3zM1359.1 34c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.1.6.2 1.1.3 1.6zM1291.6 38.7c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4 0-.2-.2-.4-.4-.4zM1218.6 28.1c-.5 0-1 0-1.5.2.1.7.6.3.9.5-.1.4-.1.8-.1 1.2 0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5 0-.5-.2-.8-.6-.9zM1373.8 36c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3c1.1.1 2.1 0 3.1 0zM1256.4 40.9c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.2-.1-.3-.3-.5-.6zM1244.1 34.6c-.1-.1-.2-.3-.2-.4-.2.3-.4.7-.9.7l-.9-.6c0 .4.1.8.4 1.1.4.3.5.8.5 1.4.1-.3.3-.5.4-.8.9.2.9.2 1.1-.7-.2-.2-.3-.5-.4-.7zM1242.9 36.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0z"/><path d="M1260 36.4c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM1252.9 39.7c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.4 0-.7-.3-.8zM1417.7 39.8c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1v-.1c.1.2.3.3.4.5.1-.4 0-.6-.4-.6 0-.2.1-.4.1-.5.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.1-.7-.4-1.3-1.1-1.6zM1223.4 27.1c-.3 0-.6.3-.6.8s.3.8.8.8c.4 0 .7-.3.7-.7 0-.5-.5-.9-.9-.9zM1277.5 39.2c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.1-.4 0-.6-.2zM1397.2 36.6c-.6-.1-1.2-.1-1.8-.2l-.1-.1c-.1.3-.2.6-.3.8.2 0 .4.2.4.1s.1-.1.1-.2c.1 0 .2.1.3.1.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.1-.9-.1-1.3-.2zM1280.4 39.6c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.5-.8-.8-1.2zM1265.4 41c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.6-.3-.9zM1363 36.3c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4 0-.3-.2-.4-.4-.6zM1225.1 31h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8-.1.2-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.6 1.1.9 1.5zM1381.1 36.2c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.4-4.2.1zM1255.8 36.2c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1zM1294 39.6c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.3.1-.5.3-.4.5zM1294.4 39.2zM1376.9 34.1c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-.9-.4-1.4zM1261.7 42.8c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.5.6-.4 1.2-.4 1.7zM1406.6 31.5c-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.2 0 .5.1.7.2-.1.1-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1 .9 1.4h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8.2-.4.5-.8.2-1.2zM1249.8 36.6c0 .6 0 1.2.1 1.9.5-.4.7-.6.8-.8.1-.6-.2-.9-.9-1.1zM1239.2 41.2v.8c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.9-.1-.8-.9-1.4zM1393.7 39.2c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.1-1.1.3-1.9.6zM1266.7 39.1c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.2-.2-.4-.4-.5zm0 .9c.1 0 .1 0 0 0l.1.1s0-.1-.1-.1zM1281.6 39.6c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1l-1 1zM1228.6 33.6zM1228 33.8c.3.6.7 1.1.7 1.8.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1l-.3-.9h-.6c-.1.1-.1.2-.1.2zM1226.7 36.5c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.3-.7-.5-.6zM1242 34.2zM1241.9 32.4s-.1-.3-.1-.4c-.2 0-.3 0-.5.1-.1 0-.1.2-.1.2 0 .4 0 .9.1 1.3.1.3.4.4.7.6-.1-.6-.6-1.2-.1-1.8zM1228.2 37.6h-.2v1.1c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.9-.5-1.3zM1223.3 38.3c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4.1-.3-.2-.4-.6-.2zM1239.9 38.3c-.1-.4-.1-.6-.2-.9v-.9c-.5.3-.8.5-.7 1 .1.5.3.8.9.8zM1263.5 41.1c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.6 0-.7.2-.7.5zM1413.6 40.1c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6l.1-.1.1.1c0-.1 0-.2.1-.2.1-.1.3-.3.3-.4 0-.4-.3-.7-.6-.7zM1234.6 34.1c0-.3-.2-.4-.4-.5-.3-.3-.6-.6-.9-1-.4.3-.4.7-.3 1.1.1.4.3.5.7.5 0 .1 0 .2-.1.3-.1.3.1.6.4.7.2.1.4-.1.5-.5.1-.2.1-.4.1-.6zM1225 28.1c.7-.7.6-1-.3-1.9 0 .7-.2 1.3.3 1.9zM1388.5 31.9c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.1-.5-.3-.7-.4zM1363.4 32.3c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.2.2.3.7.6.6zM1363.7 30.9c-.1 0 0 0 0 0zM1301.4 40.8c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1.1-.1.4-.1.5zM1248.4 36.9c-.2.2-.3.4-.1.6.1.2.2.3.4.4 0 .1 0 .1.1.2v-.2c.2.1.3.1.5.2.2-.5 0-.8-.2-1.1-.3-.2-.5-.2-.7-.1zM1253.7 41.9c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.6-.4.9-1 .8zM1258.7 42.3c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .7.2 1.2.5 1.9zM1395.4 35.9c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4h-.3c.2-.8.2-1.6-.1-2.3-.3.5-.6.9-.8 1.4.4.4.6.7 1 .9h-.9s-.1 0-.1.1c-.7-.2-.8-.1-.9.4v.5c.3-.2.6-.4.9-.7-.4.2-.3.3-.2.3zM1224.4 36.3c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.2-.4-.3-.6-.5zM1224.4 36.3zM1392.7 31.6c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM1397.4 30.2zM1397.5 32.7c.4-.9.3-1.3-.1-2.5-.3 1.9-.2 1.9.1 2.5zM1325 39.1c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.2-.3-.1zM1313.5 39.6c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5 0-.4-.2-.6-.5-.6zM1424.6 44.4c0-.1-.1-.1-.1-.1-.2-.1-.3-.2-.5-.2 0 .1.1.1.1.2-.2 0-.3.1-.2.2.1.1.2.1.3.1.4.7.7.8 1.4.8-.4-.3-.7-.7-1-1zM1222.1 35.8c-.1.5-.2 1-.4 1.6.3 0 .5.1.7 0 .1-.1.2-.3.2-.5-.1-.4-.2-.7-.5-1.1zM1358.5 31.1c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM1223.2 33.3c-.3-.3-.6-.4-.9-.4-.1 0-.2.1-.5.3.4.1.6.2.8.3.2.1.4.3.6.4.3-.2.2-.4 0-.6zM1423.7 45.3c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.6.2-1-.3-1.1zM1276.1 41.1c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 0 .2.1.4.1zM1367.7 34c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.2-.1-.4 0-.5.2zM1392 33c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM1313.6 38.1c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.2.1-.3zM1275.8 42.1c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.3.4-.4.6zM1273.2 35.8c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM1315.5 37.8c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3.1-.1-.1-.2-.2-.2zM1247.9 41.3c.6.2.9.2 1.3-.2-.5-.3-.8-.3-1.3.2zM1363.2 34c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.2-.3-.2-.6-.3-1zM1278.1 38.5c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.1.5-.3.6-.7zM1229.5 36.9l.3.6c.2-.1.5-.2.7-.3-.5-.8-.5-.8-1-.3zM1299.7 37.5c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2-.1.2-.1.4 0 .6zM1299.6 37zM1365.3 31.6v.1c.3.3.6.2 1-.1-.4-.3-.7-.3-1 0zM1259.1 39.5c.1.8.1.8.9.4-.3-.3-.5-.5-.9-.4zM1387 32.3c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2 0 .3-.2.3-.4zM1253.5 36.6c-.1.1-.3.3-.3.4 0 .2.2.5.3.9.1-.5.3-.7.3-1 0 0-.2-.1-.3-.3zM1359.4 30.5c.3-.6.1-1.2.1-1.8-.4.7-.4 1.1-.1 1.8zM1238 33c-.2-.2-.5-.3-.7-.5-.1 0-.1.1-.2.1.1.2.1.4.2.6.2.2.7.1.7-.2zM1298 40.3c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.3-.3-.3-.5-.1zM1268.3 41.5c.3-.4.2-.8 0-1.4-.4.6-.4.6 0 1.4zM1394.3 34c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.2-.1-.3-.1zM1219.2 37.7v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3 0-.6-.4-.8zM1377.8 34.8c.4.3.7.4 1.1.2-.3-.4-.6-.4-1.1-.2zM1374 34.7c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.2 0 .3-.1.6-.2zM1222.5 39.9c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM1252.7 37.4c0-.1-.1-.3-.2-.6-.2.2-.3.4-.4.5-.1.2 0 .4.2.4s.4-.2.4-.3zM1238 35.6c.3-.6.1-.9-.3-1.2 0 .4-.1.8.3 1.2zM1244.4 32.7c.1.3.1.6.2.9h.6c0-.6-.3-.8-.8-.9zM1244.6 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1419.7 41.4zM1419.7 40.5l-.2-.2c0-.1-.1-.2-.2-.2 0 0-.1.1-.2.1 0 .1.1.1.1.2l-.1.1c.1.3.3.6.5.9.2-.3.3-.6.1-.9zM1377.9 40.4c-.2 0-.4.1-.3.3 0 .1.2.2.4.3.1-.1.3-.2.3-.3-.1-.2-.3-.3-.4-.3zM1306.8 40.2c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.4-.3-.5-.4zM1251.1 42c0 .4.1.6.1 1 .5-.6.5-.7-.1-1zM1260.4 42.1c.2-.3 0-.5 0-.7l-.2-.1c-.1 0-.1.1-.1.2-.1.3 0 .6.3.6zM1305 38.3c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0-.1-.1 0-.2.1zM1244.6 42c-.1.2-.3.3-.4.5.1.1.2.2.3.2.2-.1.3-.3.4-.5 0 0 0-.2-.1-.2 0-.1-.2-.1-.2 0zM1235.7 42.2c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.1.1-.2.1zM1279.5 41.3c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM1376.4 39.4c-.1.4-.1.7.4 1 0-.4 0-.8-.4-1zM1420.5 39.7zM1223.5 37.5c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7 0 .1 0 .3.2.4zM1229.4 38c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM1229.8 37.5zM1385.5 32.5c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM1220.9 39.7c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM1391.3 34.2c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4h.1zM1422.2 44.4c.1.1.2.2.3.2.1-.1.1-.2.2-.3-.1-.1-.2-.1-.3-.2-.1 0-.2.2-.2.3zM1233.2 36.8zM1232.8 36.1s-.1.1 0 0c-.2.5.2.5.4.7 0-.3.1-.6-.4-.7zM1223.4 35.9c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM1224.4 36.3zM1223.8 36.3c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0zM1384.9 38c-.1.2-.1.3-.2.5.1.1.1.2.2.2s.2-.1.2-.1c0-.2 0-.4-.1-.5 0-.1-.1-.1-.1-.1zM1233.2 35.3c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 0 .2-.1.3-.1zM1230.4 35.1c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2-.1-.4-.2-.4zM1379.8 37.9c-.1 0-.2 0-.2.1-.1.1-.1.2-.2.3.1 0 .2.1.3.1.2 0 .3-.1.3-.4 0 0-.1-.1-.2-.1zM1283.9 41.9l.2.2c.1-.2.2-.4.3-.5-.1 0-.2-.1-.2-.1-.1.1-.2.2-.3.4zM1246.1 42.1s-.1 0 0 0c0 .2 0 .4.1.6h.2c-.1-.2-.1-.3-.2-.5 0-.1-.1-.1-.1-.1zM1242.9 42.3c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.2 0-.3.1zM1323.8 38.3c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.2-.2-.2-.3-.3zM1272.4 39.8s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.2.2-.3.3zM1244.7 41c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3 0 0 .2-.2.1-.2zM1242.5 41.1c.1.1.3.1.5.1.1 0 .2-.1.3-.2-.1 0-.2-.1-.3-.1-.4-.1-.6.1-.5.2zM1243.3 41zM1225.1 40.1s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.2.2-.2.3-.2.5zM1236.3 38.8l.6.6c.1-.5 0-.7-.6-.6zM1364 33.4l.2-.1v-.4c-.1 0-.2.1-.4.1 0 .2.1.3.2.4zM1379 31.9c-.1 0-.2.2-.3.3.1.1.2.2.3.2.1 0 .2-.2.2-.3 0-.1-.1-.3-.2-.2zM1421.6 46.1l.2.2c.1 0 .2-.1.2-.2-.1-.1-.2-.1-.3-.2 0 .1 0 .1-.1.2zM1277.1 51.6c.1 0 .1.1.2.1v-.2l-.1-.1s0 .1-.1.2zM1435.4 41.4h-.4c-.1 0-.1.2-.1.3.1 0 .2.1.2 0 .1 0 .1-.1.3-.3zM1404.8 39.9c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM1404.4 39.7zM1260.2 43h.3s.1-.1.1-.2c-.1 0-.2-.1-.3 0-.1 0-.1.1-.1.2zM1289.8 41.4c0 .1.1.3.1.3.1 0 .2-.1.3-.1-.1-.1-.1-.3-.1-.3-.1 0-.2.1-.3.1zM1274.1 41.3c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.2-.2-.2zM1248.1 42.7c.4-.3.4-.3.3-.7-.1.3-.2.4-.3.7zM1249.8 41.9c0 .1.1.2.2.3.1-.1.2-.1.2-.2-.1-.1-.1-.2-.2-.3 0 .1-.2.2-.2.2zM1321.9 39.2c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1.1-.1.2-.2.3zM1310.9 38.6v-.1zM1310.4 38.9c0 .1.1.1 0 0 .4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM1238.6 40.9s0 .2.1.2c.2 0 .4 0 .6.1-.1-.1-.3-.3-.5-.4 0 0-.1 0-.2.1zM1239.3 41.2zM1384.6 35.1c-.3 0-.5-.1-.8-.1.3.3.5.3.8.1zM1395.8 32.8s0 .1 0 0c0 .1.1.1 0 0zM1395.5 33.2l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1.1.1.1.2.2.3zM1231.8 38.5c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM1232.4 37.4c0 .2-.1.3-.1.4 0 .1.1.1.2.2 0-.1.1-.2.1-.4l-.2-.2zM1235.4 34.4c-.1.7.4.9 1 1.3v-.8c-.1-.4-.5-.5-.8-.7.1-.4.1-.8-.2-1.2-.2.5-.4 1 0 1.4zM1419.7 42c-.2 0-.5.1-.9.1.6.4.8.2.9-.1zM1407.1 40.4c0 .1.1.1.1.2.1 0 .1-.1.2-.1 0 0 0-.1-.1-.1 0-.1-.1-.1-.2 0zM1257.9 42.7c0 .1.1.1.1.2.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3-.1 0-.1.1-.1.2zM1321.5 39.8c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1237.5 42.6s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.2.4-.2.5-.2.6zM1236.5 40.7c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1 0 .1-.1.2zM1279.7 38.2h.3c-.1-.1-.1-.2-.2-.3h-.2s-.1.1 0 .1c0 .1.1.2.1.2zM1294.9 37.2c-.1 0-.1 0-.2.1 0 .1.1.1.1.2l.2-.2-.1-.1zM1386.5 33.8s.1-.1.1-.2c-.1 0-.2-.1-.3-.1 0 0-.1.1-.1.2.1 0 .2.1.3.1zM1293.8 36.8c-.1 0-.2.1-.3.1l.2.2c.1 0 .2-.1.3-.2-.1 0-.2-.1-.2-.1zM1246.5 38.2c.1 0 .2.1.2.1s.1-.1.1-.2c-.1 0-.2-.1-.2-.1s-.1.1-.1.2zM1243.7 38.3c.1.1.1.2.1.2l.2-.2v-.2c-.1.1-.2.1-.3.2zM1234.5 38.7c0 .1.1.1.2.2.1-.1.1-.2.2-.3-.1 0-.1-.1-.2-.1-.1.1-.2.1-.2.2zM1247.3 36.9c0 .1.1.1.1.2.1 0 .2-.1.2-.1 0-.1-.1-.1-.1-.2-.1 0-.1.1-.2.1zM1238.1 36.8s-.1.1-.2.1c.1.1.1.2.2.3.1-.1.2-.2.1-.2 0-.1-.1-.2-.1-.2zM1226 35.9c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0 0 0-.1.1-.2 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1253.8 41.2s-.1 0 0 0c-.1 0-.1 0-.1.1l.1-.1c0 .1 0 0 0 0zM1285.2 38.6h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM1285.2 38.1zM1257.1 39.5c0-.1-.1-.1-.1-.2-.1 0-.1.1-.1.1 0 .1.1.1.1.2 0 0 .1 0 .1-.1z"/><path d="M1407.1 32.8c-.1 0-.2 0-.2.1l.1.1c.1-.1.1-.1.1-.2zM1296 37.1c0 .1-.1.2-.1.3.1-.1.2-.1.3-.2-.1-.1-.1-.1-.2-.1zM1295.9 37.4zM1234.6 37.1h-.2v.1s.1.1.2.1v-.2zM1241.5 36.9c.1 0 .1 0 .1-.1 0 0-.1-.1-.1.1 0-.1 0-.1 0 0zM1236.1 37c0 .1 0 .1 0 0 .1 0 .1 0 .1-.1h-.1v.1zM1233.2 36.8zM1233.3 36.8c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1h-.3zM1407.2 29.9c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1-.1.1 0 0 0zM1406.4 29.9c.1 0 .1 0 0 0 .1 0 .1 0 0 0z"/><path d="M1406.5 29.9c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM1240.4 35.7l.1.1c0-.1 0-.1-.1-.1 0-.1 0-.1 0 0zM1232.1 34.3v.7c.3-.4.1-.5 0-.7zM1404.6 28s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1s-.1 0-.2.1zM1405.1 27.9c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM1237.6 34.2h-.2s0 .1.1.1.1.1.2.1c0-.1-.1-.2-.1-.2zM1237.7 34.4zM1220 32.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1219.9 33.3c.1-.1.2-.1.2-.2s0-.2-.1-.4c-.1.1-.1.2-.2.3 0 .1 0 .2.1.3zM1222.8 30.6c0 .1-.1.1-.1.2 0 0 .1 0 .1.1 0-.1.1-.1.1-.2l-.1-.1zM1418.6 42.9v.1l.1-.1c0-.1 0-.1-.1 0 .1-.1 0-.1 0 0zM1413.5 42.1v.1h.2v-.1h-.2zM1410.5 40.5c0-.1-.1-.1-.1-.2h-.1c0 .1.1.1.2.2-.1 0 0 0 0 0zM1256.5 42.9s.1.1.1 0v-.1h-.1v.1zM1437.7 34.2zM1437.9 34.4c0-.1 0-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM1243.3 41c.1-.1.1-.2.2-.4-.1 0-.1 0-.2-.1v.5zM1258.2 39.6c-.1.1-.1.1 0 0 0 .1 0 .1.1.1-.1 0 0 0-.1-.1zM1315.4 36.4h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2-.1-.1-.1-.1-.1 0zM1315.7 36.1zM1251.9 38.4c.1.1.1.1.2 0v-.1c-.1 0-.2 0-.2.1zM1361.6 33.5c0 .1 0 .1 0 0zM1361.8 33.2h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2.1.1.1.1.1 0zM1230.7 33.5zM1230.4 33.2v.2c.1 0 .1 0 .2.1 0-.1-.1-.1-.1-.2l-.1-.1zM1221 32.9c0-.1-.1-.1 0 0-.1-.1-.1 0-.1 0h.1c-.1 0 0 0 0 0zM1368.8 26.4l-.2-.2c0 .1.1.1.1.2h.1zM1231.1 30.8v-.2c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2l.1.1zM1216.6 29.7v-.1.1zM1225 24.5zM1224.8 24.8h.2c0-.1 0-.2.1-.2l-.2.2c-.1-.1-.1 0-.1 0zM1419.7 41.4v.5c.3-.1.2-.3 0-.5zM1434.2 41v0c0 .1 0 0 0 0zM1420.4 39c-.2.2-.1.4.1.6 0-.2 0-.3.1-.5-.1 0-.2 0-.2-.1zM1371.7 39.9c0-.1 0-.1.1-.2l-.1.1v.1zM1275.1 39.6c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM1375.2 35.9h0zM1295.9 37.4zM1295.7 37.5l.1-.1-.1.1c.1-.1.1 0 0 0zM1305.5 36.6v-.1.1zM1376.9 34v0zM1257.6 38.1s0-.1.1-.1c-.1 0-.1 0-.1.1 0-.1 0 0 0 0zM1257.6 38s0-.1 0 0c0-.1.1-.1 0 0 0-.1 0-.1 0 0 0-.1 0 0 0 0zM1395.8 32.8s.1 0 .1-.1c0 .1 0 .1-.1.1zM1282.3 36.8c.1 0 .1-.1.2-.1 0 0-.1 0-.2.1.1 0 0 0 0 0zM1242.9 36.8zM1242.8 37c0-.1 0-.1.1-.2l-.1.1v.1zM1255 36.4l.1-.1h-.1zM1243.8 34.1c0 .1 0 .1 0 0 .1.1.1 0 0 0zM1243.8 34l.1.1c-.1 0-.1 0-.1-.1zM1244.6 33.6l-.1.1.1-.1zM1231 33.5h-.2c0 .2.1.2.2 0zM1231 33.5zM1359.6 28.7c0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1359.7 28.6c0 .1 0 .1-.1.2l.1-.1v-.1zM1332.1 26.9c-.1.1-.2.2-.2.3.1 0 .1-.1.2-.1.1-.1 0-.2 0-.2zM1332 27.2c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0 0 0 0 0zM1375.6 25.8l-.1-.1.1.1c0-.1 0-.1 0 0zM1228.4 30.9h-.1v.1h.1c.1-.1.1-.1 0-.1zM1351 32.1c0-.1 0-.1.1-.2 0 .1 0 .1-.1.2 0-.1 0 0 0 0zM1308.5 26.2s0-.1.1-.1c0 0-.1 0-.1.1 0-.1 0 0 0 0zM1261.1 35.9l.2.2c0-.1-.1-.1-.1-.2s-.1 0-.1 0zM1261.3 36c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM1303.9 28l.2.2c0-.1-.1-.1-.1-.2h-.1zM1349.1 31.1l-.1.1c0-.1 0-.1.1-.1zM1330.3 30.2c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1l-.2-.2zM1265.7 23.5c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM1900.1 39.4zM1843.9 39.2zM1816.5 37.6zM1884.1 40.3zM1904.1 39.5c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c0 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4 0-.8.1-1.1.3zM1846 42.7c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.8-1 1zM1846.9 41.7s0-.1 0 0c0-.1 0-.1 0 0zM1847.9 40.5zM1846.5 39.1s.1 0 0 0c.1 0 .1 0 0 0zM1846.5 39.1c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.3-.5-.6-1-1-1.4zM1884 41.5v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.8-.8-.2-1.6-.5zM1872.7 42.1c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.2-.5-.3-.7-.3zM1876.1 42c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.3-.4-.4zM1802.2 33.4c0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.2-.5 0-.9-.5-.9h-.2c0-.1-.1-.2-.2-.2s-.2.1-.2.2c-.3 0-.6.1-.9.2.1.7.6.3.9.5-.1.4-.2.8-.2 1.2zM1840.9 44.3c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.4-.5-.6z"/><path d="M1844.4 39.7c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM1837.3 43c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.3 0-.6-.3-.8zM1861.9 42.5c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.2-.4.1-.6-.2zM1864.9 42.9c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5 0-.6-.5-.8-.8-1.2zM1849.8 44.3c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.5-.3-.9zM1840.3 39.5c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.4-1 .4-1-.7-2.1zM1878.4 43c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.4.2-.4.5zM1878.8 42.5zM1799.8 37.6c-.3.3-.5.6-.3.8.2.2.5.4.8.4.4 0 .6-.3.5-.8-.2-.1-.6-.2-1-.4zM1846.1 46.2c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.1-.4 1.7zM1823.9 44.7c.1 0 .1 0 0 0 .1-.2 0-.3-.1-.4-.1 0-.2.1-.2.1-.1-.1-.2-.2-.4-.3l-.2.1s0 .2.1.2h.4c.1.1.1.1.1.2v.7c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1 0-.8 0-.8-.6-1.2zM1851.1 42.5c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5 0-.3-.1-.5-.4-.5zm.1.8c0 .1 0 .1 0 0l.1.1c-.1 0-.1 0-.1-.1zM1866 43c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1-.4.3-.6.6-1 1zM1811.2 39.8c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4-.1-.3-.3-.7-.5-.6zM1812.6 40.9h-.2V42c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.8-.5-1.3zM1807.8 41.7c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.2-.5-.6-.2zM1847.9 44.4c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5.1-.7.3-.7.5zM1800.4 35.5c-.1.2.1.5.3.6.3 0 .4-.2.4-.4.1-.4.1-.9-.1-1.3l-.1-.1-.1.1v.1c-.1.2-.3.6-.4 1zM1885.8 44.2c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1 0-.1.3-.1.5zM1838.1 45.3c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.5-.4.8-1 .8zM1843.1 45.6c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .8.3 1.2.5 1.9zM1808.8 39.6c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.1-.4-.3-.6-.5zM1808.8 39.6zM1909.4 42.4c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.1-.3-.1zM1897.9 42.9c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5s-.2-.6-.5-.6zM1860.5 44.4c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 .1.3.1.4.1zM1898 41.4c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.1.1-.3zM1860.3 45.4c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.2.3-.4.5-.4.6zM1857.6 39.1c-.1 0-.2.1-.2.2-.1.4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM1900 41.1c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM1797.5 36.3z"/><path d="M1862.6 41.9c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.2-.2.5-.4.6-.7zM1813.9 40.3l.3.6c.2-.1.5-.2.7-.3-.4-.9-.5-.9-1-.3zM1884.1 40.9c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM1884.1 40.3zM1843.6 42.9c.1.8.1.8.9.4-.4-.4-.6-.6-.9-.4zM1838.2 40.3c0-.1-.2-.2-.3-.3-.1.1-.3.3-.3.4 0 .2.2.5.3.9.2-.5.3-.7.3-1zM1802.9 36.5c0-.1-.2-.2-.2-.3l-.5.5c.2.1.3.3.4.3.2-.1.4-.3.3-.5zM1882.4 43.6c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.2-.3-.3-.5-.1zM1852.7 44.8c.3-.4.2-.8 0-1.4-.4.7-.4.7 0 1.4zM1803.6 41v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM1806.9 43.2c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM1797.6 38.9c.5-.6.3-1.2.4-1.7-.3.4-.5.9-.4 1.7zM1798 37.2s0-.1 0 0c0-.1 0-.1 0 0zM1891.2 43.5c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM1835.5 45.3c0 .4.1.6.1 1 .6-.5.5-.7-.1-1zM1844.6 44.6c-.1 0-.1.1-.1.2 0 .3.1.5.4.6.2-.3 0-.5 0-.7-.1 0-.3-.1-.3-.1zM1889.5 41.6c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2-.1 0-.2 0-.2.1zM1820.2 45.5c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM1863.9 44.6c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM1808 40.8c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.4.2.4z"/><path d="M1813.8 41.3c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.2.1-.5.2-.3.5zM1814.2 40.9s0-.1 0 0c0-.1 0-.1 0 0 0-.1 0 0 0 0zM1805.3 43c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM1817.7 40.1s0 .1 0 0zM1817.3 39.5c-.1 0-.1 0 0 0-.2.5.2.5.4.7-.1-.3 0-.7-.4-.7zM1807.8 39.2c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM1808.8 39.6zM1808.3 39.6s0 .1 0 0c0 .1 0 .1 0 0zM1854.4 45.8l.2.2c.1-.1.2-.3.3-.4l-.2-.2c-.1.1-.2.3-.3.4zM1817.6 38.6c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4.1.1.2 0 .3-.1zM1814.8 38.4c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM1796.1 38.6c0 .1.1.2.2.4.1-.2.1-.3.1-.4 0-.1-.1-.1-.1-.2-.1 0-.2.1-.2.2zM1827.4 45.6c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3-.1 0-.2 0-.3.1zM1908.2 41.6c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7l-.3-.3zM1856.9 43.1s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1-.3.3zM1829.2 44.3c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.1.1-.2zM1827.7 44.3s0 .1 0 0c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM1809.5 43.4s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM1796.1 35.8c0 .1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.2-.1-.3c-.2 0-.3.1-.3.2zM1858.6 44.6c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1906.3 42.6c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1 0-.1.2-.2.3zM1895.4 41.9zM1894.8 42.3s.1.1 0 0c.4.2.4 0 .5-.3v-.1h-.1c-.1.1-.4.1-.4.4zM1816.2 41.8c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2.1-.1-.1-.3-.1-.3zM1906 43.1c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.2-.1-.2-.2zM1821.9 46s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.1.3-.2.4-.2.6zM1821 44c.1.1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c0 .1-.1.1-.1.2zM1797.3 33.7h.2c0-.1.1-.3.1-.4v-.1c.1 0 .1 0 .2-.1v-.2s-.1 0-.1.1l-.1.1c0-.1.1-.2 0-.2 0-.1-.2-.1-.3-.1l-.1.2c0 .1.1.2.2.3l-.3.3c.2 0 .2.1.2.1zM1810.4 39.3c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0-.1.1-.2.1-.2zM1834.1 43.5s.1.1.2.1v-.2h-.2v.1zM1825 43.8s0 .1 0 0c0 .1 0 .1.1.1l-.1-.1c.1.1 0 0 0 0zM1813.5 43.8c.1.1.1.3.2.4h.2v-.1c-.1-.1-.2-.2-.4-.3zM1869.6 41.9h.1c.2-.2 0-.4-.1-.5-.1.2-.2.3 0 .5zM1869.6 41.4c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM1820.7 40.3c-.1 0-.1-.1 0 0-.1 0-.1.1-.1.1s.1 0 .1.1c-.1-.1-.1-.2 0-.2zM1817.7 40.2zM1817.7 40.2c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1-.2-.1-.2-.1-.3 0zM1816.5 37.6v.7c.3-.3.1-.5 0-.7zM1807.1 34.2s.1 0 .1.1c0-.1.1-.1.1-.2 0 0-.1-.1-.1 0 0-.1 0 0-.1.1zM1798.6 32.2l-.1.1s0 .1.1.1v-.2c.1.1 0 0 0 0zM1827.8 43.9v.4c.1-.1.1-.2.2-.4-.1.1-.2 0-.2 0zM1868.8 41.3s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1v.1c-.1.1 0 .2.1.2zM1813.5 43.7c0 .1 0 .1 0 0 0 .1 0 0 0 0zM1813.4 43.4c0 .1-.1.1-.1.2s.1.1.1.2v-.2c.1-.1 0-.2 0-.2zM1911.9 39.2s.1 0 .1-.1c.1-.1.1-.1.1-.2-.1 0-.2 0-.2.1v.2zM1899.9 39.7h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2-.1-.1-.1 0-.1 0zM1900.1 39.4zM1797.5 36.3c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zM1797.2 36.4c.1 0 .2 0 .2-.1 0 0-.1 0-.2.1 0-.1 0 0 0 0zM1815.6 34.2V34c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2 0 0 0 .1.1.1zM1859.5 42.9c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM1889.9 39.9v-.1.1zM1842 41.4s0-.1.1-.1c-.1 0-.1 0-.1.1zM1842.1 41.3s0-.1 0 0c0-.1 0-.1 0 0zM1866.8 40.2c.1 0 .1-.1.2-.1-.1 0-.2 0-.2.1 0-.1 0-.1 0 0zM1797.8 29.3s.1 0 .1.1c.1 0 0 0-.1-.1.1 0 .1 0 0 0zM1916.6 30.2s-.1 0-.1.1-.1.1-.1.2c.1 0 .1-.1.2-.1v-.2zM1916.4 30.5zM1903.4 29.9c-.1 0-.1-.1-.2-.1l-.1.1h.3zM1895.7 30.2c.1 0 .2-.1.3-.1-.1-.1-.1-.2-.2-.3h-.4v.1l.3.3zM1812.8 34.2v.1h.1v-.1h-.1zM1893 29.5s0-.1.1-.1c-.1 0-.1 0-.1.1zM1845.7 39.4c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zM1888.3 31.3l.2.2c0-.1-.1-.1-.1-.2h-.1zM1910.2 37.7l-.2.2c.1 0 .1-.1.2-.1v-.1zM1914.7 33.5c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1l-.2-.2zM1850.1 26.8c0 .1 0 .1 0 0 0 .1 0 0 0 0zM1718.8 36.1zM1649.8 32.3s.1 0 0 0c.1 0 .1 0 0 0zM1662.6 35.9zM1635.2 34.3zM1809.6 29.9zM1702.8 37zM1808.2 27.9zM1722.8 36.2c.1 0 .1.1.2.1v.2s-.1 0-.1-.1c0 0-.1-.1-.1-.2-.3.1-.5.1-.8.2.1.4.2.7.3 1-.7.4-1.4 0-2 .3-.1.3 0 .6-.2.9-.2.3-.5.5-.7.8.2.3.3.6.5.9.1.2.3.3.5.3.3 0 .6-.3.7-.6 0-.1 0-.3.1-.4.2-1.1.6-1.4 1.7-1.4.2 0 .4.1.5.1.5 0 .8-.3.9-.8.1-.4.1-.8.2-1.2-.2-.1-.4-.3-.6-.4-.4-.1-.8 0-1.1.3zM1796.3 36.4c-.3 0-.5-.1-.8 0-1 .1-2 .1-2.9-.1-.7-.2-1.5-.3-2.3-.1-.2 0-.4 0-.4-.3.2-.1.5-.1.6-.2.4-.5.9-.4 1.3-.4.3 0 .5.1.8.1.3 0 .7.1 1.1-.3-.7-.2-1.2-.1-1.8-.1-.6 0-1.2-.1-1.7-.2-.6-.1-1.1-.1-1.7-.2-.3.3-.2.6 0 .9l.6.6c.2.5.6.6 1.1.7 1.2.1 2.3.3 3.5.2.7-.1 1.4.1 2.1.4.2-.2.4-.3.7-.5-.2-.3-.2-.4-.2-.5zM1639.9 30.1zM1638.8 30.1v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 .1.1.1.2.1 0 .4 0 .8-.2 1.2 0-.1-.1-.1-.1-.2 0 .1.1.1.1.2-.3.1-.5.2-.8.3.2.5.2.5-.3 1.3.3.1.6.1.9.2.5-.2.5-.2.7.2.1.2 0 .4.4.3v-.8c-.1-.5 0-.9.2-1.4.2-.4.2-.8.3-1.2-.1-.2-.3-.4-.4-.6-.4.1-.6.3-.8.5zM1664.7 39.4c-.2-.1-.3-.2-.5-.3-.2-.1-.5-.1-.5.1-.1.2 0 .5.1.6.1.2.4.2.6.4-.1.2-.2.3-.3.5-.1.4 0 .6.4.7.4-.3.3-1 .8-1.1.2.1.3.2.5.4.4-.5.4-1.2.3-1.8 0-.2-.3-.3-.4-.5-.2.4-.5.7-1 1zM1665.6 38.3zM1623.7 28.7s.1 0 0 0c.1 0 .1 0 0 0zM1622.7 31.7c-.1.1-.1.2-.2.3.2.3.4.5.6.8.4-.1.6-.5.8-.9.3.1.5.5.9.1-.2-.3-.3-.6-.5-.8l.3-.3c.1-.9-.6-1.4-.8-2.1-.1.1-.2.3-.1.4.2 1-.3 1.7-1 2.5zm1.2.1c-.1-.1-.2-.1-.3-.2 0-.1.1-.1.1-.2.1.2.1.3.2.4zM1666.6 37.1zM1665.2 35.8zM1665.2 35.8c-.3.1-.5.2-.8.3-.2.3-.3.6-.5.9l.6.9c.3.4.5.6 1 .5 0-.2-.1-.3-.1-.5.3 0 .5-.1.7-.1.3 0 .4-.3.5-.5-.2 0-.4 0-.4-.1-.4-.6-.7-1-1-1.4zM1702.7 38.2v-.6c-.3 0-.6 0-.9.1-.1 0-.1.1-.2.1 0 .2 0 .4.1.5l-.9.6c-1-.5-2-.4-3-.3-.3 0-.4.3-.3.6.4 0 .8 0 .9.6.1.3.3.3.6.1.1-.1.2-.3.4-.3.2-.1.5 0 .8 0 .3 0 .5-.1.8-.1 0-.2-.1-.3-.1-.5.2 0 .3.1.5.1.3 0 .7-.1 1 0 .4.1.6.4 1 .6.3-.4.6-.7.9-1-.4-.9-.8-.2-1.6-.5zM1771.9 38.3c-.3.7 0 1.1.1 1.6.5.3.8.5 1.3.8.1-.4.3-.7.4-1.1 0-.2-.1-.5-.2-.6-.4-.5-1-.8-1.6-.7zM1777.1 39.6c-.6-.1-1.3-.2-1.9-.3-.1 0-.2.3-.3.4.3.4.5.8.8 1.2.5-.2.8-.5 1.2-.7.1.3.2.4.3.7.2-.2.4-.2.4-.4.1-.1 0-.4-.1-.5 0-.1-.2-.3-.4-.4zM1691.4 38.7c-.2 0-.4.1-.6.2-.5.2-.9.2-1.2-.3-.1-.1-.2-.1-.4-.2 0 .2-.2.4-.1.5.2.4.4.8.7 1.2.4-.1.7-.2 1.1-.3.3.1.5.7 1 .3-.1-.2-.2-.5-.3-.7.1-.1.3-.2.5-.4-.3-.1-.5-.3-.7-.3zM1762.2 34c.1.4.5.5.8.2.5-.5.6-1.1.5-1.8-.3-.1-.7-.2-1-.2-.2.1-.4.2-.6.2.2.6.2 1.1.3 1.6zM1694.8 38.7c-.1-.1-.3 0-.4 0-.8.1-1.5-.2-2-.9h-.3c-.1.3.1.5.3.7.3.2.4.4.6.8.1.3.2.5.4.7.6-.2 1.1-.3 1.5-.5.1-.1.3-.3.3-.4-.1-.2-.3-.4-.4-.4zM1621.7 28.1c-.5 0-1 0-1.5.2.1.7.6.3.9.5-.1.4-.1.8-.1 1.2 0 .2.1.5.4.5.2-.3.1-.8.6-1 .1-.1.2-.3.3-.5.1-.5-.1-.8-.6-.9zM1777 36c.1 0 .4.1.3-.3-1.3-.1-2.7-.2-4.1-.3-.1-.2-.1-.4-.3-.9-.1.5-.2.7-.2.8 0 .2.2.4.3.4l.9.3c1 .1 2 0 3.1 0zM1659.6 40.9c-.2-.3-.3-.6-.1-.9l-.1-.3c-.1 0-.3.1-.3.1l-.6 2.7.2.2c.1-.3.3-.5.5-.9l1.2.6c.1-.1.1-.2.2-.3-.2-.2-.4-.4-.5-.6-.3-.1-.4-.3-.5-.6zM1647.2 34.6c-.1-.1-.2-.3-.2-.4-.2.3-.4.7-.9.7l-.9-.6c0 .4.1.8.4 1.1.4.3.5.8.5 1.4.1-.3.3-.5.4-.8.9.2.9.2 1.1-.7-.2-.2-.3-.5-.4-.7zM1646 36.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1647 34.2s0-.1 0 0zM1663.1 36.4c-.1-.2-.4-.3-.6-.5-.2.2-.3.6-.6.7-.6.3-.9.8-1.2 1.4.2-.1.5-.2.7-.3 1.1-.5 1.1-.5 2.3-.1.1-.2.1-.4.2-.6-.3-.1-.6-.3-.8-.6zM1656 39.7c-.2-.1-.6.1-.5.3.1.6 0 1.1-.1 1.6 0 .3.1.6.2 1.2.6-1.2.7-1.7.7-2.3.1-.4 0-.7-.3-.8z"/><path d="M1820.8 39.8c-.1.9-.4 1.7 0 2.5 0 0 .1.1.2.1v-.1c.1.2.3.3.4.5.1-.4 0-.6-.4-.6 0-.2.1-.4.1-.5.2 0 .3.1.5 0 .1-.1.4-.2.3-.3-.1-.7-.3-1.3-1.1-1.6zM1626.5 27.1c-.3 0-.6.3-.6.8s.3.8.8.8c.4 0 .7-.3.7-.7 0-.5-.5-.9-.9-.9zM1680.6 39.2c-.2 0-.4 0-.5.1-.1.1-.2.3-.2.5 0 .3.3.5.5.5.6.1 1.1-.1 1.7-.8-.4 0-.7-.1-.9-.1-.2.1-.4 0-.6-.2zM1800.3 36.6c-.6-.1-1.2-.1-1.8-.2l-.1-.1c-.1.3-.2.6-.3.8.2 0 .4.2.4.1s.1-.1.1-.2c.1 0 .2.1.3.1.9 0 1.8.1 2.7.1.1 0 .2-.1.4-.2-.2-.1-.3-.2-.4-.2-.5-.1-.9-.1-1.3-.2zM1683.5 39.6c-.4.9-.4.9.2 1.6.1.3-.3.7-.1 1.1.5-.4.7-1 .7-1.5.1-.6-.4-.8-.8-1.2zM1668.5 41c0-.3-.1-.5-.4-.4-.1.1-.3.4-.3.6 0 .3.1.6.3.8.3.3.4.7.5 1.3.2-.2.4-.2.4-.3.2-.4.1-.7-.2-1.1-.1-.3-.3-.6-.3-.9zM1766.1 36.3c-.2-.2-.5-.2-.7 0-.2.2-.4.5-.7.9.6.1.9.1 1.2.1.3 0 .5-.2.6-.4.1-.3-.2-.4-.4-.6zM1628.2 31h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8-.1.2-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.6 1.1.9 1.5zM1784.2 36.2c1.1.1 2.2.3 3.3.4.3 0 .5-.1.8-.2 0 0 .1-.2.1-.3-1.5.2-2.9-.4-4.2.1zM1658.9 36.2c-.1.4-.2.7-.3 1 .4.4.7.8 1 1.1.5-1 .5-1-.7-2.1zM1697.1 39.6c.1.6.4 1.1.7 1.6.5 0 .6-.3.6-.8-.3-.5-.8-.7-.9-1.3-.2.1-.4.3-.4.5zM1697.5 39.2zM1780 34.1c-.2.5-.3 1-.5 1.6-.3.1-.7.1-1 .2 1 .6 1.9.2 3.2.1-.7-.2-1-.3-1.3-.5-.2-.5-.3-.9-.4-1.4zM1664.8 42.8c0 .1.1.2.1.2.3.1.7.2.9-.1-.2-.6-.4-1.1-.6-1.8-.4.6-.4 1.2-.4 1.7zM1809.7 31.5c-.5.3-1 .5-1.5.7-.1.1-.1.3-.3.5.4-.1.6-.1.9-.1.2 0 .5.1.7.2-.1.1-.2.3-.3.4-.2-.1-.3-.2-.6-.3 0 .8.5 1 .9 1.4h.3c.1-.2.3-.5.4-.8-.2-.3-.4-.5-.7-.8.3-.4.5-.8.2-1.2zM1652.9 36.6c0 .6 0 1.2.1 1.9.5-.4.7-.6.8-.8.1-.6-.1-.9-.9-1.1zM1642.4 41.2v.8c-.2.3-.6.2-.6.7.5 0 1 0 1.5-.1-.1-.9-.2-.8-.9-1.4zM1796.8 39.2c1 .1 1.6.6 2.3.3.1 0 .1-.1.2-.2-.2-.2-.3-.4-.6-.7-.6.1-1.1.3-1.9.6zM1669.8 39.1c-.1 0-.3.1-.4.1 0 .6 0 1 .1 1.5v.3c.1.2.2.3.4.2 0-.3 0-.7.1-1.1.1-.2.2-.3.2-.5-.1-.2-.2-.4-.4-.5zm.1.9l.1.1c-.1 0-.1-.1-.1-.1zM1684.7 39.6c.4.7.4.7.7.5.2-.1.4-.3.7-.5-.1-.3-.3-.6-.4-1l-1 1zM1631.7 33.6zM1631.1 33.8c.3.6.7 1.1.7 1.8.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1l-.3-.9h-.6c-.1.1-.1.2-.1.2zM1629.8 36.5c-.1 0-.3.2-.3.4-.1.3-.1.7-.1 1 0 .2.2.3.5.6.2-.6.3-1 .4-1.4 0-.3-.2-.7-.5-.6zM1645.1 34.2zM1645 32.4s-.1-.3-.1-.4c-.2 0-.3 0-.5.1-.1 0-.1.2-.1.2 0 .4 0 .9.1 1.3.1.3.4.4.7.6-.1-.6-.6-1.2-.1-1.8zM1631.3 37.6h-.2v1.1c0 .4-.2.7-.2 1 .7 0 1-.2.9-.8-.2-.4-.4-.9-.5-1.3zM1626.5 38.3c.1 1.1.1 1.1.4 1.6.2-.5.3-.9.2-1.4 0-.3-.3-.4-.6-.2zM1643 38.3c-.1-.4-.1-.6-.2-.9v-.9c-.5.3-.8.5-.7 1 .1.5.3.8.9.8zM1666.6 41.1c.1.6.3 1.2.5 1.7 0 .1.1.1.3.1.1-.8-.1-1.5-.1-2.3-.5 0-.7.2-.7.5zM1816.7 40.1c-.1 0-.3 0-.4.1-.2.1-.3.4-.2.6.1.2.4.3.6.6l.1-.1.1.1c0-.1 0-.2.1-.2.1-.1.3-.3.3-.4.1-.4-.3-.7-.6-.7zM1637.7 34.1c0-.3-.2-.4-.4-.5-.3-.3-.6-.6-.9-1-.4.3-.4.7-.3 1.1.1.4.3.5.7.5 0 .1 0 .2-.1.3-.1.3.1.6.4.7.2.1.4-.1.5-.5.1-.2.1-.4.1-.6zM1628.1 28.1c.7-.7.6-1-.3-1.9.1.7-.2 1.3.3 1.9zM1791.6 31.9c-.2-.1-.5-.1-.6 0-.1.1-.2.4-.3.8.7-.1 1.2.1 1.6-.4-.3-.1-.5-.3-.7-.4zM1766.6 32.3c.2-.1.4-.3.6-.5.2-.4-.1-.6-.3-.8-.3.2-.6.5-.9.7.1.2.2.7.6.6zM1766.8 30.9zM1704.5 40.8c0 .1.2.2.3.2.6 0 .9-.4 1.2-1.1-.5.2-1 .2-1.4.4-.1.1-.1.4-.1.5zM1651.5 36.9c-.2.2-.3.4-.1.6.1.2.2.3.4.4 0 .1 0 .1.1.2v-.2c.2.1.3.1.5.2.2-.5 0-.8-.2-1.1-.3-.2-.5-.2-.7-.1zM1656.8 41.9c.1.3.2.4.2.5.3.5.5.5.8.1.2-.4.3-.8 0-1.4-.2.6-.4.9-1 .8zM1661.8 42.3c.2-.4.4-.7.6-1.1-.4-.3-.7-.5-1.1-.8 0 .7.3 1.2.5 1.9zM1798.5 35.9c.4.1.9.1 1.3-.2 0 0 0-.2.1-.4h-.3c.2-.8.2-1.6-.1-2.3-.3.5-.6.9-.8 1.4.4.4.6.7 1 .9h-.9s-.1 0-.1.1c-.7-.2-.8-.1-.9.4v.5c.3-.2.6-.4.9-.7-.4.2-.3.3-.2.3zM1627.5 36.3c.2.6.4 1.3.7 1.9.1.2.2.4.6.2-.2-.5-.4-1.1-.7-1.6-.1-.2-.4-.3-.6-.5zM1627.5 36.3zM1795.8 31.6c0 .1.1.2.2.4s.4.1.4 0c.2-.4.2-.8 0-1.4-.5.2-.6.5-.6 1zM1800.5 30.2zM1800.6 32.7c.4-.9.3-1.3-.1-2.5-.2 1.9-.2 1.9.1 2.5zM1728.1 39.1c-.1 0-.1.2-.2.3 0 .3 0 .5.1.7.1.1.3.2.4.2.3 0 .4-.2.4-.4-.1-.3-.2-.5-.4-.7 0-.1-.2-.2-.3-.1zM1716.6 39.6c-.2 0-.5.3-.5.7.1.1.3.3.5.4.3.1.5-.2.5-.5 0-.4-.2-.6-.5-.6zM1827.7 44.4c0-.1-.1-.1-.1-.1-.2-.1-.3-.2-.5-.2 0 .1.1.1.1.2-.2 0-.3.1-.2.2.1.1.2.1.3.1.4.7.7.8 1.4.8-.4-.3-.6-.7-1-1zM1625.2 35.8c-.1.5-.2 1-.4 1.6.3 0 .5.1.7 0 .1-.1.2-.3.2-.5-.1-.4-.1-.7-.5-1.1zM1761.6 31.1c0 .6.6.8.9 1.1.3-1.1.2-1.2-.9-1.1zM1626.4 33.3c-.3-.3-.6-.4-.9-.4-.1 0-.2.1-.5.3.4.1.6.2.8.3.2.1.4.3.6.4.2-.2.1-.4 0-.6zM1826.8 45.3c-.7-.1-.1.6-.4.7-.1 0-.1.1-.2.4h.9c.1-.6.2-1-.3-1.1zM1679.2 41.1c.2-.1.3-.3.3-.5-.1-.4-.3-.5-.9-.4.1.3.1.5.2.8 0 0 .2.1.4.1zM1770.8 34c-.1.2-.1.5-.2.9.4-.2.6-.2.8-.4.2-.2.2-.6-.1-.7-.1-.1-.4 0-.5.2zM1795.1 33c.1-.1.2-.1.2-.2 0-.3-.1-.6-.1-.8 0-.1-.2-.2-.3-.2-.1 0-.2.2-.2.3-.1.3 0 .6.2.8 0 .1.1.1.2.1zM1716.7 38.1c0-.1-.1-.2-.2-.3-.1-.1-.3-.1-.5-.2-.3-.1-.5.1-.5.2 0 .2.2.3.3.4.2.1.4.1.8.2 0 0 .1-.2.1-.3zM1678.9 42.1c0 .2.1.4.4.4.3 0 .4-.2.4-.4s-.2-.3-.4-.6c-.1.3-.3.4-.4.6zM1676.3 35.8c-.1 0-.2.1-.2.2 0 .4 0 .7.4 1.1.3-.5.2-.9 0-1.3h-.2zM1718.7 37.8c-.5 0-.7.2-.7.5v.1c.1.2.4.2.8-.1.1-.1.2-.2.1-.3 0-.1-.2-.2-.2-.2zM1651 41.3c.6.2.9.2 1.3-.2-.4-.3-.8-.3-1.3.2zM1766.3 34c-.5.4-.4.7-.3 1 0 .2.2.4.4.3.1 0 .2-.2.2-.3-.1-.3-.2-.6-.3-1zM1681.2 38.5c0-.2 0-.4-.1-.5 0-.1-.1-.1-.2-.1s-.2.1-.2.1c-.2.4-.2.8-.1 1.2.3-.1.6-.3.6-.7zM1632.6 36.9l.3.6c.2-.1.5-.2.7-.3-.4-.8-.5-.8-1-.3zM1702.8 37.5c.4-.1.7-.2 1.1-.3l.1-.2c0-.1-.2-.3-.2-.3-.3.1-.7.2-1 .2v.6zM1702.8 37zM1768.4 31.6v.1c.3.3.6.2 1-.1-.4-.3-.7-.3-1 0zM1662.2 39.5c.1.8.1.8.9.4-.3-.3-.5-.5-.9-.4zM1790.1 32.3c0-.2-.3-.4-.5-.2-.1.1-.2.2-.5.4.3.1.5.2.7.2.2 0 .3-.2.3-.4zM1656.6 36.6c-.1.1-.3.3-.3.4 0 .2.2.5.3.9.1-.5.3-.7.3-1 0 0-.2-.1-.3-.3zM1762.6 30.5c.3-.6.1-1.2.1-1.8-.4.7-.5 1.1-.1 1.8zM1641.1 33c-.2-.2-.5-.3-.7-.5-.1 0-.1.1-.2.1.1.2.1.4.2.6.2.2.7.1.7-.2zM1701.1 40.3c0 .3.1.6.1 1.1.6-.2.5-.6.4-1-.1-.3-.3-.3-.5-.1zM1671.4 41.5c.3-.4.2-.8 0-1.4-.4.6-.4.6 0 1.4zM1797.5 34c-.1 0-.1.2-.1.2.1.3.1.6.5.6.2-.3.1-.5-.1-.7-.1-.1-.3-.1-.3-.1zM1622.3 37.7v.8c0 .1.1.1.2.1s.2-.1.2-.1c0-.3.1-.6-.4-.8zM1781 34.8c.4.3.7.4 1.1.2-.4-.4-.7-.4-1.1-.2zM1777.2 34.7c-.3-.2-.4-.3-.6-.3-.1 0-.3.1-.3.1-.1.2.1.4.3.4.1 0 .2-.1.6-.2zM1625.6 39.9c-.2-.5-.4-.8-.7-1.4.1.9.1.9.7 1.4zM1655.8 37.4c0-.1-.1-.3-.2-.6-.2.2-.3.4-.4.5-.1.2 0 .4.2.4s.4-.2.4-.3zM1641.1 35.6c.3-.6.1-.9-.3-1.2 0 .4-.1.8.3 1.2zM1647.6 32.7c.1.3.1.6.2.9h.6c-.1-.6-.4-.8-.8-.9zM1647.8 33.6c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1822.9 41.4c-.1 0-.1 0 0 0-.1 0 0 0 0 0zM1822.8 40.5l-.2-.2c0-.1-.1-.2-.2-.2 0 0-.1.1-.2.1 0 .1.1.1.1.2l-.1.1c.1.3.3.6.5.9.2-.3.3-.6.1-.9zM1781 40.4c-.2 0-.4.1-.3.3 0 .1.2.2.4.3.1-.1.3-.2.3-.3 0-.2-.2-.3-.4-.3zM1709.9 40.2c-.1.2-.2.3-.2.4.1.1.2.3.4.3s.4-.2.3-.3c-.2-.2-.3-.3-.5-.4zM1654.2 42c0 .4.1.6.1 1 .5-.6.5-.7-.1-1zM1663.5 42.1c.2-.3 0-.5 0-.7l-.2-.1c-.1 0-.1.1-.1.2-.1.3 0 .6.3.6zM1708.1 38.3c-.1.1.1.3.3.3.1 0 .2-.1.4-.2-.3-.1-.4-.2-.5-.2 0-.1-.1 0-.2.1zM1647.7 42c-.1.2-.3.3-.4.5.1.1.2.2.3.2.2-.1.3-.3.4-.5 0 0 0-.2-.1-.2 0-.1-.2-.1-.2 0zM1638.9 42.2c-.2.2-.2.5 0 .6h.1s.1 0 .1-.1.1-.3.1-.4c0-.1-.1-.1-.1-.2-.1.1-.2.1-.2.1zM1682.6 41.3c-.1.2-.2.4-.2.6 0 .1.2.2.2.2.2 0 .3-.2.2-.4.1-.1 0-.2-.2-.4zM1779.5 39.4c-.1.4-.1.7.4 1 0-.4 0-.8-.4-1zM1823.6 39.7zM1626.7 37.5c.3-.3.3-.7.3-1.1-.2.2-.4.5-.5.7-.1.1-.1.3.2.4zM1632.5 38c.1.1.3.2.4.2 0-.2.1-.3.1-.5 0-.1-.1-.2-.1-.2h-.1c-.3.1-.5.2-.3.5zM1632.9 37.5zM1788.6 32.5c-.2-.3-.3-.5-.6-1 0 1.1 0 1.1.6 1zM1624 39.7c-.1 0-.2.1-.3.3.1.2.3.3.4.4.1-.1.2-.2.2-.3 0-.2-.1-.4-.3-.4zM1794.4 34.2c0-.1.1-.2.1-.2l-.4-.4-.2.2.4.4h.1zM1825.3 44.4c.1.1.2.2.3.2.1-.1.1-.2.2-.3-.1-.1-.2-.1-.3-.2-.1 0-.2.2-.2.3zM1636.3 36.8c.1 0 .1 0 0 0zM1635.9 36.1s-.1.1 0 0c-.2.5.2.5.4.7 0-.3.1-.6-.4-.7zM1626.5 35.9c.2.2.4.3.5.4h.5c-.2-.4-.5-.6-1-.4zM1627.5 36.3zM1627 36.3zM1788 38c-.1.2-.1.3-.2.5.1.1.1.2.2.2s.2-.1.2-.1c0-.2 0-.4-.1-.5 0-.1-.1-.1-.1-.1zM1636.3 35.3c-.1-.1-.1-.3-.2-.4 0 0-.1 0-.3.1.1.2.1.3.2.4 0 0 .2-.1.3-.1zM1633.5 35.1c-.1 0-.1.1-.2.2.1.1.1.2.2.3l.2-.1c.1-.2 0-.4-.2-.4zM1783 37.9c-.1 0-.2 0-.2.1-.1.1-.1.2-.2.3.1 0 .2.1.3.1.2 0 .3-.1.3-.4-.1 0-.2-.1-.2-.1zM1687 41.9l.2.2c.1-.2.2-.4.3-.5-.1 0-.2-.1-.2-.1-.1.1-.2.2-.3.4zM1649.2 42.1s-.1 0 0 0c0 .2 0 .4.1.6h.2c-.1-.2-.1-.3-.2-.5 0-.1 0-.1-.1-.1zM1646 42.3c.1.1.1.2.2.3 0 0 .1 0 .2-.1 0-.1-.1-.2-.1-.3 0 0-.1 0-.3.1zM1726.9 38.3c0 .1-.1.2-.1.3 0 .1.1.2.3.7.1-.4.1-.6.1-.7-.1-.2-.2-.2-.3-.3zM1675.5 39.8s0 .2-.1.2c.1 0 .3.1.3 0 .1-.1.2-.3.2-.4l-.1-.1c0 .1-.1.2-.3.3zM1647.9 41c-.1-.2-.2-.3-.2-.4-.1.1-.2.1-.3.3.2.1.3.2.4.3-.1 0 .1-.2.1-.2zM1645.6 41.1c.1.1.3.1.5.1.1 0 .2-.1.3-.2-.1 0-.2-.1-.3-.1-.3-.1-.6.1-.5.2zM1646.4 41zM1628.2 40.1s.1.1.3.1c0-.2.1-.3.1-.5 0 0-.1-.1-.2-.1-.1.2-.2.3-.2.5zM1639.5 38.8l.6.6c0-.5-.1-.7-.6-.6zM1767.1 33.4l.2-.1v-.4c-.1 0-.2.1-.4.1.1.2.1.3.2.4zM1782.1 31.9c-.1 0-.2.2-.3.3.1.1.2.2.3.2.1 0 .2-.2.2-.3.1-.1-.1-.3-.2-.2zM1824.7 46.1l.2.2c.1 0 .2-.1.2-.2-.1-.1-.2-.1-.3-.2 0 .1 0 .1-.1.2zM1680.3 51.6c.1 0 .1.1.2.1v-.2l-.1-.1c-.1 0-.1.1-.1.2zM1838.5 41.4h-.4c-.1 0-.1.2-.1.3.1 0 .2.1.2 0 .1 0 .1-.1.3-.3zM1807.9 39.9c.2-.1.3-.4 0-.5l-.4.4c.2 0 .4.1.4.1zM1807.5 39.7zM1663.3 43h.3s.1-.1.1-.2c-.1 0-.2-.1-.3 0 0 0-.1.1-.1.2zM1692.9 41.4c0 .1.1.3.1.3.1 0 .2-.1.3-.1-.1-.1-.1-.3-.1-.3-.1 0-.2.1-.3.1zM1677.3 41.3c0 .1-.1.2-.1.2 0 .1.1.2.2.3.1-.1.1-.2.1-.3l-.2-.2zM1651.2 42.7c.4-.3.4-.3.3-.7-.1.3-.2.4-.3.7zM1652.9 41.9c0 .1.1.2.2.3.1-.1.2-.1.2-.2-.1-.1-.1-.2-.2-.3 0 .1-.2.2-.2.2zM1725 39.2c.1 0 .1.1.3.1 0-.1.1-.2.1-.3l-.2-.1c-.1.1-.1.2-.2.3zM1714.1 38.6v-.1zM1713.5 38.9c0 .1.1.1 0 0 .4.2.4 0 .5-.3v-.1h-.1c-.2.1-.4.1-.4.4zM1641.7 40.9s0 .2.1.2c.2 0 .4 0 .6.1-.1-.1-.3-.3-.5-.4 0 0-.1 0-.2.1zM1642.4 41.2zM1787.7 35.1c-.3 0-.5-.1-.8-.1.3.3.5.3.8.1zM1799 32.8s0 .1 0 0c0 .1 0 .1 0 0zM1798.6 33.2l.3-.3c-.1 0-.2-.1-.3-.1-.1 0-.1.1-.2.1.1.1.2.2.2.3zM1634.9 38.5c-.1 0-.2.1-.3.2.1.1.1.2.2.3.1-.1.2-.1.2-.2s-.1-.3-.1-.3zM1635.5 37.4c0 .2-.1.3-.1.4 0 .1.1.1.2.2 0-.1.1-.2.1-.4l-.2-.2zM1638.5 34.4c-.1.7.4.9 1 1.3v-.8c-.1-.4-.5-.5-.8-.7.1-.4.1-.8-.2-1.2-.1.5-.4 1 0 1.4zM1822.9 42c-.2 0-.5.1-.9.1.5.4.7.2.9-.1zM1810.3 40.4c0 .1.1.1.1.2.1 0 .1-.1.2-.1 0 0 0-.1-.1-.1-.1-.1-.2-.1-.2 0zM1661 42.7c0 .1.1.1.1.2.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0 0-.1.1-.1.2zM1724.6 39.8c-.1.1-.1.2-.1.3 0 .1.2.1.2.2 0-.1.1-.2.1-.3 0-.1-.1-.1-.2-.2zM1640.6 42.6s.1.1.2.1l.1-.1c0-.1-.1-.2-.1-.6-.1.4-.2.5-.2.6zM1639.7 40.7c0 .1.1.1.1.2 0-.1.1-.1.1-.2s-.1-.1-.1-.2c-.1.1-.1.1-.1.2zM1682.8 38.2h.3c-.1-.1-.1-.2-.2-.3h-.2s-.1.1 0 .1c0 .1.1.2.1.2zM1698 37.2c-.1 0-.1 0-.2.1 0 .1.1.1.1.2l.2-.2-.1-.1zM1789.6 33.8s.1-.1.1-.2c-.1 0-.2-.1-.3-.1 0 0-.1.1-.1.2.1 0 .2.1.3.1zM1696.9 36.8c-.1 0-.2.1-.3.1l.2.2c.1 0 .2-.1.3-.2-.1 0-.2-.1-.2-.1zM1649.6 38.2c.1 0 .2.1.2.1s.1-.1.1-.2c-.1 0-.2-.1-.2-.1s0 .1-.1.2zM1646.8 38.3c.1.1.1.2.1.2l.2-.2v-.2c-.1.1-.2.1-.3.2zM1637.6 38.7c0 .1.1.1.2.2.1-.1.1-.2.2-.3-.1 0-.1-.1-.2-.1-.1.1-.2.1-.2.2zM1650.4 36.9c0 .1.1.1.1.2.1 0 .2-.1.2-.1 0-.1-.1-.1-.1-.2-.1 0-.1.1-.2.1zM1641.2 36.8s-.1.1-.2.1c.1.1.1.2.2.3.1-.1.2-.2.1-.2 0-.1 0-.2-.1-.2zM1629.1 35.9c-.1 0-.1-.1-.2-.1h-.2s-.1.2 0 .2.2.1.3.1c0 0 0-.1.1-.2 0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1656.9 41.2c-.1 0-.1 0-.1.1 0 0 .1 0 .1-.1 0 .1 0 0 0 0zM1688.3 38.6h.1c.2-.2 0-.4-.1-.5-.1.2-.3.3 0 .5zM1688.3 38.1zM1660.2 39.5c0-.1-.1-.1-.1-.2-.1 0-.1.1-.1.1 0 .1.1.1.1.2 0 0 .1 0 .1-.1z"/><path d="M1810.2 32.8c-.1 0-.2 0-.2.1l.1.1c.1-.1.1-.1.1-.2zM1699.2 37.1c0 .1-.1.2-.1.3.1-.1.2-.1.3-.2-.1-.1-.2-.1-.2-.1zM1699 37.4zM1637.7 37.1h-.2v.1s.1.1.2.1v-.2zM1644.6 36.9s.1 0 0 0c.1 0 .1 0 .1-.1 0 0 0-.1-.1.1 0-.1 0-.1 0 0zM1639.2 37c0 .1.1.1 0 0 .1 0 .1 0 .1-.1h-.1v.1zM1636.4 36.8zM1636.4 36.8c.1.1.1.2.2.2s.2.1.2.1l.1-.2c0-.1-.1-.1-.2-.1h-.3zM1810.4 29.9c0-.1 0 0 0 0zM1809.6 29.9zM1809.6 29.9c.3.2.5.1.8 0-.3-.2-.6-.1-.8 0zM1643.5 35.7l.1.1c0-.1 0-.1-.1-.1 0-.1 0-.1 0 0zM1635.2 34.3v.7c.3-.4.1-.5 0-.7zM1807.7 28s0 .2.1.2h.2c.1 0 .1-.1.1-.2-.1 0-.1-.1-.2-.1 0 0-.1 0-.2.1zM1808.2 27.9zM1640.7 34.2h-.2s0 .1.1.1.1.1.2.1c0-.1 0-.2-.1-.2zM1640.8 34.4zM1623.1 32.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1623 33.3c.1-.1.2-.1.2-.2s0-.2-.1-.4c-.1.1-.1.2-.2.3 0 .1.1.2.1.3zM1625.9 30.6c0 .1-.1.1-.1.2 0 0 .1 0 .1.1 0-.1.1-.1.1-.2 0 0 0-.1-.1-.1zM1821.7 42.9v.1l.1-.1c.1-.1 0-.1-.1 0 .1-.1 0-.1 0 0zM1816.6 42.1v.1h.2v-.1h-.2zM1813.6 40.5c0-.1-.1-.1-.1-.2h-.1c0 .1.1.1.2.2-.1 0 0 0 0 0zM1659.6 42.9s.1.1.1 0v-.1h-.1v.1zM1840.8 34.2zM1841.1 34.4c-.1-.1-.1-.1 0 0-.1-.1-.2-.1-.3-.2 0 .1 0 .1.1.2h.2zM1646.4 41c.1-.1.1-.2.2-.4-.1 0-.1 0-.2-.1v.5zM1661.3 39.6c0 .1 0 .1 0 0 0 .1 0 .1.1.1-.1 0 0 0-.1-.1.1 0 0 0 0 0zM1718.5 36.4h.2c0-.1 0-.2.1-.2-.1 0-.1.1-.2.2 0-.1 0-.1-.1 0zM1718.8 36.1zM1655 38.4c.1.1.1.1.2 0v-.1c-.1 0-.2 0-.2.1zM1764.7 33.5c0 .1 0 .1 0 0zM1765 33.2h-.2c0 .1 0 .1-.1.2.1 0 .1-.1.2-.2 0 .1 0 .1.1 0zM1633.8 33.5zM1633.5 33.2v.2c.1 0 .1 0 .2.1 0-.1-.1-.1-.1-.2l-.1-.1zM1624.1 32.9c0-.1 0-.1 0 0-.1-.1-.1 0-.1 0h.1zM1771.9 26.4l-.2-.2c0 .1.1.1.1.2h.1zM1634.2 30.8v-.2c-.1 0-.1 0-.2-.1 0 .1.1.1.1.2l.1.1zM1619.8 29.7l-.1-.1v.1zM1628.1 24.5zM1627.9 24.8h.2c0-.1 0-.2.1-.2l-.2.2c-.1-.1-.1 0-.1 0zM1822.9 41.4v.5c.2-.1.1-.3 0-.5zM1837.4 41v.1c-.1 0-.1 0 0-.1 0 .1 0 0 0 0zM1823.5 39c-.2.2-.1.4.1.6 0-.2 0-.3.1-.5-.1 0-.2 0-.2-.1zM1774.8 39.9c0-.1 0-.1.1-.2l-.1.1v.1zM1678.2 39.6c0-.1-.1-.3-.2-.6-.2.3-.3.5-.5.6-.2.1-.4.2-.5.4-.1.1-.1.2-.1.3.7.2 1-.2 1.3-.7l.3.6-.3-.6zM1778.4 35.9h.1-.1zM1699 37.4zM1698.9 37.5l.1-.1s-.1 0-.1.1c0-.1 0 0 0 0zM1708.6 36.6v-.1.1zM1780.1 34v.1c-.1 0-.1-.1 0-.1zM1660.7 38.1s0-.1.1-.1c-.1 0-.1 0-.1.1 0-.1 0 0 0 0zM1660.7 38s.1-.1 0 0c.1-.1.1-.1 0 0 .1-.1.1-.1 0 0 0-.1 0 0 0 0zM1799 32.8s.1 0 .1-.1l-.1.1zM1685.4 36.8c.1 0 .1-.1.2-.1 0 0-.1 0-.2.1.1 0 .1 0 0 0zM1646 36.8zM1645.9 37c0-.1 0-.1.1-.2l-.1.1v.1zM1658.2 36.4v-.1h-.1zM1647 34.2c0-.1 0-.1 0 0 0-.1 0-.1 0 0zM1646.9 34l.1.1s-.1 0-.1-.1zM1647.8 33.6l-.1.1c0-.1 0-.1.1-.1zM1634.1 33.5h-.2c0 .2.1.2.2 0zM1634.1 33.5zM1762.7 28.7c0 .1 0 .1 0 0 0 .1 0 .1 0 0zM1762.8 28.6c0 .1 0 .1-.1.2l.1-.1v-.1zM1735.3 26.9c-.1 0-.1 0 0 0-.1.1-.2.2-.2.3.1 0 .1-.1.2-.1v-.2zM1735.1 27.2c-.1 0 0 0 0 0zM1778.7 25.8l-.1-.1s.1 0 .1.1c0-.1 0-.1 0 0zM1631.6 30.9h-.1v.1h.1v-.1zM1754.2 32.1c0-.1 0-.1.1-.2-.1.1-.1.1-.1.2-.1-.1 0 0 0 0zM1711.6 26.2s0-.1.1-.1l-.1.1c0-.1 0 0 0 0zM1664.2 35.9l.2.2c0-.1-.1-.1-.1-.2s0 0-.1 0zM1664.4 36c0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0zM1707 28l.2.2c0-.1-.1-.1-.1-.2h-.1zM1752.2 31.1l-.1.1c0-.1 0-.1.1-.1zM1733.4 30.2c-.1 0-.2-.1-.2 0 0 0-.1.2 0 .2 0 .1.1.1.2.1s.2-.1.2-.1c-.1-.1-.1-.2-.2-.2zM1668.8 23.5c-.1 0-.1 0 0 0z"/><path d="M1921.2 1.1H1.2v12.1c0 .6.1 1.2.3 1.8.3 1.2.5 2.5.7 3.8.1.5.1 1.1 0 1.6-.1.6.3 1 .4 1.5 0 .9 0 1.8.1 2.7 0 .1.1.2.1.2.4 0 .8.1.7.7-.4.1-.7.3-1.2.4.3.2.5.4.7.5.2 0 .5-.1.7-.2.3.4 0 .9.4 1.2.1-.1.2-.1.2-.2 0-.8.2-1.5.3-2.2.1-.4.3-.6.5-.6.6 0 1.3-.4 1.8.3 0 0 .3-.1.5-.2.1.4.2.7.2 1 0 .4-.3.9.2 1.2.1.1.1.4 0 .5-.1.5-.2.9-.3 1.4 1-.2 1.2-.1 1.3.9 0 .3-.1.6.2.7.4-.2.4-.2.7-1-.7-1.1-1-2.5-1.1-4 .6-.4 1.1-.8 1.7-1.2.4.1.8.1 1.2.2.1 0 .2.2.2.3h.3c.2.6.6.4 1 .2 0 .4.1.8-.1 1.2-.1.4.1.9.1 1.4 0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.4.6.1 1.2.2 1.8.1.8-.1 1.4-.8 1.8l-.3.3.3.9c-.4.1-.8.2-1.1-.2.4-.6.2-1.2-.2-1.8-.3 0-.5.2-.5.5-.1.7 0 1.4.3 2.1.2.4.6.7 1.1.6.2 0 .4-.1.6-.2.3.7.1 1.4 0 2 .6 0 1.3.1 1.9-.3-.1-.3-.2-.6-.3-1-.2.1-.6.2-.6.4v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2.1-.2l-.3-1.2c.3-.6.3-1.2-.2-1.8.2-.4.3-.8.5-1.4.2.3.3.5.5.8.3.1.4-.1.5-.3.1-.3.4-.4.7-.5-.1.4-.1.9 0 1.3.1.5 0 1-.4 1.2-.9.4-.8 1.1-.7 1.8.6-.2.4-1 1-1.3.6.2 1.2.4 1.4 1.2.2.1.3.1.5.2-.2.3-.3.6-.4.9-.1.2-.1.5.2.6.3-.3.5-.6.8-.9.2-.6-.3-.9-.4-1.3.1-.4.2-.6.3-.9-.2-.2-.4-.4-.6-.4-.3 0-.7.2-1 .3 0-.7-.1-1.3-.1-1.9.2.2.4.4.6.5.4-.5 1.1 0 1.7-.4-.3-.4-.6-.7-.8-1v-.3c.4-.3.4-.3.9-.3.2.6.5 1.2.7 1.8-.1.1-.2.2-.2.3l-.3.3c-.1.2-.1.4-.1.5 0 .2.2.3.3.4.6-.4.7-1.2 1.4-1.5.1 0 .2-.2.2-.3 0-.4.1-.7.1-1.4-.5 1-1 .5-1.5.5-.1-.4.2-.4.4-.5.2-.1.3-.2.4-.3.1-.2.2-.4.3-.7.4.3.7.6 1.1.9.4-.2.7-.4 1.1-.5.1.5.3 1 .4 1.5 0 .2-.1.3-.2.5.6 0 1 .4 1.4.8.4.3.8.6 1.3.6.1.7-.6.5-.9.9.4.7.6 1.3.4 2.1-.1.3-.1.6.2.8.1.1.3.2.4.2.3-.1.3-.3.3-.6-.1-.3-.2-.5-.4-.7.2-.3.6-.7.7-1 0-1.1.5-2.2.1-3.4.6.6 1.2.8 2 .8.6 0 1.2.1 1.6.6.3-.1.6-.2.9-.2 0 .2.1.4.1.5.6.2.7.9 1.1 1.3.2-.2.5-.3.7-.4-.1-.4-.3-.8-.4-1.2 0-.2.1-.5.2-.6.1-.1.4 0 .6.1.5.2.2.8.5 1.2.5-.1.5-.6.7-.9.2-.4.6-.4.8 0 .2.3.3.8.7.9 0 .3-.1.6-.1 1-.2 0-.4.1-.6.1.1.2.1.4.2.7-.5.3-1.2-.1-1.5.5-.1.4-.2.2-.4 0h.3v-.5c.2-.8.4-.9 1.2-.7 0-.4-.1-.7-.1-1.2-.3.2-.5.3-.7.4-.3.1-.6.2-.9.2-.2 0-.5-.1-.7-.1.4.5.6 1 .6 1.7-.4 0-.8 0-1.1.4-.1.2-.3.3-.4.1v-.8c-.4.3-.8.5-1 .8-.2.2-.2.5-.4.7.2.3.4.5.6.8.2.2.3.5.5.7.1.2.3.4.6.1v-.7c0-.2.1-.5.1-.7 1.1.5 1.3.5 2.2.4.8-.1 1.5-.3 2.3-.3 1 0 1.9-.2 2.9-.2.6 0 1.3 0 2-.3.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1l.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1V35c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3.4.7.4.8.5.8 0 0 .1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.2.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6.1 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2 0 0 .1 0 .1.1s-.1.2-.1.3c0 .1.1.2.1.2-.2.1-.4.2-.7.4h.8c.2.4.4.7.9.9.1-.1.2-.3.2-.4 0-.1-.1-.3-.1-.4.2.1.5.1.7.2 0-.3.1-.6.1-.9.4.2.4.2.4.7.3 0 .6.1 1 .1 0 .2 0 .4.2.5.1-.1.2-.1.2-.2v-.3c.6 0 1.2.1 1.7.2 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1 .4-1.4 1.1-1.5-.1.3-.1.7-.2 1l-.1-.1v.4c-.1.1-.1.2-.1.3.3 1.1-.2 1.9-.9 2.6-.1.1-.1.2-.2.3.1.1.2.3.3.4-.1.1-.2.1-.3.2 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.4-.1.9-.2 1.3-.4-.1.3-.1.5-.2.8.3 0 .5.1.7 0 .1-.1.2-.3.2-.5s-.1-.3-.1-.5h.6c-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.5c0 .1.1.3.2.4.2.4.6.7 1.1.6.2 0 .4-.1.6-.2v.1c-.2 0-.4.1-.6.2v.4c.1.2.5.4.8.3 0 .4-.1.7-.1 1 .6 0 1.3.1 1.9-.3-.1-.2-.1-.4-.2-.6.2-.1.5-.3.7-.5.2.3.3.7.3 1.1.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1-.1-.3-.2-.5-.3-.8.2.1.3.3.4.6l.3.6c.9-.1 1.6-.3 2.2-1-.1.3-.3.5-.3.7-.1.2-.1.5.2.6h.1c.2-.2.6-.2.7-.8h-.1l.1-.1v-.3c.2 0 .5.1.7.1.1.3.1.6.2.8.1.3.4.5.7.3.1 0 .1-.1.2-.2l.1.1c.2.1.4-.1.5-.5 0-.2.1-.4.1-.6v-.1c.3 0 .6.2.8.6 0 0 0 .1.1.1 0 .1.1.3.2.4l.1.1c0 .1.1.1.1.2 0-.1 0-.1.1-.2.1.1.3.2.5.3V38c-.1-.2-.2-.4-.4-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.2-.2.3-.2.5-.3v0c.3-.1.7 0 1 .2.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5 0 .1-.1.2-.2.3v-.1h-.1v.1c-.1.1-.1.1-.2.1-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.1 0-.2 0-.3.1-.1-.2-.1-.4-.1-.6v-.2c.1 0 .1-.1.1-.2 0-.2-.1-.3-.2-.4v-.1c-.1-.1-.3-.1-.4-.2 0 .1.1.2.1.4-.3.2-.4.4-.4.8.1.3.2.6.5.7-.2.2-.3.4-.4.7v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.2.4-.4.9-.5 1.4h-.1c-.1.2-.3.3-.4.5.1.1.2.2.3.2.1 0 .1-.1.2-.2 0 .4.4.8.8.7.3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.1 0 .1.1.2.1-.1.1-.1.3-.3.5.3-.2.4-.3.4-.5.2.1.5.2.6.3.3-.2.6-.3.8-.5 0 .1.1.1.1.2.1-.1.2-.1.2-.2l-.1-.1c.2-.7-.3-1.2-.8-1.9h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.1-.2-.2-.2-.3 0-.1.1-.1.1-.2s-.1-.3-.2-.6c-.1.1-.1.2-.2.2 0-.1.1-.3.2-.3.9-.1 1.4-.9 2.2-1.1v-.1c.3 0 .6-.1.9-.2.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1 0 .1.1.2.1.2h.3c-.1-.1-.1-.2-.2-.3h-.2c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6 0 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1V33c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2.1 0 .2.2.4.4-.4.2-.6.3-1 .6h1.4c.4 0 .7.2 1.1.3 0-.3.1-.6.1-.9.4.2.4.2.4.7 1 .1 2.1.2 3.1.3 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1.2.5-1.6 1.6-1.5.4 0 .7.1 1.1 0 .4-.2.8-.2 1.3-.1.2.1.4 0 .4-.4-1-.3-1.2-1.1-1.2-2.1 0-.5.2-.9.7-1 0 .3.1.5.1.7.2 0 .3 0 .4.2.2.7.3 1.4 1 1.7.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.4-.2.8-.2 1.1.1.4.3.4.7.3 1.1l.9.3.4-.4c.3.4.5.8.8 1.2.2.3.6.3.9.2-.1.4-.1.8-.2 1.2-.7.1-1.2.2-1.8.3-.6.1-1.1 0-1.7.2.4.7.4.7-.1 1.8-1.4.4-2.9.2-4.3.1-.7.7-.7.7-1.5.7-.4 0-.9-.1-1.3.4 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.5-.1 1-.2 1.5-.4.4-.2.7-.2 1-.1-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.6c1 .4 1.9.3 2.9.2h.7c.6 0 1 .2 1.2.9l.3.6c.9-.1 1.6-.3 2.2-1 .5.1 1 .2 1.4.3.1.3.1.6.2.8.1.3.4.5.7.3.2-.1.3-.3.4-.5.1-.2 0-.4 0-.7.6-.1 1 0 1.3.6l.3.6c0 .1.1.1.1.2 0-.1.1-.1.1-.2.2-.1.3-.2.2-.4-.1-.1-.3-.2-.1-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.5-.5 1-.5 1.6-.1.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5-.1.2-.2.4-.4.5-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.7 0-.8.5-1 1v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.3.5-.5 1.1-.6 1.7-.1.5.3 1.1.8 1 .3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.3.1.7.3 1 .4.4-.2.7-.4 1-.6.3-.8-.3-1.3-.8-2h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.2-.3-.3-.4-.5-.1-.2-.1-.6.1-.6.9-.1 1.4-.9 2.2-1.1 0-.7 0-1.2-.2-1.8-.2-.3 0-.5.3-.6.1-.3.2-.6.1-.8-.3-.7.1-1.4 0-2.1.4-.1.7-.2 1-.2.2.3.3.5.4.7.1-.5.4-1.1.3-1.6V35c.3-.1.5-.3.4-.8-.1 0-.2-.1-.2-.1.2-.4.5-.7.9-1l.2-.2c-.1-.1-.3-.2-.4-.3-.2-.2-.2-.5-.2-.7v-.1-.3c0-.1 0-.1.1-.2.2-.4.2-.8-.2-1.2-.1.2-.2.4-.4.6-.4-.2-.3-.5-.2-.8.1-.5.3-1 .5-1.4-.3-.3-.7-.5-.9-.8-.3-.4-.9-.7-.1-1.2.1-.1 0-.4.1-.5 0-.1.1-.1.1-.2l.3.3v1.1c0 .2 0 .4.3.3.1-.7.1-1 .1-1.4.2 0 .4-.1.6-.2.3.4 0 .9.4 1.2.1-.1.2-.1.2-.2 0-.8.2-1.5.3-2.2.1-.4.3-.6.5-.6.6 0 1.3-.4 1.8.3 0 0 .3-.1.5-.2.1.4.2.7.2 1 0 .4-.3.9.2 1.2.1.1.1.4 0 .5-.1.5-.2.9-.3 1.4 1-.2 1.2-.1 1.3.9 0 .3-.1.6.2.7.5-.3.5-.3.8-1.1-.7-1.1-1-2.5-1.1-4 .6-.4 1.1-.8 1.7-1.2.4.1.8.1 1.2.2.1 0 .2.2.2.3h.3c.2.6.6.4 1 .2 0 .4.1.8-.1 1.2-.1.4.1.9.1 1.4 0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.4.6.1 1.2.2 1.8.1.8-.1 1.4-.8 1.8l-.3.3.3.9c-.4.1-.8.2-1.1-.2.4-.6.2-1.2-.2-1.8-.3 0-.5.2-.5.5-.1.7 0 1.4.3 2.1.2.4.6.7 1.1.6.2 0 .4-.1.6-.2.3.7.1 1.4 0 2 .6 0 1.3.1 1.9-.3-.1-.3-.2-.6-.3-1-.2.1-.6.2-.6.4v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2.1-.2l-.3-1.2c.3-.6.3-1.2-.2-1.8.2-.4.3-.8.5-1.4.2.3.3.5.5.8.3.1.4-.1.5-.3.1-.3.4-.4.7-.5-.1.4-.1.9 0 1.3.1.5 0 1-.4 1.2-.9.4-.8 1.1-.7 1.8.6-.2.4-1 1-1.3.6.2 1.2.4 1.4 1.2.2.1.3.1.5.2-.2.3-.3.6-.4.9-.1.2-.1.5.2.6.3-.3.5-.6.8-.9.2-.6-.3-.9-.4-1.3.1-.4.2-.6.3-.9-.2-.2-.4-.4-.6-.4-.3 0-.7.2-1 .3 0-.7-.1-1.3-.1-1.9.2.2.4.4.6.5.4-.5 1.1 0 1.7-.4-.3-.4-.6-.7-.8-1v-.3c.4-.3.4-.3.9-.3.2.6.5 1.2.7 1.8-.1.1-.2.2-.2.3l-.3.3c-.1.2-.1.4-.1.5 0 .2.2.3.3.4.6-.4.7-1.2 1.4-1.5.1 0 .2-.2.2-.3 0-.4.1-.7.1-1.4-.5 1-1 .5-1.5.5-.1-.4.2-.4.4-.5.2-.1.3-.2.4-.3.1-.2.2-.4.3-.7.4.3.7.6 1.1.9.4-.2.7-.4 1.1-.5.1.5.3 1 .4 1.5 0 .2-.1.3-.2.5.6 0 1 .4 1.4.8.4.3.8.6 1.3.6.1.7-.6.5-.9.9.4.7.6 1.3.4 2.1-.1.3-.1.6.2.8.1.1.3.2.4.2.3-.1.3-.3.3-.6-.1-.3-.2-.5-.4-.7.2-.3.6-.7.7-1 0-1.1.5-2.2.1-3.4.6.6 1.2.8 2 .8.6 0 1.2.1 1.6.6.3-.1.6-.2.9-.2 0 .2.1.4.1.5.6.2.7.9 1.1 1.3.2-.2.5-.3.7-.4-.1-.4-.3-.8-.4-1.2 0-.2.1-.5.2-.6.1-.1.4 0 .6.1.5.2.2.8.5 1.2.5-.1.5-.6.7-.9.2-.4.6-.4.8 0 .2.3.3.8.7.9 0 .3-.1.6-.1 1-.2 0-.4.1-.6.1.1.2.1.4.2.7-.5.3-1.2-.1-1.5.5-.1.4-.2.2-.4 0h.3v-.5c.2-.8.4-.9 1.2-.7 0-.4-.1-.7-.1-1.2-.3.2-.5.3-.7.4-.3.1-.6.2-.9.2-.2 0-.5-.1-.7-.1.4.5.6 1 .6 1.7-.4 0-.8 0-1.1.4-.1.2-.3.3-.4.1v-.8c-.4.3-.8.5-1 .8-.2.2-.2.5-.4.7.2.3.4.5.6.8.2.2.3.5.5.7.1.2.3.4.6.1v-.7c0-.2.1-.5.1-.7 1.1.5 1.3.5 2.2.4.8-.1 1.5-.3 2.3-.3 1 0 1.9-.2 2.9-.2.6 0 1.3 0 2-.3.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1l.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.2.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6.1 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2 0 0 .1 0 .1.1s-.1.2-.1.3c0 .1.1.2.1.2-.2.1-.4.2-.7.4h.8c.2.4.4.7.9.9.1-.1.2-.3.2-.4 0-.1-.1-.3-.1-.4.2.1.5.1.7.2 0-.3.1-.6.1-.9.4.2.4.2.4.7.3 0 .6.1 1 .1 0 .2 0 .4.2.5.1-.1.2-.1.2-.2v-.3c.6 0 1.2.1 1.7.2 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1 .4-1.4 1.1-1.5-.1.3-.1.7-.2 1l-.1-.1v.4c-.1.1-.1.2-.1.3.3 1.1-.2 1.9-.9 2.6-.1.1-.1.2-.2.3.1.1.2.3.3.4-.1.1-.2.1-.3.2 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.4-.1.9-.2 1.3-.4-.1.3-.1.5-.2.8.3 0 .5.1.7 0 .1-.1.2-.3.2-.5s-.1-.3-.1-.5h.6c-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.5c0 .1.1.3.2.4.2.4.6.7 1.1.6.2 0 .4-.1.6-.2v.1c-.2 0-.4.1-.6.2v.4c.1.2.5.4.8.3 0 .4-.1.7-.1 1 .6 0 1.3.1 1.9-.3-.1-.2-.1-.4-.2-.6.2-.1.5-.3.7-.5.2.3.3.7.3 1.1.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1-.1-.3-.2-.5-.3-.8.2.1.3.3.4.6l.3.6c.9-.1 1.6-.3 2.2-1-.1.3-.3.5-.3.7-.1.2-.1.5.2.6h.1c.2-.2.6-.2.7-.8h-.1l.1-.1v-.3c.2 0 .5.1.7.1.1.3.1.6.2.8.1.3.4.5.7.3.1 0 .1-.1.2-.2l.1.1c.2.1.4-.1.5-.5 0-.2.1-.4.1-.6v-.1c.3 0 .6.2.8.6 0 0 0 .1.1.1 0 .1.1.3.2.4l.1.1c0 .1.1.1.1.2 0-.1 0-.1.1-.2.1.1.3.2.5.3V37c-.1-.2-.2-.4-.4-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.2-.2.3-.2.5-.3v0c.3-.1.7 0 1 .2.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5 0 .1-.1.2-.2.3v-.1h-.1v.1c-.1.1-.1.1-.2.1-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.1 0-.2 0-.3.1-.1-.2-.1-.4-.1-.6v-.2c.1 0 .1-.1.1-.2 0-.2-.1-.3-.2-.4v-.1c-.1-.1-.3-.1-.4-.2 0 .1.1.2.1.4-.3.2-.4.4-.4.8.1.3.2.6.5.7-.2.2-.3.4-.4.7v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.2.4-.4.9-.5 1.4h-.1c-.1.2-.3.3-.4.5.1.1.2.2.3.2.1 0 .1-.1.2-.2 0 .4.4.8.8.7.3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.1 0 .1.1.2.1-.1.1-.1.3-.3.5.3-.2.4-.3.4-.5.2.1.5.2.6.3.3-.2.6-.3.8-.5 0 .1.1.1.1.2.1-.1.2-.1.2-.2l-.1-.1c.2-.7-.3-1.2-.8-1.9h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.1-.2-.2-.2-.3 0-.1.1-.1.1-.2s-.1-.3-.2-.6c-.1.1-.1.2-.2.2 0-.1.1-.3.2-.3.9-.1 1.4-.9 2.2-1.1v-.1c.3 0 .6-.1.9-.2.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1 0 .1.1.2.1.2h.3c-.1-.1-.1-.2-.2-.3h-.2v.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3v-.1c.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6 0 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1V32c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2.1 0 .2.2.4.4-.4.2-.6.3-1 .6h1.4c.4 0 .7.2 1.1.3 0-.3.1-.6.1-.9.4.2.4.2.4.7 1 .1 2.1.2 3.1.3 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1.2.5-1.6 1.6-1.5.4 0 .7.1 1.1 0 .4-.2.8-.2 1.3-.1.2.1.4 0 .4-.4-1-.3-1.2-1.1-1.2-2.1 0-.5.2-.9.7-1 0 .3.1.5.1.7.2 0 .3 0 .4.2.2.7.3 1.4 1 1.7.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.4-.2.8-.2 1.1.1.4.3.4.7.3 1.1l.9.3.4-.4c.3.4.5.8.8 1.2.2.3.6.3.9.2-.1.4-.1.8-.2 1.2-.7.1-1.2.2-1.8.3-.6.1-1.1 0-1.7.2.4.7.4.7-.1 1.8-1.4.4-2.9.2-4.3.1-.7.7-.7.7-1.5.7-.4 0-.9-.1-1.3.4 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.5-.1 1-.2 1.5-.4.4-.2.7-.2 1-.1-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.6c1 .4 1.9.3 2.9.2h.7c.6 0 1 .2 1.2.9l.3.6c.9-.1 1.6-.3 2.2-1 .5.1 1 .2 1.4.3.1.3.1.6.2.8.1.3.4.5.7.3.2-.1.3-.3.4-.5.1-.2 0-.4 0-.7.6-.1 1 0 1.3.6l.3.6c0 .1.1.1.1.2 0-.1.1-.1.1-.2.2-.1.3-.2.2-.4-.1-.1-.3-.2-.1-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.5-.5 1-.5 1.6-.1.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5-.1.2-.2.4-.4.5-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.7 0-.8.5-1 1v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.3.5-.5 1.1-.6 1.7-.1.5.3 1.1.8 1 .3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.3.1.7.3 1 .4.4-.2.7-.4 1-.6.3-.8-.3-1.3-.8-2h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.2-.3-.3-.4-.5-.1-.2-.1-.6.1-.6.9-.1 1.4-.9 2.2-1.1 0-.7 0-1.2-.2-1.8-.2-.3 0-.5.3-.6.1-.3.2-.6.1-.8-.3-.7.1-1.4 0-2.1.4-.1.7-.2 1-.2.2.3.3.5.4.7.1-.5.4-1.1.3-1.6-.2-1.1.3-1.7 1-2.2l.2-.2c-.1-.1-.3-.2-.4-.3-.3-.4-.3-.8-.1-1.3.2-.4.2-.8-.2-1.2-.1.2-.2.4-.4.6-.4-.2-.3-.5-.2-.8.1-.5.3-1 .5-1.4-.3-.3-.7-.5-.9-.8-.3-.4-.9-.7-.1-1.2.1-.1 0-.4.1-.5.1-.3.3-.5.4-.8.1-.3.2-.6.2-.9-.1-.8-.2-1.6-.4-2.4-.1-.5-.1-1.1-.2-1.6.3-.1.6-.1.9-.2.4-.1.8-.5 1-.9.2-.4.1-.7-.2-1-.1-.1-.1-.3 0-.4.3-.5.2-1.2.3-1.8v-.3c-.1 0-.1.1-.2.1-.3 0-.5-.1-.6-.4 0-.5 0-.9-.1-1.4 0 0-.1 0-.1-.1s-.1-.3-.1-.3c.2-.1.3.1.3.2l1.5-.3c0 .4.1.9.2 1.3.3 1.2.5 2.5.7 3.8.1.5.1 1.1 0 1.6-.1.6.3 1 .4 1.5 0 .9 0 1.8.1 2.7 0 .1.1.2.1.2.4 0 .8.1.7.7-.4.1-.7.3-1.2.4.3.2.5.4.7.5.2 0 .5-.1.7-.2.3.4 0 .9.4 1.2.1-.1.2-.1.2-.2 0-.8.2-1.5.3-2.2.1-.4.3-.6.5-.6.6 0 1.3-.4 1.8.3 0 0 .3-.1.5-.2.1.4.2.7.2 1 0 .4-.3.9.2 1.2.1.1.1.4 0 .5-.1.5-.2.9-.3 1.4 1-.2 1.2-.1 1.3.9 0 .3-.1.6.2.7.5-.3.5-.3.8-1.1-.7-1.1-1-2.5-1.1-4 .6-.4 1.1-.8 1.7-1.2.4.1.8.1 1.2.2.1 0 .2.2.2.3h.3c.2.6.6.4 1 .2 0 .4.1.8-.1 1.2-.1.4.1.9.1 1.4 0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.4.6.1 1.2.2 1.8.1.8-.1 1.4-.8 1.8l-.3.3.3.9c-.4.1-.8.2-1.1-.2.4-.6.2-1.2-.2-1.8-.3 0-.5.2-.5.5-.1.7 0 1.4.3 2.1.2.4.6.7 1.1.6.2 0 .4-.1.6-.2.3.7.1 1.4 0 2 .6 0 1.3.1 1.9-.3-.1-.3-.2-.6-.3-1-.2.1-.6.2-.6.4v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2.1-.2l-.3-1.2c.3-.6.3-1.2-.2-1.8.2-.4.3-.8.5-1.4.2.3.3.5.5.8.3.1.4-.1.5-.3.1-.3.4-.4.7-.5-.1.4-.1.9 0 1.3.1.5 0 1-.4 1.2-.9.4-.8 1.1-.7 1.8.6-.2.4-1 1-1.3.6.2 1.2.4 1.4 1.2.2.1.3.1.5.2-.2.3-.3.6-.4.9-.1.2-.1.5.2.6.3-.3.5-.6.8-.9.2-.6-.3-.9-.4-1.3.1-.4.2-.6.3-.9-.2-.2-.4-.4-.6-.4-.3 0-.7.2-1 .3 0-.7-.1-1.3-.1-1.9.2.2.4.4.6.5.4-.5 1.1 0 1.7-.4-.3-.4-.6-.7-.8-1v-.3c.4-.3.4-.3.9-.3.2.6.5 1.2.7 1.8-.1.1-.2.2-.2.3l-.3.3c-.1.2-.1.4-.1.5 0 .2.2.3.3.4.6-.4.7-1.2 1.4-1.5.1 0 .2-.2.2-.3 0-.4.1-.7.1-1.4-.5 1-1 .5-1.5.5-.1-.4.2-.4.4-.5.2-.1.3-.2.4-.3.1-.2.2-.4.3-.7.4.3.7.6 1.1.9.4-.2.7-.4 1.1-.5.1.5.3 1 .4 1.5 0 .2-.1.3-.2.5.6 0 1 .4 1.4.8.4.3.8.6 1.3.6.1.7-.6.5-.9.9.4.7.6 1.3.4 2.1-.1.3-.1.6.2.8.1.1.3.2.4.2.3-.1.3-.3.3-.6-.1-.3-.2-.5-.4-.7.2-.3.6-.7.7-1 0-1.1.5-2.2.1-3.4.6.6 1.2.8 2 .8.6 0 1.2.1 1.6.6.3-.1.6-.2.9-.2 0 .2.1.4.1.5.6.2.7.9 1.1 1.3.2-.2.5-.3.7-.4-.1-.4-.3-.8-.4-1.2 0-.2.1-.5.2-.6.1-.1.4 0 .6.1.5.2.2.8.5 1.2.5-.1.5-.6.7-.9.2-.4.6-.4.8 0 .2.3.3.8.7.9 0 .3-.1.6-.1 1-.2 0-.4.1-.6.1.1.2.1.4.2.7-.5.3-1.2-.1-1.5.5-.1.4-.2.2-.4 0h.3v-.5c.2-.8.4-.9 1.2-.7 0-.4-.1-.7-.1-1.2-.3.2-.5.3-.7.4-.3.1-.6.2-.9.2-.2 0-.5-.1-.7-.1.4.5.6 1 .6 1.7-.4 0-.8 0-1.1.4-.1.2-.3.3-.4.1v-.8c-.4.3-.8.5-1 .8-.2.2-.2.5-.4.7.2.3.4.5.6.8.2.2.3.5.5.7.1.2.3.4.6.1v-.7c0-.2.1-.5.1-.7 1.1.5 1.3.5 2.2.4.8-.1 1.5-.3 2.3-.3 1 0 1.9-.2 2.9-.2.6 0 1.3 0 2-.3.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1l.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.2.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6 0 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2 0 0 .1 0 .1.1s-.1.2-.1.3c0 .1.1.2.1.2-.2.1-.4.2-.7.4h.8c.2.4.4.7.9.9.1-.1.2-.3.2-.4 0-.1-.1-.3-.1-.4.2.1.5.1.7.2 0-.3.1-.6.1-.9.4.2.4.2.4.7.3 0 .6.1 1 .1 0 .2 0 .4.2.5.1-.1.2-.1.2-.2v-.3c.6 0 1.2.1 1.7.2 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1 .4-1.4 1.1-1.5-.1.3-.1.7-.2 1l-.1-.1v.4c-.1.1-.1.2-.1.3.3 1.1-.2 1.9-.9 2.6-.1.1-.1.2-.2.3.1.1.2.3.3.4-.1.1-.2.1-.3.2 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.4-.1.9-.2 1.3-.4-.1.3-.1.5-.2.8.3 0 .5.1.7 0 .1-.1.2-.3.2-.5s-.1-.3-.1-.5h.6c-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.5c0 .1.1.3.2.4.2.4.6.7 1.1.6.2 0 .4-.1.6-.2v.1c-.2 0-.4.1-.6.2v.4c.1.2.5.4.8.3 0 .4-.1.7-.1 1 .6 0 1.3.1 1.9-.3-.1-.2-.1-.4-.2-.6.2-.1.5-.3.7-.5.2.3.3.7.3 1.1.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1-.1-.3-.2-.5-.3-.8.2.1.3.3.4.6l.3.6c.9-.1 1.6-.3 2.2-1-.1.3-.3.5-.3.7-.1.2-.1.5.2.6h.1c.2-.2.6-.2.7-.8h-.1l.1-.1v-.3c.2 0 .5.1.7.1.1.3.1.6.2.8.1.3.4.5.7.3.1 0 .1-.1.2-.2l.1.1c.2.1.4-.1.5-.5 0-.2.1-.4.1-.6v-.1c.3 0 .6.2.8.6 0 0 0 .1.1.1 0 .1.1.3.2.4l.1.1c0 .1.1.1.1.2 0-.1 0-.1.1-.2.1.1.3.2.5.3v-.8c-.1-.2-.2-.4-.4-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.2-.2.3-.2.5-.3v0c.3-.1.7 0 1 .2.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5 0 .1-.1.2-.2.3V38h-.1v.1c-.1.1-.1.1-.2.1-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.1 0-.2 0-.3.1-.1-.2-.1-.4-.1-.6v-.2c.1 0 .1-.1.1-.2 0-.2-.1-.3-.2-.4v-.1c-.1-.1-.3-.1-.4-.2 0 .1.1.2.1.4-.3.2-.4.4-.4.8.1.3.2.6.5.7-.2.2-.3.4-.4.7v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.2.4-.4.9-.5 1.4h-.1c-.1.2-.3.3-.4.5.1.1.2.2.3.2.1 0 .1-.1.2-.2 0 .4.4.8.8.7.3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.1 0 .1.1.2.1-.1.1-.1.3-.3.5.3-.2.4-.3.4-.5.2.1.5.2.6.3.3-.2.6-.3.8-.5 0 .1.1.1.1.2.1-.1.2-.1.2-.2l-.1-.1c.2-.7-.3-1.2-.8-1.9h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.1-.2-.2-.2-.3 0-.1.1-.1.1-.2s-.1-.3-.2-.6c-.1.1-.1.2-.2.2 0-.1.1-.3.2-.3.9-.1 1.4-.9 2.2-1.1v-.1c.3 0 .6-.1.9-.2.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .4.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1 0 .1.1.2.1.2h.3c-.1-.1-.1-.2-.2-.3h-.2v.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3v-.1c.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6 0 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2.1 0 .2.2.4.4-.4.2-.6.3-1 .6h1.4c.4 0 .7.2 1.1.3 0-.3.1-.6.1-.9.4.2.4.2.4.7 1 .1 2.1.2 3.1.3 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1.2.5-1.6 1.6-1.5.4 0 .7.1 1.1 0 .4-.2.8-.2 1.3-.1.2.1.4 0 .4-.4-1-.3-1.2-1.1-1.2-2.1 0-.5.2-.9.7-1 0 .3.1.5.1.7.2 0 .3 0 .4.2.2.7.3 1.4 1 1.7.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.4-.2.8-.2 1.1.1.4.3.4.7.3 1.1l.9.3.4-.4c.3.4.5.8.8 1.2.2.3.6.3.9.2-.1.4-.1.8-.2 1.2-.7.1-1.2.2-1.8.3-.6.1-1.1 0-1.7.2.4.7.4.7-.1 1.8-1.4.4-2.9.2-4.3.1-.7.7-.7.7-1.5.7-.4 0-.9-.1-1.3.4 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.5-.1 1-.2 1.5-.4.4-.2.7-.2 1-.1-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.6c1 .4 1.9.3 2.9.2h.7c.6 0 1 .2 1.2.9l.3.6c.9-.1 1.6-.3 2.2-1 .5.1 1 .2 1.4.3.1.3.1.6.2.8.1.3.4.5.7.3.2-.1.3-.3.4-.5.1-.2 0-.4 0-.7.6-.1 1 0 1.3.6l.3.6c0 .1.1.1.1.2 0-.1.1-.1.1-.2.2-.1.3-.2.2-.4-.1-.1-.3-.2-.1-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.5-.5 1-.5 1.6-.1.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5-.1.2-.2.4-.4.5-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.7 0-.8.5-1 1v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.3.5-.5 1.1-.6 1.7-.1.5.3 1.1.8 1 .3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.3.1.7.3 1 .4.4-.2.7-.4 1-.6.3-.8-.3-1.3-.8-2h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.2-.3-.3-.4-.5-.1-.2-.1-.6.1-.6.9-.1 1.4-.9 2.2-1.1 0-.7 0-1.2-.2-1.8-.2-.3 0-.5.3-.6.1-.3.2-.6.1-.8-.3-.7.1-1.4 0-2.1.4-.1.7-.2 1-.2.2.3.3.5.4.7.1-.5.4-1.1.3-1.6v-.4c.3-.1.5-.3.4-.8-.1 0-.2-.1-.2-.1.2-.4.5-.7.9-1l.2-.2c-.1-.1-.3-.2-.4-.3-.2-.2-.2-.5-.2-.7V30v-.3c0-.1 0-.1.1-.2.2-.4.2-.8-.2-1.2-.1.2-.2.4-.4.6-.4-.2-.3-.5-.2-.8.1-.5.3-1 .5-1.4-.3-.3-.7-.5-.9-.8-.3-.4-.9-.7-.1-1.2.1-.1 0-.4.1-.5 0-.1.1-.1.1-.2l.3.3v1.1c0 .2 0 .4.3.3.1-.7.1-1 .1-1.4.2 0 .4-.1.6-.2.3.4 0 .9.4 1.2.1-.1.2-.1.2-.2 0-.8.2-1.5.3-2.2.1-.4.3-.6.5-.6.6 0 1.3-.4 1.8.3 0 0 .3-.1.5-.2.1.4.2.7.2 1 0 .4-.3.9.2 1.2.1.1.1.4 0 .5-.1.5-.2.9-.3 1.4 1-.2 1.2-.1 1.3.9 0 .3-.1.6.2.7.5-.3.5-.3.8-1.1-.7-1.1-1-2.5-1.1-4 .6-.4 1.1-.8 1.7-1.2.4.1.8.1 1.2.2.1 0 .2.2.2.3h.3c.2.6.6.4 1 .2 0 .4.1.8-.1 1.2-.1.4.1.9.1 1.4 0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.4.6.1 1.2.2 1.8.1.8-.1 1.4-.8 1.8l-.3.3.3.9c-.4.1-.8.2-1.1-.2.4-.6.2-1.2-.2-1.8-.3 0-.5.2-.5.5-.1.7 0 1.4.3 2.1.2.4.6.7 1.1.6.2 0 .4-.1.6-.2.3.7.1 1.4 0 2 .6 0 1.3.1 1.9-.3-.1-.3-.2-.6-.3-1-.2.1-.6.2-.6.4v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2.1-.2l-.3-1.2c.3-.6.3-1.2-.2-1.8.2-.4.3-.8.5-1.4.2.3.3.5.5.8.3.1.4-.1.5-.3.1-.3.4-.4.7-.5-.1.4-.1.9 0 1.3.1.5 0 1-.4 1.2-.9.4-.8 1.1-.7 1.8.6-.2.4-1 1-1.3.6.2 1.2.4 1.4 1.2.2.1.3.1.5.2-.2.3-.3.6-.4.9-.1.2-.1.5.2.6.3-.3.5-.6.8-.9.2-.6-.3-.9-.4-1.3.1-.4.2-.6.3-.9-.2-.2-.4-.4-.6-.4-.3 0-.7.2-1 .3 0-.7-.1-1.3-.1-1.9.2.2.4.4.6.5.4-.5 1.1 0 1.7-.4-.3-.4-.6-.7-.8-1v-.3c.4-.3.4-.3.9-.3.2.6.5 1.2.7 1.8-.1.1-.2.2-.2.3l-.3.3c-.1.2-.1.4-.1.5 0 .2.2.3.3.4.6-.4.7-1.2 1.4-1.5.1 0 .2-.2.2-.3 0-.4.1-.7.1-1.4-.5 1-1 .5-1.5.5-.1-.4.2-.4.4-.5.2-.1.3-.2.4-.3.1-.2.2-.4.3-.7.4.3.7.6 1.1.9.4-.2.7-.4 1.1-.5.1.5.3 1 .4 1.5 0 .2-.1.3-.2.5.6 0 1 .4 1.4.8.4.3.8.6 1.3.6.1.7-.6.5-.9.9.4.7.6 1.3.4 2.1-.1.3-.1.6.2.8.1.1.3.2.4.2.3-.1.3-.3.3-.6-.1-.3-.2-.5-.4-.7.2-.3.6-.7.7-1 0-1.1.5-2.2.1-3.4.6.6 1.2.8 2 .8.6 0 1.2.1 1.6.6.3-.1.6-.2.9-.2 0 .2.1.4.1.5.6.2.7.9 1.1 1.3.2-.2.5-.3.7-.4-.1-.4-.3-.8-.4-1.2 0-.2.1-.5.2-.6.1-.1.4 0 .6.1.5.2.2.8.5 1.2.5-.1.5-.6.7-.9.2-.4.6-.4.8 0 .2.3.3.8.7.9 0 .3-.1.6-.1 1-.2 0-.4.1-.6.1.1.2.1.4.2.7-.5.3-1.2-.1-1.5.5-.1.4-.2.2-.4 0h.3v-.5c.2-.8.4-.9 1.2-.7 0-.4-.1-.7-.1-1.2-.3.2-.5.3-.7.4-.3.1-.6.2-.9.2-.2 0-.5-.1-.7-.1.4.5.6 1 .6 1.7-.4 0-.8 0-1.1.4-.1.2-.3.3-.4.1v-.8c-.4.3-.8.5-1 .8-.2.2-.2.5-.4.7.2.3.4.5.6.8.2.2.3.5.5.7.1.2.3.4.6.1v-.7c0-.2.1-.5.1-.7 1.1.5 1.3.5 2.2.4.8-.1 1.5-.3 2.3-.3 1 0 1.9-.2 2.9-.2.6 0 1.3 0 2-.3.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1l.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6.1 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2 0 0 .1 0 .1.1s-.1.2-.1.3c0 .1.1.2.1.2-.2.1-.4.2-.7.4h.8c.2.4.4.7.9.9.1-.1.2-.3.2-.4 0-.1-.1-.3-.1-.4.2.1.5.1.7.2 0-.3.1-.6.1-.9.4.2.4.2.4.7.3 0 .6.1 1 .1 0 .2 0 .4.2.5.1-.1.2-.1.2-.2v-.3c.6 0 1.2.1 1.7.2 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1 .4-1.4 1.1-1.5-.1.3-.1.7-.2 1l-.1-.1v.4c-.1.1-.1.2-.1.3.3 1.1-.2 1.9-.9 2.6-.1.1-.1.2-.2.3.1.1.2.3.3.4-.1.1-.2.1-.3.2 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.4-.1.9-.2 1.3-.4-.1.3-.1.5-.2.8.3 0 .5.1.7 0 .1-.1.2-.3.2-.5s-.1-.3-.1-.5h.6c-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.5c0 .1.1.3.2.4.2.4.6.7 1.1.6.2 0 .4-.1.6-.2v.1c-.2 0-.4.1-.6.2v.4c.1.2.5.4.8.3 0 .4-.1.7-.1 1 .6 0 1.3.1 1.9-.3-.1-.2-.1-.4-.2-.6.2-.1.5-.3.7-.5.2.3.3.7.3 1.1.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1-.1-.3-.2-.5-.3-.8.2.1.3.3.4.6l.3.6c.9-.1 1.6-.3 2.2-1-.1.3-.3.5-.3.7-.1.2-.1.5.2.6h.1c.2-.2.6-.2.7-.8h-.1l.1-.1v-.3c.2 0 .5.1.7.1.1.3.1.6.2.8.1.3.4.5.7.3.1 0 .1-.1.2-.2l.1.1c.2.1.4-.1.5-.5 0-.2.1-.4.1-.6v-.1c.3 0 .6.2.8.6 0 0 0 .1.1.1 0 .1.1.3.2.4l.1.1c0 .1.1.1.1.2 0-.1 0-.1.1-.2.1.1.3.2.5.3v-.8c-.1-.2-.2-.4-.4-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.2-.2.3-.2.5-.3v0c.3-.1.7 0 1 .2.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5 0 .1-.1.2-.2.3V37h-.1v.1c-.1.1-.1.1-.2.1-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.1 0-.2 0-.3.1-.1-.2-.1-.4-.1-.6v-.2c.1 0 .1-.1.1-.2 0-.2-.1-.3-.2-.4v-.1c-.1-.1-.3-.1-.4-.2 0 .1.1.2.1.4-.3.2-.4.4-.4.8.1.3.2.6.5.7-.2.2-.3.4-.4.7v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.2.4-.4.9-.5 1.4h-.1c-.1.2-.3.3-.4.5.1.1.2.2.3.2.1 0 .1-.1.2-.2 0 .4.4.8.8.7.3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.1 0 .1.1.2.1-.1.1-.1.3-.3.5.3-.2.4-.3.4-.5.2.1.5.2.6.3.3-.2.6-.3.8-.5 0 .1.1.1.1.2.1-.1.2-.1.2-.2l-.1-.1c.2-.7-.3-1.2-.8-1.9h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.1-.2-.2-.2-.3 0-.1.1-.1.1-.2s-.1-.3-.2-.6c-.1.1-.1.2-.2.2 0-.1.1-.3.2-.3.9-.1 1.4-.9 2.2-1.1v-.1c.3 0 .6-.1.9-.2.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .4.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1 0 .1.1.2.1.2h.3c-.1-.1-.1-.2-.2-.3h-.2v.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6 0 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2.1 0 .2.2.4.4-.4.2-.6.3-1 .6h1.4c.4 0 .7.2 1.1.3 0-.3.1-.6.1-.9.4.2.4.2.4.7 1 .1 2.1.2 3.1.3 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1.2.5-1.6 1.6-1.5.4 0 .7.1 1.1 0 .4-.2.8-.2 1.3-.1.2.1.4 0 .4-.4-1-.3-1.2-1.1-1.2-2.1 0-.5.2-.9.7-1 0 .3.1.5.1.7.2 0 .3 0 .4.2.2.7.3 1.4 1 1.7.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.4-.2.8-.2 1.1.1.4.3.4.7.3 1.1l.9.3.4-.4c.3.4.5.8.8 1.2.2.3.6.3.9.2-.1.4-.1.8-.2 1.2-.7.1-1.2.2-1.8.3-.6.1-1.1 0-1.7.2.4.7.4.7-.1 1.8-1.4.4-2.9.2-4.3.1-.7.7-.7.7-1.5.7-.4 0-.9-.1-1.3.4 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.5-.1 1-.2 1.5-.4.4-.2.7-.2 1-.1-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.6c1 .4 1.9.3 2.9.2h.7c.6 0 1 .2 1.2.9l.3.6c.9-.1 1.6-.3 2.2-1 .5.1 1 .2 1.4.3.1.3.1.6.2.8.1.3.4.5.7.3.2-.1.3-.3.4-.5.1-.2 0-.4 0-.7.6-.1 1 0 1.3.6l.3.6c0 .1.1.1.1.2 0-.1.1-.1.1-.2.2-.1.3-.2.2-.4-.1-.1-.3-.2-.1-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.5-.5 1-.5 1.6-.1.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5-.1.2-.2.4-.4.5-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.7 0-.8.5-1 1v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.3.5-.5 1.1-.6 1.7-.1.5.3 1.1.8 1 .3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.3.1.7.3 1 .4.4-.2.7-.4 1-.6.3-.8-.3-1.3-.8-2h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.2-.3-.3-.4-.5-.1-.2-.1-.6.1-.6.9-.1 1.4-.9 2.2-1.1 0-.7 0-1.2-.2-1.8-.2-.3 0-.5.3-.6.1-.3.2-.6.1-.8-.3-.7.1-1.4 0-2.1.4-.1.7-.2 1-.2.2.3.3.5.4.7.1-.5.4-1.1.3-1.6v-.4c.3-.1.5-.3.4-.8-.1 0-.2-.1-.2-.1.2-.4.5-.7.9-1l.2-.2c-.1-.1-.3-.2-.4-.3-.2-.2-.2-.5-.2-.7V29v-.3c0-.1 0-.1.1-.2.2-.4.2-.8-.2-1.2-.1.2-.2.4-.4.6-.4-.2-.3-.5-.2-.8.1-.5.3-1 .5-1.4-.3-.3-.7-.5-.9-.8-.3-.4-.9-.7-.1-1.2.1-.1 0-.4.1-.5 0-.1.1-.1.1-.2l.3.3v1.1c0 .2 0 .4.3.3.1-.7.1-1 .1-1.4.2 0 .4-.1.6-.2.3.4 0 .9.4 1.2.1-.1.2-.1.2-.2 0-.8.2-1.5.3-2.2.1-.4.3-.6.5-.6.6 0 1.3-.4 1.8.3 0 0 .3-.1.5-.2.1.4.2.7.2 1 0 .4-.3.9.2 1.2.1.1.1.4 0 .5-.1.5-.2.9-.3 1.4 1-.2 1.2-.1 1.3.9 0 .3-.1.6.2.7.5-.3.5-.3.8-1.1-.7-1.1-1-2.5-1.1-4 .6-.4 1.1-.8 1.7-1.2.4.1.8.1 1.2.2.1 0 .2.2.2.3h.3c.2.6.6.4 1 .2 0 .4.1.8-.1 1.2-.1.4.1.9.1 1.4 0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.4.6.1 1.2.2 1.8.1.8-.1 1.4-.8 1.8l-.3.3.3.9c-.4.1-.8.2-1.1-.2.4-.6.2-1.2-.2-1.8-.3 0-.5.2-.5.5-.1.7 0 1.4.3 2.1.2.4.6.7 1.1.6.2 0 .4-.1.6-.2.3.7.1 1.4 0 2 .6 0 1.3.1 1.9-.3-.1-.3-.2-.6-.3-1-.2.1-.6.2-.6.4v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2.1-.2l-.3-1.2c.3-.6.3-1.2-.2-1.8.2-.4.3-.8.5-1.4.2.3.3.5.5.8.3.1.4-.1.5-.3.1-.3.4-.4.7-.5-.1.4-.1.9 0 1.3.1.5 0 1-.4 1.2-.9.4-.8 1.1-.7 1.8.6-.2.4-1 1-1.3.6.2 1.2.4 1.4 1.2.2.1.3.1.5.2-.2.3-.3.6-.4.9-.1.2-.1.5.2.6.3-.3.5-.6.8-.9.2-.6-.3-.9-.4-1.3.1-.4.2-.6.3-.9-.2-.2-.4-.4-.6-.4-.3 0-.7.2-1 .3 0-.7-.1-1.3-.1-1.9.2.2.4.4.6.5.4-.5 1.1 0 1.7-.4-.3-.4-.6-.7-.8-1v-.3c.4-.3.4-.3.9-.3.2.6.5 1.2.7 1.8-.1.1-.2.2-.2.3l-.3.3c-.1.2-.1.4-.1.5 0 .2.2.3.3.4.6-.4.7-1.2 1.4-1.5.1 0 .2-.2.2-.3 0-.4.1-.7.1-1.4-.5 1-1 .5-1.5.5-.1-.4.2-.4.4-.5.2-.1.3-.2.4-.3.1-.2.2-.4.3-.7.4.3.7.6 1.1.9.4-.2.7-.4 1.1-.5.1.5.3 1 .4 1.5 0 .2-.1.3-.2.5.6 0 1 .4 1.4.8.4.3.8.6 1.3.6.1.7-.6.5-.9.9.4.7.6 1.3.4 2.1-.1.3-.1.6.2.8.1.1.3.2.4.2.3-.1.3-.3.3-.6-.1-.3-.2-.5-.4-.7.2-.3.6-.7.7-1 0-1.1.5-2.2.1-3.4.6.6 1.2.8 2 .8.6 0 1.2.1 1.6.6.3-.1.6-.2.9-.2 0 .2.1.4.1.5.6.2.7.9 1.1 1.3.2-.2.5-.3.7-.4-.1-.4-.3-.8-.4-1.2 0-.2.1-.5.2-.6.1-.1.4 0 .6.1.5.2.2.8.5 1.2.5-.1.5-.6.7-.9.2-.4.6-.4.8 0 .2.3.3.8.7.9 0 .3-.1.6-.1 1-.2 0-.4.1-.6.1.1.2.1.4.2.7-.5.3-1.2-.1-1.5.5-.1.4-.2.2-.4 0h.3v-.5c.2-.8.4-.9 1.2-.7 0-.4-.1-.7-.1-1.2-.3.2-.5.3-.7.4-.3.1-.6.2-.9.2-.2 0-.5-.1-.7-.1.4.5.6 1 .6 1.7-.4 0-.8 0-1.1.4-.1.2-.3.3-.4.1v-.8c-.4.3-.8.5-1 .8-.2.2-.2.5-.4.7.2.3.4.5.6.8.2.2.3.5.5.7.1.2.3.4.6.1v-.7c0-.2.1-.5.1-.7 1.1.5 1.3.5 2.2.4.8-.1 1.5-.3 2.3-.3 1 0 1.9-.2 2.9-.2.6 0 1.3 0 2-.3.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .5.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1l.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3l.2.2s.1 0 .2-.1l-.1-.1c-.1 0-.2-.1-.2-.1.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6.3 0 .5.1.8.1.3 0 .5-.2.5-.5 0-.1.1-.1.2-.2.2.1.4.3.7.4.4-.3.9-.6 1.3-.9l.6-.6c.3-.6.6-1.2.9-1.7.7.4 1.1 1 1.2 1.9 0 .5 0 1.1.5 1.4.7 0 1.3 0 1.8-.7.2-.3.6-.2.9 0 .1.1.3.3.4.3.1 0 .4 0 .5-.1.1-.1.2-.4.1-.5-.1-.3-.3-.5-.4-.8.5-.5.8-.5.9 0 .2.5.2 1.1.6 1.6.6-.4.6-.4 1.6-.5.4 0 .5-.2.5-.7 0-.1 0-.3-.1-.4-.2-.3-.3-.6-.5-.9.1 0 .2-.1.3-.1.6.5.5 1.5 1.1 2 1.2-.2 1.2-.2 2.1.6.5-.1.5-.8 1-.8h1.3c.3.4.5.6.7.9.5-.1.6-.4.7-.8.4-.1.7-.2 1.1-.2.4.3.7.6 1.1.9.3.2.6.1.8-.2l.3-.6c.7.2 1.4.4 2 .5.1-.2.1-.3.2-.4.1-.1.3-.2.3-.2.1.1.3.3.3.4 0 .3-.1.5-.2.7.3.3.6.1.8-.1.2-.1.4-.4.5-.3.5.3.7-.3 1-.5.1.1.3.2.4.3.2.2.4.4.5.6.2.4.7.3.9 0l.3-.6c.2-.3.4-.2.6 0 .1.1.1.3.2.5.4-.1.8 0 .9-.6-.3-.3-.6-.7-1-1-.4-.3-.8-.5-1.2-.2-.3.2-.5.3-.8.4-.6-.5-.6-.5-.8-1.4-.2.1-.3.1-.5.2l-.6.6c-.8.6-1.2.6-1.8-.2-.3-.4-.7-.9-.9-1.4-.3-.5-.6-.6-1.1-.6-.3 0-.5.1-.7.2-.1.3-.2.5-.3.8-.3-.3-.6-.5-.9-.7.3-.8.3-.9.9-.9 1 0 2 .1 2.9.1.2 0 .4 0 .4-.4-.2-.2-.4-.3-.6-.5.1-.4.2-.7.3-1.1-.7.1-.9.8-1.3 1.3-.6.1-1.1.2-1.7.2-.4 0-.8-.1-1-.5.1-.2.2-.4.2-.6-.1-.4-.2-.7-.4-1-.1-.1-.3-.2-.4-.3l-.3-.3c-.6-.5-1.1-.3-1.3.5-.1.2.1.5-.3.6-.6-.2-1-.6-1.2-1.4.5-.1.9-.3 1.2-.4.2-.4.4-.7.6-1 .7-.1.9.2 1 .7.1.2.2.4.5.4.2 0 .4-.2.5-.3-.1-.4-.3-.7-.4-1 .2-.1.3-.1.5-.2h.3c.5-.1.7-.5.5-.9-.4-.8-.8-1.6-.9-2.5 0-.1-.1-.2-.2-.4s-.1-.4-.1-.5c.2 0 .3.1.5.2.6.2 1.1.1 1.6-.1h.4c.6.1 1.2.1 1.8-.1.4-.1.9-.2 1.3-.2v.1c0 .1 0 .2-.1.3-.9 1-1.8 1.5-3.1 1-.2-.1-.3-.2-.5-.2s-.5.2-.7.3c-.1 0-.1.2-.1.2.1.1.1.2.2.3h.4c1.1-.2 2.1-.1 3 .8.3.3.7.4.7.9 0 .2.2.3.3.4.3.3.3.6.4 1 .4-.6.1-1.4.4-2 .6-.3 1.2 0 1.7-.5.3-.2.8.2.9.6.1.3 0 .7.1 1 .1.8.2 1.5.3 2.3 0 .4.2.6.6.7h.1c.1 0 .2-.1.2-.1.7-.8 1.5-1 2.4-.7.4.1.9.1 1.3.1.3 0 .6 0 .8.1.4.3.8.2 1.3.2.7-.1 1.4-.2 2.1-.2.5.1 1-.1 1.6-.4-1.1-.1-2.2-.2-3.2-.3-1.1-.1-1.1-.1-2.2-.9-.1.3-.3.6-.3.7-.8 0-1.5 0-2.1-.1-.4 0-.8-.1-1.2-.2-.7-.2-.9-.9-1-1.5-.1-.7.4-.7.8-1v-.1c-.1-.1-.1-.1-.2-.1s-.3 0-.4-.1c-.6-.2-.7-.4-.5-1.1.1-.4.1-.7.2-1.1 0-.1 0-.1.1-.2h.6c.2.1.3.2.5.3v-.1c.4-.3.8-.3 1.1-.3.2.4.4.7.5 1 .6.1 1.1.1 1.5-.3.6.2 1.2.7 1.9.6.1 0 .1.2.2.3-1 .1-2 .2-2.9.3 0 1 0 1.1.8 1.2 1.7.1 3.4.2 5 .3h.7l3.9.3c.2-.1.5-.3.7-.5.3.1.6.3 1 .4.2 0 .4-.2.5-.2l2.4.6c.1.4.3.9.4 1.3 0 .1.2.1.4.1v-1.2c.4-.2.7-.3 1-.5.6.1 1.1.5 1.7.2.1-.1.1-.2.2-.3.5-.7.6-.7 1.3-.3.2.1.5.2.7.3-.1.4-.2.8-.2 1.2 0 .1.1.2.2.2h.2c.6-.6 1.2-1.3 1.8-1.9.4.1.8.1 1.2.2 0 0 .1 0 .1.1s-.1.2-.1.3c0 .1.1.2.1.2-.2.1-.4.2-.7.4h.8c.2.4.4.7.9.9.1-.1.2-.3.2-.4 0-.1-.1-.3-.1-.4.2.1.5.1.7.2 0-.3.1-.6.1-.9.4.2.4.2.4.7.3 0 .6.1 1 .1 0 .2 0 .4.2.5.1-.1.2-.1.2-.2v-.3c.6 0 1.2.1 1.7.2 0 .5.1.8.1 1.2 0 .4 0 .8.1 1.3.1-.1.3-.1.3-.1.1-.2 0-.4 0-.5.1-1 .4-1.4 1.1-1.5-.1.3-.1.7-.2 1l-.1-.1v.4c-.1.1-.1.2-.1.3.3 1.1-.2 1.9-.9 2.6-.1.1-.1.2-.2.3.1.1.2.3.3.4-.1.1-.2.1-.3.2 0 .8 0 1.6-.1 2.4l-.1.1.1-.1c-.1-.1-.1-.1-.2-.1h-.2c0 .1.1.2.1.2h.3c-.3.3-.6.7-.9 1.1.7.3 1.3.5 1.9.7h.3c.4-.1.9-.2 1.3-.4-.1.3-.1.5-.2.8.3 0 .5.1.7 0 .1-.1.2-.3.2-.5s-.1-.3-.1-.5h.6c-.1-.3-.4-.5-.6-.7-.4-.3-.9-.5-1.5-.9.9-.1 1.6-.2 2.4-.3.1-.5.2-.9.2-1.4h.5c0 .1.1.3.2.4.2.4.6.7 1.1.6.2 0 .4-.1.6-.2v.1c-.2 0-.4.1-.6.2v.4c.1.2.5.4.8.3 0 .4-.1.7-.1 1 .6 0 1.3.1 1.9-.3-.1-.2-.1-.4-.2-.6.2-.1.5-.3.7-.5.2.3.3.7.3 1.1.3.1.6.3.9-.1-.2-.3-.4-.7-.6-1-.1-.3-.2-.5-.3-.8.2.1.3.3.4.6l.3.6c.9-.1 1.6-.3 2.2-1-.1.3-.3.5-.3.7-.1.2-.1.5.2.6h.1c.2-.2.6-.2.7-.8h-.1l.1-.1v-.3c.2 0 .5.1.7.1.1.3.1.6.2.8.1.3.4.5.7.3.1 0 .1-.1.2-.2l.1.1c.2.1.4-.1.5-.5 0-.2.1-.4.1-.6v-.1c.3 0 .6.2.8.6 0 0 0 .1.1.1 0 .1.1.3.2.4l.1.1c0 .1.1.1.1.2 0-.1 0-.1.1-.2.1.1.3.2.5.3v-.8c-.1-.2-.2-.4-.4-.5.3-.1.5 0 .7.3.1.3.1.6.2.8.1.4.4.6.7.3.2-.2.3-.2.5-.3v0c.3-.1.7 0 1 .2.1 0 .1.1.2.1.2 0 .4-.1.6 0 .6.1.9-.2 1.1-.6 0 .4 0 .7.5.8.2 0 .4.3.3.5 0 .1-.1.2-.2.3V36h-.1v.1c-.1.1-.1.1-.2.1-.3.1-.6.2-.8.2-.2.3-.3.7-.4.7-.1 0-.2 0-.3.1-.1-.2-.1-.4-.1-.6v-.2c.1 0 .1-.1.1-.2 0-.2-.1-.3-.2-.4v-.1c-.1-.1-.3-.1-.4-.2 0 .1.1.2.1.4-.3.2-.4.4-.4.8.1.3.2.6.5.7-.2.2-.3.4-.4.7v.4c.2.1.5.3.7.4l.7-.7c.8.9.8.9 1.9.8.4-.1.8 0 1.1.3.2.1.4.2.6.4.6-.4 1.1-1.3 2-.6-.3.2-.7.4-.8.7-.2.4-.4.9-.5 1.4h-.1c-.1.2-.3.3-.4.5.1.1.2.2.3.2.1 0 .1-.1.2-.2 0 .4.4.8.8.7.3 0 .5-.2.7-.3.3-.2.7-.2 1 0l-.1.1.1-.1c.3-.2.6-.5 1-.8.1 0 .1.1.2.1-.1.1-.1.3-.3.5.3-.2.4-.3.4-.5.2.1.5.2.6.3.3-.2.6-.3.8-.5 0 .1.1.1.1.2.1-.1.2-.1.2-.2l-.1-.1c.2-.7-.3-1.2-.8-1.9h.8c.2 0 .4-.1.6-.1v.2c0 .3-.2.7.2.9.3.2.6 0 .8-.2.1-.1.2-.3.3-.5 0 0-.1-.1-.1-.2-.2.1-.4.2-.6.4-.2-.3-.1-.6.1-.7.8-.3 1.1-.9 1.4-1.6 0-.1.1-.2.1-.3-.1-.1-.2-.2-.2-.3 0-.1.1-.1.1-.2s-.1-.3-.2-.6c-.1.1-.1.2-.2.2 0-.1.1-.3.2-.3.9-.1 1.4-.9 2.2-1.1v-.1c.3 0 .6-.1.9-.2.3-.2.8 0 1.2-.1.4-.1.5.3.8.5.3-.5.8-.5 1.3-.2.2.1.4.2.6.4.4-.3.8-.6 1.3-1.1.4 0 1.1.1 1.3 1 .4 0 .7-.1 1-.3l.9-.6c.3-.2.6-.1.7.1.1.3-.1.4-.3.5-.1 0-.1.1-.2.2 0 .1.1.2.1.3v.2c-.3.1-.6.2-1 .3.1.3.1.5.2.7.3-.2.6-.6 1.1-.4.3.3.5.7.8 1.1.4.4.7.3 1-.3 0-.1.1-.1.2-.2.1 0 .2.1.3.1.1 0 .2.2.3.2.4-1 .7-2.9 1.1-2.9h1.3c.2 0 .4.6.6.8 0 .6-.6.4-.5.9.2.2.6-.1.5.4 0 .2.2.4.3.6.2.2.4.4.6.5-.1.6-.3 1.1-.2 1.6.2.7.2 1.4.4 2 0 .1.1.1.3.1.4-.4.4-.9.4-1.4 0-.8-.1-1.7-.1-2.5 0-.1.2-.3.3-.4.2-.3 0-.5-.3-.6-.2 0-.3.2-.5-.1.2-.2.4-.4.7-.6-.3-.2-.6-.3-.9-.5.1-.1.2-.2.2-.3h.2c-.1 0-.1 0-.2-.1.2-.6.8-.7 1.3-.8.2 0 .4.2.5.3.9-.5.9-.5 1.9.1-.3.6-.3 1.1.4 1.5.2.1.4.5.6.7.5-1 .5-1 1.5-.7h.1c.6-.2.8.2.9.7.1.5.4.9.9 1 0 .1.1.2.1.2h.3c-.1-.1-.1-.2-.2-.3h-.2v.1-.1c0-.3 0-.5.3-.4.6.1 1-.1 1.4-.6-.5-.2-.9-.4-1.3-.6-.3-.1-.5-.4-.5-.8.3.1.5.5.8.1v-.1c-.2-.4-.5-.2-.8-.2-.1-.3-.2-.7-.2-1 .4-.1.7.3 1.1 0 .4-.3.9-.2 1.5-.1-.3.5-.6.9-.8 1.3.1.5.5.6.8.7.3.1.5 0 .7.4.2.1.5.2.7-.1.2-.6.5-.4 1-.2-.1.1-.2.2-.2.3-.1.1-.2.2-.2.3v.5c.1.1.3.2.4.3v-.1c.1-.4.4-.7.9-.8.2 0 .4 0 .5.3-.1.2-.2.5-.3.7.8-.1.9-.3.7-1-.1-.3-.2-.5-.3-.8.7-.3 1.4-.4 2.1-.4.4.4.8.9 1.4 1.1.2-.1.5-.1.7-.2.6-.1 1.1 0 1.5.7 0 .1.2 0 .2.1.1-.3.2-.7.4-1.2-.1-.1-.3-.1-.4-.3-.1-.1-.3-.2-.1-.4.5 0 1.1.1 1.6.2.1-.1.3-.1.4-.1v.3h-.5s-.1.2-.1.5c.5 0 1-.2 1.4-.1 1 .4 1.9 0 2.9 0 .2 0 .4-.2.6-.2-.9-.2-1.9 0-2.8-.5 0-.3 0-.6-.1-.6-.6-.1-.8-.6-1-1.2.2-.2.4-.3.5-.4.4.3.7.5 1 .8.2 1 .3 1.1 1.2 1.1.5 0 1 0 1.6.1.3.7.7 1.3 1.3 1.5.2-.5.5-1.1.8-1.6.7 0 1.1.5 1.6.8.7.4 1 1 .7 1.9v.4c.6.4 1.3.8 1.7 1.5 0 0 .1 0 .3-.1-.3-.9-.6-1.7-.9-2.6.4-.6.8-1.3 1.7-.7.4.2.4-.4.8-.5.5.2 1.1.4 1.7.6.6-.8.6-.8 1.3-.2-.6.1-.8.3-.7.9 0 .2.4.4.1.4-.5 0-1 0-1.6.1-.1 0-.1.4-.2.5.7.2.9 1 1.1 1.5.2.5.6.9 1 1.2.1.1.4.1.5 0 .1-.1.2-.3.2-.4 0-.2-.1-.5-.1-.7-.3-.1-.5-.2-.7-.3.1-.3.1-.6.2-.8.4-.1.7-.2 1.1-.4.4-.1.6 0 .8.3.3-.1.3-.3.2-.5-.1-.1-.3-.2-.4-.3-.2-.1-.3-.2-.5-.3-.3-.3-.4-.6-.3-1 .1-.3.3-.6.8-.6h.9c.6.1 1.2.1 1.9.2-.1.2-.2.4-.2.6 0 .1 0 .4.1.4.2 0 .4 0 .5-.1.2-.2.4-.4.5-.7.2-.4.5-.6.8-.9.2.3.4.5.6.8.5-.3 1.1-.3 1.6-.3.8 0 1.5-.1 2-.7.5.3 1 .6 1.4.9.4-.1.9-.1 1.3-.2.7-.2 1.4-.3 2.1 0 .3.1.6.1.9 0 .9-.4 1.8-.4 2.7 0 0 .1.1.1.1.2.1.8-.2 1.1-.8 1-.2 0-.5-.1-.7-.2-.3.4-.8.7-.4 1.4h1c.3 0 .6.1.9.2.2.1.4.3.2.6l-.9.3c.1.3.1.6.2.9.1.1.3.3.4.3.3.1.5.1.8 0 .3-.1.5-.2.7-.4l.3-.3c-.1-.3-.2-.7-.2-1 .2-.2.4-.5.6-.7-.2-.4-.6-.5-.7-1 0-.4-.2-.9-.3-1.3 1.3-.6 1.8-.5 2.4.7-.1.2-.2.5-.4.7.1.1.1.2.1.3.5.5.8 1 .4 1.7-.1.2-.1.5 0 .7 0 .3.4.4.6.2.2-.1.2-.3.4-.5.3-.4.8-.8.8-1.1v-1.2c0-.4-.3.4-.7.6.2-.8-.2-1.5 0-2.3.4-.2.7 0 .9.4.4.8.4 1.9 1.2 2.5v.1c-.3.6.3 1 .3 1.6.5.1.8.2 1.1-.1.2-.9-.9-1.4-.5-2.4.7.8.8 1.8 1.2 2.6l-6.2-38.5zM5 22.9c-.1 0-.1-.1 0 0 0-.1 0-.2.1-.2-.1 0-.1.1-.1.2zm9.3 8.8c.1.2.1.5.2.8-.3-.1-.5-.3-.6-.6 0-.1.1-.2.1-.3.1-.1.3 0 .3.1zm.6-3.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1s.1.1.1.2c-.1.1-.2.1-.2.1zm1.7 1c0 .1 0 .1 0 0 0 .1 0 0 0 0zm.5 1c0-.6 0-.6.8-.8-.3.3-.6.5-.8.8zm4-6.1c-.1 0-.1 0 0 0-.1-.1-.1-.2 0-.2l.1.1-.1.1zm.9 2.8c-.3-.5-.1-.9.2-1.4.1.6-.2.9-.2 1.4zm1.5-1.1c-.1-.1-.2-.1-.2-.2s.1-.1.1-.2c.1 0 .2 0 .2.1-.1.1-.1.2-.1.3zm11.8-.8c.1 0 .1-.1.2-.1h.1c.1.1.1.1-.1.1 0 .1-.1.1-.2 0zm-3.9.6c.3-.1.6-.2.8 0 .1 0 .1.1.2.1 0 .2-.2.5-.4.9-.2-.2-.4-.3-.5-.4-.1-.2-.2-.4-.3-.5 0 0 .1-.1.2-.1zm-1.1.1c.1 0 .1 0 0 0 .1 0 .1 0 0 0zm-2.8.4l.1.1c0 .1-.1.1-.1.2 0 0 0-.1-.1-.1.1-.1.1-.1.1-.2zm-.3 1.1h-.1c-.5 0-.6 0-.4-.5.1.2.3.3.5.5zm-.8-1.3c.3.2.2.5.2.7-.2-.1-.4-.2-.7-.4.2-.1.4-.2.5-.3zm-.6 1.5zm-2 .1v-.1.1zm1.7 3.1v-.1h.1c0 .1-.1.1-.1.1zm.8.9s0-.1 0 0c0-.1 0-.1 0 0zm.7-1.7c-.3-.2-.5-.4-.8-.5H26c-1 .6-1.1.5-1.2-.8-.1-1.1-.1-2.1-.1-3.3.2.1.4.1.4.2.1.4.1.7.1 1.1v2.3c.9-.3.9-.3 1.9-.1.1-.5.1-1 .2-1.4h.6c0 .3-.1.6-.1.9 0 .3.1.5.2.8-.5.2-.7.5-1 .8zm4.8 1.3h-.2c0-.1.1-.2.1-.2.1 0 .2.1.3.1-.1 0-.1.1-.2.1zm.8-1.4c-.2.1-.5 0-.8-.1-.2-.1-.4-.3-.7-.5-.2-.1-.4-.3-.5-.4-.4 0-.4.5-.6.7-.2.2-.3.4-.5.6-.2-.3-.3-.7-.5-.9-.6-.6-.5-1.2-.1-1.9.1-.2.4-.3.5-.5-.4-.3-1-.7-1-1 .2.1.5.2.7.1.2-.1.4-.1.7-.1.2 1.5.5 1.5 1.4 2.2.3.3.9.5 1.1.9 0 0 .3 0 .4-.1.1-.1.1-.3.1-.4-.2-.4-.4-.7-.6-1.1.4-.3.6-.3.7 0 .2.3.3.6.4.9.1.8-.1 1.4-.7 1.6zm1.2-2.2c-.2-.4-.5-.8-.8-1.2 0-.1.1-.2.2-.3h1.2c.1.2.3.4.5.7 0 .2 0 .4.1.5l-1.2.3zm1.2 1.3v-.1.1zm.8-1.6c-.3-.2-.3-.9-.9-.6.1-.2.1-.4.1-.6.4 0 .8 0 1.2.1v.1c.1.3 0 .7-.4 1zm.6 1.7c-.1-.1-.1-.1 0-.1v.1c.1-.1 0 0 0 0zm-4.5 7.3s0-.1 0 0c0-.1 0 0 0 0zm5.3-10.8c.1 0 .3 0 .4.1 0 0 0 .1-.1.1h-.3c.1-.1 0-.1 0-.2 0 0 0-.1 0 0zm-.1.7c.2-.1.5-.1.7-.1.3 0 .5-.1.6-.2.1.2.1.3-.1.5-.1.2-.1.5-.2.7-.6.9-.6 1 0 2-.2.2-.5.3-.7.5-.4-.3-.5-.8-.4-1.2.1-.8-.2-1.5.1-2.2zm1.4 5.4s-.1.1-.1.2l-.1-.1v-.4c.1 0 .1.1.2.3zm-1.8.5c0-.4-.1-.8-.1-1.3h1.3c.1 0 .2.2.3.3-.5.1-.5.6-.7.9-.2.1-.5-.4-.8.1zm1.7 1.9l-.3.3c-.1.1-.3.1-.4.1-.1-.1-.2-.3-.3-.5.1-.2.2-.5.3-.6.3-.4.6-.4.8-.3.3.2.2.6-.1 1zm.7.4v-.1.1zm.3-2.7h.2c0 .3-.1.2-.2 0zm.3 2h.1-.1zm0-2c.1-.1.2-.3.4-.5 0 .5-.2.5-.4.5zm4.8-2.8zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2 0-.2.1-.2.1-.2zm-1.8 16.4s.1 0 .1-.1v.2c-.1.1-.2.1-.3.2.1-.1.2-.2.2-.3zm-.2.4c0 .1.1.1 0 .2l-.1.1v-.1c.1-.1.1-.1.1-.2zm.4 2.2c-.1.2-.2.3-.3.4l-.2-.1v-.5c0-.1.2-.2.4-.4.1.3.1.5.1.6zm.3-8c-.2-.1-.4-.2-.4-.5.3 0 .5 0 .8-.1.1-.1.2-.1.3-.1 0 .1-.1.2-.2.3.2.8 1.2 1.2 1 2.3-.7-.6-1.3-.8-1.4-1.7.1 0 0-.1-.1-.2zm.4 3c.3-.2.5-.1.7.1.1 0 .1.2.1.2 0 .1-.1.1-.2.1-.3.1-.5 0-.6-.4zm.6 4c.6.6.6.6.9 1.8-.9-.4-.7-1.1-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.2.6.5.4 1zm-.4-1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1.5-.1 1 .7 1.3-.3.2.4.4.6.5.9-.2.3-.7.3-.7.8zm.8-6.7c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2-.1.2-.2.3-.3.3zm.7 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 .1 0 .1-.1.1zm.6-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.5.2 1-.1 1.4zm.4 7.4c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2c0 .1-.1.2-.3.3zm.5-1.4l.1-.1-.1.1zm.6-6.1c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1-.1-.4-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.5c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 .1-.1.2-.1.2zm.8-.4c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm0 .8v0zm.4-5.8c.1 0 .2.1.2.1-.1 0-.2-.1-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1v-.1l.1.1c.1 0 0 .1 0 .1zm.2 2.6h.1-.1zm.5-10.3H53l-.3-.3V24c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .5 0 .8zm0 5.3v-.1h.2v.2c0-.1-.1-.1-.2-.1zm.6 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.4-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4-.1.6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.5-.4.4-.8.4zm1.2 4.4l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.1 0-.2.1-.4.2zm0-1.3c.1-.2.2-.4.3-.7.3.4-.1.5-.3.7zm1.7 1.2v-.1.1zm-.3-1.6c.5-.8.5-.8 1.1-.3-.3.2-.6.2-1.1.3zm2.3 4.9c0-.1 0-.1 0 0v-.2s.1 0 0 .2c.1-.1.1-.1 0 0zm.1-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6v-.2l.1-.1c.1 0 .1.1.1.2-.1 0-.2 0-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1-.1-.2-.1-.2-.2zm.9 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.1.3-.3.3zm1.3 1.9s0-.1 0 0c0 0 .1 0 .1.1l-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.4zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.1.1-.2.1zm.6-15.7c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.2.1-.2.1zm.5-16c0 .1 0 0 0 0zm1.8 16.1c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1.1-.1.2-.1.2zm3.8-.3zm-.5-5.2s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zM71 15.6c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.2.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.2.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1 0 .1 0 .2.1zm-.3 4.2c0 .1 0 .1-.1.1l.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4 0-.1-.1-.2-.1-.2zm1.5 7.2c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.2-1.1.3-1.5.4zm5.8-12c.1 0 .1 0 0 0 .1 0 .1.1 0 0 .1.1 0 0 0 0zm-.7 3.9c.1 0 .1 0 0 0 .1.1.1.1 0 .1.1 0 0 0 0-.1 0 .1 0 0 0 0zm-.3 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1zM72.9 16v-.1l.1.1h-.1zm1 19c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.7-1.5.6-2.2.4zm2.6 1.3c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2 0 0 0 .1-.1.2zm.9-9.5h.1v.2c-.1 0-.1 0-.2-.1.1 0 .1-.1.1-.1zm-.1 5.1c0 .1.1.1 0 0v0c0 .1 0 .1 0 0zm.2 3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.2.6-.2.9-.2.2 0 .3.1.8.9-.6.1-1.1.1-1.6 0zm.8-14.4c-.1-.1-.1-.3 0-.4V20v.5zm0 6.2s0 .1-.1.1c0 0 0-.1.1-.1-.1 0-.1 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.3-.1-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.4-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1 0-.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.2.6-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-3.3.3zm-.5-.3c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.2 0 .5-.1.8-.2zm-9.7-6.4c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.1-.2.2-.3zm-5-7.1v0zM94 18.2l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3 0-.1-.1-.2 0-.2zm-1-.9c0 .1 0 .1 0 0 0 .1 0 .1 0 0zm-1.1.1zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8s.1 0 0 0c.1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3 0 0 .2.1.3.2zM84.8 14s0 .1 0 0zm-1.7 17.7v.1H83s-.1 0-.1-.1c.1.1.2.1.2 0zm-1.5-9.6v-.2s.1 0 .1.1l-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1V27zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.6-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .3-.2.6-.8.6zm1.1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.2-4.4zm2 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.6-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 1.9c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .2-.1.2zm1-2.1c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.5c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.8-.5-1.3-.4zm1.5 4.5v.1h-.2v-.1c.1-.1.1-.1.2 0zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.2-1.7-.2zm1.9.2s-.1 0 0 0c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.3-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0-.1 0 0zm-.3-3.1s-.1-.1-.1-.2h.4s.1.1.1.2h-.4zm.3-12c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.3zm-.2-9.6c.1 0 .2.1.3.2-.2 0-.3-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .1-.1.2-.1zm0 9.4s-.1 0-.1-.1c.1 0 .1 0 .1.1 0-.1 0 0 0 0zm.3-8h-.1v-.1c0-.1.1-.1.2-.2-.1.2-.1.2-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2c-.2-.1-.4-.1-.7 0zm.5 6.6zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.7s-.1 0 0 0c-.1 0-.1-.1 0 0-.1-.1 0-.1 0 0zm1.2-2c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.1-.5-.2-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.7-.2-1.3-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s-.1 0-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9 0-1.3.1zm1.3-6.9c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.4.2.9-.1 1.5zm.6 4h-.1c0-.1-.1-.1-.1-.2h.2c.1 0 .1.1 0 .2zm.5-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.7s-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1zm0-2.3c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.4c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.6-1.3-.9zm4.9 4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c-.1 0-.1 0 0 0-.1 0-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm-3-3.4c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.5 0 .8-.3 1.1zm1.4 3.2c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.7.3.4.9.5 1.4zm.3-2.1c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.2-.6-.7-.7-1.5zm2.5 4.8c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.7.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s-.1 0 0 0c0 0 0-.1 0 0 0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .1-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-1-.1-1.7.2-2.3.5zm1.6 5.9zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.2.3-.4.5-.6.8zm.7-4.3s-.1 0 0 0c-.1 0-.1 0 0 0-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.3-.3-.4-.5-.5-.6zm4.5 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1-.1-.2 0-.4 0zm-1.1-4.9c.1-.2.3-.2.4 0l.7.7c-.7.2-.7.2-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.4.6.8.1 1.1zm-.8-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.7.8-1.4.3-1.9.5zm7.5-1.1c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1 0-.1.1-.1zm-3.6 11.7c-.1 0-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1 .6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.5.5 0 .9 0 1.3zm-1-1.9c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.2-1 .2-1.5.2zm2.1 4.2c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.7c0-.4 0-.4.5-.6-.2.3-.3.5-.5.6zm.5-.5c.3-.2.5-.4.9-.6-.2.6-.2.7-.9.6zm.4-5.6h.2v.1h-.2v-.1zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.3.6-.3.9zm.4 2.1V31s0-.1.1-.1c-.1 0 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.2-.4.4-.6 0zm.8 5.6V34c.1 0 .1-.1.2-.1v.1s-.1 0-.2.1zm-.2-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm-.1-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.2-.2-.6-.4-.9-.5zm1.1 2.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm14.2 7.8c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.2.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.3 0-.6-.1-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3 0 .2-.3.4-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.3-.7.4-1.1.4zm2.6-.4l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.1-.4.4-.1.6-.3zm-.4 6v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7 0-1.4.1-2 .1zm.7 3.2v-.1.1zm.5 1.6V36h.1c.1.1.1.2.2.3-.1-.1-.2-.1-.3-.1zm.5.2c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1-.1.1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.2-3v-.1.1zm.6-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.2.2.4.1.5zm.7 2.2c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5-.1.1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.2-.5.5-.6zm-.7 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.3-.6.7-1 1.1-.8zm-2.3 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .1-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c-.1-.1-.1-.1-.2-.1zm1.8 1.9l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4 0 1.1-.1 1.1-1.3.4zm1.4-1.4c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.1.4.1.5.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5c-.1 0-.1 0 0 0-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.2.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .1-.1.2-.1zm-7.2-.3l.1.1c-.1 0-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.2-.7.1zm.7-.1c0-.2.1-.4.1-.5H160.6c-.1.2-.2.4-.4.5zm5.2 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.3.9-.5 1.4zm3.5 1.2c0-.2 0-.4-.1-.7.3.4.2.6.1.7zm1.8-.9c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1-.1-.1-.1 0-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.2c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1v.2zm0-2.3c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.8c-.4-.2-.1-.6-.2-.8.5.4.5.4.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c-.1-.1-.1-.2-.1-.4-.1.1 0 .1 0 0zm-.3 2.1c.4-.3.6 0 .8.1-.3 0-.5-.1-.8-.1zm.9 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2.1.3-.2.4-.4.6zm.4-1.4v-.2c.1.1.1.1 0 .2.1-.1.1 0 0 0zm3-.1h.2v.1c-.1 0-.1.1-.2.1v-.2zm-1.8-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.2-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2 0-.3.1-.3.1zm.6.9c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.3c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1c-.1-.1-.2-.1-.2-.2h.3c-.1 0-.1.1-.2.1 0 .1.1.1.1.1zm.1-.1c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm2.2-3.3zm-.7 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.2.1-.3.1-.3zm.1 2c0-.1 0-.2-.1-.3 0 0 .2-.1.2 0s.1.2.1.2-.1 0-.2.1zm.6-3.8s0-.1 0 0c-.1-.1-.1-.1 0-.1 0 0 .1 0 0 .1.1-.1.1 0 0 0zm.8 3c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.2 0 .4 0 .1-.1.2-.1.2zm1.6-.1v-.2c0-.2.1-.3.2-.4 0 .2 0 .4.1.6h-.3zm2.1.1zm12.7 4.3c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-3.3.3c.1.1 0 .1 0 .1-.1 0-.1-.1 0-.1-.1 0-.1 0 0 0zm-1-2.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1 0-.1-.1-.1-.1-.2s.1-.1.2-.1zm-.1 1.4zm-2.5-4.1c0 .1.1.1.1.2-.1 0-.1-.1-.2-.1 0 0 0-.1-.1-.1h.2zm-3.6.7s-.1 0 0 0c-.1 0-.1 0 0 0-.1-.1 0-.1 0 0zm-1.4 5.6zm-.1.2l.1-.1v0c0 .1.1.2.1.3 0-.1-.1-.1-.2-.2zm.2.5h-.1c.1-.1.1-.2.2-.3.2.1.3.2.5.2-.2 0-.3.1-.6.1zm5.8-2.2c.1.5 0 1-.3 1.4-.5.1-1 .1-1.4.2-.1-.2-.2-.4-.3-.5-.3 0-.5.2-.5.5v.1c-.6 0-1.1-.1-1.7-.1-.4.4-.5.5-.8.6.1 0 .1 0 .2-.1-.2-.3-.3-.6-.5-.8l.3-.3c0-.7-.3-1.1-.6-1.7.1.1.3.1.6.2l-.6-.6c.8-.1 1 0 1.1.9 0 .3-.1.6.2.7.4-.3.5-.3.7-.9 0-.1.1-.1.1-.2v-.1c-.3-.5-.6-1.1-.8-1.8h.2c.2-.1.4-.1.5-.1-.1.1-.1.3-.1.5 0 .5.3.8.8.8.4 0 .7-.3.7-.7 0-.2-.1-.4-.3-.6.1-.1.2-.2.1-.3-1-.3-1.2-1.1-1.2-2.1 0-.2 0-.3.1-.4.2-.2.4-.3.7-.5h.1c0 .2.1.4.1.6.2 0 .3 0 .4.2.1.5.2 1.1.6 1.4 0 .7-.2 1.3.3 1.8.6-.7.6-1-.1-1.7.1.1.2.1.3.2.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.2-.1.3-.1.5-.1 0 .3 0 .6-.1.9-.1.2 0 .4 0 .6-.1 0-.2-.1-.3-.1 0 .3-.2.6.2.9.1 0 .1-.1.2-.1v.1c0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.2.6 0 1.2.1 1.8zm1.5 3.6v.2c.1.1.1.2.2.4-.3 0-.5.1-.8.6-.2.1-.4.2-.4.3v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2 0-.3v-.2c.2 0 .4.1.6.2h-.6zm0-2.1c-.1 0-.1 0 0 0-.1-.2-.1-.4-.3-.6v-.1c.5 0 1-.1 1.6 0h.5c0 .3 0 .5-.2.7-.6.1-1.1-.2-1.6 0zm1.9 2.6c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2-.2-.1-.3 0-.5 0zm1.9-2.2c-.1-.1-.3-.2-.4-.2h-.2c-.2-.2-.5-.3-.8-.4 0-.3 0-.7-.1-1l.1-.1.4.4s.1 0 .1-.1c.2.1.5.3.7.4.4.1.8.2 1.1.6-.3.2-.6.3-.9.4zm.6-1.6c.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0-.1.1-.1.1-.2.1.2.2.5.3.8-.2 0-.3-.1-.4-.2zm1.2 2.4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1.1 0 0 0 0 .1zm1.5-6.8c.1 0 .2-.1.3-.1 0 .2 0 .3-.1.4-.1-.1-.1-.2-.2-.3zm-1.3 2.8l.3-.3c.1-.1.1-.2.2-.4h.4c.1.1.2.1.3.2-.3.3-.4.4-.6.9-.2-.1-.4-.2-.6-.4zm.8.5c0 .1-.1.1-.2.1 0-.1 0-.1-.1-.2.1 0 .2.1.3.1zm.1 2.4c.2.4.2.5 0 .9-.1.1-.2.1-.3.2-.1-.5-.2-.9-.4-1.3l.6-.6c.2.3.4.4.8.5-.2.1-.5.2-.7.3zm1-1.4v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 0 .1.1.2.1-.1.2-.2.3-.3.5-.2 0-.5.1-.7.1v-.4c0-.1.1-.2.1-.2 0-.3 0-.6.1-.9.2 0 .4.1.6.1v-.1c0-.1.1-.1.1-.2 0 .1 0 .2.1.3l.3.3c-.1.1-.2.3-.3.5zm.7 2.7c-.1-.1-.1-.1 0 0l-.1-.1c0-.4 0-.7.1-1.1.1.1.1.4.1.8 0 .1-.1.2-.1.4zm.9-1.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .2-.2.3-.2.4zm1.4 2.9zm2.2-7.4c0 .1-.1.1-.1.2s-.2.1-.3 0v-.2h.4zm-.2 1.6zm-.3-1.7c-.1 0 0 0 0 0zm.6 8.1c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.2.2-.2.4zm-.5-3.1h-.2v-.3c.2 0 .5.1 1 .2-.4.1-.6.1-.8.1zm1.7 7.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.3-.3-.1-.5 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8c0-.1.1-.1 0 0 .1-.1.1-.1 0 0 .1-.1.1-.1 0 0zm.2 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.4-5.3zm1.7 6.1s.1 0 .1-.1c0 .2 0 .3.1.5 0-.1-.1-.2-.2-.4zm.4.7c0-.1-.1-.1-.1-.2.1.1.1.1.1.2.1-.1.1 0 .1.1 0-.1-.1-.1-.1-.1zm-.4 3.8zm1.1-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3.1 0 0 .1-.1.2zm1.1-.5v-.1h.1c0-.1 0 0-.1.1.1-.1 0-.1 0 0zm.7-.2c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2s0 .1-.1.1zm.6 1.3c0-.1-.1-.1-.1-.2v-.1s.1 0 .1-.1l.1.1c0 .2-.1.3-.1.3zm5.9-8.3c0 .1-.1.2-.1.3l-.1.1c-.2-.2 0-.4.2-.4zm2.9-4.6zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2.1-.1.1-.2.1-.2zm-.3 18.1c.6.6.6.6.9 1.8-.9-.5-.7-1.2-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.1.6.4.4 1zm-.4-1.1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1v0c.4 0 .9.6 1.2-.3.2.4.4.6.5.9-.1.3-.6.4-.6.8zm.8-6.6c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2l-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5l-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.4.2.9-.1 1.4zm.5 7.3c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.3l.1-.1-.1.1zm.5-6.2c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1 0-.3-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.4c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 0-.1.1-.1.2zm.8-.5c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.2 0-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3v-.1c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .6 0 .8zm.1 5.3v-.1h.2v.2c-.1 0-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.5-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.3 0 .4 0 .6-.1zm-.4 1.5c.2-.5.5-.4.8-.4-.3.6-.5.4-.8.4zm1.2 4.5l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.4c.1-.2.2-.4.3-.7.2.5-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.5c.5-.8.5-.8 1.1-.3-.3.1-.6.2-1.1.3zm2.4 4.8c-.1 0-.1 0 0 0l-.1-.1s.1 0 .1.1c0-.1 0 0 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6V32l.1-.1c.1 0 .1.1.1.2-.1 0-.2.1-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1 0-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c0 .3-.2.3-.3.3zm1.2 1.9s.1 0 .1.1c0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.5zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.6-15.8c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1 0-.2.1zm.6-16.1c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1.1-.1.1 0 0zm-.1 0c0 .1 0 .1 0 0zm1.1-5.7c-.1-.1-.2-.2-.2-.3.1 0 .2.1.2.1.1.1.1.2 0 .2.1 0 0 0 0 0zm.7 21.9c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1 0-.1.2-.1.2zm3.8-.3zm-.5-5.3s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.1.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.1.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1.1.2.1.2.1zm-.3 4.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4l-.1-.2zm1.5 7.3c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.1-1 .2-1.5.4zm6.8-8.6h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.2 5.2c.1 0 .1 0 0 0v0zm-.7-8.6s-.1 0 0 0c-.1 0-.1 0 0 0zm-.7 3.8s0 .1 0 0c.1.1.1.1 0 .1 0 .1-.1 0 0-.1-.1.1-.1 0 0 0zm-.4 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1c0 .1 0 0 0 0zm-2.6-15.9v-.1l.1.1h-.1zm1 19.1c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.6-1.5.6-2.2.4zm2.6 1.2c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1.1 0 .1-.1.2zm.1-25.4v-.1c.1 0 .1.1 0 .1zm.5-.3c-.1 0-.2.1-.3.1 0-.1 0-.3.1-.4 0 0 0-.1.1-.1 0 .2 0 .3.1.4zm.5 24.3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4v-.1.5zm0 6.2s0 .1-.1.1l.1-.1c-.1 0 0 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2 0-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.5-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.7-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1 0 .1-.1zm-3.2.3c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zm-.6-.2c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.2.8-.2zm-9.7-6.5c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.2-.2.2-.3zm-5-7.3s.1 0 0 0c.1.1.1.3.1.4-.1-.1-.2-.2-.1-.4-.1.1 0 0 0 0zm-5.5 5.7l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.8c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0zm-1.2 0zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8c.1 0 .1.1 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zm-4.2-17.8c0 .1 0 .1 0 0 0 .1 0 0 0 0zm-1.6 17.8v.1h-.1s-.1 0-.1-.1h.2zm-1.6-9.7v-.2s.1 0 .1.1-.1.1-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1v-.4zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8-.1.4-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.7-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 2c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .1-.1.2zm1-2.2c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.4c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.8-.5-1.3-.4zm1.5 4.4v.1h-.2v-.1h.2zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.1-1.7-.2zm1.9.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.4-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.1.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0 0 0 0zm-.3-3s-.1-.1-.1-.2h.4s.1.1.1.2c-.2-.1-.3 0-.4 0zm.3-12.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.4zm-.2-9.7c.1 0 .2.1.3.2-.2 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2 0 .2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2-.1.3-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2h-.7zm.5 6.6c0 .1 0 .1 0 0 .1 0 0 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.8s-.1 0 0 0c-.1-.1-.1-.1 0 0-.1-.2 0-.1 0 0 0-.1 0-.1 0 0zm1.2-2.1c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.2-.4-.1-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.7-.1-1.3-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s0 .1-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9.1-1.3.1zm1.3-6.8c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7l.1-.1c0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2 0 .3.1.9-.2 1.5zm.7 3.9h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.8c0-.1-.1-.1 0 0l-.1-.1c.1-.1.1-.1.1.1 0-.1 0-.1 0 0zm0-2.4c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.3c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.7-1.3-.9zm4.9 3.9c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c0 .1-.1.1 0 0-.1 0-.1 0-.1-.1 0 .1 0 0 .1.1zm-3-3.3c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.4 0 .7-.3 1.1zm1.4 3.1c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.4.9.5 1.4zm.3-2c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.3-.6-.8-.7-1.5zm2.5 4.7c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.8.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .2-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9 0-1.6.2-2.3.5zm1.6 5.9c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.4.6-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.4-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.2 0-.3.1-.4 0zm-1.2-4.8c.1-.2.3-.2.4 0l.7.7c-.7.1-.7.1-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.3.6.8.1 1.1zm-.8-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.2-1.9.5zm7.5-1.2s0 .1 0 0c0 .1 0 .1-.1.1s0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1.1-.1.1-.1zm-3.6 11.7s-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1.1.6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.4.6-.1.9 0 1.3zm-1.1-1.8c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.1-1 .1-1.5.2zm2.1 4.1c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.8c0-.4 0-.4.5-.6-.2.2-.3.4-.5.6zm.5-.6c.3-.2.5-.4.9-.6-.2.7-.2.7-.9.6zm.4-5.6h.2v.1h-.2V34zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.2.7-.3.9zm.4 2.1v-.1s0-.1.1-.1c-.1.1 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.3-.4.4-.6 0zm.9 5.6v-.1c.1 0 .1-.1.2-.1v.1c-.1 0-.2.1-.2.1zm-.3-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm0-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.3-.9-.5zm1 2.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1.1-.2.1-.2.2zm14.2 7.7c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.1.3-.1zM314 34.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.2 0-.6 0-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3.1.2-.3.5-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.4-.7.4-1.1.4zm2.6-.3l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.2-.5.4-.2.6-.3zm-.4 5.9v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7.1-1.3.1-2 .1zm.8 3.3v-.1.1zm.4 1.5v-.2h.1c.1.1.1.2.2.3 0-.1-.2-.1-.3-.1zm.5.3c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1 0-.2.1zm.2-3v-.1.1zm.7-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2 0 .1.1.3.1.5zm.6 2.1c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.3-.5.5-.6zm-.6 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.2-.6.6-.9 1.1-.8zm-2.4 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .2-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1s-.1-.1-.2-.1zm1.8 2l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-.9-1.9c.4-.6.8-.4 1.3-.4-.1 1-.2 1-1.3.4zm1.3-1.5c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.2.4.1.6.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5s-.1 0 0 0c-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.3.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .2-.1.2-.1zm-7.2-.3s.1 0 0 0l.1.1c-.1.1-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.3-.7.1zm.7-.1c0-.2.1-.4.1-.5H341.9c-.1.2-.2.4-.4.5zm5.3 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.4.9-.5 1.4zm3.4 1.3c0-.2 0-.4-.1-.7.3.3.2.5.1.7zm1.8-1c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1 0-.1-.1.1-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.3c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1.1 0 0 .1 0 .2zm0-2.4c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.9c-.4-.2-.1-.6-.2-.8.5.3.5.3.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c-.1-.1-.1-.3-.1-.4zm-.3 2c.4-.3.6 0 .8.1-.3 0-.5 0-.8-.1zm1 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2 0 .3-.3.4-.4.6zm.3-1.4v-.2c.1.1.1.1 0 .2.1 0 .1 0 0 0zm3.1-.1h.2v.1c-.1 0-.1.1-.2.1s-.1-.1 0-.2zm-1.9-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.1-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2.1-.2.1-.3.1zm.6 1c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.4c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1.1c-.1-.1-.1-.2-.2-.3h.3c0 .1-.1.2-.1.3zm2.4-3.5s-.1 0 0 0c-.1 0 0 0 0 0zm-.8 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.1.1-.3.1-.3zm.1 2v-.4s.2-.1.2 0 .1.2.1.2c-.1.1-.2.2-.3.2zm.7-3.8c-.1 0-.1 0 0 0-.1-.1-.1-.1 0-.1-.1 0 0 0 0 .1 0-.1 0 0 0 0zm2.5.9c0 .1 0 .1-.1.2.1-.1.1-.2.1-.2zm-1.8 2.2c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.3.1.4-.1 0-.2.1-.2.2zm.6-1.8c-.1 0-.2 0-.2-.1-.1-.1-.2-.3-.2-.4.1 0 .1-.1.2-.1.1.1.2.3.3.4 0 0 0 .1-.1.2zm.5 1.9c-.2-.4 0-.5.1-.7 0 .2 0 .4-.1.7zm.2-.7c0-.5-.1-1.1.5-1.4.1.6.1 1.2.2 1.8-.5.1-.5-.3-.7-.4zm.8-3.7l-.2-.2c.1-.1.2-.1.4-.1 0 0-.1.1-.2.3zm1.6 4.2zm.6-2.3c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1 0 0 .1.1.1.2 0 0-.1 0-.2.1zm.9 1c.1-.1.2-.3.3-.3 0 0 .1.1.2.1-.1.1-.2.3-.3.4 0-.1-.1-.1-.2-.2zm.5 1.9c0 .1-.1 0 0 0-.1-.1-.1-.2 0-.3.1 0 .1.1.2.1-.1.1-.1.2-.2.2zm.4-2.9l-1.2-2.1c.1-.2.1-.3.2-.5h.5v.5c.1.4.6.5.5 1-.1.3.2.7.2 1-.1.2-.2.2-.2.1zm.5-2.2s-.1 0 0 0v-.2.2zm.9.6c-.2-.3-.2-.5 0-.8h.1c0 .3 0 .5-.1.8zm1.4 2.5c-.1 0-.2-.1-.2-.1 0-.2.1-.5.2-.7.2.1.3.1.3.2 0 .2-.1.5-.3.6zm.4-3.7c0 .1 0 .1 0 0-.1.1 0 .1 0 0zm.1 5s0-.1-.1-.1h.2c0 .1.1.1.1.2-.1 0-.2 0-.2-.1zm2-4.3c-.1 0-.1-.1-.2-.1l.1-.1c.1 0 .1.1.1.2zm.3 1.4c-.1 0-.1-.1-.2-.1v-.1c.1 0 .2 0 .2.1v.1zm.5.9zm4.1 4.6c.1 0 .3.2.4.3.1.2-.2.5-.4.4-.1-.1-.2-.2-.5-.4.2-.1.4-.3.5-.3zm.1 1.9c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-1-3.7zm0 .8s.1.1 0 .1c0 0-.1 0-.1.1 0 0-.1 0-.1-.1.1 0 .2 0 .2-.1zm-.3 2.3c0 .1 0 .1-.1.1l.1-.1c-.1 0 0 0 0 0zm-.7-1.4c-.1 0-.1 0 0 0l-.1.1c0-.1 0-.1.1-.1zm-1.3 2.2c.1.1 0 .1 0 .1s-.1 0 0-.1c-.1 0 0 0 0 0zm.8 4.1c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2h-.5zm1.5-2c-.4-.5-1.1-.8-1.6-.6-.7.3-1.3-.2-2 0-.3.1-.4-.3-.3-.7.5 0 1-.1 1.6 0 .6.1.9-.1 1.2-.6.4.3.8.5 1.2.7.4.1.8.2 1.1.6-.4.3-.7.4-1.2.6zm1-2.3c.1.2.2.5.3.8-.6-.3-.6-.3-.3-.8zm2.5-3.8c-.2.2-.4.3-.6.6-.3-.1-.6-.3-.9-.4.1-.5.5-.5 1.5-.2zm-1.6 3.6s-.1 0-.1-.1V36s.1 0 .1.1v.1zm.2 3.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1.1 0 0 .1 0 .1zm.3-2.1h-.2v-.1c.1 0 .1 0 .2.1 0-.1 0 0 0 0zm-.3-2.4c.5-.1 1-.1 1.7-.2-.6.5-.6.5-.9 1.1-.4-.2-.8-.3-.8-.9zm2 .8c0 .1 0 .2.1.3l.3.3c-.2.3-.3.7-.5 1-.2 0-.5.1-.7.1 0-.3 0-.6-.1-.9 0-.3-.2-.5-.2-.8.4.1.7.2 1.1.2v-.1c-.1.1 0 0 0-.1zm0-1.7c0-.1.1-.2.1-.2.1 0 .2 0 .2.1v.2c-.1 0-.2 0-.3-.1zm.8 5.6c-.1-.1-.3-.1-.4-.2-.2-.2-.3-.5-.6-.9-.3.3-.6.6-1 .9-.1-.5-.2-.9-.4-1.3l.6-.6c.2.4.6.5 1 .6.8.1.8.2.8 1.1.1.1 0 .2 0 .4zm.1-6.4c-.1.2-.5.3-.8.1-.2-.1-.4-.4-.6-.6.3-.1.6-.3 1-.4.1 0 .2.1.2.1.1.2.3.4.2.8zm1.7-15.4v.1-.1zm-.4 1.2c.1 0 .2 0 .2.1.2.2.1.4 0 .6-.1-.2-.2-.3-.3-.5.1-.1.1-.1.1-.2zm-.7 5.2c.1 0 .1-.1 0 0 .1 0 .1 0 .2.1h-.2v-.1zm.2 11zm0 3.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .3-.2.4-.2.4zm.2-8.8zm.3 2.8v-.1.1zm.2-11.6s-.2 0-.2-.1c-.1-.4-.3-.8.2-1.1 0 .1.1.2.1.2.1.4.3.8-.1 1zm6.3-9.3zm-1.1-.1c-.1 0-.2.1-.4.1v-.1h.4zm-1.2 0c.1.1 0 .3 0 .4-.1-.1-.3-.2-.3-.4h.3zm-.6 3c0 .1-.1.3-.1.4-.2.3-.4.6-.6 1-.1-.9 0-1.4.4-2.3.3.2.3.6.3.9zm-.4-.9c-.1 0-.2 0-.2-.1v-.2h.1c.1.2.1.3.1.3zm-.8-2.1h.4c.1.2.2.3.3.5l-.6.9c-.1.1-.1.1-.6-.1.2-.4.3-.9.5-1.3zM389 14s.2.1.1.2-.1.2-.2.2c0-.1-.1-.1-.2-.2.1-.1.2-.1.3-.2zm-.9 27.2zm.1-28.5zm.5 19.6c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.2.1-.2.1zm-.2-14.9c0-.2.1-.5.1-.7 0-.3-.1-.5-.2-.8.2 0 .4-.1.4-.1.4.6 1 1.2.8 2.2-.3-.2-.7-.4-1.1-.6zm.8 1.5zm-.1 6.8c.3-.2.6-.3.9-.5 0 .2.1.5.1.7 0 .4-.2.6-.5.7-.3 0-.5-.2-.6-.6 0-.1.1-.2.1-.3zm1.3 6.8s.1 0 .2.1c0 .5-.2 1-.5 1.4 0 .1-.2.1-.3 0l-.1-.2c.2-.4.4-.8.7-1.3zm-.3-9.9zm-.1 12.8zm-.2-10.8c0-.1.1-.1.1-.2.1.1.3.1.2.2 0 .2-.1.4-.1.6-.1-.2-.2-.4-.2-.6zm.5 17.2c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.1.3-.2.4zm-.5-3h-.6l-.1-.1c.5-.3.5-.3 1.6 0-.5 0-.7 0-.9.1zm1.1-15.1c-.1 0-.1-.1-.1-.2s.1-.1.1-.2c.1.1.1.2.2.3l-.2.1zm.6 22.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.2-.3-.1-.4 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8h-.2c.1 0 .2-.1.2 0 .1-.1.1 0 0 0zm.2 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.1-24c-.2.4-.4.2-.8.2.1-.4.2-.6.3-.9h.3c.3.1.3.4.2.7zm-.4-4.6c0 .4-.1.7 0 .9.1.6 0 1.1-.3 1.6-.4.7-.6 1.6-.9 2.4-.1-.2-.2-.4-.4-.6-.4-.1-.5.2-.5.5.1.5.1.9 0 1.4-.1.3-.3.3-.5.2 0-.1-.1-.2-.1-.3-.2-1.7-.2-1.7 1.2-2.8.4-.3.6-.6.7-1.2 0-.5.1-1 .3-1.4.4-.8.3-1.7 0-2.5-.1-.3-.2-.6-.3-1v-1.1c.3-.1.5-.2.8-.3 0 .1.1.2.1.2.3.6.1 1-.4 1.2.2.5.3.9.5 1.3.4.2 1 0 1.3.6l-.3.9c-.1.1-.3.2-.5.3-.3.1-.4 0-.7-.3zm.7 23.3zm.4-20.3c-.1 0-.1-.1-.2-.1 0-.1.1-.2.1-.2.1 0 .1.1.2.1-.1 0-.1.1-.1.2zm.2-1.6c0 .1-.1.1 0 0zm.1-.1c-.1-.4-.2-.7-.3-1.1.2.4.5.7.3 1.1zm.4-3.7c.4 0 .5.4.7.8-.8-.1-.8-.1-.7-.8zm.7 31.8s.1 0 .1-.1c0 .2 0 .3.1.5-.1-.1-.2-.2-.2-.4zm.3.7c0-.1-.1-.1-.1-.2.1.1.1.1.1.2.1-.1.1 0 .1.1l-.1-.1zm.2-32.7s0-.1 0 0l.1-.1c-.1 0-.1.1-.1.1zm-.6 36.5zm1.2-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3 0 .1-.1.1-.1.2zm.5-35.2c-.3.1-.8-.2-1 .3 0-.2 0-.4.1-.6.1-.2.4-.3.5-.3.4 0 .4.3.4.6zm.5 1.2v.1h-.1l.1-.1zm0 33.5V47h.1l-.1.1c.1 0 0 0 0 0zm.2-29.6s0-.1-.1-.1l.2-.2.1.1-.2.2zm.5 29.4c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2.1.1 0 .1-.1.1zm.1-32.7v-.1.1zm.5 34.1c0-.1-.1-.1-.1-.2s.1-.1.1-.2c0 .1.1.1.1.2 0 0 0 .1-.1.2zm1-30.5h-.1c0-.1 0-.1.1-.2h.1c-.1.1-.1.1-.1.2zm.6-5c.1-.3.1-.5.2-1 .3.5.5.8.7 1.2-.3 0-.5 0-.9-.2zm4.3 16.8c.1 0 .2 0 .2.1.2.2.4.4-.1.7 0-.3-.1-.6-.1-.8zm.2-9.5c.1-.2.2-.3.4-.4 0 0 .2 0 .2.1v.2c-.3 0-.4 0-.6.1zm1.3 1.8zm-1.6-1.6c.1-.1.2-.1.3-.2 0 .1 0 .2-.1.4 0 0-.1.1-.2.1 0-.1-.1-.2 0-.3zm-1.2 21zm1-12.9c.1.5.2.8.2 1.1-.3-.1-.4-.4-.2-1.1zm2.3 3s-.1-.1 0 0l-.1-.1s.1 0 .1.1zm-1.3-6l.5-1c.2.6.1.8-.5 1zm1.1.4c0-.1-.1-.2-.1-.3v.3c-.1 0-.2.1-.2.1.1-.1.2-.3.2-.4 0-.2.1-.4.2-.6.4 0 .6.2.6.7-.3 0-.5.1-.7.2zm2.1-2.9c-.1 0-.1-.1 0 0 0-.1 0-.2.1-.2-.1 0-.1.1-.1.2zm9.4 8.8c.1.2.1.5.2.8-.3-.1-.5-.3-.6-.6 0-.1.1-.2.1-.3.1-.1.2 0 .3.1zm.5-3.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1s.1.1.1.2c-.1.1-.1.1-.2.1zm1.7 1c0 .1 0 .1 0 0 0 .1 0 0 0 0 .1 0 .1 0 0 0zm.5 1c0-.6 0-.6.8-.8l-.8.8zm4-6.1s-.1 0 0 0c-.1-.1-.1-.2 0-.2l.1.1-.1.1zm.9 2.8c-.3-.5-.1-.9.2-1.4.1.6-.2.9-.2 1.4zm1.5-1.1c-.1-.1-.2-.1-.2-.2s.1-.1.1-.2c.1 0 .2 0 .2.1s-.1.2-.1.3zm11.8-.8c.1 0 .1-.1.2-.1h.1c.1.1.1.1-.1.1 0 .1-.1.1-.2 0zm-3.9.6c.3-.1.6-.2.8 0 .1 0 .1.1.2.1 0 .2-.2.5-.4.9-.2-.2-.4-.3-.5-.4-.1-.2-.2-.4-.3-.5 0 0 .1-.1.2-.1zm-1 .1zm-2.8.4l.1.1c0 .1-.1.1-.1.2 0 0 0-.1-.1-.1 0-.1 0-.1.1-.2zm-.4 1.1h-.1c-.5 0-.6 0-.4-.5.1.2.3.3.5.5zm-.8-1.3c.3.2.2.5.2.7-.2-.1-.4-.2-.7-.4.2-.1.4-.2.5-.3zm-.6 1.5zm-2 .1v-.1.1zm1.7 3.1v-.1h.1c0 .1 0 .1-.1.1zm.8.9s0-.1 0 0c.1-.1.1-.1 0 0zm.7-1.7c-.3-.2-.5-.4-.8-.5h-.2c-1 .6-1.1.5-1.2-.8-.1-1.1-.1-2.1-.1-3.3.2.1.4.1.4.2.1.4.1.7.1 1.1v2.3c.9-.3.9-.3 1.9-.1.1-.5.1-1 .2-1.4h.6c0 .3-.1.6-.1.9 0 .3.1.5.2.8-.5.2-.7.5-1 .8zM435 31h-.2c0-.1.1-.2.1-.2.1 0 .2.1.3.1-.1 0-.2.1-.2.1zm.7-1.4c-.2.1-.5 0-.8-.1-.2-.1-.4-.3-.7-.5-.2-.1-.4-.3-.5-.4-.4 0-.4.5-.6.7-.2.2-.3.4-.5.6-.2-.3-.3-.7-.5-.9-.6-.6-.5-1.2-.1-1.9.1-.2.4-.3.5-.5-.4-.3-1-.7-1-1 .2.1.5.2.7.1.2-.1.4-.1.7-.1.2 1.5.5 1.5 1.4 2.2.3.3.9.5 1.1.9 0 0 .3 0 .4-.1.1-.1.1-.3.1-.4-.2-.4-.4-.7-.6-1.1.4-.3.6-.3.7 0 .2.3.3.6.4.9.1.8-.1 1.4-.7 1.6zm1.2-2.2c-.2-.4-.5-.8-.8-1.2 0-.1.1-.2.2-.3h1.2c.1.2.3.4.5.7 0 .2 0 .4.1.5-.4.1-.7.2-1.2.3zm1.2 1.3v-.1.1zm.8-1.6c-.3-.2-.3-.9-.9-.6.1-.2.1-.4.1-.6.4 0 .8 0 1.2.1v.1c.1.3 0 .7-.4 1zm.6 1.7c-.1-.1-.1-.1 0-.1 0 0 .1 0 0 .1.1-.1.1 0 0 0zm-4.5 7.3s0-.1 0 0c.1-.1 0 0 0 0zm5.4-10.8c.1 0 .3 0 .4.1 0 0 0 .1-.1.1h-.3c0-.1-.1-.1 0-.2-.1 0-.1-.1 0 0zm-.2.7c.2-.1.5-.1.7-.1.3 0 .5-.1.6-.2.1.2.1.3-.1.5-.1.2-.1.5-.2.7-.6.9-.6 1 0 2-.2.2-.5.3-.7.5-.4-.3-.5-.8-.4-1.2.1-.8-.2-1.5.1-2.2zm1.4 5.4s-.1.1-.1.2l-.1-.1v-.4c.1 0 .2.1.2.3zm-1.7.5c0-.4-.1-.8-.1-1.3h1.3c.1 0 .2.2.3.3-.5.1-.5.6-.7.9-.3.1-.6-.4-.8.1zm1.6 1.9l-.3.3c-.1.1-.3.1-.4.1-.1-.1-.2-.3-.3-.5.1-.2.2-.5.3-.6.3-.4.6-.4.8-.3.3.2.2.6-.1 1zm.8.4v-.1.1zm.2-2.7h.2c0 .3-.1.2-.2 0zm.3 2h.1-.1zm0-2c.1-.1.2-.3.4-.5 0 .5-.2.5-.4.5zm4.8-2.8zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2l.1-.2zm-1.7 16.4s.1 0 .1-.1v.2c-.1.1-.2.1-.3.2 0-.1.1-.2.2-.3zm-.2.4c0 .1.1.1 0 .2l-.1.1v-.1c0-.1 0-.1.1-.2zm.3 2.2c-.1.2-.2.3-.3.4l-.2-.1v-.5c0-.1.2-.2.4-.4.1.3.2.5.1.6zm.3-8c-.2-.1-.4-.2-.4-.5.3 0 .5 0 .8-.1.1-.1.2-.1.3-.1 0 .1-.1.2-.2.3.2.8 1.2 1.2 1 2.3-.7-.6-1.3-.8-1.4-1.7.1 0 0-.1-.1-.2zm.5 3c.3-.2.5-.1.7.1.1 0 .1.2.1.2 0 .1-.1.1-.2.1-.3.1-.6 0-.6-.4zm.5 4c.6.6.6.6.9 1.8-.8-.4-.7-1.1-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.2.6.5.4 1zm-.4-1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1.5-.1 1 .7 1.3-.3.2.4.4.6.5.9-.2.3-.7.3-.7.8zm.8-6.7c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2-.1.2-.2.3-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 .1-.1.1-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.5.2 1-.1 1.4zm.5 7.4c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.4l.1-.1-.1.1zm.5-6.1c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1-.1-.3-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.5c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 .1 0 .2-.1.2zm.8-.4c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.2-.1-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3V24c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .5 0 .8zm.1 5.3v-.1h.2v.2c-.1-.1-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.4-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.3 0 .5-.1.6-.1zm-.4 1.5c.2-.5.5-.4.8-.4-.3.5-.5.4-.8.4zm1.2 4.4l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.3c.1-.2.2-.4.3-.7.2.4-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.6c.5-.8.5-.8 1.1-.3-.3.2-.6.2-1.1.3zm2.4 4.9c-.1-.1-.1-.1 0 0l-.1-.1c0-.1.1-.1.1.1 0-.1 0-.1 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6v-.2l.1-.1c.1 0 .1.1.1.2-.1 0-.2 0-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c0-.1-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c0 .3-.2.3-.3.3zm1.2 1.9s0-.1 0 0c0 0 .1 0 .1.1 0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.4zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.1.1-.2.1zm.6-15.7c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1.1-.2.1zm.6-16c-.1.1-.1 0 0 0zm1.7 16.1c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1.1-.1.2-.1.2zm3.8-.3zm-.5-5.2s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.2.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.2.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1 0 .2 0 .2.1zm-.3 4.2c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4 0-.1-.1-.2-.1-.2zm1.5 7.2c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.2-1 .3-1.5.4zm5.9-12s0 .1 0 0c0 .1-.1 0 0 0-.1 0-.1 0 0 0zm-.7 3.9c.1.1.1.1 0 .1 0 0-.1 0 0-.1-.1.1-.1 0 0 0zm-.4 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1zM476 16v-.1l.1.1h-.1zm1 19c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.7-1.5.6-2.2.4zm2.6 1.3c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1 0 0 .1-.1.2zm1-9.5h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.2 5.1c.1.1.1.1 0 0v0c0 .1 0 .1 0 0zm.3 3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4V20v.5zm0 6.2s0 .1-.1.1c0 0 0-.1.1-.1-.1 0 0 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2-.1-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.4-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1 0-.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.6-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-3.2.3s-.1 0 0 0c-.1 0-.1 0 0 0zm-.6-.3c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.1.8-.2zm-9.7-6.4c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.2-.2.2-.3zm-4.9-7.1v.1c-.1 0-.1 0 0-.1zm-5.6 5.5l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.9c-.1.1-.1.1 0 0-.1.1-.1.1 0 0-.1 0-.1 0 0 0zm-1.1.1zm-2.5 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zM491 15.1c.1 0 .1 0 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zM487.9 14s0 .1 0 0zm-1.6 17.7v.1h-.1s-.1 0-.1-.1c0 .1.1.1.2 0zm-1.6-9.6v-.2s.1 0 .1.1l-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1V27zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8-.1.3-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.6-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 1.9c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .2-.1.2zm1-2.1c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.5c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.8-.5-1.3-.4zm1.5 4.5v.1h-.2v-.1c.1-.1.2-.1.2 0zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.2-1.7-.2zm1.9.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.3-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.2-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.6 1-1 1zm1.9 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0-.1 0 0zm-.3-3.1s-.1-.1-.1-.2h.4s.1.1.1.2h-.4zm.3-12c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.3zm-.2-9.6c.1 0 .2.1.3.2-.1 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2-.1.2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2-.1.2-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2c-.2-.1-.4-.1-.7 0zm.5 6.6c.1 0 0 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.7s-.1 0 0 0c-.1 0-.1-.1 0 0-.1-.1 0-.1 0 0zm1.2-2c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.1-.4-.2-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.6-.2-1.2-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2l-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9 0-1.3.1zm1.3-6.9c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.4.2.9-.1 1.5zm.7 4h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.7s-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1zm0-2.3c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.4c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.6-1.3-.9zm4.9 4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2s-.1 0 0 0c-.1 0-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm-3-3.4c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.5 0 .8-.3 1.1zm1.4 3.2c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.5.9.5 1.4zm.3-2.1c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.2-.6-.7-.7-1.5zm2.5 4.8c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.7.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c.1-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .1-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9-.1-1.6.2-2.3.5zm1.6 5.9c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.4.5-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.5-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1-.1-.3 0-.4 0zm-1.2-4.9c.1-.2.3-.2.4 0l.7.7c-.7.2-.7.2-1.1-.7zm2.9.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.2.4.5.8.1 1.1zm-.9-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.3-1.9.5zm7.5-1.1c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1.1-.1.1-.1zm-3.6 11.7s-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1c0 0 0 .1-.1.1zm1.1.6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.4.5-.1.9 0 1.3zm-1.1-1.9c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.2-1 .2-1.5.2zm2.1 4.2c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.7c0-.4 0-.4.5-.6-.2.3-.3.5-.5.6zm.5-.5c.3-.2.5-.4.9-.6-.2.6-.2.7-.9.6zm.4-5.6h.2v.1h-.2v-.1zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.2.6-.3.9zm.4 2.1V31s0-.1.1-.1c-.1 0 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.2-.4.4-.6 0zm.9 5.6V34c.1 0 .1-.1.2-.1v.1c-.1 0-.2 0-.2.1zm-.3-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm0-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.4-.9-.5zm1 2.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm14.2 7.8c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.2.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.2 0-.5-.1-.5-.5zm1.3 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6-.1-.3 0-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.6 0-1.1.2-1.4.7zm1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3.1.2-.3.4-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.3-.7.4-1.1.4zm2.6-.4l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.2-.4.4-.1.6-.3zm-.4 6v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7 0-1.3.1-2 .1zm.8 3.2v-.1.1zm.4 1.6V36h.1c.1.1.1.2.2.3 0-.1-.1-.1-.3-.1zm.5.2c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1-.1.1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.2-3v-.1.1zm.7-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2 0 .2.1.4.1.5zm.6 2.2c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.3-.5.5-.6zm-.6 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.2-.6.6-1 1.1-.8zm-2.4 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .1-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c0-.1-.1-.1-.2-.1zm1.8 1.9l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-.9-1.9c.4-.6.8-.4 1.3-.4-.1 1.1-.2 1.1-1.3.4zm1.3-1.4c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.2.4.1.5.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5s-.1 0 0 0c-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.2.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .2-.1.2-.1zm-7.2-.3s.1 0 0 0l.1.1c-.1 0-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.2-.7.1zm.7-.1c0-.2.1-.4.1-.5H563.7c0 .2-.2.4-.4.5zm5.3 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.4.9-.5 1.4zM572 29c0-.2 0-.4-.1-.7.3.4.2.6.1.7zm1.8-.9c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1 0-.1-.1 0-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.2c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1.1.1 0 .2 0 .2zm0-2.3c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.8c-.4-.2-.1-.6-.2-.8.5.4.5.4.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c0-.1-.1-.2-.1-.4 0 .1 0 .1 0 0zm-.3 2.1c.4-.3.6 0 .8.1-.2 0-.5-.1-.8-.1zm1 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2 0 .3-.3.4-.4.6zm.3-1.4v-.2c.1.1.1.1 0 .2.1-.1.1 0 0 0zm3.1-.1h.2v.1c-.1 0-.1.1-.2.1-.1-.1-.1-.1 0-.2zm-1.9-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.1-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2 0-.2.1-.3.1zm.6.9c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.3c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1c-.1-.1-.2-.1-.2-.2h.3c-.1 0-.1.1-.2.1l.1.1zm.1-.1c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm2.3-3.3zm-.8 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.2.1-.3.1-.3zm.1 2c0-.1 0-.2-.1-.3 0 0 .2-.1.2 0s.1.2.1.2-.1 0-.2.1zm.7-3.8c-.1 0-.1-.1 0 0-.1-.1-.1-.1 0-.1-.1 0 0 0 0 .1 0-.1 0 0 0 0zm.7 3c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.2 0 .4 0 .1-.1.2-.1.2zm1.6-.1v-.2c0-.2.1-.3.2-.4 0 .2 0 .4.1.6h-.3zm2.1.1zm12.7 4.3c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-3.3.3c.1.1 0 .1 0 .1s-.1-.1 0-.1c-.1 0 0 0 0 0zm-1-2.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1 0-.1-.1-.1-.1-.2.1-.1.1-.1.2-.1zm-.1 1.4zm-2.5-4.1c0 .1.1.1.1.2-.1 0-.1-.1-.2-.1 0 0 0-.1-.1-.1h.2zm-3.6.7c-.1 0-.1 0 0 0-.1-.1 0-.1 0 0zm-1.4 5.6zm-.1.2l.1-.1v0c0 .1.1.2.1.3 0-.1-.1-.1-.2-.2zm.3.5h-.1c.1-.1.1-.2.2-.3.2.1.3.2.5.2-.3 0-.4.1-.6.1zm5.7-2.2c.1.5 0 1-.3 1.4-.5.1-1 .1-1.4.2-.1-.2-.2-.4-.3-.5-.3 0-.5.2-.5.5v.1c-.6 0-1.1-.1-1.7-.1-.4.4-.5.5-.8.6.1 0 .1 0 .2-.1-.2-.3-.3-.6-.5-.8l.3-.3c0-.7-.3-1.1-.6-1.7.1.1.3.1.6.2l-.6-.6c.8-.1 1 0 1.1.9 0 .3-.1.6.2.7.4-.3.5-.3.7-.9 0-.1.1-.1.1-.2v-.1c-.3-.5-.6-1.1-.8-1.8h.2c.2-.1.4-.1.5-.1-.1.1-.1.3-.1.5 0 .5.3.8.8.8.4 0 .7-.3.7-.7 0-.2-.1-.4-.3-.6.1-.1.2-.2.1-.3-1-.3-1.2-1.1-1.2-2.1 0-.2 0-.3.1-.4.2-.2.4-.3.7-.5h.1c0 .2.1.4.1.6.2 0 .3 0 .4.2.1.5.2 1.1.6 1.4 0 .7-.2 1.3.3 1.8.6-.7.6-1-.1-1.7.1.1.2.1.3.2.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.2-.1.3-.1.5-.1 0 .3 0 .6-.1.9-.1.2 0 .4 0 .6-.1 0-.2-.1-.3-.1 0 .3-.2.6.2.9.1 0 .1-.1.2-.1v.1c0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.2.6 0 1.2.1 1.8zm1.5 3.6v.2c.1.1.1.2.2.4-.3 0-.5.1-.8.6-.2.1-.4.2-.4.3v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2 0-.3v-.2c.2 0 .4.1.6.2h-.6zm0-2.1c-.1-.2-.1-.4-.3-.6v-.1c.5 0 1-.1 1.6 0h.5c0 .3 0 .5-.2.7-.5.1-1.1-.2-1.6 0zm2 2.6c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2-.3-.1-.4 0-.5 0zm1.8-2.2c-.1-.1-.3-.2-.4-.2h-.2c-.2-.2-.5-.3-.8-.4 0-.3 0-.7-.1-1l.1-.1.4.4s.1 0 .1-.1c.2.1.5.3.7.4.4.1.8.2 1.1.6-.3.2-.6.3-.9.4zm.6-1.6c.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0-.1.1-.1.1-.2.1.2.2.5.3.8-.2 0-.3-.1-.4-.2zm1.2 2.4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1.1 0 .1 0 0 .1zm1.5-6.8c.1 0 .2-.1.3-.1 0 .2 0 .3-.1.4 0-.1-.1-.2-.2-.3zM605 32l.3-.3c.1-.1.1-.2.2-.4h.4c.1.1.2.1.3.2-.3.3-.4.4-.6.9-.2-.1-.4-.2-.6-.4zm.8.5c0 .1-.1.1-.2.1 0-.1 0-.1-.1-.2.2 0 .2.1.3.1zm.1 2.4c.2.4.2.5 0 .9-.1.1-.2.1-.3.2-.1-.5-.2-.9-.4-1.3l.6-.6c.2.3.4.4.8.5-.2.1-.4.2-.7.3zm1-1.4v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 0 .1.1.2.1-.1.2-.2.3-.3.5-.2 0-.5.1-.7.1v-.4c0-.1.1-.2.1-.2 0-.3 0-.6.1-.9.2 0 .4.1.6.1v-.1c0-.1.1-.1.1-.2 0 .1 0 .2.1.3l.3.3c-.1.1-.2.3-.3.5zm.7 2.7c0-.1-.1-.1 0 0l-.1-.1c0-.4 0-.7.1-1.1.1.1.1.4.1.8 0 .1 0 .2-.1.4zm.9-1.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .2-.1.3-.2.4zm1.4 2.9zm2.2-7.4c0 .1-.1.1-.1.2s-.2.1-.3 0v-.2h.4zm-.2 1.6zm-.3-1.7zm.6 8.1c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.1.2-.2.4zm-.5-3.1h-.2v-.3c.2 0 .5.1 1 .2-.4.1-.6.1-.8.1zm1.7 7.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.2-.3-.1-.5 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.8-.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm.1 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.4-5.3zm1.8 6.1s.1 0 .1-.1c0 .2 0 .3.1.5-.1-.1-.2-.2-.2-.4zm.3.7c0-.1-.1-.1-.1-.2.1.1.2.1.1.2.1-.1.1 0 .1.1 0-.1 0-.1-.1-.1zm-.4 3.8zm1.2-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3 0 0-.1.1-.1.2zm1-.5v-.1h.1c0-.1 0 0-.1.1.1-.1 0-.1 0 0zm.7-.2c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2.1 0 0 .1-.1.1zm.6 1.3c0-.1-.1-.1-.1-.2v-.1s.1 0 .1-.1l.1.1c0 .2 0 .3-.1.3zm5.9-8.3c0 .1-.1.2-.1.3l-.1.1c-.2-.2 0-.4.2-.4zm2.9-4.6zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2.1-.1.1-.2.1-.2zm-.3 18.1c.6.6.6.6.9 1.8-.8-.5-.6-1.2-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.1.7.4.4 1zm-.3-1.1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1v0c.4 0 .9.6 1.2-.3.2.4.4.6.5.9-.2.3-.6.4-.6.8zm.7-6.6c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2l-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5l-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.4.2.9-.1 1.4zm.5 7.3c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.3l.1-.1-.1.1zm.5-6.2c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1 0-.3-.2-.4-.4zm.8 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.3 0-.3.1-.4.1zm1-.4zm0-1.4c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 0 0 .1-.1.2zm.8-.5c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2c.1-.2 0-.5 0-.7zm.3 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.7-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.1 0-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1s0 .1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3v-.1c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .6 0 .8zm.1 5.3v-.1h.2v.2c-.1 0-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.3.2.1.5-.1.7zm.9-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4 0 .6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.6-.5.4-.8.4zm1.2 4.5l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.4c.1-.2.2-.4.3-.7.2.5-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.5c.5-.8.5-.8 1.1-.3-.3.1-.6.2-1.1.3zm2.4 4.8c-.1 0-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1 0-.1 0 0 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6V32l.1-.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2s-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.2.3-.3.3zm1.2 1.9s.1 0 .1.1c0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3.1.5 0 .7zm1.5 4.5zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.7-15.8c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3-.1.2-.1.4-.1.6zm.5 13.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1 0-.2.1zm.6-16.1c-.1.1-.1.1 0 0zm1-5.7c-.1-.1-.2-.2-.2-.3.1 0 .2.1.2.1.1.1.1.2 0 .2.1 0 .1 0 0 0zm.7 21.9c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1 0-.1.2-.1.2zm3.8-.3zm-.5-5.3s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c.1-.1.1-.2.2-.2zm-.6-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c0-.1 0-.2.1-.3zm-.5 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c.1-.1.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1.1.2.1.2.1zM654 31s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4l-.1-.2zm1.5 7.3c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.1-1 .2-1.5.4zm6.8-8.6h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.1 5.2v.1c-.1 0-.1-.1 0-.1-.1 0-.1 0 0 0zm-.8-8.6zm-.7 3.8s0 .1 0 0c.1.1.1.1 0 .1v-.1c-.1.1 0 0 0 0zm-.3 4.7l.1.1c-.1 0-.2 0-.1-.1-.1.1-.1 0 0 0zm-2.7-15.9v-.1l.1.1h-.1zm1 19.1c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.7.6-1.4.6-2.2.4zm2.6 1.2c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1.1 0 .1-.1.2zm.2-25.4v-.1.1zm.4-.3c-.1 0-.2.1-.3.1 0-.1 0-.3.1-.4 0 0 0-.1.1-.1 0 .2 0 .3.1.4zm.5 24.3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4v-.1.5zm0 6.2s0 .1-.1.1l.1-.1zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2 0-.4-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.5-.3.5zm2.1 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.2.1-.2.1-.2.2zm-.4-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.7-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1 0 .1-.1zm-3.2.3zm-.6-.2c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.2.8-.2zm-9.7-6.5s.1 0 0 0c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.2-.1.2-.2.2-.3zm-5-7.3s.1 0 0 0c.1.1.1.3.1.4-.1-.1-.2-.2-.1-.4 0 .1 0 0 0 0zm-5.5 5.7l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3.1-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.8s-.1 0 0 0c-.1 0-.1 0 0 0-.1 0-.1 0 0 0zm-1.1 0zm-2.5 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8c.1 0 .1.1 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zm-4.2-17.8c.1.1.1.1 0 0 0 .1 0 0 0 0zm-1.6 17.8v.1h-.1s-.1 0-.1-.1h.2zm-1.6-9.7v-.2s.1 0 .1.1 0 .1-.1.1zm.8 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1-.1-.2 0-.3 0-.4zm.6 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .4-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.7-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.2.1-.5.2-.8.3zm1.4 2c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .1-.1.2zm1-2.2c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2.1.4 0 .6zm-.2-6.4c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.3-.6-.8-.5-1.3-.4zm1.5 4.4v.1h-.2v-.1h.2zm-.6 3.9s-.1 0 0 0c-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1 0 .2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.3.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.3 1.6-.5 2zm-1-6.8c-.1 0-.1 0 0 0 .2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.6-.1-1.2-.1-1.7-.2zm1.8.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.4-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3 0 0 .1.2 0 .2zm.2-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.6 1-1 1zm1.9 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0 0 0 0zm-.3-3s-.1-.1-.1-.2h.4s.1.1.1.2c-.2-.1-.3 0-.4 0zm.3-12.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.4zm-.2-9.7c.1 0 .2.1.3.2-.1 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2 0 .2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2 0 .3-.1.3zm.7 7.1zm-.1-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2h-.7zm.4 6.6c0 .1 0 .1 0 0 .1 0 .1 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c0 0-.1.1-.2.1zm.4 1.8c-.1-.1-.1-.1 0 0 0-.2 0-.1 0 0 0-.1 0-.1 0 0zm1.2-2.1c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.3.2-.4-.1-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.6-.1-1.2-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s0 .1-.1.1zm.2-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.5.3-1 .1-1.3.1zm1.3-6.8c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7l.1-.1c0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2 0 .3 0 .9-.2 1.5zm.6 3.9h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.8c0-.1 0-.1 0 0l-.1-.1c.1-.1.1-.1.1.1.1-.1 0-.1 0 0zm0-2.4c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.3c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.7-1.3-.9zm4.9 3.9c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c0 .1-.1.1 0 0-.1 0-.1 0-.1-.1 0 .1 0 0 .1.1zm-2.9-3.3c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.1.4-.1.7-.3 1.1zm1.3 3.1c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.5.9.5 1.4zm.4-2c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.7-.3-.7-.8-.7-1.5zm2.4 4.7c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.4.4.3.8.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c.1-.1.1 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .2-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9 0-1.6.2-2.3.5zm1.6 5.9s.1 0 0 0c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.3.6-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.4-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1 0-.3.1-.4 0zm-1.2-4.8c.1-.2.3-.2.4 0l.7.7c-.7.1-.7.1-1.1-.7zm2.9.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.2.3.5.8.1 1.1zm-.9-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.2-1.9.5zm7.5-1.2c.1 0 .1.1 0 0 0 .1 0 .1-.1.1s0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1.1-.1.1-.1zm-3.6 11.7s0-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.2-10.7zm.7.5v-.1l.1-.1s.1.1 0 .1c0 0 0 .1-.1.1zm1.1.6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.4.6-.1.9 0 1.3zm-1-1.8c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.6.1-1.1.1-1.5.2zm2 4.1c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.8c0-.4 0-.4.5-.6-.1.2-.3.4-.5.6zm.6-.6c.3-.2.5-.4.9-.6-.3.7-.3.7-.9.6zm.3-5.6h.2v.1h-.2V34zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.1.4-.2.7-.3.9zm.4 2.1v-.1s0-.1.1-.1c0 .1 0 .1-.1.2.1 0 .1 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.3-.4.4-.6 0zm.9 5.6v-.1c.1 0 .1-.1.2-.1v.1c-.1 0-.2.1-.2.1zm-.3-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm0-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.3-.9-.5zm1 2.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1.1-.2.1-.2.2zm14.2 7.7c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.2-.1.3-.1.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.2 0-.5 0-.5-.5zm1.3 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3 0-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.6 0-1.1.2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3 0 .2-.3.5-.6.4zm-.6-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.4-.7.4-1.1.4zm2.7-.3l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.1-.5.4-.2.6-.3zm-.5 5.9v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7.1-1.3.1-2 .1zm.8 3.3v-.1.1zm.5 1.5v-.2h.1c.1.1.1.2.2.3-.1-.1-.2-.1-.3-.1zm.4.3c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c0 0-.1 0-.2.1zm.2-3v-.1.1zm.7-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.1.1.3.1.5zm.6 2.1c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.7-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.2-.5.2-.5.5-.6zm-.7 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.2-.6.6-.9 1.1-.8zm-2.4 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .2 0 .3-.2.4zm-.4-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c-.1 0-.2-.1-.2-.1zm1.8 2l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s-.1.2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4-.1 1-.2 1-1.3.4zm1.3-1.5c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.2.4.2.6.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5s-.1 0 0 0c-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8H736c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.3.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .2-.1.2-.1zM748 29s.1 0 0 0l.1.1c-.1.1-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.3-.7.1zm.7-.1c0-.2.1-.4.1-.5H745c0 .2-.2.4-.4.5zm5.3 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.4.9-.5 1.4zm3.4 1.3c0-.2 0-.4-.1-.7.4.3.2.5.1.7zm1.8-1c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.1.2-.3.2-.5.2zm1 3.2c-.1-.4-.1-.4.2-.8.2.4 0 .6-.2.8zm1.9-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1 0-.1 0 .1-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.3c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1.1 0 0 .1 0 .2zm.1-2.4c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c-.1-.3-.2-.5-.3-.7zm.9 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.9c-.4-.2-.1-.6-.2-.8.5.3.5.3.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c0-.1-.1-.3-.1-.4zm-.3 2c.4-.3.6 0 .8.1-.2 0-.5 0-.8-.1zm1 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2 0 .3-.3.4-.4.6zm.4-1.4v-.2.2zm3-.1h.2v.1c-.1 0-.1.1-.2.1s-.1-.1 0-.2zm-1.9-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.1-.3-.2-.6-.2-1zm-.2 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.2 0-.3.1-.3.2zm.2-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2.1-.2.1-.3.1zm.6 1c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zM765 30c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1.1c-.1-.1-.1-.2-.2-.3h.3c0 .1 0 .2-.1.3zm2.4-3.5zm-.8 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.1.1-.3.1-.3zm.1 2v-.4s.2-.1.2 0 .1.2.1.2c-.1.1-.2.2-.3.2zm.7-3.8s-.1 0 0 0c-.1-.1-.1-.1 0-.1v.1c0-.1 0 0 0 0zm2.5.9c0 .1 0 .1-.1.2.1-.1.1-.2.1-.2zm-1.8 2.2c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.3.1.4-.1 0-.2.1-.2.2zm.7-1.8c-.1 0-.2 0-.2-.1-.1-.1-.2-.3-.2-.4.1 0 .1-.1.2-.1.1.1.2.3.3.4-.1 0-.1.1-.1.2zm.5 1.9c-.2-.4 0-.5.1-.7-.1.2-.1.4-.1.7zm.1-.7c0-.5-.1-1.1.5-1.4.1.6.1 1.2.2 1.8-.5.1-.5-.3-.7-.4zm.8-3.7l-.2-.2c.1-.1.2-.1.4-.1 0 0-.1.1-.2.3zm1.6 4.2zm.7-2.3c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1 0 0 .1.1.1.2-.1 0-.2 0-.2.1zm.8 1c.1-.1.2-.3.3-.3 0 0 .1.1.2.1-.1.1-.2.3-.3.4 0-.1-.1-.1-.2-.2zm.5 1.9c0 .1-.1 0 0 0-.1-.1-.1-.2 0-.3.1 0 .1.1.2.1 0 .1-.1.2-.2.2zm.4-2.9l-1.2-2.1c.1-.2.1-.3.2-.5h.5v.5c.1.4.6.5.5 1-.1.3.2.7.2 1-.1.2-.2.2-.2.1zm.5-2.2v-.2.2zm1 .6c-.2-.3-.2-.5 0-.8h.1c-.1.3-.1.5-.1.8zm1.3 2.5c-.1 0-.2-.1-.2-.1 0-.2.1-.5.2-.7.2.1.3.1.3.2 0 .2-.1.5-.3.6zm.4-3.7c0 .1 0 .1 0 0 0 .1 0 .1 0 0zm.1 5s0-.1-.1-.1h.2c0 .1.1.1.1.2-.1 0-.2 0-.2-.1zm2-4.3c-.1 0-.1-.1-.2-.1l.1-.1c.1 0 .1.1.1.2zm.3 1.4c-.1 0-.1-.1-.2-.1v-.1c.1 0 .2 0 .2.1v.1zm.5.9zm4.1 4.6c.1 0 .3.2.4.3.1.2-.2.5-.4.4-.1-.1-.2-.2-.5-.4.3-.1.4-.3.5-.3zm.1 1.9c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-1-3.7zm.1.8s.1.1 0 .1c0 0-.1 0-.1.1 0 0-.1 0-.1-.1 0 0 .1 0 .2-.1zm-.4 2.3c0 .1 0 .1-.1.1l.1-.1c-.1 0 0 0 0 0zm-.7-1.4s-.1 0 0 0l-.1.1c0-.1 0-.1.1-.1zm-1.3 2.2s.1 0 0 0c.1.1 0 .1 0 .1v-.1zm.8 4.1c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2h-.5zm1.6-2c-.4-.5-1.1-.8-1.6-.6-.7.3-1.3-.2-2 0-.3.1-.4-.3-.3-.7.5 0 1-.1 1.6 0 .6.1.9-.1 1.2-.6.4.3.8.5 1.2.7.4.1.8.2 1.1.6-.5.3-.8.4-1.2.6zm.9-2.3c.1.2.2.5.3.8-.6-.3-.6-.3-.3-.8zm2.6-3.8c-.2.2-.4.3-.6.6-.3-.1-.6-.3-.9-.4 0-.5.4-.5 1.5-.2zm-1.7 3.6s-.1 0-.1-.1V36s.1 0 .1.1v.1zm.3 3.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm.2-2.1h-.2v-.1c.1 0 .1 0 .2.1 0-.1 0 0 0 0zm-.3-2.4c.5-.1 1-.1 1.7-.2-.6.5-.6.5-.9 1.1-.3-.2-.8-.3-.8-.9zm2 .8c0 .1 0 .2.1.3l.3.3c-.2.3-.3.7-.5 1-.2 0-.5.1-.7.1 0-.3 0-.6-.1-.9 0-.3-.2-.5-.2-.8.4.1.7.2 1.1.2v-.1c-.1.1 0 0 0-.1zm0-1.7c0-.1.1-.2.1-.2.1 0 .2 0 .2.1v.2c-.1 0-.2 0-.3-.1zm.8 5.6c-.1-.1-.3-.1-.4-.2-.2-.2-.3-.5-.6-.9-.3.3-.6.6-1 .9-.1-.5-.2-.9-.4-1.3l.6-.6c.2.4.6.5 1 .6.8.1.8.2.8 1.1.1.1.1.2 0 .4zm.1-6.4c-.1.2-.5.3-.8.1-.2-.1-.4-.4-.6-.6.3-.1.6-.3 1-.4.1 0 .2.1.2.1.1.2.3.4.2.8zm1.7-15.4v.1-.1zm-.3 1.2c.1 0 .2 0 .2.1.2.2.1.4 0 .6-.1-.2-.2-.3-.3-.5 0-.1 0-.1.1-.2zm-.7 5.2s0-.1 0 0c.1 0 .1 0 .2.1h-.2c-.1 0-.1-.1 0-.1zm.1 11zm0 3.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .3-.1.4-.2.4zm.2-8.8zm.3 2.8v-.1.1zm.3-11.6s-.2 0-.2-.1c-.1-.4-.3-.8.2-1.1 0 .1.1.2.1.2.1.4.2.8-.1 1zm6.3-9.3zm-1.2-.1c-.1 0-.2.1-.4.1v-.1h.4zm-1.2 0c.1.1 0 .3 0 .4-.1-.1-.3-.2-.3-.4h.3zm-.6 3c0 .1-.1.3-.1.4-.2.3-.4.6-.6 1-.1-.9 0-1.4.4-2.3.3.2.3.6.3.9zm-.3-.9c-.1 0-.2 0-.2-.1v-.2h.1c0 .2 0 .3.1.3zm-.8-2.1h.4c.1.2.2.3.3.5l-.6.9c-.1.1-.1.1-.6-.1.1-.4.3-.9.5-1.3zm-.7 2.7s.2.1.1.2-.1.2-.2.2c0-.1-.1-.1-.2-.2.1-.1.2-.1.3-.2zm-.9 27.2zm.1-28.5zm.5 19.6c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.2.1-.2.1zm-.2-14.9c0-.2.1-.5.1-.7 0-.3-.1-.5-.2-.8.2 0 .4-.1.4-.1.4.6 1 1.2.8 2.2-.3-.2-.6-.4-1.1-.6zm.8 1.5zm-.1 6.8c.3-.2.6-.3.9-.5 0 .2.1.5.1.7 0 .4-.2.6-.5.7-.3 0-.5-.2-.6-.6 0-.1.1-.2.1-.3zm1.3 6.8s.1 0 .2.1c0 .5-.2 1-.5 1.4 0 .1-.2.1-.3 0l-.1-.2c.2-.4.4-.8.7-1.3zm-.2-9.9zm-.2 12.8zm-.2-10.8c0-.1.1-.1.1-.2.1.1.3.1.2.2 0 .2-.1.4-.1.6-.1-.2-.2-.4-.2-.6zm.5 17.2c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3 0 .1-.1.3-.2.4zm-.4-3h-.6l-.1-.1c.5-.3.5-.3 1.6 0-.6 0-.7 0-.9.1zm1-15.1c-.1 0-.1-.1-.1-.2s.1-.1.1-.2c.1.1.1.2.2.3l-.2.1zm.6 22.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.2-.3-.1-.4 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.8-.8h-.2c.1 0 .1-.1.2 0 0-.1 0 0 0 0zm.1 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.1-24c-.2.4-.4.2-.8.2.1-.4.2-.6.3-.9h.3c.3.1.3.4.2.7zm-.4-4.6c0 .4-.1.7 0 .9.1.6 0 1.1-.3 1.6-.4.7-.6 1.6-.9 2.4-.1-.2-.2-.4-.4-.6-.4-.1-.5.2-.5.5.1.5.1.9 0 1.4-.1.3-.3.3-.5.2 0-.1-.1-.2-.1-.3-.2-1.7-.2-1.7 1.2-2.8.4-.3.6-.6.7-1.2 0-.5.1-1 .3-1.4.4-.8.3-1.7 0-2.5-.1-.3-.2-.6-.3-1v-1.1c.3-.1.5-.2.8-.3 0 .1.1.2.1.2.3.6.1 1-.4 1.2.2.5.3.9.5 1.3.4.2 1 0 1.3.6l-.3.9c-.1.1-.3.2-.5.3-.2.1-.4 0-.7-.3zm.7 23.3zm.4-20.3c-.1 0-.1-.1-.2-.1 0-.1.1-.2.1-.2.1 0 .1.1.2.1 0 0-.1.1-.1.2zm.3-1.6c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1.1-.1.1 0 0zm0-.1c-.1-.4-.2-.7-.3-1.1.3.4.5.7.3 1.1zm.4-3.7c.4 0 .5.4.7.8-.8-.1-.8-.1-.7-.8zm.7 31.8s.1 0 .1-.1c0 .2 0 .3.1.5-.1-.1-.1-.2-.2-.4zm.4.7c0-.1-.1-.1-.1-.2 0 .1.1.1.1.2.1-.1.1 0 .1.1-.1 0-.1 0-.1-.1zm.1-32.7s0-.1 0 0l.1-.1c-.1 0-.1.1-.1.1zm-.5 36.5zm1.1-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3 0 .1-.1.1-.1.2zm.5-35.2c-.3.1-.8-.2-1 .3 0-.2 0-.4.1-.6.1-.2.4-.3.5-.3.5 0 .5.3.4.6zm.5 1.2v.1h-.1l.1-.1zm0 33.5V47h.1l-.1.1c.1 0 .1 0 0 0zm.2-29.6s0-.1-.1-.1l.2-.2.1.1c0 .1-.1.1-.2.2zm.5 29.4c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2.1.1 0 .1-.1.1zm.1-32.7v-.1.1zm.5 34.1c0-.1-.1-.1-.1-.2s.1-.1.1-.2c0 .1.1.1.1.2.1 0 0 .1-.1.2zm1-30.5h-.1c0-.1 0-.1.1-.2h.1c0 .1-.1.1-.1.2zm.7-5c.1-.3.1-.5.2-1 .3.5.5.8.7 1.2-.4 0-.6 0-.9-.2zm6.2 18.6s0-.1 0 0l-.1-.1c.1 0 .1 0 .1.1zM808.1 14h.1v.1h-.1V14zm-.2 5.6s.2 0 .2.1v.2c-.2.1-.4.1-.6.2.1-.2.2-.3.4-.5zm-.7.7c.1-.1.2-.1.3-.2 0 .1 0 .2-.1.4 0 0-.1.1-.2.1 0-.1-.1-.2 0-.3zm-1.2 21zm1.1-12.9c.1.5.2.8.2 1.1-.4-.1-.5-.4-.2-1.1zm.3 2c-.1-.3-.1-.5-.2-.8.1 0 .2 0 .2.1.3.2.5.4 0 .7zm.6-5l.5-1c.2.6.1.8-.5 1zm1-11.6c0-.1-.1-.2-.1-.3 0-.1.1-.1.1-.2 0 .1.1.2.1.2 0 .2-.1.2-.1.3zm1.3-2.4c-.1-.1-.1-.1 0-.1h.1c0 .1-.1.1-.1.1zm4.7 11.5s0-.1 0 0c0-.1 0-.2.1-.2 0 0 0 .1-.1.2.1 0 .1 0 0 0zm9.4 8.8c.1.2.1.5.2.8-.3-.1-.5-.3-.6-.6 0-.1.1-.2.1-.3.1-.1.3 0 .3.1zm.6-3.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1s.1.1.1.2c-.1.1-.2.1-.2.1zm1.7 1c0 .1 0 .1 0 0 0 .1 0 0 0 0zm.5 1c0-.6 0-.6.8-.8-.3.3-.6.5-.8.8zm3.9-6.1c-.1-.1-.1-.2 0-.2l.1.1c0 .1 0 .1-.1.1zm.9 2.8c-.3-.5-.1-.9.2-1.4.2.6-.1.9-.2 1.4zm1.5-1.1c-.1-.1-.2-.1-.2-.2s.1-.1.1-.2c.1 0 .2 0 .2.1s0 .2-.1.3zm11.9-.8c.1 0 .1-.1.2-.1h.1c.1.1.1.1-.1.1 0 .1-.1.1-.2 0zm-3.9.6c.3-.1.6-.2.8 0 .1 0 .1.1.2.1 0 .2-.2.5-.4.9-.2-.2-.4-.3-.5-.4-.1-.2-.2-.4-.3-.5 0 0 .1-.1.2-.1zm-1.1.1zm-2.8.4l.1.1c0 .1-.1.1-.1.2 0 0 0-.1-.1-.1 0-.1.1-.1.1-.2zm-.3 1.1h-.1c-.5 0-.6 0-.4-.5.1.2.3.3.5.5zm-.8-1.3c.3.2.2.5.2.7-.2-.1-.4-.2-.7-.4.2-.1.3-.2.5-.3zm-.7 1.5zm-1.9.1v-.1.1zm1.7 3.1v-.1h.1l-.1.1zm.8.9s0-.1 0 0c0-.1 0-.1 0 0zm.7-1.7c-.3-.2-.5-.4-.8-.5h-.2c-1 .6-1.1.5-1.2-.8-.1-1.1-.1-2.1-.1-3.3.2.1.4.1.4.2.1.4.1.7.1 1.1v2.3c.9-.3.9-.3 1.9-.1.1-.5.1-1 .2-1.4h.6c0 .3-.1.6-.1.9 0 .3.1.5.2.8-.5.2-.8.5-1 .8zm4.8 1.3h-.2c0-.1.1-.2.1-.2.1 0 .2.1.3.1-.1 0-.1.1-.2.1zm.7-1.4c-.2.1-.5 0-.8-.1-.2-.1-.4-.3-.7-.5-.2-.1-.4-.3-.5-.4-.4 0-.4.5-.6.7-.2.2-.3.4-.5.6-.2-.3-.3-.7-.5-.9-.6-.6-.5-1.2-.1-1.9.1-.2.4-.3.5-.5-.4-.3-1-.7-1-1 .2.1.5.2.7.1.2-.1.4-.1.7-.1.2 1.5.5 1.5 1.4 2.2.3.3.9.5 1.1.9 0 0 .3 0 .4-.1.1-.1.1-.3.1-.4-.2-.4-.4-.7-.6-1.1.4-.3.6-.3.7 0 .2.3.3.6.4.9.2.8 0 1.4-.7 1.6zm1.3-2.2c-.2-.4-.5-.8-.8-1.2 0-.1.1-.2.2-.3h1.2c.1.2.3.4.5.7 0 .2 0 .4.1.5l-1.2.3zm1.2 1.3v-.1.1zm.8-1.6c-.3-.2-.3-.9-.9-.6.1-.2.1-.4.1-.6.4 0 .8 0 1.2.1v.1c.1.3 0 .7-.4 1zm.6 1.7s-.1 0 0 0c-.1-.1-.1-.1 0-.1v.1c0-.1 0 0 0 0zm-4.5 7.3s-.1 0 0 0c0 0 0-.1 0 0 0-.1 0 0 0 0zm5.3-10.8c.1 0 .3 0 .4.1 0 0 0 .1-.1.1h-.3v-.2s0-.1 0 0zm-.1.7c.2-.1.5-.1.7-.1.3 0 .5-.1.6-.2.1.2.1.3-.1.5-.1.2-.1.5-.2.7-.6.9-.6 1 0 2-.2.2-.5.3-.7.5-.4-.3-.5-.8-.4-1.2.1-.8-.2-1.5.1-2.2zm1.4 5.4s-.1.1-.1.2l-.1-.1v-.4c.1 0 .1.1.2.3zm-1.8.5c0-.4-.1-.8-.1-1.3h1.3c.1 0 .2.2.3.3-.5.1-.5.6-.7.9-.2.1-.5-.4-.8.1zm1.7 1.9l-.3.3c-.1.1-.3.1-.4.1-.1-.1-.2-.3-.3-.5.1-.2.2-.5.3-.6.3-.4.6-.4.8-.3.2.2.2.6-.1 1zm.7.4v-.1.1zm.3-2.7h.2c0 .3-.1.2-.2 0zm.3 2h.1-.1zm0-2c.1-.1.2-.3.4-.5 0 .5-.3.5-.4.5zm4.8-2.8zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2 0-.2 0-.2.1-.2zm-1.8 16.4s.1 0 .1-.1v.2c-.1.1-.2.1-.3.2.1-.1.2-.2.2-.3zm-.2.4c0 .1.1.1 0 .2l-.1.1v-.1c0-.1.1-.1.1-.2zm.4 2.2c-.1.2-.2.3-.3.4l-.2-.1v-.5c0-.1.2-.2.4-.4.1.3.1.5.1.6zm.3-8c-.2-.1-.4-.2-.4-.5.3 0 .5 0 .8-.1.1-.1.2-.1.3-.1 0 .1-.1.2-.2.3.2.8 1.2 1.2 1 2.3-.7-.6-1.3-.8-1.4-1.7 0 0 0-.1-.1-.2zm.4 3c.3-.2.5-.1.7.1.1 0 .1.2.1.2 0 .1-.1.1-.2.1-.3.1-.5 0-.6-.4zm.6 4c.6.6.6.6.9 1.8-.9-.4-.7-1.1-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .4.2.6.5.4 1zm-.4-1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1.5-.1 1 .7 1.3-.3.2.4.4.6.5.9-.2.3-.7.3-.7.8zm.8-6.7c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2-.1.2-.2.3-.3.3zm.7 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 .1 0 .1-.1.1zm.6-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.5.2 1-.1 1.4zm.4 7.4c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2c0 .1-.1.2-.3.3zm.5-1.4l.1-.1-.1.1zm.6-6.1c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1-.1-.4-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.5c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 .1-.1.2-.1.2zm.8-.4c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.7-8.1v.3c.1 0 .1-.2 0-.3zm.1.8v0zm.3-5.8c.1 0 .1 0 0 0 .1 0 .2.1.2.1s-.1-.1-.2-.1zm.6 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1c-.1 0-.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3V24c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3v.8zm0 5.3v-.1h.2v.2c0-.1-.1-.1-.2-.1zm.6 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.4-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4-.1.6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.5-.5.4-.8.4zm1.2 4.4l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.1 0-.2.1-.4.2zm0-1.3c.1-.2.2-.4.3-.7.2.4-.1.5-.3.7zm1.7 1.2v-.1.1zm-.3-1.6c.5-.8.5-.8 1.1-.3-.4.2-.6.2-1.1.3zm2.3 4.9c0-.1 0-.1 0 0l-.1-.1c.1-.1.1-.1.1.1.1-.1 0-.1 0 0zm.1-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.1.5-.1.7-.4 1zm.5 4.6v-.2l.1-.1c.1 0 .1.1.1.2 0 0-.1 0-.2.1zm.9-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1-.1-.2-.1-.2-.2zm.9 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.1.3-.3.3zm1.3 1.9s0-.1 0 0c0 0 .1 0 .1.1l-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1v.7zm1.5 4.4zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.2.1-.2.1zm.6-15.7c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2-.1.4-.1.6zm.6 13.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.2.1-.2.1zm.5-16c-.1.1 0 0 0 0zm1.7 16.1c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c0 .1 0 .2-.1.2zm3.9-.3zm-.5-5.2s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.2.1-.2.1-.3zm-.5 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c.1-.2.2-.2.2-.2zm-.2-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1 0 .1 0 .2.1zm-.3 4.2c0 .1 0 .1-.1.1 0 0 0-.1.1-.1zm-.5.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4 0-.1-.1-.2-.1-.2zm1.5 7.2c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.2-1 .3-1.5.4zm5.9-12s.1 0 0 0c.1 0 .1.1 0 0 0 .1 0 0 0 0zm-.7 3.9s.1 0 0 0c.1.1.1.1 0 .1v-.1c0 .1 0 0 0 0zm-.3 4.7s.1 0 0 0l.1.1c-.1 0-.1 0-.1-.1zM883 16v-.1l.1.1h-.1zm1 19c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.7-1.5.6-2.2.4zm2.6 1.3c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2 0 0-.1.1-.1.2zm.9-9.5h.1v.2c-.1 0-.1 0-.2-.1.1 0 .1-.1.1-.1zm-.1 5.1c0 .1 0 .1 0 0v.1c0 .1-.1 0 0-.1-.1.1 0 .1 0 0zm.2 3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.6.1-1.1.1-1.6 0zm.8-14.4c-.1-.1-.1-.3 0-.4V20v.1c-.1.3-.1.4 0 .4zm0 6.2s0 .1-.1.1c0 0 0-.1.1-.1-.1 0-.1 0 0 0zm0-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2-.1-.4-.1-.6-.3zm.4-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c0 .3-.1.4-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1 0-.2.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.2.6-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1l.1-.1zm-3.3.3zm-.5-.3c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.2 0 .5-.1.8-.2zm-9.7-6.4c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.1-.2.2-.3zm-5-7.1v0zm-5.6 5.5c.1 0 .1 0 0 0l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3.1-.1.2-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.9c0 .1 0 .1 0 0 0 .1-.1.1 0 0zm-1.1.1zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1 0 .1-.1 0 0-.1zM898 15.1s.1 0 0 0c.1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3 0 0 .2.1.3.2zM894.9 14s0 .1 0 0zm-1.7 17.7v.1h-.1s-.1 0-.1-.1c.1.1.1.1.2 0zm-1.6-9.6v-.2s.1 0 .1.1c.1 0 0 .1-.1.1zm.8 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1V27zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8 0 .6-.3 1.1-.7 1.6zm2.6-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .3-.3.6-.8.6zm1.1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1-.1 0-.1.1-.1.1zm.2-4.4zm2 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.2.4-.1.6-.2.8zm.7 1.3zm-.6-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.6.2-.8.3zm1.4 1.9c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1-.1.2-.1.2zm1-2.1c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.5c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.9-.5-1.3-.4zm1.5 4.5v.1h-.2v-.1c0-.1.1-.1.2 0zm-.7 3.9s-.1 0 0 0c-.1-.1-.1-.1-.1-.2h.1c.1.1.1.2 0 .2zm.9.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c-.1.1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.4-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2.1.8.3 1.6-.5 2zm-1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.2-1.7-.2zm1.9.2c-.1 0-.1 0 0 0 .3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.3-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1l-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1l.1.1c0-.1 0-.1 0 0zm-.3-3.1s-.1-.1-.1-.2h.4s.1.1.1.2h-.4zm.3-12c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.2 9.3zm-.2-9.6c.1 0 .1 0 0 0 .1 0 .2.1.3.2-.1 0-.2-.1-.3-.2zm.5 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .1-.1.2-.1zm-.1 9.3h.1v.1l-.1-.1zm.4-7.9h-.1v-.1c0-.1.1-.1.2-.2-.1.2-.1.2-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2c-.2-.1-.5-.1-.7 0zm.5 6.6s-.1 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.2.1-.2.1zm.4 1.7c-.1 0-.1 0 0 0-.1 0-.1-.1 0 0-.1-.1-.1-.1 0 0zm1.1-2c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.3.1-.4-.2-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.6-.2-1.2-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1.1 0 .1 0 0 .1zm.8.9h-.2l.1-.1h.2s-.1 0-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.5.3-.9 0-1.3.1zm1.3-6.9c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.4.1.9-.1 1.5zm.6 4h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.5-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.5.6-.7.5zm.9 3.7c-.1 0-.1 0 0 0l-.1-.1s.1 0 .1.1zm0-2.3c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.2-2.4c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.8-.6-1.3-.9zm5 4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c-.1 0-.1 0 0 0-.1 0-.1 0-.1-.1l.1.1c-.1-.1-.1 0 0 0zm-3-3.4c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.5-.1.8-.3 1.1zm1.4 3.2c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.7.3.4.9.5 1.4zm.3-2.1c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.2-.6-.7-.7-1.5zm2.5 4.8c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.2.7.1 1zm1.2-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5.1.9 0 1.6 0 2.4zm.2-2.3s-.1 0 0 0c-.1 0 0-.1 0 0 0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .1-.1.2.1 0 0 0 0 0zm-.4-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9-.1-1.6.2-2.3.5zm1.7 5.9c-.1 0-.1 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.2.3-.4.5-.6.8zm.6-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.3-.5-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1-.1-.2 0-.4 0zm-1.1-4.9c.1-.2.3-.2.4 0l.7.7c-.8.2-.8.2-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.4.5.8.1 1.1zm-.9-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.3-1.9.5zm7.6-1.1c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1 0-.1.1-.1zm-3.6 11.7c-.1 0-.1-.1 0 0v-.1s.1.1.1.2l-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1 .6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.5.5 0 .9 0 1.3zm-1-1.9c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.2-1 .2-1.5.2zm2 4.2c.2.5.4.8.5 1.1l-.1.2h-.2c-.3-.3-.4-.7-.2-1.3zm.1 5.7c0-.4 0-.4.5-.6-.2.3-.4.5-.5.6zm.5-.5c.3-.2.5-.4.9-.6-.3.6-.3.7-.9.6zm.3-5.6h.2v.1h-.2v-.1zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.1.4-.2.6-.3.9zm.5 2.1V31s0-.1.1-.1c-.1 0-.1.1-.1.2.1 0 0 0 0 0zm0-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.2-.3.4-.6 0zm.9 5.6V34c.1 0 .1-.1.2-.1v.1c-.1 0-.1 0-.2.1zm-.2-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c-.1-.1-.1-.2-.2-.3zm-.1-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.4-.9-.5zm1 2.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1.1-.1.2-.2.2zm14.2 7.8c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.2-.1.3-.2.3-.1zm-13.3-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.3 0-.6-.1-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3 0 .2-.3.4-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.3-.7.4-1.1.4zm2.6-.4l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.1-.4.4-.1.6-.3zm-.4 6v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7 0-1.4.1-2 .1zm.7 3.2v-.1.1zm.5 1.6V36h.1c.1.1.1.2.2.3-.1-.1-.2-.1-.3-.1zm.5.2c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1-.1.1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.2-3v-.1.1zm.6-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.2.1.4.1.5zm.6 2.2c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.7-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.2-.5.5-.6zm-.7 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.3-.6.6-1 1.1-.8zm-2.3 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .1-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c-.1-.1-.1-.1-.2-.1zm1.8 1.9l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4 0 1.1-.1 1.1-1.3.4zm1.4-1.4c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.1.4.1.5.1.7zm3.1-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5c-.1-.1-.1-.1 0-.2h.1c0 .1 0 .2-.1.2zm1.2-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.2.2.3.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.6.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .1-.1.2-.1zm-7.2-.3l.1.1c-.1 0-.1 0-.1-.1-.1.1-.1 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.5.2-.7.1zm.7-.1c0-.2.1-.4.1-.5H970.7c-.1.2-.2.4-.4.5zm5.2 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.3.9-.5 1.4zM979 29c0-.2 0-.4-.1-.7.3.4.2.6.1.7zm1.8-.9c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.3.3-.4.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.4.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1-.1-.1-.1 0-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2c-.1 0-.1.1-.2.2zm1.1 1.2c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1v.2zm0-2.3c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c-.1-.3-.2-.5-.3-.7zm.9 1.7c-.2-.4-.4-.7-.5-1.1.5.2.5.6.5 1.1zm.2.8c-.4-.2-.1-.6-.2-.8.6.4.6.4.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c0-.1 0-.2-.1-.4 0 .1 0 .1 0 0zm-.2 2.1c.4-.3.6 0 .8.1-.3 0-.5-.1-.8-.1zm.9 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2.1.3-.2.4-.4.6zm.4-1.4v-.2c.1.1.1.1 0 .2.1-.1 0 0 0 0zm3-.1h.2v.1c-.1 0-.1.1-.2.1v-.2zm-1.8-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.2-.3-.2-.6-.2-1-.1 0-.1 0 0 0zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2 0-.3.1-.3.1zm.6.9c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2-.3.1-.4.2-.6.3zm1.1-1.3c.1.3.2.5.3.8-.4-.3-.4-.3-.3-.8zm.6 1c-.1-.1-.2-.1-.2-.2h.3c-.1 0-.1.1-.2.1 0 .1.1.1.1.1zm.1-.1c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm2.2-3.3zm-.7 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.2 0-.3.1-.3zm.1 2c0-.1 0-.2-.1-.3 0 0 .2-.1.2 0s.1.2.1.2c-.1 0-.1 0-.2.1zm.6-3.8s0-.1 0 0c-.1-.1-.1-.1 0-.1v.1c.1-.1 0 0 0 0zm.7 3c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.2 0 .4 0 .1 0 .2-.1.2zm1.7-.1v-.2c0-.2.1-.3.2-.4 0 .2 0 .4.1.6h-.3zm2 .1zm12.8 4.3c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-3.3.3c.1.1 0 .1 0 .1-.1 0-.1-.1 0-.1-.1 0-.1 0 0 0zm-1.1-2.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1 0-.1-.1-.1-.1-.2.1-.1.2-.1.2-.1zm0 1.4s-.1 0 0 0c-.1 0-.1 0 0 0zm-2.6-4.1c0 .1.1.1.1.2-.1 0-.1-.1-.2-.1 0 0 0-.1-.1-.1h.2zm-3.5.7c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1-.1-.1-.1 0 0zm-1.4 5.6zm-.2.2l.1-.1v0c0 .1.1.2.1.3 0-.1-.1-.1-.2-.2zm.3.5h-.1c.1-.1.1-.2.2-.3.2.1.3.2.5.2-.2 0-.4.1-.6.1zm5.7-2.2c.1.5 0 1-.3 1.4-.5.1-1 .1-1.4.2-.1-.2-.2-.4-.3-.5-.3 0-.5.2-.5.5v.1c-.6 0-1.1-.1-1.7-.1-.4.4-.5.5-.8.6.1 0 .1 0 .2-.1-.2-.3-.3-.6-.5-.8l.3-.3c0-.7-.3-1.1-.6-1.7.1.1.3.1.6.2l-.6-.6c.8-.1 1 0 1.1.9 0 .3-.1.6.2.7.4-.3.5-.3.7-.9 0-.1.1-.1.1-.2v-.1c-.3-.5-.6-1.1-.8-1.8h.2c.2-.1.4-.1.5-.1-.1.1-.1.3-.1.5 0 .5.3.8.8.8.4 0 .7-.3.7-.7 0-.2-.1-.4-.3-.6.1-.1.2-.2.1-.3-1-.3-1.2-1.1-1.2-2.1 0-.2 0-.3.1-.4.2-.2.4-.3.7-.5h.1c0 .2.1.4.1.6.2 0 .3 0 .4.2.1.5.2 1.1.6 1.4 0 .7-.2 1.3.3 1.8.6-.7.6-1-.1-1.7.1.1.2.1.3.2.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.2-.1.3-.1.5-.1 0 .3 0 .6-.1.9-.1.2 0 .4 0 .6-.1 0-.2-.1-.3-.1 0 .3-.2.6.2.9.1 0 .1-.1.2-.1v.1c0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.3.6 0 1.2.1 1.8zm1.6 3.6v.2c.1.1.1.2.2.4-.3 0-.5.1-.8.6-.2.1-.4.2-.4.3v-.8c0-.1.7-.3 1-.4-.1-.1-.1-.2 0-.3v-.2c.2 0 .4.1.6.2h-.6zm-.1-2.1c-.1-.2-.1-.4-.3-.6v-.1c.5 0 1-.1 1.6 0h.5c0 .3 0 .5-.2.7-.5.1-1-.2-1.6 0zm2 2.6c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2-.2-.1-.3 0-.5 0zm1.9-2.2c-.1-.1-.3-.2-.4-.2h-.2c-.2-.2-.5-.3-.8-.4 0-.3 0-.7-.1-1l.1-.1.4.4s.1 0 .1-.1c.2.1.5.3.7.4.4.1.8.2 1.1.6-.3.2-.6.3-.9.4zm.6-1.6c.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0-.1.1-.1.1-.2.1.2.2.5.3.8-.2 0-.3-.1-.4-.2zm1.2 2.4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm1.5-6.8c.1 0 .2-.1.3-.1 0 .2 0 .3-.1.4-.1-.1-.2-.2-.2-.3zM1012 32l.3-.3c.1-.1.1-.2.2-.4h.4c.1.1.2.1.3.2-.3.3-.4.4-.6.9-.2-.1-.5-.2-.6-.4zm.8.5c0 .1-.1.1-.2.1 0-.1 0-.1-.1-.2.1 0 .2.1.3.1zm.1 2.4c.2.4.2.5 0 .9-.1.1-.2.1-.3.2-.1-.5-.2-.9-.4-1.3l.6-.6c.2.3.4.4.8.5-.2.1-.5.2-.7.3zm1-1.4v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4-.1 0 .1.1.2.1-.1.2-.2.3-.3.5-.2 0-.5.1-.7.1v-.4c0-.1.1-.2.1-.2 0-.3 0-.6.1-.9.2 0 .4.1.6.1v-.1c0-.1.1-.1.1-.2 0 .1 0 .2.1.3l.3.3c-.1.1-.2.3-.3.5zm.7 2.7c-.1-.1-.1-.1 0 0l-.1-.1c0-.4 0-.7.1-1.1.1.1.1.4.1.8 0 .1-.1.2-.1.4zm.8-1.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .2-.1.3-.2.4zm1.4 2.9zm2.2-7.4c0 .1-.1.1-.1.2s-.2.1-.3 0v-.2h.4zm-.1 1.6zm-.4-1.7s.1 0 0 0c.1 0 0 0 0 0zm.7 8.1c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.2.2-.2.4zm-.5-3.1h-.2v-.3c.2 0 .5.1 1 .2-.4.1-.6.1-.8.1zm1.7 7.1c.1 0 .1 0 .1-.1v.1h-.1zm.1-2v.6c-.2-.3-.1-.5 0-.6zm.1-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8c0-.1 0-.1 0 0 .1-.1.1-.1 0 0 .1-.1 0-.1 0 0zm.1 1.1v-.2h.1l.1.1c-.1 0-.1 0-.2.1zm.5-5.3zm1.7 6.1s.1 0 .1-.1c0 .2 0 .3.1.5 0-.1-.1-.2-.2-.4zm.4.7c0-.1-.1-.1-.1-.2 0 .1.1.1.1.2.1-.1.1 0 .1.1 0-.1-.1-.1-.1-.1zm-.4 3.8zm1.1-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3.1 0 0 .1-.1.2zm1.1-.5v-.1h.1c-.1-.1 0 0-.1.1.1-.1 0-.1 0 0zm.7-.2c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2l-.1.1zm.6 1.3c0-.1-.1-.1-.1-.2v-.1s.1 0 .1-.1l.1.1c0 .2-.1.3-.1.3zm5.9-8.3c0 .1-.1.2-.1.3l-.1.1c-.2-.2 0-.4.2-.4zm2.9-4.6zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2 0-.1.1-.2.1-.2zm-.3 18.1c.6.6.6.6.9 1.8-.9-.5-.7-1.2-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.1.6.4.4 1zm-.4-1.1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1v0c.4 0 .9.6 1.2-.3.2.4.4.6.5.9-.1.3-.6.4-.6.8zm.8-6.6c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2l-.3.3zm.7 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 0 0 .1-.1.1zm.6-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.4.2.9-.1 1.4zm.4 7.3c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2c0 .1-.1.2-.3.3zm.5-1.3l.1-.1-.1.1zm.6-6.2c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1 0-.4-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.4c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 0-.1.1-.1.2zm.8-.5c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm0 .8v0zm.4-5.8c.1 0 .2.1.2.1-.1 0-.2 0-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3v-.1c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .6 0 .8zm0 5.3v-.1h.2v.2s-.1-.1-.2-.1zm.6 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.5-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4 0 .6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.6-.5.4-.8.4zm1.2 4.5l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.1 0-.2.1-.4.2zm0-1.4c.1-.2.2-.4.3-.7.3.5-.1.5-.3.7zm1.7 1.2v-.1.1zm-.3-1.5c.5-.8.5-.8 1.1-.3-.4.1-.6.2-1.1.3zm2.3 4.8l-.1-.1c.1 0 .2 0 .1.1.1-.1 0 0 0 0zm.1-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.1.5-.1.7-.4 1zm.6 4.6V32l.1-.1c.1 0 .1.1.1.2-.1 0-.2.1-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1 0-.2-.1-.2-.2zm.9 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.1.3-.3.3zm1.3 1.9s.1 0 .1.1l-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1v.7zm1.5 4.5zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.2.1-.2.1zm.6-15.8c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2-.1.4-.1.6zm.6 13.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.2 0-.2.1zm.5-16.1c0 .1 0 .1 0 0zm0 0c0 .1 0 .1 0 0zm1.1-5.7c-.1-.1-.2-.2-.2-.3.1 0 .2.1.2.1v.2zm.7 21.9c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1 0-.1.2-.1.2zm3.8-.3zm-.5-5.3s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.1.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.1.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1.1.1.1.2.1zm-.3 4.2s0 .1 0 0c0 .1 0 .1-.1.1l.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4l-.1-.2zm1.4 7.3c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.4.1-1 .2-1.5.4zm6.8-8.6h.1v.2c-.1 0-.1 0-.2-.1.1 0 .1-.1.1-.1zm-.1 5.2s.1 0 0 0v.1s-.1-.1 0-.1zm-.8-8.6c.1 0 .1 0 0 0 .1 0 .1 0 0 0 .1 0 0 0 0 0zm-.7 3.8c.1 0 .1.1 0 0 .1.1.1.1 0 .1.1.1 0 0 0-.1 0 .1 0 0 0 0zm-.3 4.7c.1 0 .1 0 0 0l.1.1c-.1 0-.1 0-.1-.1 0 .1 0 0 0 0zm-2.6-15.9v-.1l.1.1h-.1zm1 19.1c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.6-1.5.6-2.2.4zm2.6 1.2c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2 0 .1-.1.1-.1.2zm.1-25.4v-.1.1zm.5-.3c-.1 0-.2.1-.3.1 0-.1 0-.3.1-.4 0 0 0-.1.1-.1-.1.2 0 .3.1.4zm.4 24.3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.6.1-1.1.1-1.6 0zm.8-14.4c-.1-.1-.1-.3 0-.4v-.1.5zm0 6.2s0 .1-.1.1l.1-.1c-.1 0-.1 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.3 0-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.5-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.2.7-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1 0 0 .1 0 .1-.1zm-3.3.3zm-.5-.2c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.2 0 .5-.2.8-.2zm-9.7-6.5c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.1-.2.2-.3zm-5-7.3c.1.1.1.3.1.4-.2-.1-.2-.2-.1-.4-.1.1-.1 0 0 0zm-5.5 5.7l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3 0-.1-.1-.1 0-.2zm-1-.8zm-1.1 0zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1 0 .1-.1 0 0-.1zm-1.3-12.8s.1.1 0 0c.1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3 0 0 .2.1.3.2zm-4.2-17.8c0 .1 0 .1 0 0 0 .1 0 0 0 0zm-1.7 17.8v.1h-.1s-.1 0-.1-.1h.2zm-1.6-9.7v-.2s.1 0 .1.1c.1.1 0 .1-.1.1zm.8 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1v-.4zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.6-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .4-.3.6-.8.6zm1.1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1-.1 0-.1.1-.1.1zm.2-4.4zm2 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.7-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 2c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .1-.1.2zm1-2.2c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.4c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.9-.5-1.3-.4zm1.5 4.4v.1h-.2v-.1h.2zm-.7 3.9c-.1-.1-.1-.1-.1-.2h.1c.1.2.1.2 0 .2zm.9.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.1-1.7-.2zm1.9.2s-.1 0 0 0c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.4-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1l-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm-.3-3s-.1-.1-.1-.2h.4s.1.1.1.2c-.2-.1-.3 0-.4 0zm.3-12.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.2 9.4zm-.1-9.7c.1 0 .2.1.3.2-.2 0-.3-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .1 0 .2-.1zm0 9.4s-.1 0-.1-.1c.1 0 .1 0 .1.1 0-.1 0 0 0 0zm.3-8h-.1v-.1c0-.1.1-.1.2-.2-.1.2-.1.3-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2h-.7zm.5 6.6c0 .1 0 .1 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.8s-.1 0 0 0c-.1-.1-.1-.1 0 0-.1-.2 0-.1 0 0 0-.1 0-.1 0 0zm1.1-2.1c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.3.2-.4-.1-.3-.5zm-.6-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.7-.1-1.3-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2l-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.5.3-.9.1-1.3.1zm1.3-6.8c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.3.2.9-.1 1.5zm.6 3.9h-.1c0-.1-.1-.1-.1-.2h.2c.1 0 .1.1 0 .2zm.5-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.8c0-.1-.1-.1 0 0l-.1-.1c.1-.1.1-.1.1.1 0-.1 0-.1 0 0zm0-2.4c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.3c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.7-1.3-.9zm4.9 3.9c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c-.1.1-.1.1 0 0-.1 0-.1 0-.1-.1 0 .1 0 0 .1.1-.1 0 0 0 0 0zm-3-3.3c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.4 0 .7-.3 1.1zm1.4 3.1c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.7.3.4.9.5 1.4zm.3-2c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.3-.6-.8-.7-1.5zm2.5 4.7c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.8.1 1zm1.2-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5.1.9.1 1.7 0 2.4zm.2-2.3s-.1 0 0 0c0 0 0-.1 0 0 0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .2-.1.2.1 0 0 0 0 0zm-.4-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9 0-1.6.2-2.3.5zm1.7 5.9s-.1 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.2.3-.4.6-.6.8zm.6-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.3-.4-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1 0-.2.1-.4 0zm-1.1-4.8c.1-.2.3-.2.4 0l.7.7c-.7.1-.7.1-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.3.5.8.1 1.1zm-.8-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.7.8-1.4.2-1.9.5zm7.5-1.2s0 .1 0 0c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1 0-.1.1-.1zm-3.6 11.7c-.1 0-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1 .6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.5.6 0 .9 0 1.3zm-1-1.8c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.1-1 .1-1.5.2zm2.1 4.1c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.8c0-.4 0-.4.5-.6-.2.2-.3.4-.5.6zm.5-.6c.3-.2.5-.4.9-.6-.2.7-.3.7-.9.6zm.4-5.6h.2v.1h-.2V34zm.6-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.1.4-.2.7-.3.9zm.5 2.1v-.1s0-.1.1-.1c-.1.1 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.3-.4.4-.6 0zm.8 5.6v-.1c.1 0 .1-.1.2-.1v.1s-.1.1-.2.1zm-.2-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm-.1-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.2-.2-.6-.3-.9-.5zm1.1 2.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.2.1-.2.1-.2.2zm14.2 7.7c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.1.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.3 0-.6 0-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3 0 .2-.3.5-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.4-.7.4-1.1.4zm2.6-.3l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.1-.5.4-.2.6-.3zm-.4 5.9v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7.1-1.4.1-2 .1zm.7 3.3v-.1.1zm.5 1.5v-.2h.1c.1.1.1.2.2.3-.1-.1-.2-.1-.3-.1zm.5.3c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1 0-.2.1zm.2-3v-.1.1zm.6-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.1.2.3.1.5zm.7 2.1c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5-.1.1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.2-.5.5-.6zm-.7 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.3-.6.7-.9 1.1-.8zm-2.3 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .2-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c-.1 0-.1-.1-.2-.1zm1.8 2l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4 0 1-.1 1-1.3.4zm1.4-1.5c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.1.4.1.6.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.1 1.5c-.1-.1-.1-.1 0-.2h.1c0 .1 0 .2-.1.2zm1.2-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.2.3.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .1-.1.2-.1zm-7.2-.3l.1.1c-.1.1-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.3-.7.1zm.7-.1c0-.2.1-.4.1-.5H1152c-.1.2-.2.4-.4.5zm5.2 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.3.9-.5 1.4zm3.5 1.3c0-.2 0-.4-.1-.7.3.3.2.5.1.7zm1.8-1c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.4.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1-.1-.1-.1.1-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.3c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1v.2zm0-2.4c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.4.6.5 1.1zm.2.9c-.4-.2-.1-.6-.2-.8.5.3.5.3.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c-.1-.1-.1-.3-.1-.4-.1 0 0 0 0 0zm-.3 2c.4-.3.6 0 .8.1-.3 0-.5 0-.8-.1zm.9 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2.1.3-.2.4-.4.6zm.4-1.4v-.2c.1.1.1.1 0 .2.1 0 0 0 0 0zm3-.1h.2v.1c-.1 0-.1.1-.2.1v-.2zm-1.8-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.2-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2.1-.3.1-.3.1zm.6 1c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.4c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1.1c-.1-.1-.1-.2-.2-.3h.3c0 .1-.1.2-.1.3zm2.3-3.5zm-.7 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.1.1-.3.1-.3zm.1 2v-.4s.2-.1.2 0 .1.2.1.2c-.1.1-.2.2-.3.2zm.6-3.8c-.1-.1-.1-.1 0-.1 0 0 .1 0 0 .1.1-.1.1 0 0 0zm2.6.9c0 .1 0 .1-.1.2.1-.1.1-.2.1-.2zm-1.9 2.2c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.3.1.4l-.2.2zm.7-1.8c-.1 0-.2 0-.2-.1-.1-.1-.2-.3-.2-.4.1 0 .1-.1.2-.1.1.1.2.3.3.4 0 0-.1.1-.1.2zm.5 1.9c-.2-.4 0-.5.1-.7 0 .2 0 .4-.1.7zm.1-.7c0-.5-.1-1.1.5-1.4.1.6.1 1.2.2 1.8-.5.1-.5-.3-.7-.4zm.9-3.7l-.2-.2c.1-.1.2-.1.4-.1-.1 0-.1.1-.2.3zm1.6 4.2zm.6-2.3c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1 0 0 .1.1.1.2-.1 0-.1 0-.2.1zm.9 1c.1-.1.2-.3.3-.3 0 0 .1.1.2.1-.1.1-.2.3-.3.4 0-.1-.1-.1-.2-.2zm.5 1.9c0 .1-.1 0 0 0-.1-.1-.1-.2 0-.3.1 0 .1.1.2.1-.1.1-.1.2-.2.2zm.4-2.9l-1.2-2.1c.1-.2.1-.3.2-.5h.5v.5c.1.4.6.5.5 1-.1.3.2.7.2 1-.1.2-.2.2-.2.1zm.5-2.2c-.1 0-.1 0 0 0v-.2.2zm.9.6c-.2-.3-.2-.5 0-.8h.1c0 .3 0 .5-.1.8zm1.3 2.5c-.1 0-.2-.1-.2-.1 0-.2.1-.5.2-.7.2.1.3.1.3.2.1.2 0 .5-.3.6zm.5-3.7c0 .1-.1.1 0 0-.1.1-.1.1 0 0zm0 5s0-.1-.1-.1h.2c0 .1.1.1.1.2 0 0-.1 0-.2-.1zm2-4.3c-.1 0-.1-.1-.2-.1l.1-.1c.1 0 .2.1.1.2.1 0 0 0 0 0zm.3 1.4c-.1 0-.1-.1-.2-.1v-.1c.1 0 .2 0 .2.1.1-.1 0 0 0 .1zm.6.9zm4.1 4.6c.1 0 .3.2.4.3.1.2-.2.5-.4.4-.1-.1-.2-.2-.5-.4.2-.1.4-.3.5-.3zm.1 1.9c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-1-3.7zm0 .8s.1.1 0 .1c0 0-.1 0-.1.1 0 0-.1 0-.1-.1.1 0 .2 0 .2-.1zm-.3 2.3c0 .1 0 .1-.1.1l.1-.1c-.1 0-.1 0 0 0zm-.8-1.4l-.1.1.1-.1zm-1.2 2.2c.1.1 0 .1 0 .1-.1 0-.1 0 0-.1-.1 0-.1 0 0 0zm.7 4.1c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2h-.5zm1.6-2c-.4-.5-1.1-.8-1.6-.6-.7.3-1.3-.2-2 0-.3.1-.4-.3-.3-.7.5 0 1-.1 1.6 0 .6.1.9-.1 1.2-.6.4.3.8.5 1.2.7.4.1.8.2 1.1.6-.4.3-.8.4-1.2.6zm1-2.3c.1.2.2.5.3.8-.6-.3-.6-.3-.3-.8zm2.5-3.8c-.2.2-.4.3-.6.6-.3-.1-.6-.3-.9-.4.1-.5.5-.5 1.5-.2zm-1.7 3.6s-.1 0-.1-.1V36s.1 0 .1.1c.1 0 0 0 0 .1zm.3 3.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm.3-2.1h-.2v-.1c.1 0 .1 0 .2.1 0-.1 0 0 0 0zm-.3-2.4c.5-.1 1-.1 1.7-.2-.6.5-.6.5-.9 1.1-.4-.2-.8-.3-.8-.9zm2 .8c0 .1 0 .2.1.3l.3.3c-.2.3-.3.7-.5 1-.2 0-.5.1-.7.1 0-.3 0-.6-.1-.9 0-.3-.2-.5-.2-.8.4.1.7.2 1.1.2v-.1c-.1.1 0 0 0-.1zm0-1.7c0-.1.1-.2.1-.2.1 0 .2 0 .2.1v.2c-.1 0-.2 0-.3-.1zm.8 5.6c-.1-.1-.3-.1-.4-.2-.2-.2-.3-.5-.6-.9-.3.3-.6.6-1 .9-.1-.5-.2-.9-.4-1.3l.6-.6c.2.4.6.5 1 .6.8.1.8.2.8 1.1.1.1 0 .2 0 .4zm.1-6.4c-.1.2-.5.3-.8.1-.2-.1-.4-.4-.6-.6.3-.1.6-.3 1-.4.1 0 .2.1.2.1.1.2.3.4.2.8zm1.6-15.4v.1-.1zm-.3 1.2c.1 0 .2 0 .2.1.2.2.1.4 0 .6-.1-.2-.2-.3-.3-.5.1-.1.1-.1.1-.2zm-.7 5.2s.1-.1 0 0c.1 0 .1 0 .2.1h-.2v-.1zm.2 11zm-.1 3.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3.1.3-.1.4-.2.4zm.2-8.8zm.4 2.8v-.1.1zm.2-11.6s-.2 0-.2-.1c-.1-.4-.3-.8.2-1.1 0 .1.1.2.1.2.1.4.3.8-.1 1zm6.3-9.3zm-1.1-.1c-.1 0-.2.1-.4.1v-.1h.4zm-1.2 0c.1.1 0 .3 0 .4-.1-.1-.3-.2-.3-.4h.3zm-.7 3c0 .1-.1.3-.1.4-.2.3-.4.6-.6 1-.1-.9 0-1.4.4-2.3.4.2.4.6.3.9zm-.3-.9c-.1 0-.2 0-.2-.1v-.2h.1c.1.2.1.3.1.3zm-.8-2.1h.4c.1.2.2.3.3.5l-.6.9c-.1.1-.1.1-.6-.1.1-.4.3-.9.5-1.3zm-.7 2.7s.2.1.1.2-.1.2-.2.2c0-.1-.1-.1-.2-.2.2-.1.3-.1.3-.2zm-.8 27.2zm.1-28.5zm.4 19.6c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.1.1-.2.1zm-.1-14.9c0-.2.1-.5.1-.7 0-.3-.1-.5-.2-.8.2 0 .4-.1.4-.1.4.6 1 1.2.8 2.2-.3-.2-.7-.4-1.1-.6zm.8 1.5zm-.1 6.8c.3-.2.6-.3.9-.5 0 .2.1.5.1.7 0 .4-.2.6-.5.7-.3 0-.5-.2-.6-.6 0-.1 0-.2.1-.3zm1.2 6.8s.1 0 .2.1c0 .5-.2 1-.5 1.4 0 .1-.2.1-.3 0l-.1-.2c.2-.4.5-.8.7-1.3zm-.2-9.9zm-.1 12.8zm-.2-10.8c0-.1.1-.1.1-.2.1.1.3.1.2.2 0 .2-.1.4-.1.6-.1-.2-.2-.4-.2-.6zm.5 17.2c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.2.3-.2.4zm-.5-3h-.6l-.1-.1c.5-.3.5-.3 1.6 0-.5 0-.7 0-.9.1zm1.1-15.1c-.1 0-.1-.1-.1-.2s.1-.1.1-.2c.1.1.1.2.2.3l-.2.1zm.6 22.1c.1 0 .1 0 .1-.1v.1h-.1zm.1-2v.6c-.2-.3 0-.4 0-.6zm.1-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8h-.2c.1 0 .2-.1.2 0 .1-.1 0 0 0 0zm.2 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.1-24c-.2.4-.4.2-.8.2.1-.4.2-.6.3-.9h.3c.3.1.3.4.2.7zm-.4-4.6c0 .4-.1.7 0 .9.1.6 0 1.1-.3 1.6-.4.7-.6 1.6-.9 2.4-.1-.2-.2-.4-.4-.6-.4-.1-.5.2-.5.5.1.5.1.9 0 1.4-.1.3-.3.3-.5.2 0-.1-.1-.2-.1-.3-.2-1.7-.2-1.7 1.2-2.8.4-.3.6-.6.7-1.2 0-.5.1-1 .3-1.4.4-.8.3-1.7 0-2.5-.1-.3-.2-.6-.3-1v-1.1c.3-.1.5-.2.8-.3 0 .1.1.2.1.2.3.6.1 1-.4 1.2.2.5.3.9.5 1.3.4.2 1 0 1.3.6l-.3.9c-.1.1-.3.2-.5.3-.3.1-.5 0-.7-.3zm.7 23.3zm.3-20.3c-.1 0-.1-.1-.2-.1 0-.1.1-.2.1-.2.1 0 .1.1.2.1 0 0 0 .1-.1.2zm.3-1.6c0 .1-.1.1 0 0zm.1-.1c-.1-.4-.2-.7-.3-1.1.2.4.5.7.3 1.1zm.4-3.7c.4 0 .5.4.7.8-.8-.1-.8-.1-.7-.8zm.6 31.8s.1 0 .1-.1c0 .2 0 .3.1.5 0-.1-.1-.2-.2-.4zm.4.7c0-.1-.1-.1-.1-.2.1.1.1.1.1.2.1-.1.1 0 .1.1 0 0-.1 0-.1-.1zm.1-32.7c.1 0 .1-.1 0 0l.1-.1s0 .1-.1.1zm-.5 36.5zm1.1-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3.1.1 0 .1-.1.2zm.6-35.2c-.3.1-.8-.2-1 .3 0-.2 0-.4.1-.6.1-.2.4-.3.5-.3.4 0 .4.3.4.6zm.5 1.2v.1h-.1l.1-.1zm0 33.5V47h.1l-.1.1c.1 0 0 0 0 0zm.2-29.6s0-.1-.1-.1l.2-.2.1.1-.2.2zm.5 29.4c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2 0 .1-.1.1-.1.1zm.1-32.7v-.1.1zm.5 34.1c0-.1-.1-.1-.1-.2s.1-.1.1-.2c0 .1.1.1.1.2 0 0-.1.1-.1.2zm1-30.5h-.1c0-.1 0-.1.1-.2h.1c-.1.1-.1.1-.1.2zm.6-5c.1-.3.1-.5.2-1 .3.5.5.8.7 1.2-.3 0-.6 0-.9-.2zm4.2 16.8c.1 0 .2 0 .2.1.2.2.4.4-.1.7 0-.3 0-.6-.1-.8zm.2-9.5c.1-.2.2-.3.4-.4 0 0 .2 0 .2.1v.2c-.2 0-.4 0-.6.1zm1.3 1.8zm-1.6-1.6c.1-.1.2-.1.3-.2 0 .1 0 .2-.1.4 0 0-.1.1-.2.1v-.3zm-1.1 21zm1-12.9c.1.5.2.8.2 1.1-.3-.1-.4-.4-.2-1.1zm2.3 3c-.1 0-.1-.1 0 0l-.1-.1.1.1zm-1.3-6l.5-1c.1.6 0 .8-.5 1zm1.1.4c0-.1-.1-.2-.1-.3v.3c-.1 0-.2.1-.2.1.1-.1.2-.3.2-.4 0-.2.1-.4.2-.6.4 0 .6.2.6.7-.3 0-.5.1-.7.2zm2-2.9s0-.1 0 0c0-.1 0-.2.1-.2 0 0 0 .1-.1.2.1 0 .1 0 0 0zm9.4 8.8c.1.2.1.5.2.8-.3-.1-.5-.3-.6-.6 0-.1.1-.2.1-.3.1-.1.3 0 .3.1zm.6-3.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1s.1.1.1.2c-.1.1-.2.1-.2.1zm1.7 1c0 .1 0 .1 0 0 0 .1 0 0 0 0zm.5 1c0-.6 0-.6.8-.8-.3.3-.6.5-.8.8zm4-6.1c-.1 0-.1 0 0 0-.1-.1-.1-.2 0-.2l.1.1-.1.1zm.9 2.8c-.3-.5-.1-.9.2-1.4.1.6-.2.9-.2 1.4zm1.5-1.1c-.1-.1-.2-.1-.2-.2s.1-.1.1-.2c.1 0 .2 0 .2.1-.1.1-.1.2-.1.3zm11.8-.8c.1 0 .1-.1.2-.1h.1c.1.1.1.1-.1.1 0 .1-.1.1-.2 0zm-3.9.6c.3-.1.6-.2.8 0 .1 0 .1.1.2.1 0 .2-.2.5-.4.9-.2-.2-.4-.3-.5-.4-.1-.2-.2-.4-.3-.5 0 0 .1-.1.2-.1zm-1.1.1c.1 0 .1 0 0 0 .1 0 .1 0 0 0zm-2.8.4l.1.1c0 .1-.1.1-.1.2 0 0 0-.1-.1-.1.1-.1.1-.1.1-.2zm-.3 1.1h-.1c-.5 0-.6 0-.4-.5.1.2.3.3.5.5zm-.8-1.3c.3.2.2.5.2.7-.2-.1-.4-.2-.7-.4.2-.1.4-.2.5-.3zm-.6 1.5zm-2 .1v-.1.1zm1.7 3.1v-.1h.1c0 .1-.1.1-.1.1zm.8.9s0-.1 0 0c0-.1 0-.1 0 0zm.7-1.7c-.3-.2-.5-.4-.8-.5h-.2c-1 .6-1.1.5-1.2-.8-.1-1.1-.1-2.1-.1-3.3.2.1.4.1.4.2.1.4.1.7.1 1.1v2.3c.9-.3.9-.3 1.9-.1.1-.5.1-1 .2-1.4h.6c0 .3-.1.6-.1.9 0 .3.1.5.2.8-.5.2-.7.5-1 .8zm4.8 1.3h-.2c0-.1.1-.2.1-.2.1 0 .2.1.3.1-.1 0-.1.1-.2.1zm.8-1.4c-.2.1-.5 0-.8-.1-.2-.1-.4-.3-.7-.5-.2-.1-.4-.3-.5-.4-.4 0-.4.5-.6.7-.2.2-.3.4-.5.6-.2-.3-.3-.7-.5-.9-.6-.6-.5-1.2-.1-1.9.1-.2.4-.3.5-.5-.4-.3-1-.7-1-1 .2.1.5.2.7.1.2-.1.4-.1.7-.1.2 1.5.5 1.5 1.4 2.2.3.3.9.5 1.1.9 0 0 .3 0 .4-.1.1-.1.1-.3.1-.4-.2-.4-.4-.7-.6-1.1.4-.3.6-.3.7 0 .2.3.3.6.4.9.1.8-.1 1.4-.7 1.6zm1.2-2.2c-.2-.4-.5-.8-.8-1.2 0-.1.1-.2.2-.3h1.2c.1.2.3.4.5.7 0 .2 0 .4.1.5l-1.2.3zm1.2 1.3v-.1.1zm.8-1.6c-.3-.2-.3-.9-.9-.6.1-.2.1-.4.1-.6.4 0 .8 0 1.2.1v.1c.1.3 0 .7-.4 1zm.6 1.7c-.1-.1-.1-.1 0-.1v.1c.1-.1 0 0 0 0zm-4.5 7.3s0-.1 0 0c0-.1 0 0 0 0zm5.3-10.8c.1 0 .3 0 .4.1 0 0 0 .1-.1.1h-.3c.1-.1 0-.1 0-.2 0 0 0-.1 0 0zm-.1.7c.2-.1.5-.1.7-.1.3 0 .5-.1.6-.2.1.2.1.3-.1.5-.1.2-.1.5-.2.7-.6.9-.6 1 0 2-.2.2-.5.3-.7.5-.4-.3-.5-.8-.4-1.2.1-.8-.2-1.5.1-2.2zm1.4 5.4s-.1.1-.1.2l-.1-.1v-.4c.1 0 .1.1.2.3zm-1.8.5c0-.4-.1-.8-.1-1.3h1.3c.1 0 .2.2.3.3-.5.1-.5.6-.7.9-.2.1-.5-.4-.8.1zm1.7 1.9l-.3.3c-.1.1-.3.1-.4.1-.1-.1-.2-.3-.3-.5.1-.2.2-.5.3-.6.3-.4.6-.4.8-.3.3.2.2.6-.1 1zm.7.4v-.1.1zm.3-2.7h.2c0 .3-.1.2-.2 0zm.3 2h.1-.1zm0-2c.1-.1.2-.3.4-.5 0 .5-.2.5-.4.5zm4.8-2.8zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2 0-.2.1-.2.1-.2zm-1.8 16.4s.1 0 .1-.1v.2c-.1.1-.2.1-.3.2.1-.1.2-.2.2-.3zm-.2.4c0 .1.1.1 0 .2l-.1.1v-.1c.1-.1.1-.1.1-.2zm.4 2.2c-.1.2-.2.3-.3.4l-.2-.1v-.5c0-.1.2-.2.4-.4.1.3.1.5.1.6zm.3-8c-.2-.1-.4-.2-.4-.5.3 0 .5 0 .8-.1.1-.1.2-.1.3-.1 0 .1-.1.2-.2.3.2.8 1.2 1.2 1 2.3-.7-.6-1.3-.8-1.4-1.7.1 0 0-.1-.1-.2zm.4 3c.3-.2.5-.1.7.1.1 0 .1.2.1.2 0 .1-.1.1-.2.1-.3.1-.5 0-.6-.4zm.6 4c.6.6.6.6.9 1.8-.9-.4-.7-1.1-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.2.6.5.4 1zm-.4-1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1.5-.1 1 .7 1.3-.3.2.4.4.6.5.9-.2.3-.7.3-.7.8zm.8-6.7c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2-.1.2-.2.3-.3.3zm.7 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 .1 0 .1-.1.1zm.6-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.5.2 1-.1 1.4zm.4 7.4c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2c0 .1-.1.2-.3.3zm.5-1.4l.1-.1-.1.1zm.6-6.1c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1-.1-.4-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.5c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 .1-.1.2-.1.2zm.8-.4c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm0 .8v0zm.4-5.8c.1 0 .2.1.2.1-.1 0-.2-.1-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1v-.1l.1.1c.1 0 0 .1 0 .1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3V24c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .5 0 .8zm0 5.3v-.1h.2v.2c0-.1-.1-.1-.2-.1zm.6 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.4-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4-.1.6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.5-.4.4-.8.4zm1.2 4.4l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.1 0-.2.1-.4.2zm0-1.3c.1-.2.2-.4.3-.7.3.4-.1.5-.3.7zm1.7 1.2v-.1.1zm-.3-1.6c.5-.8.5-.8 1.1-.3-.3.2-.6.2-1.1.3zm2.3 4.9c0-.1 0-.1 0 0l-.1-.1c.1-.1.2-.1.1.1.1-.1.1-.1 0 0zm.1-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6v-.2l.1-.1c.1 0 .1.1.1.2-.1 0-.2 0-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1-.1-.2-.1-.2-.2zm.9 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.1.3-.3.3zm1.3 1.9s0-.1 0 0c0 0 .1 0 .1.1l-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.4zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.1.1-.2.1zm.6-15.7c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.2.1-.2.1zm.5-16c0 .1 0 0 0 0zm1.8 16.1c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1.1-.1.2-.1.2zm3.8-.3zm-.5-5.2s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.2.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.2.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1 0 .1 0 .2.1zm-.3 4.2c0 .1 0 .1-.1.1l.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4 0-.1-.1-.2-.1-.2zm1.5 7.2c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.2-1.1.3-1.5.4zm5.8-12c.1 0 .1 0 0 0 .1 0 .1.1 0 0 .1.1 0 0 0 0zm-.7 3.9c.1 0 .1 0 0 0 .1.1.1.1 0 .1.1 0 0 0 0-.1 0 .1 0 0 0 0zm-.3 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1zm-2.6-15.9v-.1l.1.1h-.1zm1 19c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.7-1.5.6-2.2.4zm2.6 1.3c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2 0 0 0 .1-.1.2zm.9-9.5h.1v.2c-.1 0-.1 0-.2-.1.1 0 .1-.1.1-.1zm-.1 5.1c0 .1.1.1 0 0v0c0 .1 0 .1 0 0zm.2 3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.6.1-1.1.1-1.6 0zm.8-14.4c-.1-.1-.1-.3 0-.4V20v.5zm0 6.2s0 .1-.1.1c0 0 0-.1.1-.1-.1 0-.1 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.3-.1-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.4-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1 0-.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.2.6-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-3.3.3zm-.5-.3c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.2 0 .5-.1.8-.2zm-9.7-6.4c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.1-.2.2-.3zm-5-7.1v0zm-5.5 5.5l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3 0-.1-.1-.2 0-.2zm-1-.9c0 .1 0 .1 0 0 0 .1 0 .1 0 0zm-1.1.1zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8s.1 0 0 0c.1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3 0 0 .2.1.3.2zM1298 14s0 .1 0 0zm-1.7 17.7v.1h-.1s-.1 0-.1-.1c.1.1.2.1.2 0zm-1.5-9.6v-.2s.1 0 .1.1l-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1V27zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.6-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .3-.2.6-.8.6zm1.1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.2-4.4zm2 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.6-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 1.9c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .2-.1.2zm1-2.1c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.5c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.9-.5-1.3-.4zm1.5 4.5v.1h-.2v-.1c.1-.1.1-.1.2 0zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.2-1.7-.2zm1.9.2s-.1 0 0 0c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.3-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0-.1 0 0zm-.3-3.1s-.1-.1-.1-.2h.4s.1.1.1.2h-.4zm.3-12c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.2 9.3zm-.1-9.6c.1 0 .2.1.3.2-.2 0-.3-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .1-.1.2-.1zm0 9.4s-.1 0-.1-.1c.1 0 .1 0 .1.1 0-.1 0 0 0 0zm.3-8h-.1v-.1c0-.1.1-.1.2-.2-.1.2-.1.2-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2c-.2-.1-.4-.1-.7 0zm.5 6.6zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.7s-.1 0 0 0c-.1 0-.1-.1 0 0-.1-.1 0-.1 0 0zm1.2-2c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.1-.5-.2-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.7-.2-1.3-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s-.1 0-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9 0-1.3.1zm1.3-6.9c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.4.2.9-.1 1.5zm.6 4h-.1c0-.1-.1-.1-.1-.2h.2c.1 0 .1.1 0 .2zm.5-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.7s-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1zm0-2.3c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.4c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.6-1.3-.9zm4.9 4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c-.1 0-.1 0 0 0-.1 0-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm-3-3.4c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.5 0 .8-.3 1.1zm1.4 3.2c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.7.3.4.9.5 1.4zm.3-2.1c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.2-.6-.7-.7-1.5zm2.5 4.8c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.7.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s-.1 0 0 0c0 0 0-.1 0 0 0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .1-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-1-.1-1.7.2-2.3.5zm1.6 5.9s-.1 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.2.3-.4.5-.6.8zm.6-4.3c.1 0 0 0 0 0-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.3-.5-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1-.1-.2 0-.4 0zm-1.1-4.9c.1-.2.3-.2.4 0l.7.7c-.7.2-.7.2-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.4.6.8.1 1.1zm-.8-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.7.8-1.4.3-1.9.5zm7.5-1.1c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1 0-.1.1-.1zm-3.6 11.7c-.1 0-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1 .6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.5.5 0 .9 0 1.3zm-1-1.9c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.2-1 .2-1.5.2zm2.1 4.2c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.7c0-.4 0-.4.5-.6-.2.3-.3.5-.5.6zm.5-.5c.3-.2.5-.4.9-.6-.2.6-.2.7-.9.6zm.4-5.6h.2v.1h-.2v-.1zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.3.6-.3.9zm.4 2.1V31s0-.1.1-.1c-.1 0 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.2-.4.4-.6 0zm.8 5.6V34c.1 0 .1-.1.2-.1v.1s-.1 0-.2.1zm-.2-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm-.1-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.2-.2-.6-.4-.9-.5zm1.1 2.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.2.1-.2.2-.2.2zm14.2 7.8c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.2.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.3 0-.6-.1-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3 0 .2-.3.4-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.3-.7.4-1.1.4zm2.6-.4l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.1-.4.4-.1.6-.3zm-.4 6v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7 0-1.4.1-2 .1zm.7 3.2v-.1.1zm.5 1.6V36h.1c.1.1.1.2.2.3-.1-.1-.2-.1-.3-.1zm.5.2c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1-.1.1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.2-3v-.1.1zm.6-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.2.2.4.1.5zm.7 2.2c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5-.1.1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.2-.5.5-.6zm-.7 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.3-.6.7-1 1.1-.8zm-2.3 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .1-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c-.1-.1-.1-.1-.2-.1zm1.8 1.9l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4 0 1.1-.1 1.1-1.3.4zm1.4-1.4c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.1.4.1.5.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.1 1.5c-.1-.1-.1-.1 0-.2h.1c0 .1 0 .2-.1.2zm1.2-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.2.2.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .1-.1.2-.1zm-7.2-.3l.1.1c-.1 0-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.2-.7.1zm.7-.1c0-.2.1-.4.1-.5H1373.8c-.1.2-.2.4-.4.5zm5.2 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.3.9-.5 1.4zm3.5 1.2c0-.2 0-.4-.1-.7.3.4.2.6.1.7zm1.8-.9c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1-.1-.1-.1 0-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.2c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1v.2zm0-2.3c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.8c-.4-.2-.1-.6-.2-.8.5.4.5.4.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c-.1-.1-.1-.2-.1-.4-.1.1 0 .1 0 0zm-.3 2.1c.4-.3.6 0 .8.1-.3 0-.5-.1-.8-.1zm.9 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2.1.3-.2.4-.4.6zm.4-1.4v-.2c.1.1.1.1 0 .2.1-.1.1 0 0 0zm3-.1h.2v.1c-.1 0-.1.1-.2.1v-.2zM1392 25c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.2-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2 0-.3.1-.3.1zm.6.9c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.3c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1c-.1-.1-.2-.1-.2-.2h.3c-.1 0-.1.1-.2.1 0 .1.1.1.1.1zm.1-.1c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm2.2-3.3zm-.7 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.2.1-.3.1-.3zm.1 2c0-.1 0-.2-.1-.3 0 0 .2-.1.2 0s.1.2.1.2-.1 0-.2.1zm.6-3.8s0-.1 0 0c-.1-.1-.1-.1 0-.1 0 0 .1 0 0 .1.1-.1.1 0 0 0zm.8 3c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.2 0 .4 0 .1-.1.2-.1.2zm1.6-.1v-.2c0-.2.1-.3.2-.4 0 .2 0 .4.1.6h-.3zm2.1.1zm12.7 4.3c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-3.3.3c.1.1 0 .1 0 .1-.1 0-.1-.1 0-.1-.1 0-.1 0 0 0zm-1-2.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1 0-.1-.1-.1-.1-.2s.1-.1.2-.1zm-.1 1.4zm-2.5-4.1c0 .1.1.1.1.2-.1 0-.1-.1-.2-.1 0 0 0-.1-.1-.1h.2zm-3.6.7s-.1 0 0 0c-.1 0-.1 0 0 0-.1-.1 0-.1 0 0zm-1.4 5.6zm-.1.2l.1-.1v0c0 .1.1.2.1.3 0-.1-.1-.1-.2-.2zm.2.5h-.1c.1-.1.1-.2.2-.3.2.1.3.2.5.2-.2 0-.3.1-.6.1zm5.8-2.2c.1.5 0 1-.3 1.4-.5.1-1 .1-1.4.2-.1-.2-.2-.4-.3-.5-.3 0-.5.2-.5.5v.1c-.6 0-1.1-.1-1.7-.1-.4.4-.5.5-.8.6.1 0 .1 0 .2-.1-.2-.3-.3-.6-.5-.8l.3-.3c0-.7-.3-1.1-.6-1.7.1.1.3.1.6.2l-.6-.6c.8-.1 1 0 1.1.9 0 .3-.1.6.2.7.4-.3.5-.3.7-.9 0-.1.1-.1.1-.2v-.1c-.3-.5-.6-1.1-.8-1.8h.2c.2-.1.4-.1.5-.1-.1.1-.1.3-.1.5 0 .5.3.8.8.8.4 0 .7-.3.7-.7 0-.2-.1-.4-.3-.6.1-.1.2-.2.1-.3-1-.3-1.2-1.1-1.2-2.1 0-.2 0-.3.1-.4.2-.2.4-.3.7-.5h.1c0 .2.1.4.1.6.2 0 .3 0 .4.2.1.5.2 1.1.6 1.4 0 .7-.2 1.3.3 1.8.6-.7.6-1-.1-1.7.1.1.2.1.3.2.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.2-.1.3-.1.5-.1 0 .3 0 .6-.1.9-.1.2 0 .4 0 .6-.1 0-.2-.1-.3-.1 0 .3-.2.6.2.9.1 0 .1-.1.2-.1v.1c0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.2.6 0 1.2.1 1.8zm1.5 3.6v.2c.1.1.1.2.2.4-.3 0-.5.1-.8.6-.2.1-.4.2-.4.3v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2 0-.3v-.2c.2 0 .4.1.6.2h-.6zm0-2.1c-.1 0-.1 0 0 0-.1-.2-.1-.4-.3-.6v-.1c.5 0 1-.1 1.6 0h.5c0 .3 0 .5-.2.7-.6.1-1.1-.2-1.6 0zm1.9 2.6c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2-.2-.1-.3 0-.5 0zm1.9-2.2c-.1-.1-.3-.2-.4-.2h-.2c-.2-.2-.5-.3-.8-.4 0-.3 0-.7-.1-1l.1-.1.4.4s.1 0 .1-.1c.2.1.5.3.7.4.4.1.8.2 1.1.6-.3.2-.6.3-.9.4zm.6-1.6c.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0-.1.1-.1.1-.2.1.2.2.5.3.8-.2 0-.3-.1-.4-.2zm1.2 2.4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm1.5-6.8c.1 0 .2-.1.3-.1 0 .2 0 .3-.1.4-.1-.1-.1-.2-.2-.3zm-1.3 2.8l.3-.3c.1-.1.1-.2.2-.4h.4c.1.1.2.1.3.2-.3.3-.4.4-.6.9-.2-.1-.5-.2-.6-.4zm.8.5c0 .1-.1.1-.2.1 0-.1 0-.1-.1-.2.1 0 .2.1.3.1zm.1 2.4c.2.4.2.5 0 .9-.1.1-.2.1-.3.2-.1-.5-.2-.9-.4-1.3l.6-.6c.2.3.4.4.8.5-.2.1-.5.2-.7.3zm1-1.4v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 0 .1.1.2.1-.1.2-.2.3-.3.5-.2 0-.5.1-.7.1v-.4c0-.1.1-.2.1-.2 0-.3 0-.6.1-.9.2 0 .4.1.6.1v-.1c0-.1.1-.1.1-.2 0 .1 0 .2.1.3l.3.3c-.1.1-.2.3-.3.5zm.7 2.7c-.1-.1-.1-.1 0 0l-.1-.1c0-.4 0-.7.1-1.1.1.1.1.4.1.8 0 .1-.1.2-.1.4zm.9-1.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .2-.2.3-.2.4zm1.4 2.9zm2.2-7.4c0 .1-.1.1-.1.2s-.2.1-.3 0v-.2h.4zm-.2 1.6zm-.3-1.7c-.1 0 0 0 0 0zm.6 8.1c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.2.2-.2.4zm-.5-3.1h-.2v-.3c.2 0 .5.1 1 .2-.4.1-.6.1-.8.1zm1.7 7.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.3-.3-.1-.5 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8c0-.1.1-.1 0 0 .1-.1.1-.1 0 0 .1-.1.1-.1 0 0zm.2 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.4-5.3zm1.7 6.1s.1 0 .1-.1c0 .2 0 .3.1.5 0-.1-.1-.2-.2-.4zm.4.7c0-.1-.1-.1-.1-.2.1.1.1.1.1.2.1-.1.1 0 .1.1 0-.1-.1-.1-.1-.1zm-.4 3.8zm1.1-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3.1 0 0 .1-.1.2zm1.1-.5v-.1h.1c0-.1 0 0-.1.1.1-.1 0-.1 0 0zm.7-.2c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2s0 .1-.1.1zm.6 1.3c0-.1-.1-.1-.1-.2v-.1s.1 0 .1-.1l.1.1c0 .2-.1.3-.1.3zm5.9-8.3c0 .1-.1.2-.1.3l-.1.1c-.2-.2 0-.4.2-.4zm2.9-4.6zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2.1-.1.1-.2.1-.2zm-.3 18.1c.6.6.6.6.9 1.8-.9-.5-.7-1.2-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.1.6.4.4 1zm-.4-1.1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1v0c.4 0 .9.6 1.2-.3.2.4.4.6.5.9-.1.3-.6.4-.6.8zm.8-6.6c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2l-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5l-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.4.2.9-.1 1.4zm.5 7.3c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.3l.1-.1-.1.1zm.5-6.2c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1 0-.3-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.4c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 0-.1.1-.1.2zm.8-.5c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.2 0-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3v-.1c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .6 0 .8zm.1 5.3v-.1h.2v.2c-.1 0-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.5-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.3 0 .4 0 .6-.1zm-.4 1.5c.2-.5.5-.4.8-.4-.3.6-.5.4-.8.4zm1.2 4.5l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.4c.1-.2.2-.4.3-.7.2.5-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.5c.5-.8.5-.8 1.1-.3-.3.1-.6.2-1.1.3zm2.4 4.8c-.1 0-.1 0 0 0l-.1-.1s.1 0 .1.1c0-.1 0 0 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6V32l.1-.1c.1 0 .1.1.1.2-.1 0-.2.1-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c-.1 0-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c0 .3-.2.3-.3.3zm1.2 1.9s.1 0 .1.1c0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.5zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.6-15.8c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1 0-.2.1zm.6-16.1c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1.1-.1.1 0 0zm-.1 0c0 .1 0 .1 0 0zm1.1-5.7c-.1-.1-.2-.2-.2-.3.1 0 .2.1.2.1.1.1.1.2 0 .2.1 0 0 0 0 0zm.7 21.9c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1 0-.1.2-.1.2zm3.8-.3zm-.5-5.3s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.1.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.1.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1.1.2.1.2.1zm-.3 4.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4l-.1-.2zm1.5 7.3c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.1-1 .2-1.5.4zm6.8-8.6h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.2 5.2c.1 0 .1 0 0 0v0zm-.7-8.6s-.1 0 0 0c-.1 0-.1 0 0 0zm-.7 3.8s0 .1 0 0c.1.1.1.1 0 .1 0 .1-.1 0 0-.1-.1.1-.1 0 0 0zm-.4 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1c0 .1 0 0 0 0zm-2.6-15.9v-.1l.1.1h-.1zm1 19.1c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.6-1.5.6-2.2.4zm2.6 1.2c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1.1 0 .1-.1.2zm.1-25.4v-.1c.1 0 .1.1 0 .1zm.5-.3c-.1 0-.2.1-.3.1 0-.1 0-.3.1-.4 0 0 0-.1.1-.1 0 .2 0 .3.1.4zm.5 24.3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4v-.1.5zm0 6.2s0 .1-.1.1l.1-.1c-.1 0 0 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2 0-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.5-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.7-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1 0 .1-.1zm-3.3.3c.1 0 .1 0 0 0zm-.5-.2c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.2.8-.2zm-9.7-6.5c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.2-.2.2-.3zm-5-7.3s.1 0 0 0c.1.1.1.3.1.4-.1-.1-.2-.2-.1-.4-.1.1 0 0 0 0zm-5.5 5.7l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-1-.8zm-1.1 0zm-2.4 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8c.1 0 .1.1 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zm-4.2-17.8c0 .1 0 .1 0 0 0 .1 0 0 0 0zm-1.6 17.8v.1h-.1s-.1 0-.1-.1h.2zm-1.6-9.7v-.2s.1 0 .1.1-.1.1-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1v-.4zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8-.1.4-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.7-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 2c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .1-.1.2zm1-2.2c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.4c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.8-.5-1.3-.4zm1.5 4.4v.1h-.2v-.1h.2zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.1-1.7-.2zm1.9.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.4-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.1.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0 0 0 0zm-.3-3s-.1-.1-.1-.2h.4s.1.1.1.2c-.2-.1-.3 0-.4 0zm.3-12.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.4zm-.2-9.7c.1 0 .2.1.3.2-.2 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2 0 .2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2-.1.3-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2h-.7zm.5 6.6c0 .1 0 .1 0 0 .1 0 0 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.8s-.1 0 0 0c-.1-.1-.1-.1 0 0-.1-.2 0-.1 0 0 0-.1 0-.1 0 0zm1.2-2.1c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.2-.4-.1-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.7-.1-1.3-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s0 .1-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9.1-1.3.1zm1.3-6.8c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7l.1-.1c0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2 0 .3.1.9-.2 1.5zm.7 3.9h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.8c0-.1-.1-.1 0 0l-.1-.1c.1-.1.1-.1.1.1 0-.1 0-.1 0 0zm0-2.4c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.3c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.7-1.3-.9zm4.9 3.9c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c0 .1-.1.1 0 0-.1 0-.1 0-.1-.1 0 .1 0 0 .1.1zm-3-3.3c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.4 0 .7-.3 1.1zm1.4 3.1c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.4.9.5 1.4zm.3-2c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.3-.6-.8-.7-1.5zm2.5 4.7c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.8.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c0-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .2-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9 0-1.6.2-2.3.5zm1.6 5.9c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.4.6-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.4-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.2 0-.3.1-.4 0zm-1.2-4.8c.1-.2.3-.2.4 0l.7.7c-.7.1-.7.1-1.1-.7zm2.8.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.3.3.6.8.1 1.1zm-.8-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.2-1.9.5zm7.5-1.2s0 .1 0 0c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1.1-.1.1-.1zm-3.6 11.7s-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1.1.6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.4.6-.1.9 0 1.3zm-1.1-1.8c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.1-1 .1-1.5.2zm2.1 4.1c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.8c0-.4 0-.4.5-.6-.2.2-.3.4-.5.6zm.5-.6c.3-.2.5-.4.9-.6-.2.7-.2.7-.9.6zm.4-5.6h.2v.1h-.2V34zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.2.7-.3.9zm.4 2.1v-.1s0-.1.1-.1c-.1.1 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.3-.4.4-.6 0zm.9 5.6v-.1c.1 0 .1-.1.2-.1v.1c-.1 0-.2.1-.2.1zm-.3-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm0-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.3-.9-.5zm1 2.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1.1-.2.1-.2.2zm14.2 7.7c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.1.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.2 0-.6 0-.5-.5zm1.2 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6 0-.3.1-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.5 0-1 .2-1.4.7zm1.1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3.1.2-.3.5-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.4-.7.4-1.1.4zm2.6-.3l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.2-.5.4-.2.6-.3zm-.4 5.9v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7.1-1.3.1-2 .1zm.8 3.3v-.1.1zm.4 1.5v-.2h.1c.1.1.1.2.2.3 0-.1-.2-.1-.3-.1zm.5.3c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1 0-.2.1zm.2-3v-.1.1zm.6-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2.1.1.2.3.1.5zm.7 2.1c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.3-.5.5-.6zm-.6 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.2-.6.6-.9 1.1-.8zm-2.4 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .2-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1s-.1-.1-.2-.1zm1.8 2l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-1-1.9c.4-.6.8-.4 1.3-.4 0 1-.1 1-1.3.4zm1.4-1.5c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.2.4.1.6.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5s-.1 0 0 0c-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.3.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .2-.1.2-.1zm-7.2-.3s.1 0 0 0l.1.1c-.1.1-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.3-.7.1zm.7-.1c0-.2.1-.4.1-.5H1555.1c-.1.2-.2.4-.4.5zm5.3 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.4.9-.5 1.4zm3.4 1.3c0-.2 0-.4-.1-.7.3.3.2.5.1.7zm1.8-1c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1-.1-.1-.1.1-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.3c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1.1 0 0 .1 0 .2zm0-2.4c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.9c-.4-.2-.1-.6-.2-.8.5.3.5.3.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c-.1-.1-.1-.3-.1-.4zm-.3 2c.4-.3.6 0 .8.1-.3 0-.5 0-.8-.1zm1 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2 0 .3-.3.4-.4.6zm.3-1.4v-.2c.1.1.1.1 0 .2.1 0 .1 0 0 0zm3.1-.1h.2v.1c-.1 0-.1.1-.2.1s-.1-.1 0-.2zm-1.9-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.1-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2.1-.2.1-.3.1zm.6 1c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.4c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1.1c-.1-.1-.1-.2-.2-.3h.3c0 .1-.1.2-.1.3zm2.4-3.5s-.1 0 0 0c-.1 0 0 0 0 0zm-.8 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.1.1-.3.1-.3zm.1 2v-.4s.2-.1.2 0 .1.2.1.2c-.1.1-.2.2-.3.2zm.7-3.8c-.1 0-.1 0 0 0-.1-.1-.1-.1 0-.1-.1 0 0 0 0 .1 0-.1 0 0 0 0zm2.5.9c0 .1 0 .1-.1.2.1-.1.1-.2.1-.2zm-1.8 2.2c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.3.1.4-.1 0-.2.1-.2.2zm.6-1.8c-.1 0-.2 0-.2-.1-.1-.1-.2-.3-.2-.4.1 0 .1-.1.2-.1.1.1.2.3.3.4 0 0 0 .1-.1.2zm.5 1.9c-.2-.4 0-.5.1-.7 0 .2 0 .4-.1.7zm.2-.7c0-.5-.1-1.1.5-1.4.1.6.1 1.2.2 1.8-.5.1-.5-.3-.7-.4zm.8-3.7l-.2-.2c.1-.1.2-.1.4-.1 0 0-.1.1-.2.3zm1.6 4.2zm.6-2.3c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1 0 0 .1.1.1.2 0 0-.1 0-.2.1zm.9 1c.1-.1.2-.3.3-.3 0 0 .1.1.2.1-.1.1-.2.3-.3.4 0-.1-.1-.1-.2-.2zm.5 1.9c0 .1-.1 0 0 0-.1-.1-.1-.2 0-.3.1 0 .1.1.2.1-.1.1-.1.2-.2.2zm.4-2.9l-1.2-2.1c.1-.2.1-.3.2-.5h.5v.5c.1.4.6.5.5 1-.1.3.2.7.2 1-.1.2-.2.2-.2.1zm.5-2.2s-.1 0 0 0v-.2.2zm.9.6c-.2-.3-.2-.5 0-.8h.1c0 .3 0 .5-.1.8zm1.4 2.5c-.1 0-.2-.1-.2-.1 0-.2.1-.5.2-.7.2.1.3.1.3.2 0 .2-.1.5-.3.6zm.4-3.7c0 .1 0 .1 0 0-.1.1-.1.1 0 0zm.1 5s0-.1-.1-.1h.2c0 .1.1.1.1.2-.1 0-.2 0-.2-.1zm2-4.3c-.1 0-.1-.1-.2-.1l.1-.1c.1 0 .1.1.1.2zm.3 1.4c-.1 0-.1-.1-.2-.1v-.1c.1 0 .2 0 .2.1v.1zm.5.9zm4.1 4.6c.1 0 .3.2.4.3.1.2-.2.5-.4.4-.1-.1-.2-.2-.5-.4.2-.1.4-.3.5-.3zm.1 1.9c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-1-3.7zm0 .8s.1.1 0 .1c0 0-.1 0-.1.1 0 0-.1 0-.1-.1.1 0 .2 0 .2-.1zm-.3 2.3c0 .1 0 .1-.1.1l.1-.1c-.1 0 0 0 0 0zm-.7-1.4c-.1 0-.1 0 0 0l-.1.1c0-.1 0-.1.1-.1zm-1.3 2.2c.1.1 0 .1 0 .1s-.1 0 0-.1c-.1 0 0 0 0 0zm.8 4.1c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2h-.5zm1.5-2c-.4-.5-1.1-.8-1.6-.6-.7.3-1.3-.2-2 0-.3.1-.4-.3-.3-.7.5 0 1-.1 1.6 0 .6.1.9-.1 1.2-.6.4.3.8.5 1.2.7.4.1.8.2 1.1.6-.4.3-.7.4-1.2.6zm1-2.3c.1.2.2.5.3.8-.6-.3-.6-.3-.3-.8zm2.5-3.8c-.2.2-.4.3-.6.6-.3-.1-.6-.3-.9-.4.1-.5.5-.5 1.5-.2zm-1.6 3.6s-.1 0-.1-.1V36s.1 0 .1.1v.1zm.2 3.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1.1 0 0 .1 0 .1zm.3-2.1h-.2v-.1c.1 0 .1 0 .2.1 0-.1 0 0 0 0zm-.3-2.4c.5-.1 1-.1 1.7-.2-.6.5-.6.5-.9 1.1-.4-.2-.8-.3-.8-.9zm2 .8c0 .1 0 .2.1.3l.3.3c-.2.3-.3.7-.5 1-.2 0-.5.1-.7.1 0-.3 0-.6-.1-.9 0-.3-.2-.5-.2-.8.4.1.7.2 1.1.2v-.1c-.1.1 0 0 0-.1zm0-1.7c0-.1.1-.2.1-.2.1 0 .2 0 .2.1v.2c-.1 0-.2 0-.3-.1zm.8 5.6c-.1-.1-.3-.1-.4-.2-.2-.2-.3-.5-.6-.9-.3.3-.6.6-1 .9-.1-.5-.2-.9-.4-1.3l.6-.6c.2.4.6.5 1 .6.8.1.8.2.8 1.1.1.1 0 .2 0 .4zm.1-6.4c-.1.2-.5.3-.8.1-.2-.1-.4-.4-.6-.6.3-.1.6-.3 1-.4.1 0 .2.1.2.1.1.2.3.4.2.8zm1.6-15.4v.1-.1zm-.3 1.2c.1 0 .2 0 .2.1.2.2.1.4 0 .6-.1-.2-.2-.3-.3-.5.1-.1.1-.1.1-.2zm-.7 5.2c.1 0 .1-.1 0 0 .1 0 .1 0 .2.1h-.2v-.1zm.2 11zm0 3.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .3-.2.4-.2.4zm.2-8.8zm.3 2.8v-.1.1zm.2-11.6s-.2 0-.2-.1c-.1-.4-.3-.8.2-1.1 0 .1.1.2.1.2.1.4.3.8-.1 1zm6.3-9.3zm-1.1-.1c-.1 0-.2.1-.4.1v-.1h.4zm-1.2 0c.1.1 0 .3 0 .4-.1-.1-.3-.2-.3-.4h.3zm-.6 3c0 .1-.1.3-.1.4-.2.3-.4.6-.6 1-.1-.9 0-1.4.4-2.3.3.2.3.6.3.9zm-.4-.9c-.1 0-.2 0-.2-.1v-.2h.1c.1.2.1.3.1.3zm-.8-2.1h.4c.1.2.2.3.3.5l-.6.9c-.1.1-.1.1-.6-.1.2-.4.3-.9.5-1.3zm-.6 2.7s.2.1.1.2-.1.2-.2.2c0-.1-.1-.1-.2-.2.1-.1.2-.1.3-.2zm-.9 27.2zm.1-28.5zm.5 19.6c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.2.1-.2.1zm-.2-14.9c0-.2.1-.5.1-.7 0-.3-.1-.5-.2-.8.2 0 .4-.1.4-.1.4.6 1 1.2.8 2.2-.3-.2-.7-.4-1.1-.6zm.8 1.5zm-.1 6.8c.3-.2.6-.3.9-.5 0 .2.1.5.1.7 0 .4-.2.6-.5.7-.3 0-.5-.2-.6-.6 0-.1.1-.2.1-.3zm1.3 6.8s.1 0 .2.1c0 .5-.2 1-.5 1.4 0 .1-.2.1-.3 0l-.1-.2c.2-.4.4-.8.7-1.3zm-.3-9.9zm-.1 12.8zm-.2-10.8c0-.1.1-.1.1-.2.1.1.3.1.2.2 0 .2-.1.4-.1.6-.1-.2-.2-.4-.2-.6zm.5 17.2c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.1.3-.2.4zm-.5-3h-.6l-.1-.1c.5-.3.5-.3 1.6 0-.5 0-.7 0-.9.1zm1.1-15.1c-.1 0-.1-.1-.1-.2s.1-.1.1-.2c.1.1.1.2.2.3l-.2.1zm.6 22.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.2-.3-.1-.4 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.7-.8h-.2c.1 0 .2-.1.2 0 .1-.1.1 0 0 0zm.2 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.1-24c-.2.4-.4.2-.8.2.1-.4.2-.6.3-.9h.3c.3.1.3.4.2.7zm-.4-4.6c0 .4-.1.7 0 .9.1.6 0 1.1-.3 1.6-.4.7-.6 1.6-.9 2.4-.1-.2-.2-.4-.4-.6-.4-.1-.5.2-.5.5.1.5.1.9 0 1.4-.1.3-.3.3-.5.2 0-.1-.1-.2-.1-.3-.2-1.7-.2-1.7 1.2-2.8.4-.3.6-.6.7-1.2 0-.5.1-1 .3-1.4.4-.8.3-1.7 0-2.5-.1-.3-.2-.6-.3-1v-1.1c.3-.1.5-.2.8-.3 0 .1.1.2.1.2.3.6.1 1-.4 1.2.2.5.3.9.5 1.3.4.2 1 0 1.3.6l-.3.9c-.1.1-.3.2-.5.3-.3.1-.4 0-.7-.3zm.7 23.3zm.4-20.3c-.1 0-.1-.1-.2-.1 0-.1.1-.2.1-.2.1 0 .1.1.2.1-.1 0-.1.1-.1.2zm.2-1.6c0 .1-.1.1 0 0zm.1-.1c-.1-.4-.2-.7-.3-1.1.2.4.5.7.3 1.1zm.4-3.7c.4 0 .5.4.7.8-.8-.1-.8-.1-.7-.8zm.7 31.8s.1 0 .1-.1c0 .2 0 .3.1.5-.1-.1-.2-.2-.2-.4zm.3.7c0-.1-.1-.1-.1-.2.1.1.1.1.1.2.1-.1.1 0 .1.1l-.1-.1zm.2-32.7s0-.1 0 0l.1-.1c-.1 0-.1.1-.1.1zm-.6 36.5zm1.2-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3 0 .1-.1.1-.1.2zm.5-35.2c-.3.1-.8-.2-1 .3 0-.2 0-.4.1-.6.1-.2.4-.3.5-.3.4 0 .4.3.4.6zm.5 1.2v.1h-.1l.1-.1zm0 33.5V47h.1l-.1.1c.1 0 0 0 0 0zm.2-29.6s0-.1-.1-.1l.2-.2.1.1-.2.2zm.5 29.4c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2.1.1 0 .1-.1.1zm.1-32.7v-.1.1zm.5 34.1c0-.1-.1-.1-.1-.2s.1-.1.1-.2c0 .1.1.1.1.2 0 0 0 .1-.1.2zm1-30.5h-.1c0-.1 0-.1.1-.2h.1c-.1.1-.1.1-.1.2zm.6-5c.1-.3.1-.5.2-1 .3.5.5.8.7 1.2-.3 0-.5 0-.9-.2zm4.3 16.8c.1 0 .2 0 .2.1.2.2.4.4-.1.7 0-.3-.1-.6-.1-.8zm.2-9.5c.1-.2.2-.3.4-.4 0 0 .2 0 .2.1v.2c-.3 0-.5 0-.6.1zm1.3 1.8zm-1.6-1.6c.1-.1.2-.1.3-.2 0 .1 0 .2-.1.4 0 0-.1.1-.2.1 0-.1-.1-.2 0-.3zm-1.2 21zm1-12.9c.1.5.2.8.2 1.1-.3-.1-.4-.4-.2-1.1zm2.3 3s-.1-.1 0 0l-.1-.1s.1 0 .1.1zm-1.3-6l.5-1c.1.6.1.8-.5 1zm1.1.4c0-.1-.1-.2-.1-.3v.3c-.1 0-.2.1-.2.1.1-.1.2-.3.2-.4 0-.2.1-.4.2-.6.4 0 .6.2.6.7-.3 0-.5.1-.7.2zm2.1-2.9c-.1 0-.1-.1 0 0 0-.1 0-.2.1-.2-.1 0-.1.1-.1.2zm9.3 8.8c.1.2.1.5.2.8-.3-.1-.5-.3-.6-.6 0-.1.1-.2.1-.3.2-.1.3 0 .3.1zm.6-3.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1s.1.1.1.2c-.1.1-.1.1-.2.1zm1.7 1c0 .1 0 .1 0 0 0 .1 0 0 0 0 .1 0 .1 0 0 0zm.5 1c0-.6 0-.6.8-.8l-.8.8zm4-6.1s-.1 0 0 0c-.1-.1-.1-.2 0-.2l.1.1-.1.1zm.9 2.8c-.3-.5-.1-.9.2-1.4.1.6-.2.9-.2 1.4zm1.5-1.1c-.1-.1-.2-.1-.2-.2s.1-.1.1-.2c.1 0 .2 0 .2.1s-.1.2-.1.3zm11.8-.8c.1 0 .1-.1.2-.1h.1c.1.1.1.1-.1.1 0 .1-.1.1-.2 0zm-3.9.6c.3-.1.6-.2.8 0 .1 0 .1.1.2.1 0 .2-.2.5-.4.9-.2-.2-.4-.3-.5-.4-.1-.2-.2-.4-.3-.5 0 0 .1-.1.2-.1zm-1 .1zm-2.8.4l.1.1c0 .1-.1.1-.1.2 0 0 0-.1-.1-.1 0-.1 0-.1.1-.2zm-.4 1.1h-.1c-.5 0-.6 0-.4-.5.1.2.3.3.5.5zm-.8-1.3c.3.2.2.5.2.7-.2-.1-.4-.2-.7-.4.2-.1.4-.2.5-.3zm-.6 1.5zm-2 .1v-.1.1zm1.7 3.1v-.1h.1c0 .1 0 .1-.1.1zm.8.9s0-.1 0 0c.1-.1.1-.1 0 0zm.7-1.7c-.3-.2-.5-.4-.8-.5h-.2c-1 .6-1.1.5-1.2-.8-.1-1.1-.1-2.1-.1-3.3.2.1.4.1.4.2.1.4.1.7.1 1.1v2.3c.9-.3.9-.3 1.9-.1.1-.5.1-1 .2-1.4h.6c0 .3-.1.6-.1.9 0 .3.1.5.2.8-.5.2-.7.5-1 .8zm4.9 1.3h-.2c0-.1.1-.2.1-.2.1 0 .2.1.3.1-.1 0-.2.1-.2.1zm.7-1.4c-.2.1-.5 0-.8-.1-.2-.1-.4-.3-.7-.5-.2-.1-.4-.3-.5-.4-.4 0-.4.5-.6.7-.2.2-.3.4-.5.6-.2-.3-.3-.7-.5-.9-.6-.6-.5-1.2-.1-1.9.1-.2.4-.3.5-.5-.4-.3-1-.7-1-1 .2.1.5.2.7.1.2-.1.4-.1.7-.1.2 1.5.5 1.5 1.4 2.2.3.3.9.5 1.1.9 0 0 .3 0 .4-.1.1-.1.1-.3.1-.4-.2-.4-.4-.7-.6-1.1.4-.3.6-.3.7 0 .2.3.3.6.4.9.1.8-.1 1.4-.7 1.6zm1.2-2.2c-.2-.4-.5-.8-.8-1.2 0-.1.1-.2.2-.3h1.2c.1.2.3.4.5.7 0 .2 0 .4.1.5-.4.1-.7.2-1.2.3zm1.2 1.3v-.1.1zm.8-1.6c-.3-.2-.3-.9-.9-.6.1-.2.1-.4.1-.6.4 0 .8 0 1.2.1v.1c.1.3 0 .7-.4 1zm.6 1.7c-.1-.1-.1-.1 0-.1 0 0 .1 0 0 .1.1-.1.1 0 0 0zm-4.5 7.3s0-.1 0 0c.1-.1 0 0 0 0zm5.4-10.8c.1 0 .3 0 .4.1 0 0 0 .1-.1.1h-.3c0-.1-.1-.1 0-.2-.1 0-.1-.1 0 0zm-.2.7c.2-.1.5-.1.7-.1.3 0 .5-.1.6-.2.1.2.1.3-.1.5-.1.2-.1.5-.2.7-.6.9-.6 1 0 2-.2.2-.5.3-.7.5-.4-.3-.5-.8-.4-1.2.1-.8-.2-1.5.1-2.2zm1.4 5.4s-.1.1-.1.2l-.1-.1v-.4c.1 0 .2.1.2.3zm-1.7.5c0-.4-.1-.8-.1-1.3h1.3c.1 0 .2.2.3.3-.5.1-.5.6-.7.9-.3.1-.6-.4-.8.1zm1.6 1.9l-.3.3c-.1.1-.3.1-.4.1-.1-.1-.2-.3-.3-.5.1-.2.2-.5.3-.6.3-.4.6-.4.8-.3.3.2.2.6-.1 1zm.8.4v-.1.1zm.2-2.7h.2c0 .3-.1.2-.2 0zm.3 2h.1-.1zm0-2c.1-.1.2-.3.4-.5 0 .5-.2.5-.4.5zm4.8-2.8zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2l.1-.2zm-1.7 16.4s.1 0 .1-.1v.2c-.1.1-.2.1-.3.2 0-.1.1-.2.2-.3zm-.2.4c0 .1.1.1 0 .2l-.1.1v-.1c0-.1 0-.1.1-.2zm.3 2.2c-.1.2-.2.3-.3.4l-.2-.1v-.5c0-.1.2-.2.4-.4.1.3.2.5.1.6zm.3-8c-.2-.1-.4-.2-.4-.5.3 0 .5 0 .8-.1.1-.1.2-.1.3-.1 0 .1-.1.2-.2.3.2.8 1.2 1.2 1 2.3-.7-.6-1.3-.8-1.4-1.7.1 0 0-.1-.1-.2zm.5 3c.3-.2.5-.1.7.1.1 0 .1.2.1.2 0 .1-.1.1-.2.1-.3.1-.6 0-.6-.4zm.5 4c.6.6.6.6.9 1.8-.8-.4-.7-1.1-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.2.6.5.4 1zm-.4-1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1.5-.1 1 .7 1.3-.3.2.4.4.6.5.9-.2.3-.7.3-.7.8zm.8-6.7c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2-.1.2-.2.3-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5 0 .1-.1.1-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.5.2 1-.1 1.4zm.5 7.4c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.4l.1-.1-.1.1zm.5-6.1c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1-.1-.3-.2-.4-.4zm.7 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.2 0-.3.1-.4.1zm1.1-.4zm0-1.5c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 .1 0 .2-.1.2zm.8-.4c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2v-.7zm.2 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.8-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.2-.1-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3V24c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .5 0 .8zm.1 5.3v-.1h.2v.2c-.1-.1-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.2.2.1.4-.1.7zm.8-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.3 0 .5-.1.6-.1zm-.4 1.5c.2-.5.5-.4.8-.4-.3.5-.5.4-.8.4zm1.2 4.4l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.3c.1-.2.2-.4.3-.7.2.4-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.6c.5-.8.5-.8 1.1-.3-.3.2-.6.2-1.1.3zm2.4 4.9c-.1-.1-.1-.1 0 0l-.1-.1c0-.1.1-.1.1.1 0-.1 0-.1 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6v-.2l.1-.1c.1 0 .1.1.1.2-.1 0-.2 0-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2c0-.1-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c0 .3-.2.3-.3.3zm1.2 1.9s0-.1 0 0c0 0 .1 0 .1.1 0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3 0 .5 0 .7zm1.5 4.4zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1.1-.1.1-.2.1zm.6-15.7c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3 0 .2 0 .4-.1.6zm.6 13.4c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1.1-.2.1zm.6-16c-.1.1-.1 0 0 0zm1.7 16.1c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1.1-.1.2-.1.2zm3.8-.3zm-.5-5.2s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c0-.1.1-.2.2-.2zm-.7-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c.1-.2.1-.2.1-.3zm-.4 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c0-.2.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1 0 .2 0 .2.1zm-.3 4.2c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4 0-.1-.1-.2-.1-.2zm1.5 7.2c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.2-1 .3-1.5.4zm5.9-12s0 .1 0 0c0 .1-.1 0 0 0-.1 0-.1 0 0 0zm-.7 3.9c.1.1.1.1 0 .1 0 0-.1 0 0-.1-.1.1-.1 0 0 0zm-.4 4.7c.1 0 .1 0 0 0l.1.1s-.1 0-.1-.1zm-2.6-15.9v-.1l.1.1h-.1zm1 19c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.7-1.5.6-2.2.4zm2.6 1.3c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1 0 0 .1-.1.2zm1-9.5h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.2 5.1c.1.1.1.1 0 0v0c0 .1 0 .1 0 0zm.3 3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4V20v.5zm0 6.2s0 .1-.1.1c0 0 0-.1.1-.1-.1 0 0 0 0 0zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2-.1-.5-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.4-.3.5zm2 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.1 0-.1.1-.2.2zm-.3-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.6-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-3.2.3s-.1 0 0 0c-.1 0-.1 0 0 0zm-.6-.3c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.1.8-.2zm-9.7-6.4c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.1-.1.2-.2.2-.3zm-4.9-7.1v.1c-.1 0-.1 0 0-.1zm-5.6 5.5l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.9c-.1.1-.1.1 0 0-.1.1-.1.1 0 0-.1 0-.1 0 0 0zm-1.1.1zm-2.5 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8c.1 0 .1 0 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zm-4.2-17.8s0 .1 0 0zm-1.6 17.7v.1h-.1s-.1 0-.1-.1c0 .1.1.1.2 0zm-1.6-9.6v-.2s.1 0 .1.1l-.1.1zm.7 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1V27zm.7 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8-.1.3-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.6-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.3.1-.5.2-.8.3zm1.4 1.9c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .2-.1.2zm1-2.1c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2 0 .4 0 .6zm-.2-6.5c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.4-.6-.8-.5-1.3-.4zm1.5 4.5v.1h-.2v-.1c.1-.1.2-.1.2 0zm-.6 3.9c-.1 0-.1 0 0 0-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1-.1.2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.4.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.2 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.2-1.7-.2zm1.9.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.3-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3v.2zm.1-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.1.8-.5 1-1 1zm2 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0-.1 0 0zm-.3-3.1s-.1-.1-.1-.2h.4s.1.1.1.2h-.4zm.3-12c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.3zm-.2-9.6c.1 0 .2.1.3.2-.2 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2-.1.2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2-.1.2-.1.3zm.7 7.1zm-.2-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2c-.2-.1-.4-.1-.7 0zm.5 6.6c.1 0 0 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.7s-.1 0 0 0c-.1 0-.1-.1 0 0-.1-.1 0-.1 0 0zm1.2-2c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.4.1-.4-.2-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.6-.2-1.2-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2l-.1.1zm.1-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.4.3-.9 0-1.3.1zm1.3-6.9c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7h.2c-.1 0-.1-.1-.2-.1 0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2.1.4.2.9-.1 1.5zm.7 4h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.7s-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1zm0-2.3c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.4c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.6-1.3-.9zm4.9 4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2s-.1 0 0 0c-.1 0-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm-3-3.4c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.2.5 0 .8-.3 1.1zm1.4 3.2c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.5.9.5 1.4zm.3-2.1c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.6-.2-.6-.7-.7-1.5zm2.5 4.8c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.3.4.3.7.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c.1-.1 0 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .1-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9-.1-1.6.2-2.3.5zm1.6 5.9c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.4.5-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.5-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1-.1-.3 0-.4 0zm-1.2-4.9c.1-.2.3-.2.4 0l.7.7c-.7.2-.7.2-1.1-.7zm2.9.1c-.5.4-.7.8-.7 1.4 0 .1-.1.2-.2.5-.1-.2-.2-.3-.2-.4.1-1 .2-1-.3-2 .4-.2.9-.4 1.3-.6.2.4.5.8.1 1.1zm-.9-2.2c-.7.3-1.3-.4-1.9-.4-.4.4-.3.8-.3 1.2 0 .3-.2.5-.4.6v-.3c0-.1-.1-.3-.2-.3-.2-.1-.3.1-.3.3.2.1.3.2.5.3-.2-.1-.3-.2-.5-.3-.2 0-.3.1-.5.1-.1-.4-.3-.7-.4-1-.2 0-.3-.1-.6-.2.2-.4.4-.8.7-1h.1c.2 0 .3.1.3.4 0 .1 0 .2.1.2s.2 0 .3-.1c.1 0 .2-.1.2-.2.1-.1.3-.1.4 0 .1.1.3.2.5.1.4-.1.8-.1 1.2 0 .5.2 1.1.2 1.7-.1.3-.1.7-.1.9.2h.1c-.6.8-1.3.3-1.9.5zm7.5-1.1c0 .1 0 .1-.1.1 0 0 0-.1-.1-.1h.2zm-1.4 1h.4c-.2 0-.3 0-.5.1 0-.1.1-.1.1-.1zm-3.6 11.7s-.1-.1 0 0v-.1s.1.1.1.2c0-.1-.1-.1-.1-.1zm.1-10.7zm.8.5v-.1l.1-.1s.1.1 0 .1l-.1.1zm1.1.6c0 .4 0 .8-.1 1.3-.2-.3-.3-.5-.5-.8 0-.6.2-1.2.6-1.8.4.5-.1.9 0 1.3zm-1.1-1.9c-.4-.2-.3-.6-.4-.9l-.3-.3h.3c.5.5 1.1.9 1.9 1-.5.2-1 .2-1.5.2zm2.1 4.2c.2.5.4.8.5 1.1l-.1.2h-.2c-.4-.3-.4-.7-.2-1.3zm0 5.7c0-.4 0-.4.5-.6-.2.3-.3.5-.5.6zm.5-.5c.3-.2.5-.4.9-.6-.2.6-.2.7-.9.6zm.4-5.6h.2v.1h-.2v-.1zm.7-1.7c-.4.1-.9.1-1.4.2.2-.4.2-.6.3-.9.7.1.7.1 1.4-.2-.2.4-.2.6-.3.9zm.4 2.1V31s0-.1.1-.1c-.1 0 0 .1-.1.2.1 0 0 0 0 0zm.1-2.6c-.1-.1-.2-.2-.2-.3.4-.3.6.1.8.3-.2.2-.4.4-.6 0zm.9 5.6V34c.1 0 .1-.1.2-.1v.1c-.1 0-.2 0-.2.1zm-.3-1.9c.1 0 .2-.1.2-.1.1 0 .1.1.1.2s-.1.1-.1.2c0-.1-.1-.2-.2-.3zm0-3.7c.1-.3.2-.5.5-.5.2 0 .5 0 .5.3 0 .2 0 .4-.1.7-.3-.2-.6-.4-.9-.5zm1 2.6c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1-.2.2zm14.2 7.8c.1.1.3.3.4.5-.2-.1-.4-.1-.6-.2 0 0 0-.2-.1-.2.1-.1.2-.2.3-.1zm-13.4-8.1c.3-.2.6-.1 1 0 .1 0 .1.1.1.2s-.1.3-.1.3c-.1.1-.3.1-.5 0-.2 0-.6-.1-.5-.5zm1.3 1.1c.2 0 .5.3.4.5-.1.2-.2.3-.4.5-.4-.1-.3-.4-.3-.6-.1-.3 0-.4.3-.4zm-.8 5.5c-.1-.1-.1-.2-.2-.3.4-.4.8-.7 1.2-1.1.3.3.3.3.4.7-.6 0-1.1.2-1.4.7zm1-9.2c-.1 0-.2-.2-.2-.3.2-.1.3-.3.5-.4.1.1.3.2.3.3.1.2-.3.4-.6.4zm-.5-1.6c.1 0 .2 0 .3-.1.2-.1.4-.1.6-.2.1 0 .1 0 .2-.1-.3.3-.7.4-1.1.4zm2.6-.4l.1.1c.2.2.5.2.8.2h.1c-.2.1-.4.1-.6.2-.3 0-.7.2-1-.2.2-.4.4-.1.6-.3zm-.4 6v-.1.1zm.6-.8c-.2 0-.5-.1-.7-.2v-.4c.5-.3 2.7-.2 3.5 0-.1.1-.1.3-.2.3-.2.1-.4.2-.6.2-.7 0-1.3.1-2 .1zm.8 3.2v-.1.1zm.4 1.6V36h.1c.1.1.1.2.2.3 0-.1-.1-.1-.3-.1zm.5.2c0-.1-.1-.1-.1-.2l.2.2h-.1zm.5 1.4c-.1 0-.1-.1-.2-.1.1-.1.1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.2-3v-.1.1zm.7-2.2c-.1.6-.3.8-.8.7-.5 0-1-.2-1.5-.2 0-.3-.1-.5-.1-.8 0-.5.1-.5.7-.4.5-.2 1 0 1.6.2 0 .2.1.4.1.5zm.6 2.2c0-.2-.1-.3-.1-.5 0 0 .1-.1.3-.2.1.2.1.3.1.5 0 .1-.2.2-.3.2zm3.6-2.2c-.1.3 0 .7-.4.7l-.1-.1c-.1-.5.3-.5.5-.6zm-.6 1.4c.4.1 1 .1 1.3.6-.4.1-.9.3-1.2.1-.4-.2-.7.1-1.2.1.2-.6.6-1 1.1-.8zm-2.4 2.2c.1 0 .2.1.3.2 0 0 .1 0 .2-.1.2-.1.3-.4.5-.4s.5.2.7.4c.1.1.1.3.2.5.2.8.3.9 1.1.5.1-.1.2-.1.6-.2-.5.5-.9.8-1.2 1.2.1.3.2.7.2 1.1l-.2-.2c-.7-.4-1.2-.9-1.3-1.8-.3-.1-.5-.3-.7-.4-.1-.1-.3-.2-.4-.4-.2-.1-.2-.3 0-.4zm.7-4.9l-.4-.2.4-.4s.3.2.2.2c0 .1-.1.3-.2.4zm-.5-3.4l.2-.2c0 .1.1.1.1.2l-.1.1c0-.1-.1-.1-.2-.1zm1.8 1.9l-.2-.2c0-.1.1-.2.1-.2.1 0 .2 0 .2.1s0 .2-.1.3zm-.9-1.9c.4-.6.8-.4 1.3-.4-.1 1.1-.2 1.1-1.3.4zm1.3-1.4c-.7 0-1.4.3-2.2-.2-.1-.1-.3-.1-.4-.1-.9.4-1.8.4-2.7.2.5-.1.9-.3 1.2-.6 0 0 .1 0 .1-.1l.1.1c.2-.1.4-.1.6-.2v.3c0 .1.2.1.3.1.5 0 1 0 1.5.1s1 0 1.4-.3c.2.4.1.5.1.7zm3.2-.5c.1-.1.2-.1.3 0h-.3zm5.2 1.5s-.1 0 0 0c-.1-.1-.1-.1 0-.2h.1c-.1.1-.1.2-.1.2zm1.1-.8h-1.1c-.7 0-.9-.1-.9-.9.4-.1.8 0 1.2 0 .1.1.2.1.3.2.3.2.4.5.5.7.1-.4.2-.6.3-1h.1c.1.3.2.6.4.9-.3.1-.5.1-.8.1zm18.1-.7s.1.1.1.2c-.1 0-.1.1-.2.1 0 0-.1-.1-.1-.2.1 0 .2-.1.2-.1zm-7.2-.3s.1 0 0 0l.1.1c-.1 0-.1 0-.1-.1 0 .1 0 0 0 0zm-4.1.6c-.5-.2-.5-.2-.9.3-1-.1-1.1-.1-1-1h.1c.1 0 .3.1.4.2.1.1.3.2.4.1.2-.2.5-.2.8-.3.2.1.5.3.9.6-.2.2-.4.2-.7.1zm.7-.1c0-.2.1-.4.1-.5H1776.9c0 .2-.2.4-.4.5zm5.3 1.6c-.4.2-.9.4-1.4.6-.4-.4-.8-.6-1.3-.8-.5-.1-.9-.4-1.3-.6-.2-.1-.1-.3 0-.5l.1-.1v.1c.3-.3.6-.6.8-.9h.4c.1 0 .1.1.2.2.1.4.1.8.1 1.2.6-.2.6-.2 1.4-1 .2.4-.2.9.2 1.2.1.1.2.1.2.1.5-.1.4-1 1.1-.9-.2.5-.4.9-.5 1.4zm3.4 1.2c0-.2 0-.4-.1-.7.3.4.2.6.1.7zm1.8-.9c-.3.6-.8.7-1.3.3-.2-.2-.4-.5-.6-.7-.7.2-.7.2-1.3-.6-.3.1-.7.2-1.2.4 0-.6.4-1 .5-1.5.5.2.8.7 1.3.1.2-.3.6-.5.9-.7h.1c.2.6.2.6-.3 1.2.1.2.3.3.4.5.4 0 .7-.5 1.1 0 .2.2.6 0 .9 0-.2.3-.3.7-.5 1zm.2-2.9c.1-.1.3-.1.4-.3 0 0 0 .1.1.1-.2.2-.3.2-.5.2zm.9 3.2c-.1-.4-.1-.4.2-.8.2.4.1.6-.2.8zm2-.2h-.4v-.1c.1-.1.2-.1.4-.1 0 0 .1 0 .1.1 0-.1-.1 0-.1.1zm-.1-1.4l-.2-.1c0-.1.1-.2.2-.3l.2.2-.2.2zm1.1 1.2c-.1 0-.1-.1-.2-.1 0-.1.1-.1.1-.2 0 0 .1 0 .1.1.1.1 0 .2 0 .2zm0-2.3c-.1-.2-.1-.4 0-.6h.1c.3.1.2.3.2.6v.7c0-.3-.2-.5-.3-.7zm1 1.7c-.2-.4-.4-.7-.5-1.1.4.2.5.6.5 1.1zm.2.8c-.4-.2-.1-.6-.2-.8.5.4.5.4.2.8zm.6-3.4c.1.1.2.1.3.2 0 0 0 .1-.1.2h-.1c0-.1-.1-.2-.1-.4 0 .1 0 .1 0 0zm-.3 2.1c.4-.3.6 0 .8.1-.3 0-.5-.1-.8-.1zm1 1c-.3-.3-.1-.6-.1-.8.2 0 .4.1.5.2 0 .3-.3.4-.4.6zm.3-1.4v-.2c.1.1.1.1 0 .2.1-.1.1 0 0 0zm3.1-.1h.2v.1c-.1 0-.1.1-.2.1-.1-.1-.1-.1 0-.2zm-1.9-1.4c.1 0 .1-.1.2-.1.6.3.7.4.7.8-.1.3-.3.4-.7.3-.1-.3-.2-.6-.2-1zm-.3 4c-.1-.1-.2-.1-.2-.2.1-.1.2-.2.3-.2l.2.2c-.1 0-.2.1-.3.2zm.3-1.9h-.2s-.1-.2 0-.2c.1-.1.2-.1.3-.1.1 0 .1.1.2.2-.2 0-.2.1-.3.1zm.6.9c-.2-.4-.3-.7-.4-1.1.2-.1.3-.2.6-.4.2.4.3.8.4 1.2l-.6.3zm1.2-1.3c.1.3.2.5.3.8-.5-.3-.5-.3-.3-.8zm.5 1c-.1-.1-.2-.1-.2-.2h.3c-.1 0-.1.1-.2.1l.1.1zm.1-.1c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm2.3-3.3zm-.8 3.2c.1 0 .2.1.3.2 0 .1-.1.2-.1.2-.1 0-.2-.1-.3-.1 0-.2.1-.3.1-.3zm.1 2c0-.1 0-.2-.1-.3 0 0 .2-.1.2 0s.1.2.1.2-.1 0-.2.1zm.7-3.8c-.1 0-.1-.1 0 0-.1-.1-.1-.1 0-.1-.1 0 0 0 0 .1 0-.1 0 0 0 0zm.7 3c-.1-.1-.2-.1-.2-.2 0-.2.1-.3.1-.4h.2c0 .1.1.2 0 .4 0 .1-.1.2-.1.2zm1.6-.1v-.2c0-.2.1-.3.2-.4 0 .2 0 .4.1.6h-.3zm2.1.1zm12.7 4.3c-.1-.1-.3-.2-.4-.4.4-.1.4-.1.4.4zm-3.3.3c.1.1 0 .1 0 .1s-.1-.1 0-.1c-.1 0 0 0 0 0zm-1-2.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1 0-.1-.1-.1-.1-.2.1-.1.1-.1.2-.1zm-.1 1.4zm-2.5-4.1c0 .1.1.1.1.2-.1 0-.1-.1-.2-.1 0 0 0-.1-.1-.1h.2zm-3.6.7c-.1 0-.1 0 0 0-.1-.1 0-.1 0 0zm-1.4 5.6zm-.1.2l.1-.1v0c0 .1.1.2.1.3 0-.1-.1-.1-.2-.2zm.3.5h-.1c.1-.1.1-.2.2-.3.2.1.3.2.5.2-.3 0-.4.1-.6.1zm5.7-2.2c.1.5 0 1-.3 1.4-.5.1-1 .1-1.4.2-.1-.2-.2-.4-.3-.5-.3 0-.5.2-.5.5v.1c-.6 0-1.1-.1-1.7-.1-.4.4-.5.5-.8.6.1 0 .1 0 .2-.1-.2-.3-.3-.6-.5-.8l.3-.3c0-.7-.3-1.1-.6-1.7.1.1.3.1.6.2l-.6-.6c.8-.1 1 0 1.1.9 0 .3-.1.6.2.7.4-.3.5-.3.7-.9 0-.1.1-.1.1-.2v-.1c-.3-.5-.6-1.1-.8-1.8h.2c.2-.1.4-.1.5-.1-.1.1-.1.3-.1.5 0 .5.3.8.8.8.4 0 .7-.3.7-.7 0-.2-.1-.4-.3-.6.1-.1.2-.2.1-.3-1-.3-1.2-1.1-1.2-2.1 0-.2 0-.3.1-.4.2-.2.4-.3.7-.5h.1c0 .2.1.4.1.6.2 0 .3 0 .4.2.1.5.2 1.1.6 1.4 0 .7-.2 1.3.3 1.8.6-.7.6-1-.1-1.7.1.1.2.1.3.2.2-.4.3-.8.5-1.2.1 0 .1-.1.2-.1.2-.1.3-.1.5-.1 0 .3 0 .6-.1.9-.1.2 0 .4 0 .6-.1 0-.2-.1-.3-.1 0 .3-.2.6.2.9.1 0 .1-.1.2-.1v.1c0 .2-.1.4-.2.5h.6v.1c-.2 0-.4.1-.6.1.2.6 0 1.2.1 1.8zm1.5 3.6v.2c.1.1.1.2.2.4-.3 0-.5.1-.8.6-.2.1-.4.2-.4.3v-.8c0-.1.7-.3 1-.4-.1-.1 0-.2 0-.3v-.2c.2 0 .4.1.6.2h-.6zm0-2.1c-.1-.2-.1-.4-.3-.6v-.1c.5 0 1-.1 1.6 0h.5c0 .3 0 .5-.2.7-.5.1-1.1-.2-1.6 0zm2 2.6c-.1 0-.1-.1-.2-.1.1-.1.2-.2.3-.1.1 0 .2.1.4.2-.3-.1-.4 0-.5 0zm1.8-2.2c-.1-.1-.3-.2-.4-.2h-.2c-.2-.2-.5-.3-.8-.4 0-.3 0-.7-.1-1l.1-.1.4.4s.1 0 .1-.1c.2.1.5.3.7.4.4.1.8.2 1.1.6-.3.2-.6.3-.9.4zm.6-1.6c.1 0 .1-.1.2-.1-.1-.1-.1-.2-.2-.3 0-.1.1-.1.1-.2.1.2.2.5.3.8-.2 0-.3-.1-.4-.2zm1.2 2.4c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1.1 0 0 0 0 .1zm1.5-6.8c.1 0 .2-.1.3-.1 0 .2 0 .3-.1.4 0-.1-.1-.2-.2-.3zm-1.3 2.8l.3-.3c.1-.1.1-.2.2-.4h.4c.1.1.2.1.3.2-.3.3-.4.4-.6.9-.2-.1-.4-.2-.6-.4zm.8.5c0 .1-.1.1-.2.1 0-.1 0-.1-.1-.2.2 0 .2.1.3.1zm.1 2.4c.2.4.2.5 0 .9-.1.1-.2.1-.3.2-.1-.5-.2-.9-.4-1.3l.6-.6c.2.3.4.4.8.5-.2.1-.4.2-.7.3zm1-1.4v-.3c0-.1-.1-.1-.2-.2 0 .1-.1.2 0 .4 0 0 .1.1.2.1-.1.2-.2.3-.3.5-.2 0-.5.1-.7.1v-.4c0-.1.1-.2.1-.2 0-.3 0-.6.1-.9.2 0 .4.1.6.1v-.1c0-.1.1-.1.1-.2 0 .1 0 .2.1.3l.3.3c-.1.1-.2.3-.3.5zm.7 2.7c0-.1-.1-.1 0 0l-.1-.1c0-.4 0-.7.1-1.1.1.1.1.4.1.8 0 .1 0 .2-.1.4zm.9-1.2c-.1-.1-.2-.2-.2-.3 0-.1.1-.2.2-.4.1.1.2.2.2.3 0 .2-.2.3-.2.4zm1.4 2.9zm2.2-7.4c0 .1-.1.1-.1.2s-.2.1-.3 0v-.2h.4zm-.2 1.6zm-.3-1.7zm.6 8.1c-.1-.1-.2-.2-.2-.3v-.4s.2-.1.2 0c.1.1.2.2.2.3-.1.1-.1.2-.2.4zm-.5-3.1h-.2v-.3c.2 0 .5.1 1 .2-.4.1-.6.1-.8.1zm1.7 7.1c.1 0 .1 0 .1-.1v.1h-.1zm.2-2v.6c-.2-.3-.1-.5 0-.6zm0-.1c0-.1-.1-.2-.1-.3-.1-.5 0-.6.4-.6h.2c-.2.3-.3.6-.5.9zm.8-.8c0-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0zm.1 1.1v-.2h.1l.1.1c-.1 0-.2 0-.2.1zm.4-5.3zm1.8 6.1s.1 0 .1-.1c0 .2 0 .3.1.5-.1-.1-.2-.2-.2-.4zm.3.7c0-.1-.1-.1-.1-.2.1.1.2.1.1.2.1-.1.1 0 .1.1 0-.1 0-.1-.1-.1zm-.4 3.8zm1.2-1.7c-.1-.1-.1-.2-.2-.3l.2-.2c.1.1.1.2.1.3 0 0-.1.1-.1.2zm1-.5v-.1h.1c0-.1 0 0-.1.1.1-.1 0-.1 0 0zm.7-.2c0-.1-.1-.2-.1-.2l.1-.1c0 .1.1.2.1.2.1 0 0 .1-.1.1zm.6 1.3c0-.1-.1-.1-.1-.2v-.1s.1 0 .1-.1l.1.1c0 .2 0 .3-.1.3zm5.9-8.3c0 .1-.1.2-.1.3l-.1.1c-.2-.2 0-.4.2-.4zm2.9-4.6zm-1.3-14.3c.1.1.1.2.2.3 0 0 0 .1-.1.1-.1-.1-.1-.2-.2-.2.1-.1.1-.2.1-.2zm-.3 18.1c.6.6.6.6.9 1.8-.8-.5-.6-1.2-.9-1.8zm1.7.8c-.4-.3-.3-.7-.4-1 .5.1.7.4.4 1zm-.3-1.1c-.3-.4-.8-.4-1.4-.3.1-.5.2-.8.3-1.1v0c.4 0 .9.6 1.2-.3.2.4.4.6.5.9-.2.3-.6.4-.6.8zm.7-6.6c0-.1-.1-.1-.1-.3.1-.1.2-.1.3-.2 0 .1.1.2.1.2l-.3.3zm.8 8.4c-.4 0-.3-.4-.4-.6.2.2.5.1.5.5l-.1.1zm.5-8.5c-.4.1-.4-.2-.5-.4v-.7l.6-.3c.2.4.2.9-.1 1.4zm.5 7.3c0-.1-.1-.1-.2-.3.1-.1.3-.2.4-.2l.1.2-.3.3zm.5-1.3l.1-.1-.1.1zm.5-6.2c-.1-.3 0-.7-.1-1h-.6v-.4h.1c.4.3.9.4 1.4.5v1.2c-.2 0-.4.1-.4.1-.1 0-.3-.2-.4-.4zm.8 7.5c-.1 0-.2-.1-.3-.2.2-.1.3-.2.4-.2.1 0 .2.2.3.3-.3 0-.3.1-.4.1zm1-.4zm0-1.4c-.1 0-.1-.1-.2-.1 0-.1 0-.1.1-.2.1 0 .1.1.2.1 0 0 0 .1-.1.2zm.8-.5c0-.1.1-.1.2-.3.1.2.2.2.2.3.1.3.2.6-.2.7h-.2c.1-.2 0-.5 0-.7zm.3 1.4h.1c.2.2.3.4.6.8-.9-.1-.9-.1-.7-.8zm.7-8.1v0zm.4-5c.1 0 .2.1.2.1-.1 0-.1 0-.2-.1zm.5 18.1c0-.1-.1-.1-.1-.2 0 0 .1-.1.1 0s.1.1.1.2h-.1zm.2-4.8l-.1-.1s0-.1.1-.1l.1.1s0 .1-.1.1zm.2 2.6h.1-.1zm.5-10.3h-.2l-.3-.3v-.1c-.1-.2-.2-.3-.3-.5l-.1.1v-.1s0-.1.1-.1h.1v-.1c.2.1.6.1.7.3.1.2 0 .6 0 .8zm.1 5.3v-.1h.2v.2c-.1 0-.2-.1-.2-.1zm.5 3c0 .1-.2.1-.2.1-.1 0-.1-.1-.1-.2 0-.3.1-.5.4-.6.3.2.1.5-.1.7zm.9-9.2l.1.2c0 .2-.3.4-.5.2-.1 0-.1-.1-.2-.3.2 0 .4 0 .6-.1zm-.5 1.5c.2-.5.5-.4.8-.4-.2.6-.5.4-.8.4zm1.2 4.5l-.2-.2c0-.4-.1-.7-.1-1.1h.3c.1.3.2.7.4 1.1-.2 0-.3.1-.4.2zm0-1.4c.1-.2.2-.4.3-.7.2.5-.1.5-.3.7zm1.6 1.2v-.1.1zm-.3-1.5c.5-.8.5-.8 1.1-.3-.3.1-.6.2-1.1.3zm2.4 4.8c-.1 0-.1 0 0 0l-.1-.1c.1 0 .1 0 .1.1 0-.1 0 0 0 0zm0-8.3c-.2-.2-.5-.4-.8-.7.4-.5.8-.4 1.2-.3.2.5-.1.7-.4 1zm.6 4.6V32l.1-.1c.1 0 .1.1.1.2-.1 0-.1.1-.2.1zm.8-10.5c0-.1.1-.2.2-.3.1.1.2.2.2.3l-.2.2s-.2-.1-.2-.2zm1 14.2c-.2 0-.4-.1-.6-.1v-.2h.9c.1.3-.2.3-.3.3zm1.2 1.9s.1 0 .1.1c0-.1-.1-.1-.1-.1zm.4-2.2zm.1-4.6c-.1 0-.2-.1-.3-.1.1-.2.1-.4.2-.6h.1c.1.3.1.5 0 .7zm1.5 4.5zm.2 2.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1s.1.1.2.1c-.1 0-.1.1-.2.1zm.7-15.8c-.2 0-.3-.1-.4-.2l-.1-.1c.2-.5.2-.5.6-.3-.1.2-.1.4-.1.6zm.5 13.5c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1 0 0 .1.1.2.1-.1 0-.1 0-.2.1zm.6-16.1c-.1.1-.1.1 0 0zm1-5.7c-.1-.1-.2-.2-.2-.3.1 0 .2.1.2.1.1.1.1.2 0 .2.1 0 .1 0 0 0zm.7 21.9c-.1 0-.1-.1-.2-.1.1 0 .1-.1.2-.1h.1c-.1 0-.1.2-.1.2zm3.8-.3zm-.5-5.3s.1.1.2.1c-.1.1-.1.2-.2.3l-.2-.2c.1-.1.1-.2.2-.2zm-.6-11.3c.1.1.2.1.2.2s-.1.2-.1.3l-.2-.2c0-.1 0-.2.1-.3zm-.5 16.5s.1.1.1.2c-.1 0-.1.1-.2.1l-.1-.1c.1-.1.1-.2.2-.2zm-.3-4.4v.1-.1zm-.4-4.2l-.1.1c0-.1-.1-.1-.1-.2.1.1.2.1.2.1zm-.3 4.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1-.1.1-.1zm-.4.4c0-.3.2-.2.3-.2 0 .2.1.4-.2.4l-.1-.2zm1.5 7.3c-.4.1-.7-.2-1.2-.2.3-.4.5-.6.6-.9.4-.1.7-.1.9.3h.2c.1-.1.2-.2.3-.2.2-.1.4-.2.6 0 .1.2.1.4.1.6-.5.1-1 .2-1.5.4zm6.8-8.6h.1v.2c-.1 0-.1 0-.2-.1 0 0 0-.1.1-.1zm-.2 5.2c.1 0 .1 0 0 0v0zm-.7-8.6zm-.7 3.8s0 .1 0 0c.1.1.1.1 0 .1v-.1c-.1.1 0 0 0 0zm-.3 4.7l.1.1c-.1 0-.2 0-.1-.1-.1.1-.1 0 0 0zm-2.7-15.9v-.1l.1.1h-.1zm1 19.1c-.2 0-.3-.3-.4-.5 0-.1.1-.3.2-.3.8.2 1.6-.1 2.4.4-.8.6-1.5.6-2.2.4zm2.6 1.2c-.1-.1-.1-.2-.2-.3.1 0 .1-.1.2-.1.1.1.2.1.1.2.1.1 0 .1-.1.2zm.2-25.4v-.1.1zm.4-.3c-.1 0-.2.1-.3.1 0-.1 0-.3.1-.4 0 0 0-.1.1-.1 0 .2 0 .3.1.4zm.5 24.3c-.1 0-.3-.2-.3-.3 0-.1.1-.4.2-.4.3-.1.6-.2.9-.2.2 0 .3.1.8.9-.7.1-1.2.1-1.6 0zm.7-14.4c-.1-.1-.1-.3 0-.4v-.1.5zm0 6.2s0 .1-.1.1l.1-.1zm.1-6.1s.1 0 .2.1h.2c.1 0 .2.1.2.2-.2 0-.4-.1-.6-.3zm.3-4.1c-.1-.1 0-.3-.1-.4 0 0 0-.1-.1-.2-.2.1-.3.2-.5.3 0-.1-.1-.2-.1-.2 0-.2.1-.3.2-.4.1 0 .2.1.3 0 .1 0 .2-.1.3-.1.2.1.3.2.3.4v.1c.1.3-.1.5-.3.5zm2.1 15.7c0-.1-.1-.1-.1-.2.1 0 .1-.1.2-.1l.1.1c-.2.1-.2.1-.2.2zm-.4-4.8c-.1 0-.3 0-.3-.1s0-.3.1-.4c.2-.2.5-.3.9-.4-.1.7-.4.8-.7.9zm37.6-1.2s0 .1 0 0c0 .1 0 .1-.1.1.1 0 .1 0 .1-.1zm-3.2.3zm-.6-.2c.2-.1.4 0 .5.2-.2.1-.5.2-.7.3-.3.2-.5 0-.6-.3.3 0 .5-.2.8-.2zm-9.7-6.5s.1 0 0 0c.2-.1.4 0 .4.2 0 .1-.2.3-.3.3-.1-.1-.2-.1-.3-.2.2-.1.2-.2.2-.3zm-5-7.3s.1 0 0 0c.1.1.1.3.1.4-.1-.1-.2-.2-.1-.4-.1.1 0 0 0 0zm-5.5 5.7l.6.3c-.1.1-.2.3-.2.3-.2 0-.3-.1-.6-.3 0-.1.1-.2.2-.3zm-.3 4.9l.1-.1c0 .1-.1.2-.1.3v-.2zm-.9-.8c-.1 0-.1 0 0 0-.1 0-.1 0 0 0-.1 0-.1 0 0 0zm-1.1 0zm-2.5 5.6c.4-.4.5-.9.6-1.5 0-.1.2-.2.3-.3 0 0 .1 0 .1.1 0 0 .1 0 .1-.1.1 0 .2.1.3.2.1.2.1.4.2.6 0 .1.2 0 .3 0 .3.7.3.7-.2 1.2-.2.2-.5.2-.7 0-.3-.3-.5-.2-.8 0 0 0-.2 0-.2-.1v-.1zm-1.3-12.8c.1 0 .1.1 0 0 .1.2 0 .2-.1.1v-.1h.1zm.1 11.8l.9-.3c0 .4 0 .4-.8 1.1-.5-.4-.5-.6-.1-.8zm1 4.9c-.1.1-.1.3-.2.3s-.3-.1-.5-.2c.2-.2.3-.3.4-.3.1 0 .2.1.3.2zm-4.2-17.8c.1.1.1.1 0 0 0 .1 0 0 0 0zm-1.6 17.8v.1h-.1s-.1 0-.1-.1h.2zm-1.6-9.7v-.2s.1 0 .1.1 0 .1-.1.1zm.8 4.9c.1 0 .2 0 .3.1v.4c-.1 0-.2-.1-.3-.1-.1-.2-.1-.3 0-.4zm.6 8c-.2-.3-.4-.5-.6-.7 0 0 0-.1.1-.1.3-.4.5-1 1.2-.8.1.6-.2 1.1-.7 1.6zm2.7-.4c-.1 0-.2-.1-.4-.1h-.1.1c-.2.1-.5.2-.7.2-.1 0-.3-.1-.3-.2-.2-.5.1-1.2.6-1.3h.8c.5 0 .7.3.8.8 0 .4-.3.6-.8.6zm1-2.7c-.1 0-.2-.1-.3-.1.1-.1.2-.1.2-.1.1 0 .1.1.2.1l-.1.1zm.3-4.4zm1.9 6.9c-.1.1-.4.1-.6.1-.2 0-.4-.2-.6-.2-.3 0-.5 0-.6-.4-.1-.3.2-.5.4-.7.2-.1.4-.2.6-.4.2.3.3.6.5.9.1 0 .3-.1.5-.1-.1.4-.1.7-.2.8zm.8 1.3zm-.7-2c-.1-.3-.1-.5.2-.6.3-.1.4.1.6.3-.2.1-.5.2-.8.3zm1.4 2c0-.1-.1-.1-.1-.2.1 0 .1 0 .2-.1 0 0 .1.1 0 .1 0 .1 0 .1-.1.2zm1-2.2c-.2.7-.7.9-1.2.4-.2-.1-.3-.4-.4-.5.5-.2.9-.8 1.6-.5.2.2.1.4 0 .6zm-.2-6.4c.1-.3.2-.5.3-.7.2-.1.3-.1.5-.1h.6v.4c.5.2.9.5 1.4.7.3.2.4.5.4.8-.6-.1-1.1-.6-1.7-.5-.1 0-.2-.1-.2-.2-.3-.6-.8-.5-1.3-.4zm1.5 4.4v.1h-.2v-.1h.2zm-.6 3.9s-.1 0 0 0c-.1-.1-.1-.1-.1-.2h.1v.2zm.8.1c-.1 0-.1-.1-.2-.2.1 0 .1-.1.2-.1l.1.1c0 .1 0 .2-.1.2zm1.1 0c.5-.4 1-.4 1.5-.5-.3.4-.8.6-1.5.5zm1.5-.6c-.3-.3-.6-.5-1-.8-.4.2-.8.3-1.2.4-.2.1-.5 0-.8-.1-.3-.1-.5-.6-.4-.8.2-.3.4-.2.7-.1.1.1.2.1.4.1.2-.3.5-.6.7-.9.4.2.8.4 1.1.5.4-.1.5-.7.9-.5 0 .1.1.2.1.2 0 .8.3 1.6-.5 2zm-1.1-6.8c.2-.9.2-.9-.4-1.8.5-.2.8-.7 1.4-.3.2 0 .4 0 .5.1v.1l.1.1c-.2 1-.2 1.1.1 2-.5-.1-1.1-.1-1.7-.2zm1.9.2c.3-.7.8-1.2 1.3-1.7l-.2-.1v-.6c0-.6 1.5.2 2-.4v1c.3.1.4.1.6.2 0 .1.1.2 0 .3-.3.4-.7.6-1.2.7-.5.1-1 .1-1.4.7-.2.4-.7.2-1.1-.1zm.8 4.7c-.1 0-.2-.1-.3-.1.1-.1.1-.2.2-.2s.2.1.3.1c-.1.1-.1.2-.2.2zm1 2.2c-.2.2-.4.1-.6.1.1-.4.3-.4.6-.3 0 0 .1.2 0 .2zm.2-2c-.1 0-.2-.1-.3-.2 0-.1 0-.3.1-.4l1.2-.4c-.2.8-.6 1-1 1zm1.9 1.2s-.1 0-.1-.1c0 0 .1 0 .1.1 0-.1 0 0 0 0zm-.3-3s-.1-.1-.1-.2h.4s.1.1.1.2c-.2-.1-.3 0-.4 0zm.3-12.1c-.1 0-.1 0-.2-.1v-.1c.1 0 .1-.1.2-.1v.3zm.3 9.4zm-.2-9.7c.1 0 .2.1.3.2-.1 0-.2-.1-.3-.2zm.4 6.8c-.1.1 0 .3.1.3h.2c-.2.1-.3 0-.5-.2.1 0 .2 0 .2-.1zm.1 9.4s-.1 0-.1-.1l.1.1c0-.1 0 0 0 0zm.2-8h-.1v-.1c0-.1.1-.1.2-.2 0 .2 0 .3-.1.3zm.7 7.1zm-.1-5.7v-.3c.2 0 .5-.1.7-.1 0 0 .1.1.1.2s-.1.2-.1.2h-.7zm.4 6.6c0 .1 0 .1 0 0 .1 0 .1 0 0 0zm.4-4.1s-.1-.1-.2-.1c.1 0 .1-.1.2-.1s.1 0 .2.1c-.1 0-.1.1-.2.1zm.4 1.8c-.1-.1-.1-.1 0 0 0-.2 0-.1 0 0 0-.1 0-.1 0 0zm1.2-2.1c.6 0 1.2 0 1.9-.1 0 0 0 .1.1.2-.1.1-.2.2-.3.2-.5.1-.9 0-1.4.2-.3.2-.4-.1-.3-.5zm-.7-2.3c.5-.4.8-.4 2.3.1-.2.1-.3.2-.4.2-.6-.1-1.2-.2-1.9-.3zm1 5.7c-.1 0-.1-.1-.2-.1 0 0 .1 0 .1-.1 0 0 .1 0 .1.1v.1zm.7.9h-.2l.1-.1h.2s0 .1-.1.1zm.2-1c-.1-.1-.2-.1-.2-.2-.2-.3-.6-.6-.4-1 .2-.5.7-.3 1.1-.3.1 0 .3 0 .5.1.1.5.2.9.3 1.3-.5.3-1 .1-1.3.1zm1.3-6.8c-.2 0-.4.1-.6.1-.7-.2-1.4-.1-2.1.1-.4.1-.8.1-1.2.1h-.1c-.5 0-.9-.2-1.3-.5.4-.4.4-.4 1.2 0 .1-.3.3-.6.5-.9.2.1.3.1.4.2.5.6.5.7 1.2.3-.1-.2-.2-.3-.2-.5.1 0 .2-.1.2-.1.4.2.9.4 1.3.7l.1-.1c0-.2.1-.5.1-.7l.2.2.2-.1c.1-.1-.1-.3-.2-.3 0 0-.1 0-.1.1v-.1c0-.1.2-.2.3-.2.1 0 .3.1.3.2 0 .3 0 .9-.2 1.5zm.6 3.9h-.1c0-.1-.1-.1-.1-.2h.2v.2zm.4-4.1c-.3-.1-.5-.4-.4-.7.1-.2.3-.2.5-.1.3.2.5.1.7-.1 0 .1 0 .3-.1.4-.2.4-.4.6-.7.5zm.9 3.8c0-.1 0-.1 0 0l-.1-.1c.1-.1.1-.1.1.1.1-.1 0-.1 0 0zm0-2.4c-.1-.1-.2-.1-.3-.2 0 0 .1-.1.1-.3l.3.3s-.1.1-.1.2zm-.1-2.3c.1-.1.2-.2.4-.3h.5c.1 0 .1.1.2.1.2.2.4.3.7.5.8-.4 1.6.2 2.5-.4 0-.1-.1-.2-.1-.3l.1-.1c.1-.1.2-.2.3-.2.1.4.4.7.6 1.1-.1.2-.3.3-.4.5 0 .1.1.4.2.5.3.2.4.6.5 1-.6.3-1.2.2-1.8.3-.4 0-.8-.2-1.1-.4l-.9-.6c-.1-.3-.2-.6-.4-.8-.4-.4-.9-.7-1.3-.9zm4.9 3.9c-.1 0-.1 0-.2-.1v-.1c.1 0 .1 0 .2.1v.1zm-.6 2.2c0 .1-.1.1 0 0-.1 0-.1 0-.1-.1 0 .1 0 0 .1.1zm-2.9-3.3c-.4-.2-.5-.5-.4-1 .2 0 .4-.1.7-.1.1.4-.1.7-.3 1.1zm1.3 3.1c0 .3-.1.4-.4.4-.2-.6-.4-1.1-.1-1.8.8.3.5.9.5 1.4zm.4-2c.5.2.8.3 1.1.4-.1.4-.2.7-.4 1.1-.7-.3-.7-.8-.7-1.5zm2.4 4.7c-.2.3-.6.3-1 .2-.2-.1-.3-.3-.5-.4-.1-.6-.1-.7.3-.8h1.1c.4.4.3.8.1 1zm1.3-2.6c-.1 0-.1.1-.2.1-.2-.3-.3-.6-.4-.7-.4.1-.4.3-.4.4 0 .6-.3.8-.8 1-.4-.7 0-1.2.2-1.7.2-.8.8-1.4 1.6-1.5v2.4zm.1-2.3s0-.1 0 0c.1-.1.1 0 0 0zm.2 4.9v-.2h.1c0 .1 0 .2-.1.2.1 0 0 0 0 0zm-.3-5.9c-.5.2-.9 0-1.3-.3.9.1 1.6-.4 2.3-.9.2-.1.4-.4.2-.7-.8-.1-.8-.1-1.3-.4.2 0 .4 0 .5-.2.4-.1.8-.3 1.2-.5 0 .1.1.2.2.3.1.1.4.1.4 0 .1-.1.1-.2.2-.2.2.1.4.3.6.4-.3.5-.7.9-1 1.4.2.2.3.4.4.5 0 .1-.1.1-.1.1-.9 0-1.6.2-2.3.5zm1.6 5.9s.1 0 0 0c.1 0 0 0 0 0zm-.1-.1l-.1-.1c-.2-.8-.1-.9.7-.7-.1.3-.3.6-.6.8zm.7-4.3c-.1.3-.3.5-.5.9-.4-.3-.7-.6-.7-1.1.2-.1.4-.4.7-.5.2-.1.5 0 .7.1.2.1.3.3.4.5.1.1 0 .3-.1.7-.2-.3-.4-.4-.5-.6zm4.6 3.4c-.2 0-.4-.2-.6-.2-.3 0-.5 0-.8.1-.3.2-.1.5-.1.8 0 0-.1.1-.1.2-.3-.2-.5-.4-.9-.7.2-.2.3-.4.5-.6-.4-.6-.8-.9-1.5-.6-.2.1-.3 0-.5 0-.1 0-.1-.1-.2-.1.7-.6.7-.6 2.1-.3.1-.1.3-.3.4-.5.1-.1.1-.4 0-.5-.2-.3-.3-.1-.5 0-.1.1-.4.1-.5 0-.3-.6-.6-1.2-.4-2.2.5 1.1 1.2 1.1 2 1.3.1.5.1 1.1.2 1.7.2.1.5.3.8.4.1.3.3.7.5 1.2-.1 0-.3.1-.4 0zm-1.2-4.8c.1-.2.3-.2.4 0l.7.7c-.7.1-.7.1-1.1-.7z"/></svg>';

			// Prev Row SVG for previous to last row
			prevRow.append('<div class="mkdf-uncovering-row-landing-prev-svg">'+ svgTest +'</div>');
			// Don't forget to add custom CSS on page to override default VC styles
		}
	}

    /**
     * Init Owl Carousel
     */
    function mkdfOwlSlider() {
        var sliders = $('.mkdf-owl-slider');

        if (sliders.length) {
            sliders.each(function(){
                var slider = $(this),
                    owlSlider = $(this),
	                slideItemsNumber = slider.children().length,
	                numberOfItems = 1,
	                loop = true,
	                autoplay = true,
	                autoplayHoverPause = true,
	                sliderSpeed = 3000,
	                sliderSpeedAnimation = 600,
	                margin = 0,
	                responsiveMargin = 0,
	                responsiveMargin1 = 0,
	                stagePadding = 0,
	                stagePaddingEnabled = false,
	                center = false,
	                autoWidth = false,
	                animateInClass = false, // keyframe css animation
	                animateOutClass = false, // keyframe css animation
	                navigation = true,
	                pagination = false,
	                thumbnail = false,
                    thumbnailSlider,
	                sliderIsCPTList = !!slider.hasClass('mkdf-list-is-slider'),
	                sliderDataHolder = sliderIsCPTList ? slider.parent() : slider;  // this is condition for cpt to set list to be slider
	
	            if (typeof slider.data('number-of-items') !== 'undefined' && slider.data('number-of-items') !== false && ! sliderIsCPTList) {
		            numberOfItems = slider.data('number-of-items');
	            }
	            if (typeof sliderDataHolder.data('number-of-columns') !== 'undefined' && sliderDataHolder.data('number-of-columns') !== false && sliderIsCPTList) {
		            switch (sliderDataHolder.data('number-of-columns')) {
			            case 'one':
				            numberOfItems = 1;
				            break;
			            case 'two':
				            numberOfItems = 2;
				            break;
			            case 'three':
				            numberOfItems = 3;
				            break;
			            case 'four':
				            numberOfItems = 4;
				            break;
			            case 'five':
				            numberOfItems = 5;
				            break;
			            case 'six':
				            numberOfItems = 6;
				            break;
			            default :
				            numberOfItems = 4;
				            break;
		            }
	            }
	            if (sliderDataHolder.data('enable-loop') === 'no') {
		            loop = false;
	            }
	            if (sliderDataHolder.data('enable-autoplay') === 'no') {
		            autoplay = false;
	            }
	            if (sliderDataHolder.data('enable-autoplay-hover-pause') === 'no') {
		            autoplayHoverPause = false;
	            }
	            if (typeof sliderDataHolder.data('slider-speed') !== 'undefined' && sliderDataHolder.data('slider-speed') !== false) {
		            sliderSpeed = sliderDataHolder.data('slider-speed');
	            }
	            if (typeof sliderDataHolder.data('slider-speed-animation') !== 'undefined' && sliderDataHolder.data('slider-speed-animation') !== false) {
		            sliderSpeedAnimation = sliderDataHolder.data('slider-speed-animation');
	            }
	            if (typeof sliderDataHolder.data('slider-margin') !== 'undefined' && sliderDataHolder.data('slider-margin') !== false) {
		            if (sliderDataHolder.data('slider-margin') === 'no') {
			            margin = 0;
		            } else {
			            margin = sliderDataHolder.data('slider-margin');
		            }
	            } else {
		            if(slider.parent().hasClass('mkdf-huge-space')) {
			            margin = 60;
		            } else if (slider.parent().hasClass('mkdf-large-space')) {
			            margin = 50;
		            } else if (slider.parent().hasClass('mkdf-medium-space')) {
			            margin = 40;
		            } else if (slider.parent().hasClass('mkdf-normal-space')) {
			            margin = 30;
		            } else if (slider.parent().hasClass('mkdf-small-space')) {
			            margin = 20;
		            } else if (slider.parent().hasClass('mkdf-tiny-space')) {
			            margin = 10;
		            }
	            }
	            if (sliderDataHolder.data('slider-padding') === 'yes') {
		            stagePaddingEnabled = true;
		            stagePadding = parseInt(slider.outerWidth() * 0.28);
		            margin = 50;
	            }
	            if (sliderDataHolder.data('enable-center') === 'yes') {
		            center = true;
	            }
	            if (sliderDataHolder.data('enable-auto-width') === 'yes') {
		            autoWidth = true;
	            }
	            if (typeof sliderDataHolder.data('slider-animate-in') !== 'undefined' && sliderDataHolder.data('slider-animate-in') !== false) {
		            animateInClass = sliderDataHolder.data('slider-animate-in');
	            }
	            if (typeof sliderDataHolder.data('slider-animate-out') !== 'undefined' && sliderDataHolder.data('slider-animate-out') !== false) {
                    animateOutClass = sliderDataHolder.data('slider-animate-out');
	            }
	            if (sliderDataHolder.data('enable-navigation') === 'no') {
		            navigation = false;
	            }
	            if (sliderDataHolder.data('enable-pagination') === 'yes') {
		            pagination = true;
	            }

	            if (sliderDataHolder.data('enable-thumbnail') === 'yes') {
                    thumbnail = true;
	            }

	            if(thumbnail && !pagination) {
                    /* page.index works only when pagination is enabled, so we add through html, but hide via css */
	                pagination = true;
                    owlSlider.addClass('mkdf-slider-hide-pagination');
                }

	            if(navigation && pagination) {
		            slider.addClass('mkdf-slider-has-both-nav');
	            }

	            if (slideItemsNumber <= 1) {
		            loop       = false;
		            autoplay   = false;
		            navigation = false;
		            pagination = false;
	            }

	            var responsiveNumberOfItems1 = 1,
		            responsiveNumberOfItems2 = 2,
		            responsiveNumberOfItems3 = 3,
		            responsiveNumberOfItems4 = numberOfItems,
		            responsiveNumberOfItems5 = numberOfItems;

	            if (numberOfItems < 3) {
		            responsiveNumberOfItems2 = numberOfItems;
		            responsiveNumberOfItems3 = numberOfItems;
	            }

	            if (numberOfItems > 4) {
		            responsiveNumberOfItems4 = 4;
	            }
	
	            if (numberOfItems > 5) {
		            responsiveNumberOfItems5 = 5;
	            }

	            if (stagePaddingEnabled || margin > 30) {
		            responsiveMargin = 20;
		            responsiveMargin1 = 30;
	            }

	            if (margin > 0 && margin <= 30) {
		            responsiveMargin = margin;
		            responsiveMargin1 = margin;
	            }

	            slider.waitForImages(function () {
		            owlSlider = slider.owlCarousel({
			            items: numberOfItems,
			            loop: loop,
			            autoplay: autoplay,
			            autoplayHoverPause: autoplayHoverPause,
			            autoplayTimeout: sliderSpeed,
			            smartSpeed: sliderSpeedAnimation,
			            margin: margin,
			            stagePadding: stagePadding,
			            center: center,
			            autoWidth: autoWidth,
			            animateIn: animateInClass,
			            animateOut: animateOutClass,
			            dots: pagination,
			            nav: navigation,
			            navText: [
				            '<span class="mkdf-prev-icon ion-ios-arrow-thin-left"></span>'+ mkdfGlobalVars.vars.sliderNavNextArrowSVG,
				            '<span class="mkdf-next-icon ion-ios-arrow-thin-right"></span>' + mkdfGlobalVars.vars.sliderNavNextArrowSVG
			            ],
			            responsive: {
				            0: {
					            items: responsiveNumberOfItems1,
					            margin: 0,
					            stagePadding: 0,
					            center: false,
					            autoWidth: false,
					            nav: false,
				            },
				            681: {
					            items: responsiveNumberOfItems2,
					            margin: responsiveMargin1,
					            nav: false
				            },
				            769: {
					            items: responsiveNumberOfItems2,
					            margin: responsiveMargin1
				            },
				            1025: {
					            items: responsiveNumberOfItems4
				            },
				            1281: {
					            items: responsiveNumberOfItems5
				            },
				            1367: {
					            items: numberOfItems
				            }
			            },
			            onInitialize: function () {
				            slider.css('visibility', 'visible');
							mkdfInitParallax();
							setTimeout(function() {
								mkdfTiltFx().init();
							}, 500);
				            if (slider.find('iframe').length || slider.find('video').length) {
					            setTimeout(function () {
						            mkdfSelfHostedVideoSize();
						            mkdfFluidVideo();
					            }, 500);
				            }
				            if (thumbnail) {
					            thumbnailSlider.find('.mkdf-slider-thumbnail-item:first-child').addClass('active');
				            }
			            },
			            onRefreshed: function () {
				            if (autoWidth === true) {
					            var oldSize = parseInt(slider.find('.owl-stage').css('width'));
					            slider.find('.owl-stage').css('width', (oldSize + 1) + 'px');
				            }
			            },
			            onTranslate: function (e) {
				            if (thumbnail) {
					            var index = e.page.index + 1;
					            thumbnailSlider.find('.mkdf-slider-thumbnail-item.active').removeClass('active');
					            thumbnailSlider.find('.mkdf-slider-thumbnail-item:nth-child(' + index + ')').addClass('active');
				            }
			            },
			            onDrag: function (e) {
				            if (mkdf.body.hasClass('mkdf-smooth-page-transitions-fadeout')) {
					            var sliderIsMoving = e.isTrigger > 0;
					
					            if (sliderIsMoving) {
						            slider.addClass('mkdf-slider-is-moving');
					            }
				            }
			            },
			            onDragged: function () {
				            if (mkdf.body.hasClass('mkdf-smooth-page-transitions-fadeout') && slider.hasClass('mkdf-slider-is-moving')) {
					
					            setTimeout(function () {
						            slider.removeClass('mkdf-slider-is-moving');
					            }, 500);
				            }
			            }
		            });
	            });
	
	            if (thumbnail) {
		            thumbnailSlider = slider.parent().find('.mkdf-slider-thumbnail');
		
		            var numberOfThumbnails = parseInt(thumbnailSlider.data('thumbnail-count'));
		            var numberOfThumbnailsClass = '';
		
		            switch (numberOfThumbnails % 6) {
			            case 2 :
				            numberOfThumbnailsClass = 'two';
				            break;
			            case 3 :
				            numberOfThumbnailsClass = 'three';
				            break;
			            case 4 :
				            numberOfThumbnailsClass = 'four';
				            break;
			            case 5 :
				            numberOfThumbnailsClass = 'five';
				            break;
			            case 0 :
				            numberOfThumbnailsClass = 'six';
				            break;
			            default :
				            numberOfThumbnailsClass = 'six';
				            break;
		            }
		
		            if (numberOfThumbnailsClass !== '') {
			            thumbnailSlider.addClass('mkdf-slider-columns-' + numberOfThumbnailsClass);
		            }
		
		            thumbnailSlider.find('.mkdf-slider-thumbnail-item').on('click', function () {
			            $(this).siblings('.active').removeClass('active');
			            $(this).addClass('active');
			            owlSlider.trigger('to.owl.carousel', [$(this).index(), sliderSpeedAnimation]);
		            });
	            }
            });
        }
    }

	function mkdfDashboardForm() {
		var forms = $('.mkdf-dashboard-form');

		if (forms.length) {
			forms.each(function () {
				var thisForm = $(this),
					btnText = thisForm.find('button.mkdf-dashboard-form-button'),
					updatingBtnText = btnText.data('updating-text'),
					updatedBtnText = btnText.data('updated-text'),
					actionName = thisForm.data('action');

				thisForm.on('submit', function (e) {
					e.preventDefault();
					var prevBtnText = btnText.html(),
						gallery = $(this).find('.mkdf-dashboard-gallery-upload-hidden'),
						namesArray = [];

					btnText.html(updatingBtnText);

					//get data
					var formData = new FormData();

					//get files
					gallery.each(function () {
						var thisGallery = $(this),
							thisName = thisGallery.attr('name'),
							thisRepeaterID = thisGallery.attr('id'),
							thisFiles = thisGallery[0].files,
							newName;

						//this part is needed for repeater with image uploads
						//adding specific names so they can be sorted in regular files and files in repeater
						if (thisName.indexOf("[") > -1) {
							newName = thisName.substring(0, thisName.indexOf("[")) + '_mkdf_regarray_';

							var firstIndex = thisRepeaterID.indexOf('['),
								lastIndex = thisRepeaterID.indexOf(']'),
								index = thisRepeaterID.substring(firstIndex + 1, lastIndex);

							namesArray.push(newName);
							newName = newName + index + '_';
						} else {
							newName = thisName + '_mkdf_reg_';
						}

						//if file not sent, send dummy file - so repeater fields are sent
						if (thisFiles.length === 0) {
							formData.append(newName, new File([""], "mkdf-dummy-file.txt", {
								type: "text/plain"
							}));
						}

						for (var i = 0; i < thisFiles.length; i++) {
							var allowedTypes = ['image/png','image/jpg','image/jpeg','application/pdf'];
							//security purposed - check if there is more than one dot in file name, also check whether the file type is in allowed types
							if (thisFiles[i].name.match(/\./g).length === 1 && $.inArray(thisFiles[i].type, allowedTypes) !== -1) {
								formData.append(newName + i, thisFiles[i]);
							}
						}
					});

					formData.append('action', actionName);

					//get data from form
					var otherData = $(this).serialize();
					formData.append('data', otherData);

					$.ajax({
						type: 'POST',
						data: formData,
						contentType: false,
						processData: false,
						url: mkdfGlobalVars.vars.mkdfAjaxUrl,
						success: function (data) {
							var response;
							response = JSON.parse(data);

							// append ajax response html
							mkdf.modules.socialLogin.mkdfRenderAjaxResponseMessage(response);
							if (response.status === 'success') {
								btnText.html(updatedBtnText);
								window.location = response.redirect;
							} else {
								btnText.html(prevBtnText);
							}
						}
					});

					return false;
				});
			});
		}
	}

    /**
     * Init Perfect Scrollbar
     */
    function mkdfInitPerfectScrollbar() {
	    var defaultParams = {
		    wheelSpeed: 0.6,
		    suppressScrollX: true
	    };
	
	    var mkdfInitScroll = function (holder) {
		    var ps = new PerfectScrollbar(holder.selector, defaultParams);
		    
		    $(window).resize(function () {
			    ps.update();
		    });
	    };
	
	    return {
		    init: function (holder) {
			    if (holder.length) {
				    mkdfInitScroll(holder);
			    }
		    }
	    };
    }

})(jQuery);